/*  
 *  - - - - - - - - - - - -
 *   g a l _ a c c s r p s  
 *  - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     Computes the perturbational acceleration due to solar 
 *     radiation pressure using the simplified formula
 *  
 *  Status: 
 *  
 *     support routine.  
 *  
 *  Given:  
 *
 *     psat            d[3]         Position vector of satellite
 *     psun            d[3]         Position vector of the Sun
 *     p                d           Solar radiation pressure at one AU ( Newtons meters^-1 )
 *     au               d           Length of Astronomical Unit  ( meters )
 *     area             d           Satellite surface area ( meters^2 )
 *     mass             d           Satellite mass ( kg )
 *     eps              d           Reflectivity ( see Note 1 )
 *     v                d           Shadow function ( 0 = eclipse, 1 = full sunlight )
 *  
 *  Returned:  
 *  
 *     a                d[3]         Acceleration (a=d^2r/dt^2)
 *
 *  Notes:
 *
 *  1) Reflectivity is usually in the range 0.2 to 0.9.
 *
 *     Solar Panel                       0.21
 *     High Gain Antenna                 0.30
 *     Aluminium coated mylar solar sail 0.88
 *
 *  Called:
 *
 *  References:
 *
 *     Satellite Orbits
 *     Oliver Montenbruck, Eberhard Gill
 *     Springer 2005
 *     Pages 77-79
 *  
 *  This revision:  
 * 
 *     2009 January 3 
 *  
 *  Copyright (C) 2009 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_ACCSRPS_H_  
#define _GAL_ACCSRPS_H_ 1  

#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

void
gal_accsrps
  (
    double psat[3],
    double psun[3],
    double p,
    double au,
    double area,
    double mass,
    double eps,
    double v,
    double a[3] 
  ) ;
 
__END_DECLS  
  
#endif /* !_GAL_ACCSRPS_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
