/*  
 *  - - - - - - - - - - - -
 *   g a l _ b e b p v 8 7 
 *  - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Earth-Moon Barycentre barycentric position and velocity, with respect to the 
 *  FK5 Reference Frame.  
 *  
 *  Status:
 *  
 *     internal support routine.  
 *  
 *  Given:
 *  
 *     tt1                 d            TT epoch part 1 (Note 1)  
 *     tt2                 d            TT epoch part 2 (Note 1)  
 *     ref                 i            Reference frame
 *                                        0 = dynamical equinox and ecliptic J2000.
 *                                        1 = FK5 (VSOP87)
 *  
 *  Returned:
 *  
 *     pv               d[2][3]         position/velocity (AU, AU/Day)  
 *  
 *  Called:
 *
 *     gal_vsop87                       Compute VSOP87 position and velocity
 *
 *  Notes:  
 *  
 *  1) The epoch tt1+tt2 is a Julian Date, apportioned in  
 *     any convenient way between the two arguments.  For example,  
 *     JD(TDB)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *               tt1          tt2
 *  
 *         2450123.7          0.0       (JD method)  
 *         2451545.0      -1421.3       (J2000 method)  
 *         2400000.5      50123.2       (MJD method)  
 *         2450123.5          0.2       (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *     However, the accuracy of the result is more likely to be  
 *     limited by the algorithm itself than the way the epoch has been  
 *     expressed.  
 *  
 *  2) On return, the arrays pvh and pvb contain the following:  
 *  
 *        pv[0][0]  x       }  
 *        pv[0][1]  y       } position, AU  
 *        pv[0][2]  z       }  
 *  
 *        pv[1][0]  xdot    }  
 *        pv[1][1]  ydot    } velocity, AU/day  
 *        pv[1][2]  zdot    }  
 *  
 *     The vectors are barycentric with respect to the FK5 Reference Frame.  
 *     The time unit is one day in TT 
 *  
 *  3) The routine is a soution from the planetary theory VSOP87 
 *  
 *  4) The main version of VSOP87 is similar to the previous theory VSOP82.
 *     In the both cases the constants of integration have been determined by
 *     fitting to the numerical integration DE200 of the Jet Propulsion Laboratory.
 *
 *     The differences between VSOP87 and VSOP82 mainly improve the validity time-span
 *     for Mercury, Venus, Earth-Moon barycenter and Mars with a precision of 1" for
 *     4000 years before and after J2000.
 *     The same precision is ensured for Jupiter and Saturn over 2000 years and for
 *     Uranus and Neptune over 6000 years before and after J2000.
 *     
 *     The size of the relative precision p0 of VSOP87 solutions is given hereunder.
 *     That means that the actual precision is close by p0*a0 au for the distances
 *     (a0 being the semi-major axis) and close by p0 radian for the other variables.
 *     By derivation with respect to time expressed in day (d), the precision of the
 *     velocities is close by p0*a0 au/d for the distances and close by p0 radian/d
 *     for the other variables.
 *     
 *     Body          a0 (au)      p0 (10**-8)
 *     ----          -------      -----------
 *     Mercury        0.3871          0.6
 *     Venus          0.7233          2.5
 *     Earth          1.0000          2.5
 *     Mars           1.5237         10.0
 *     Jupiter        5.2026         35.0
 *     Saturn         9.5547         70.0
 *     Uranus        19.2181          8.0
 *     Neptune       30.1096         42.0
 *  
 *  References:
 *
 *     Bretagnon P., Francou G., : 1988, Astron. Astrophys., 202, 309.
 *
 *  This revision:
 *  
 *     2008 June 29  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_BEBPV87_H_  
#define _GAL_BEBPV87_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

void 
gal_bebpv87  
 (  
    double tt1,  
    double tt2, 
    int ref, 
    double pv[2][3]
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_GAL_BEBPV87_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
