/*  
 *  - - - - - - - - -  
 *   g a l _ b i 0 0  
 *  - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Frame bias components of IAU 2000 precession-nutation models (part of  
 *  MHB2000 with additions).  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     canonical model.  
 *  
 *  Returned:
 *  
 *     dpsibi,depsbi       d        longitude and obliquity corrections  
 *     dra                 d        the ICRS RA of the J2000 mean equinox  
 *  
 *  Notes:  
 *  
 *  1) The frame bias corrections in longitude and obliquity (radians)  
 *     are required in order to correct for the offset between the GCRS  
 *     pole and the mean J2000 pole.  They define, with respect to the  
 *     GCRS frame, a J2000 mean pole that is consistent with the rest of  
 *     the IAU 2000A precession-nutation model.  
 *  
 *  2) In addition to the displacement of the pole, the complete  
 *     description of the frame bias requires also an offset in right  
 *     ascension. This is not part of the IAU 2000A model, and is from  
 *     Chapront et al. (2002).  It is returned in radians.  
 *  
 *  3) This is a supplemented implementation of one aspect of the IAU  
 *     2000A nutation model, formally adopted by the IAU General Assembly  
 *     in 2000, namely MHB2000 (Mathews et al. 2002).  
 *  
 *  References:  
 *  
 *     Chapront, J., Chapront-Touze, M. & Francou, G., Astron.Astrophys.,  
 *     387, 700, 2002.  
 *  
 *     Mathews, P.M., Herring, T.A., Buffet, B.A., "Modeling of nutation  
 *     and precession   New nutation series for nonrigid Earth and  
 *     insights into the Earth's interior", J.Geophys.Res., 107, B4,  
 *     2002.  The MHB2000 code itself was obtained on 9th September 2002  
 *     from ftp://maia.usno.navy.mil/conv2000/chapter5/IAU2000A.  
 *  
 *  This revision:
 *  
 *     2005 August 24 ( c version 2008 January 18 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_BI00_H_  
#define _GAL_BI00_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_bi00  
 (  
    double *dpsibi,  
    double *depsbi,  
    double *dra  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_BI00_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
