/*  
 *  - - - - - - - - - - 
 *   g a l _ d p p e r  
 *  - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine calculates the deep space long period periodic contributions
 *     to the mean elements.  By design, these periodics are zero at epoch.
 *     This used to be dscom which included initialization, but it's really a
 *     recurring function.
 *  
 *  Status: 
 *  
 *     SGP4 support routine.  
 *  
 *  Given:  
 *
 *     e3               d
 *     ee2              d
 *     peo              d
 *     pgho             d
 *     pho              d
 *     pinco            d
 *     plo              d
 *     se2              d
 *     se3              d
 *     sgh2             d
 *     sgh3             d
 *     sgh4             d
 *     sh2              d
 *     sh3              d
 *     si2              d
 *     si3              d
 *     sl2              d
 *     sl3              d
 *     sl4              d
 *     t                d
 *     xgh2             d
 *     xgh3             d
 *     xgh4             d
 *     xh2              d
 *     xh3              d
 *     xi2              d
 *     xi3              d
 *     xl2              d
 *     xl3              d
 *     xl4              d
 *     zmol             d
 *     zmos             d 
 *     inclo            d           Inclination - needed for lyddane modification
 *     init             c
 *     *ep              d           Eccentricity [0.0 - 1.0]
 *     *nodep           d           Right Ascension of Ascending Node
 *     *argpp           d           Argument of Perigee
 *     *mp              d           Mean Anomaly
 *  
 *  Returned:  
 *  
 *     *ep              d           Eccentricity [0.0 - 1.0]
 *     *inclp           d           Inclination
 *     *nodep           d           Right Ascension of Ascending Node
 *     *argpp           d           Argument of Perigee
 *     *mp              d           Mean Anomaly
 *  
 *  Notes:  
 *  
 *  1) This routine is a translation from c++ to c of David Vallado's SGP4UNIT.dpper 
 *     routine ( 2007 November 16 ).
 *
 *  References:
 *
 *     NORAD Spacetrack Report #3 1980
 *     Hoots, Roehrich 
 *
 *     NORAD Spacetrack Report #6 1986
 *     Hoots 
 *
 *     Hoots, Schumacher and Glover 2004
 *
 *     Revisting Spacetrack Report #3
 *     Vallado, David, Crawford, Paul, Hujsak, Richard, Kelso, T.S.
 *     AIAA 2006-6753
 *
 *  This revision:  
 * 
 *     2008 April 6 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_DPPER_H_  
#define _GAL_DPPER_H_ 1  
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void 
gal_dpper
  (
    double e3,     
    double ee2,    
    double peo,     
    double pgho,   
    double pho,
    double pinco,  
    double plo,    
    double se2,     
    double se3,    
    double sgh2,
    double sgh3,   
    double sgh4,   
    double sh2,     
    double sh3,    
    double si2,
    double si3,    
    double sl2,    
    double sl3,     
    double sl4,    
    double t,
    double xgh2,   
    double xgh3,   
    double xgh4,    
    double xh2,    
    double xh3,
    double xi2,    
    double xi3,    
    double xl2,     
    double xl3,    
    double xl4,
    double zmol,   
    double zmos,   
    double inclo,
    char   init,
    double *ep,    
    double *inclp, 
    double *nodep,  
    double *argpp, 
    double *mp
  ) ;
  
__END_DECLS  
  
#endif /* !_GAL_DPPER_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
