/*  
 *  - - - - - - - - -  
 *   g a l _ e e 0 0  
 *  - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  The equation of the equinoxes, compatible with IAU 2000 resolutions,  
 *  given the nutation in longitude and the mean obliquity.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     canonical model.  
 *  
 *  Given:
 *  
 *     date1,date2         d        TT as a 2-part Julian Date (Note 1)  
 *     epsa                d        mean obliquity (Note 2)  
 *     dpsi                d        nutation in longitude (Note 3)  
 *  
 *  Returned:
 *  
 *     gal_ee00            d        equation of the equinoxes (Note 4)  
 *  
 *  Notes:  
 *  
 *  1) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  2) The obliquity, in radians, is mean of date.  
 *  
 *  3) The result, which is in radians, operates in the following sense:  
 *  
 *        Greenwich apparent ST = GMST + equation of the equinoxes  
 *  
 *  4) The result is compatible with the IAU 2000 resolutions.  For  
 *     further details, see IERS Conventions 2003 and Capitaine et al.  
 *     (2002).  
 *  
 *  Called:
 *  
 *     gal_eect00         equation of the equinoxes complementary terms  
 *  
 *  References:  
 *  
 *     Capitaine, N., Wallace, P.T. and McCarthy, D.D., "Expressions to  
 *     implement the IAU 2000 definition of UT1", Astronomy &  
 *     Astrophysics, 406, 1135-1149 (2003)  
 *  
 *     McCarthy, D. D., Petit, G. (eds.), IERS Conventions (2003),  
 *     IERS Technical Note No. 32, BKG (2004)  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 January 18 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_EE00_H_  
#define _GAL_EE00_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
double  
gal_ee00  
 (  
    double date1,  
    double date2,  
    double epsa,  
    double dpsi  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_EE00_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
