/*  
 *  - - - - - - - - - - -  
 *   g a l _ e e c t 0 0  
 *  - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Equation of the equinoxes complementary terms, consistent with  
 *  IAU 2000 resolutions.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     canonical model.  
 *  
 *  Given:
 *  
 *     date1,date2         d        TT as a 2-part Julian Date (Note 1)  
 *  
 *  Returned:
 *  
 *     gal_eect00          d        complementary terms (Note 2)  
 *  
 *  Notes:  
 *  
 *  1) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  2) The "complementary terms" are part of the equation of the  
 *     equinoxes (EE), classically the difference between apparent and  
 *     mean Sidereal Time:  
 *  
 *        GAST = GMST + EE  
 *  
 *     with:  
 *  
 *        EE = dpsi * cos(eps)  
 *  
 *     where dpsi is the nutation in longitude and eps is the obliquity  
 *     of date.  However, if the rotation of the Earth were constant in  
 *     an inertial frame the classical formulation would lead to apparent  
 *     irregularities in the UT1 timescale traceable to side-effects of  
 *     precession-nutation.  In order to eliminate these effects from  
 *     UT1, "complementary terms" were introduced in 1994 (IAU, 1994) and  
 *     took effect from 1997 (Capitaine and Gontier, 1993):  
 *  
 *        GAST = GMST + CT + EE  
 *  
 *     By convention, the complementary terms are included as part of the  
 *     equation of the equinoxes rather than as part of the mean Sidereal  
 *     Time.  This slightly compromises the "geometrical" interpretation  
 *     of mean sidereal time but is otherwise inconsequential.  
 *  
 *     The present routine computes CT in the above expression,  
 *     compatible with IAU 2000 resolutions (Capitaine et al., 2002, and  
 *     IERS Conventions 2003).  
 *  
 *  Called:
 *  
 *     gal_fal03          mean anomaly of the Moon  
 *     gal_falp03         mean anomaly of the Sun  
 *     gal_faf03          mean argument of the latitude of the Moon  
 *     gal_fad03          mean elongation of the Moon from the Sun  
 *     gal_faom03         mean longitude of the Moon's ascending node  
 *     gal_fave03         mean longitude of Venus  
 *     gal_fae03          mean longitude of Earth  
 *     gal_fapa03         general accumulated precession in longitude  
 *  
 *  References:  
 *  
 *     Capitaine, N. & Gontier, A.-M., Astron. Astrophys., 275,  
 *     645-650 (1993)  
 *  
 *     Capitaine, N., Wallace, P.T. and McCarthy, D.D., "Expressions to  
 *     implement the IAU 2000 definition of UT1", Astronomy &  
 *     Astrophysics, 406, 1135-1149 (2003)  
 *  
 *     IAU Resolution C7, Recommendation 3 (1994)  
 *  
 *     McCarthy, D. D., Petit, G. (eds.), IERS Conventions (2003),  
 *     IERS Technical Note No. 32, BKG (2004)  
 *  
 *  This revision:
 *  
 *     2007 February 9 ( c version 2008 January 18 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_EECT00_H_  
#define _GAL_EECT00_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
double  
gal_eect00  
 (  
    double date1,  
    double date2  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_EECT00_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
