/*  
 *  - - - - - - - - - - - - - - 
 *   g a l _ e m d e t a i l s  
 *  - - - - - - - - - - - - - - 
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine returns the full details of the requested ellipsoid model.
 *  
 *  Status: 
 *  
 *     Canonical model.  
 *  
 *  Given:  
 *
 *     em               i           Ellipsoid Model Identifier (Note 1)
 *  
 *  Returned:  
 *  
 *     *body            i           Solar System Body Identifier
 *     *name          c[40]         Ellipsoid Model name
 *     *sma             d           Semi-major axis ( m )
 *     *inf             d           Inverse flattening factor 
 *     gal_emdetails    i           0 = success
 *                                  1 = invalid Ellipsoid Model Identifier 
 *  
 *  Notes:  
 *  
 *  1) The header file gal_ellipsoids.h defines the following constants for the valid
 *     values of em:
 *
 *     Identifier                 Ellisoid Model
 *     ----------                 --------------
 *
 *	   GAL_EMEA_DEL1800	          Delambre 1800
 *	   GAL_EMEA_AIRY1830          Airy 1830
 *	   GAL_EMEA_EVER1830          Everest 1830
 *	   GAL_EMEA_EVER1830BA        Everest 1830 Boni Alt
 *	   GAL_EMEA_BESL1841          Bessel 1841
 *	   GAL_EMEA_CL1866            Clarke 1866
 *	   GAL_EMEA_CL1880	          Clarke 1880
 *	   GAL_EMEA_CLA1880M          Clarke 1880 Modified
 *	   GAL_EMEA_HEL1906	          Helmert 1906
 *	   GAL_EMEA_INTL1909          International 1909
 *	   GAL_EMEA_KRSV	          Krassovsky
 *	   GAL_EMEA_MERC1960	      Mercury 1960
 *	   GAL_EMEA_WGS1960	          World Geodetic System 1960
 *	   GAL_EMEA_IAU1964	          IAU 1964
 *	   GAL_EMEA_AUSNAT1965	      Australian National 1965
 *	   GAL_EMEA_WGS1966	          World Geodetic System 1966
 *	   GAL_EMEA_MERC1968M	      Modified Mercury 1968
 *	   GAL_EMEA_SA1969		      South American 1969
 *	   GAL_EMEA_GRS1967	          Geodetic Reference System 1967
 *	   GAL_EMEA_WGS1972	          World Geodetic System 1972
 *	   GAL_EMEA_IAG1975	          IAG 1975
 *	   GAL_EMEA_IAU1976           IAU 1976
 *	   GAL_EMEA_GRS1980	          Geodetic Reference System 1980
 *	   GAL_EMEA_MERIT1983	      MERIT 1983
 *	   GAL_EMEA_WGS1984	          World Geodetic System 1984
 *	   GAL_EMEA_IERS1989          IERS 1989
 *	   GAL_EMEA_IERS2000          IERS 2000
 *     GAL_EMME_IAU1991           IAU/IAG/COSPAR 1991 Mercury    
 *     GAL_EMVE_IAU1991           IAU/IAG/COSPAR 1991 Venus      
 *     GAL_EMEA_IAU1991           IAU/IAG/COSPAR 1991 Earth      
 *     GAL_EMMA_IAU1991           IAU/IAG/COSPAR 1991 Mars       
 *     GAL_EMJU_IAU1991           IAU/IAG/COSPAR 1991 Jupiter    
 *     GAL_EMSA_IAU1991           IAU/IAG/COSPAR 1991 Saturn     
 *     GAL_EMUR_IAU1991           IAU/IAG/COSPAR 1991 Uranus     
 *     GAL_EMNE_IAU1991           IAU/IAG/COSPAR 1991 Neptune    
 *     GAL_EMPL_IAU1991           IAU/IAG/COSPAR 1991 Pluto      
 *     GAL_EMSU_IAU1991           IAU/IAG/COSPAR 1991 Sun        
 *
 *  2) Where differences in values were found between references 
 *     Seidelmann was selected. IAU/IAG/COSPAR 1991 values are taken
 *     from Davis et al. 1991
 *  
 *  References:
 *  
 *     Explanatory Supplement to the Astronomical Almanac
 *     Edited by P. Kenneth Seidelmann, 1992
 *     Page 220
 *
 *     Map Projection Transformations
 *     by Qihe Yang, John P. Snyder and Waldo R. Tobler
 *     Page 14
 *
 *     McCarthy, D.D., IERS Conventions 2000, Chapter 4 (2002).
 *
 *     Report of the IAU/IAG/COSPAR Working Group on
 *     Cartographic Coordinates and Rotational Elements of
 *     the Planets and Satellites: 1991
 *     M. E. Davis et al.
 *  
 *  This revision:  
 * 
 *     2009 January 6 
 *  
 *  Copyright (C) 2008, 2009 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_EMDETAILS_H_
#define _GAL_EMDETAILS_H_ 1

#undef __BEGIN_DECLS
#undef __END_DECLS
#ifdef __cplusplus
#define __BEGIN_DECLS extern "C" {
#define __END_DECLS }
#else
#define __BEGIN_DECLS /* empty */
#define __END_DECLS   /* empty */
#endif

__BEGIN_DECLS

int
gal_emdetails  
  (
    const int em,
    int *body,
    char *name,
    double *sma,
    double *inf
  ) ;
 
__END_DECLS

#endif /* !_GAL_EMDETAILS_H_ */

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008, 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
