/*  
 *  - - - - - - - - - -  
 *   g a l _ e o 0 6 a  
 *  - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Equation of the origins, IAU 2006 precession and IAU 2000A nutation.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     date1,date2         d        TT as a 2-part Julian Date (Note 1)  
 *  
 *  Returned:
 *  
 *     gal_eo06a           d        equation of the origins in radians  
 *  
 *  Notes:  
 *  
 *  1) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  2) The equation of the origins is the distance between the true  
 *     equinox and the celestial intermediate origin and, equivalently,  
 *     the difference between Earth rotation angle and Greenwich  
 *     apparent sidereal time (ERA-GST).  It comprises the precession  
 *     (since J2000.0) in right ascension plus the equation of the  
 *     equinoxes (including the small correction terms).  
 *  
 *  Called:
 *  
 *     gal_pnm06a         classical NPB matrix, IAU 2006/2000A  
 *     gal_bpn2xy         extract CIP X,Y coordinates from NPB matrix  
 *     gal_s06            the CIO locator s, given X,Y, IAU 2006  
 *     gal_eors           equation of the origins, given NPB matrix and s  
 *  
 *  References:  
 *  
 *     Capitaine, N. & Wallace, P.T., 2006, Astron.Astrophys. 450, 855  
 *  
 *     Wallace, P.T. & Capitaine, N., 2006, Astron.Astrophys. 459, 981  
 *  
 *  This revision:
 *  
 *     2007 February 13  ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_EO06A_H_  
#define _GAL_EO06A_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
double  
gal_eo06a  
 (  
    double date1,  
    double date2  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_EO06A_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
