/*  
 *  - - - - - - - - - -  
 *   g a l _ f k 5 h z  
 *  - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Transform an FK5 (J2000) star position into the system of the  
 *  Hipparcos catalogue, assuming zero Hipparcos proper motion.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     r5                  d        FK5 RA (radians), equinox J2000, at date  
 *     d5                  d        FK5 Dec (radians), equinox J2000, at date  
 *     date1,date2         d        TDB date (Notes 1,2)  
 *  
 *  Returned:
 *  
 *     *rh                 d        Hipparcos RA (radians)  
 *     *dh                 d        Hipparcos Dec (radians)  
 *  
 *  Notes:  
 *  
 *  1) This routine converts a star position from the FK5 system to  
 *     the Hipparcos system, in such a way that the Hipparcos proper  
 *     motion is zero.  Because such a star has, in general, a non-zero  
 *     proper motion in the FK5 system, the routine requires the date  
 *     at which the position in the FK5 system was determined.  
 *  
 *  2) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  3) The FK5 to Hipparcos transformation is modeled as a pure  
 *     rotation and spin;  zonal errors in the FK5 catalogue are  
 *     not taken into account.  
 *  
 *  4) It was the intention that Hipparcos should be a close  
 *     approximation to an inertial frame, so that distant objects  
 *     have zero proper motion;  such objects have (in general)  
 *     non-zero proper motion in FK5, and this routine returns those  
 *     fictitious proper motions.  
 *  
 *  5) The position returned by this routine is in the FK5 J2000  
 *     reference system but at date date1+date2.  
 *  
 *  6) See also gal_fk52h, gal_h2fk5, gal_hfk5z.  
 *  
 *  Called:
 *  
 *     gal_s2c            spherical coordinates to unit vector  
 *     gal_fk5hip         FK5 to Hipparcos rotation and spin  
 *     gal_sxp            multiply p-vector by scalar  
 *     gal_rv2m           r-vector to r-matrix  
 *     gal_trxp           product of transpose of r-matrix and p-vector  
 *     gal_pxp            vector product of two p-vectors  
 *     gal_c2s            p-vector to spherical  
 *     gal_anp            normalize angle into range 0 to 2pi  
 *  
 *  References:  
 *  
 *     F.Mignard & M.Froeschle, Astron. Astrophys. 354, 732-739 (2000).  
 *  
 *  This revision:
 *  
 *     2007 April 18 ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_FK5HZ_H_  
#define _GAL_FK5HZ_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_fk5hz  
 (  
    double r5,  
    double d5,  
    double date1,  
    double date2,  
    double *rh,  
    double *dh  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_FK5HZ_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
