/*  
 *  - - - - - - - - - - - - - - 
 *   g a l _ g m g l g m 1 . h  
 *  - - - - - - - - - - - - - - 
 *  
 *  This file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This file defines the external variables for the GLGM1 Lunar gravity model.
 *  
 *  Status: 
 *  
 *     Support file gravity model sub-system  
 *
 *  Defines:  
 *
 *     gal_glgm1    gal_gm_t      GLGM1 gravity model structure
 *
 *
 *  Notes:  
 *
 *  1) This model is derived from a tracking of Lunar Orbiters 1,2,3,4 & 5, the Apollo-15
 *     subsatellite, and Clementine: 361,000 observations from Clementine,
 *     and 300,000 observations from the other spacecraft.  
 * 
 *  2) The field was derived using the 1992 IAU Model for the Moon.
 *     Note that the reference for this model has typographical errors for two of
 *     the quantities describing the angular librations.
 * 
 *     Report of the IAU/IAG/COSPAR Working Group on Cartographic
 *     Coordinates and Rotational Elements of the Planets and Satellites
 *     1991, by M E Davies, V K Abalakin, A. Brahic, M. Bursa, B H Chovitz,
 *     J H Lieske, P K Seidelmann, A T Sinclair, and Y S Tjuflin,
 *     Cel. Mechanics and Dynamical Astronomy, 53, 377-397, 1992.
 * 
 *     Table II lists the IAU model for the orientation for the lunar pole
 *     and prime meridian.
 * 
 *     The quantities which read E3 = 260.008 - 13.012001*d
 * 		    E5 = 357.529 -  0.985600*d
 *     should instead read   E3 = 260.008 + 13.012001*d
 *	        E5 = 357.529 +  0.985600*d
 *
 *  3) The Reference radius for this model is 1738.0 km.
 *
 *     The following list gives the Planet GM in meters**3/seconds**2,
 *     and the Spherical Harmonic Coefficients (GCOEFC for the C terms
 *     and GCOEFS for the S terms).  All the C and S terms are normalized.
 *
 *  4) LUNAR GRAVITY MODEL,70x70 LGM0281 (1994) GM(1 sigma error) = .000946 km**3/s**2
 *
 *  References:  
 *
 *     Goddard Lunar Gravity Model-1 (GLGM-1): A 70th degree and order gravity model
 *     for the Moon, by F G Lemoine, D E Smith, and M T Zuber, 
 *     P11A-9, EOS, Transactions of the American Geophysical Union
 *     Volume 75, No. 44, 1994.
 *
 *  This revision:  
 * 
 *     2008 September 20 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_GMGLGM1_H_  
#define _GAL_GMGLGM1_H_ 1  

#include "gal_gm.h"
#include "gal_const.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

double gal_gmglgm1_terms[71][71] = {
{
                    0e+00,                     0e+00,         1.06402272802e-07,         5.10941609989e-06,         1.37046437979e-06, 
       -4.31605600816e-06,        -2.84042906069e-06,         4.43830232458e-07,         1.36652599254e-06,         6.22959794423e-07, 
       -6.42719054620e-07,         3.45626044982e-07,         1.76245929158e-06,        -3.70164919908e-07,        -6.21236737866e-07, 
        4.96157438382e-07,         9.32312685047e-07,        -1.39508980518e-08,         9.91977355276e-09,        -3.26843357713e-07, 
       -4.56516261118e-07,         4.42938275923e-07,         4.11904648236e-07,        -5.01865301424e-07,        -8.88666688405e-08, 
        3.97771250715e-07,        -1.57182923616e-07,        -2.31707733328e-07,         2.11142400280e-07,         6.27728434221e-08, 
       -1.33980597546e-07,         5.09989810050e-08,         4.86587692469e-08,        -1.04017758340e-07,        -2.10365806266e-08, 
        1.15377548009e-07,         4.18394887336e-08,        -1.07282743649e-07,        -6.45644292699e-08,         9.10553605048e-08, 
        5.76277395947e-08,        -6.87455378441e-08,        -2.46088843936e-08,         4.23358053474e-08,        -8.77403545543e-09, 
       -1.77215314823e-08,         2.14783886277e-08,         2.09423525415e-09,        -1.19633240030e-08,         1.78521747362e-09, 
       -5.92214822680e-09,         2.39207355465e-09,         1.72554248850e-08,        -7.54741798437e-09,        -1.67572095244e-08, 
        8.48256129413e-09,         9.25670998311e-09,        -4.84964368761e-09,        -2.76386160600e-09,         4.60482127945e-11, 
        1.55137563576e-09,         2.32685603163e-09,        -4.28427609884e-09,        -1.25107674879e-09,         6.93755268460e-09, 
       -1.55782532925e-09,        -6.78575646807e-09,         3.58864063204e-09,         4.12160969132e-09,        -3.57384291122e-09, 
       -1.11579580278e-09, 
},
{
                    0e+00,                     0e+00,        -1.12672583416e-07,         4.80738312473e-06,        -5.90977646904e-06, 
        1.44823184382e-06,        -1.96592771643e-06,         2.64789595398e-06,         9.75285332032e-07,        -1.90638816052e-06, 
       -1.34827855122e-06,        -2.69146529597e-06,         1.04344864636e-06,        -1.57011451062e-07,         6.73351175414e-07, 
        3.50589903727e-07,         6.01246936271e-07,        -8.45741935017e-07,        -3.57416514383e-08,         1.24165949620e-07, 
        2.33374014556e-07,        -6.53547099252e-08,        -8.76117512351e-08,        -1.80626299338e-07,         2.76605999484e-07, 
        1.12800467383e-07,        -4.23795837770e-07,        -1.23384368600e-08,         4.89425818753e-07,        -1.15218349343e-07, 
       -3.87189486352e-07,         1.58731345581e-07,         1.90070119033e-07,        -1.32542509742e-07,        -1.18801626728e-08, 
        6.45684896500e-08,        -6.99965719854e-08,        -3.86955614929e-09,         5.67324103590e-08,        -2.55452899235e-08, 
       -2.94682757656e-09,         2.48128269825e-08,        -3.65509272862e-08,        -1.30697901115e-08,         4.10629503582e-08, 
        7.30382588369e-09,        -2.43169230074e-08,        -1.15452447506e-08,         1.05455836035e-08,         1.83191118006e-08, 
       -1.19029312593e-08,        -1.85210194195e-08,         2.27830342565e-08,         9.77471129853e-09,        -2.98943710632e-08, 
        2.57889434746e-09,         2.54240188115e-08,        -1.08480754928e-08,        -1.22570168812e-08,         1.11321877616e-08, 
       -6.00845884966e-10,        -5.40513666152e-09,         6.22316561431e-09,        -1.11095569056e-09,        -4.32552395142e-09, 
        4.28719968624e-09,        -3.26250156938e-10,        -3.57044094919e-09,         2.81646760066e-09,         1.26129806562e-09, 
       -1.70048734255e-09, 
},
{
       -9.11174684476e-05,        -1.91403789731e-07,         3.43814726347e-05,        -2.01530084386e-06,        -1.35302463268e-05, 
        8.83070734896e-06,        -3.89318179774e-06,         2.36412602930e-06,         7.22559257222e-07,         1.80199708830e-06, 
        1.50782270427e-06,         5.19677864984e-07,        -2.68936703154e-06,        -1.08482798207e-06,         6.30253650763e-07, 
       -3.25679337373e-08,         7.73210951515e-08,        -3.20338320424e-07,        -2.18098305807e-07,         8.01937305183e-07, 
       -3.10434462205e-07,        -6.36575422293e-07,         7.59266810203e-07,         5.27175930196e-07,        -8.95818596399e-07, 
       -2.16705986300e-07,         6.76709187649e-07,        -2.10374721108e-08,        -3.72267071784e-07,         1.59300534059e-07, 
        1.64785161785e-07,        -1.64866450238e-07,        -9.11197683036e-08,         9.85640082845e-08,         7.81979448761e-08, 
       -2.64975749452e-08,        -6.16315955555e-08,        -1.56412932719e-08,         2.51058457680e-08,         2.92816432195e-08, 
        8.60285806602e-09,        -3.36676387347e-08,        -1.72188398805e-08,         4.12684275783e-08,        -5.96790059373e-10, 
       -5.03428032426e-08,         2.77808438493e-08,         5.12041583416e-08,        -4.59216454413e-08,        -3.86430483346e-08, 
        4.75885663090e-08,         1.73084564709e-08,        -3.74071109891e-08,         2.18385006994e-09,         2.48586191339e-08, 
       -1.17032097087e-08,        -1.67151668556e-08,         1.07905309356e-08,         1.40403899779e-08,        -5.29835865018e-09, 
       -1.39274030374e-08,         1.79379551790e-09,         1.30265893807e-08,        -2.83187451878e-09,        -9.97971290300e-09, 
        6.36069716443e-09,         5.66381494247e-09,        -8.66631652449e-09,        -1.88476643442e-09,         7.75553064469e-09, 
       -1.34562923969e-10, 
},
{
       -3.87895130050e-06,         2.59452321380e-05,         1.43368639459e-05,         1.26842369624e-05,         4.49116619635e-06, 
        9.43423679200e-08,        -4.75254834532e-06,         1.15803383964e-06,        -7.84438812073e-07,        -1.07418262610e-06, 
        1.91691465427e-06,         1.76002759622e-06,         3.40523533673e-08,        -1.72795466537e-06,        -2.28161293047e-06, 
       -2.25571724917e-06,         3.35472498119e-07,         1.44976090534e-06,         8.52742245837e-07,        -1.28584878875e-06, 
       -4.64251367807e-07,         8.98905318222e-07,         2.05225588888e-07,        -3.39083321920e-07,         8.31948430796e-08, 
        5.39954320796e-08,        -2.94386943995e-08,         4.50057657944e-08,        -8.42940110463e-08,         6.23901494709e-08, 
        1.72494566732e-07,        -1.80848005533e-07,        -1.48809919357e-07,         2.32228639853e-07,         7.97863114053e-08, 
       -1.90275978529e-07,        -3.19403840294e-08,         1.08754690130e-07,         3.93148537989e-08,        -4.27955635676e-08, 
       -7.90391224187e-08,         1.82949697668e-08,         1.11009503974e-07,        -2.40635039865e-08,        -1.11174933690e-07, 
        3.52764670057e-08,         8.50699677471e-08,        -3.59266042122e-08,        -5.42704440334e-08,         2.66885890268e-08, 
        3.58698325599e-08,        -1.74729773299e-08,        -3.16459533124e-08,         1.55698629553e-08,         3.21128653717e-08, 
       -1.99064151251e-08,        -2.77144829109e-08,         2.39158016465e-08,         1.65605306966e-08,        -2.22417621064e-08, 
       -3.85008420615e-09,         1.48579395099e-08,        -4.14936989580e-09,        -6.03123563421e-09,         5.35257502435e-09, 
        2.07083050267e-10,        -2.47686978857e-09,         1.24821850816e-09,        -1.93311784232e-10,        -1.80413963984e-10, 
        3.56874589547e-10, 
},
{
        3.00284469438e-06,        -5.60302689690e-06,        -6.52557516713e-06,        -1.45142423485e-06,        -6.60593956351e-06, 
       -3.48652611362e-06,        -1.03186048600e-05,         2.43844928099e-06,         2.72346427407e-06,        -3.47231040591e-06, 
       -1.10140019716e-06,         1.68704753299e-06,         4.58846817508e-07,         5.08391122686e-07,         2.54280982180e-07, 
       -1.39343304536e-06,         2.96264558488e-07,        -1.55443058551e-06,         7.94446359624e-07,         5.68314850549e-07, 
        1.40409055145e-07,        -5.89941453306e-07,        -3.31379472165e-07,        -4.34642980254e-08,         6.05634468488e-07, 
        1.81902193210e-07,        -4.82596076581e-07,        -2.27079496864e-07,         2.72400334642e-07,         1.73408395183e-07, 
       -5.50215705138e-08,        -1.36245342493e-07,        -3.28553349189e-08,         1.14129395250e-07,         2.41728771026e-08, 
       -8.99756859221e-08,         1.72964614423e-08,         5.55865786428e-08,        -2.83975396916e-08,        -2.12591064368e-08, 
        1.53994548868e-09,         4.57213695375e-09,         3.66432777039e-08,        -9.34350785880e-09,        -5.52554122159e-08, 
        2.48852296123e-08,         4.53402079017e-08,        -3.51264436824e-08,        -1.97411258816e-08,         3.18938951061e-08, 
       -1.92979212146e-09,        -1.85692680921e-08,         8.93844100058e-09,         4.85700096225e-09,        -3.82002918642e-09, 
        1.89438346399e-09,        -3.86347692390e-09,        -1.14641775338e-09,         6.70474451315e-09,        -2.53960279441e-09, 
       -3.98406424140e-09,         4.45255026185e-09,        -2.30400643422e-10,        -3.25466795731e-09,         1.94360020879e-09, 
        8.44713599076e-10,        -4.56251586813e-10,         2.72858019534e-10,        -2.01718666766e-09,         6.69607878865e-10, 
        2.96599953106e-09, 
},
{
       -3.74983052737e-07,        -1.26489505287e-06,         3.82651270768e-06,        -9.44027315803e-07,         3.01766938549e-06, 
        3.78868436783e-06,         7.94152230145e-06,         1.23012857418e-06,        -3.71051843441e-06,        -3.33956395369e-06, 
       -1.85775105436e-06,        -1.40204444583e-06,         1.55071637021e-06,         1.98183063036e-06,         1.99003085560e-06, 
        6.47943748149e-07,        -1.19731288778e-06,        -6.57480785774e-07,         2.56468940286e-07,         6.02234954275e-07, 
       -1.41285789143e-07,        -1.97013247471e-07,        -1.57946093387e-07,         9.22626650663e-08,         6.52118767500e-08, 
       -1.46448922949e-07,        -2.44943664700e-08,         1.68446095029e-07,        -8.73870785147e-08,        -1.80316324065e-07, 
        1.55307509532e-07,         1.22291196005e-07,        -1.91913577337e-07,        -4.92471678514e-08,         1.78118264686e-07, 
       -1.45850750335e-08,        -1.37425107720e-07,         4.40805182888e-08,         9.23292761862e-08,        -4.86503451543e-08, 
       -6.16090364976e-08,         4.64863333795e-08,         4.71193715324e-08,        -5.07185099838e-08,        -3.93475167292e-08, 
        6.05909930087e-08,         2.90177957748e-08,        -6.72704081598e-08,        -1.47485478667e-08,         6.40764329968e-08, 
        1.85877644332e-09,        -5.21419274362e-08,         4.46129238575e-09,         3.84059928407e-08,        -4.11183473667e-09, 
       -2.92216321348e-08,         1.60602283313e-09,         2.58497001984e-08,        -1.63916628117e-09,        -2.48364263425e-08, 
        5.32471421851e-09,         2.19448834096e-08,        -1.00308650309e-08,        -1.57303333561e-08,         1.22525023100e-08, 
        8.10542665085e-09,        -1.05974883195e-08,        -2.15794280531e-09,         6.52249416181e-09,        -4.42098669719e-10, 
       -2.72761655411e-09, 
},
{
        3.77877381602e-06,         2.03720896817e-06,        -4.17000677298e-06,        -2.82350085404e-06,         1.86870599787e-06, 
        1.32190603524e-06,        -5.31424585320e-06,        -2.36517605836e-06,         2.99295285592e-06,         1.26064883516e-06, 
       -9.52532868060e-07,        -3.10695469855e-06,        -1.04744198391e-06,        -1.32230481786e-06,         4.95254810024e-07, 
        1.62448272243e-06,        -8.94143547821e-07,        -1.32586132000e-06,        -5.42090908482e-07,         4.56821621612e-07, 
       -5.06665883115e-07,         6.15242811202e-07,         1.80748186108e-07,        -8.44601200919e-07,        -3.10210786910e-08, 
        6.94508728899e-07,        -1.92156792119e-07,        -3.13011756259e-07,         2.20843754542e-07,         2.73137581453e-08, 
       -1.72609170982e-07,         6.11230393296e-08,         8.25909372556e-08,        -2.41459729241e-08,        -2.96822492557e-08, 
       -4.65132318311e-08,         2.27315971677e-08,         7.95616089541e-08,        -4.66792893598e-08,        -7.15670551967e-08, 
        7.03640842600e-08,         4.35913483714e-08,        -7.73019732600e-08,        -2.10290614051e-08,         6.64613035857e-08, 
        1.11106950951e-08,        -4.70583862678e-08,        -9.33692510386e-09,         2.85763095644e-08,         8.66163866921e-09, 
       -1.60376780489e-08,        -7.15033017993e-09,         9.93855406992e-09,         6.66289953662e-09,        -8.68980372713e-09, 
       -8.62064198363e-09,         1.04098707429e-08,         1.14521551942e-08,        -1.33273868683e-08,        -1.20574997248e-08, 
        1.56721454529e-08,         8.84403702496e-09,        -1.60190661261e-08,        -3.20984787275e-09,         1.39942628823e-08, 
       -1.72318995533e-09,        -1.05449852170e-08,         3.65856807952e-09,         7.30775805415e-09,        -2.67162616811e-09, 
       -5.48088531886e-09, 
},
{
        6.60664967733e-06,         8.20508417801e-06,        -1.59729223468e-06,         3.73933621336e-07,        -1.19881077105e-06, 
       -1.75339772574e-06,        -9.36384069385e-07,        -1.36910767501e-06,         2.95434075237e-06,        -1.69082104833e-06, 
        1.53345409068e-06,         1.20710988595e-08,        -2.35243758665e-06,        -1.80236864272e-06,         9.72821396421e-07, 
        1.15159757869e-06,         5.19981989102e-07,        -8.09409015555e-07,         2.15312585358e-07,         6.29478707930e-07, 
        2.21873025234e-07,        -7.52557980744e-09,         8.53008218273e-09,        -3.27173895120e-07,         1.87484583365e-07, 
        5.00071907526e-07,        -1.33791366479e-07,        -3.20139117775e-07,         1.54133630649e-07,         1.23649962802e-07, 
       -8.85315606769e-08,         7.08051220872e-08,         5.14848908607e-08,        -1.61023747197e-07,        -3.18443811891e-08, 
        1.88784384837e-07,         2.74965736587e-08,        -1.73941866655e-07,        -1.18051259480e-08,         1.44393465773e-07, 
       -1.67003873942e-08,        -1.05188430434e-07,         4.20031522365e-08,         6.12786838108e-08,        -4.52524134796e-08, 
       -2.23589475561e-08,         2.19500439481e-08,         6.36391180045e-10,         1.39968674375e-08,        -8.18890279140e-10, 
       -4.14957499962e-08,         1.55030028859e-08,         4.71706422262e-08,        -3.01605367269e-08,        -3.30907990990e-08, 
        3.31800846819e-08,         1.25270229061e-08,        -2.29309961950e-08,         8.78694191036e-10,         6.87820550646e-09, 
       -1.89580049999e-09,         5.28238462365e-09,        -5.21571910007e-09,        -8.59364325920e-09,         1.22299690592e-08, 
        4.96028638737e-09,        -1.37019314962e-08,        -1.99794106971e-11,         9.93298487134e-09,        -1.80776324401e-09, 
       -5.04818941209e-09, 
},
{
        2.70573200365e-06,        -6.77482624983e-07,         2.63605101651e-06,        -1.30192793729e-06,         3.57798424459e-06, 
       -1.00144931033e-06,        -9.76549935360e-08,        -1.36616350258e-06,        -2.88138236692e-06,         1.69349065141e-06, 
       -5.34760256696e-07,         1.13907433667e-06,         5.13141109128e-07,         1.07113779926e-06,        -7.53458951061e-07, 
       -1.32498293254e-06,         4.55156292006e-07,         8.72852861783e-07,        -5.60757809861e-08,        -4.68865794124e-07, 
        4.00006023308e-07,        -1.23040438572e-07,         3.45060353491e-07,         2.43641944803e-07,        -2.70226069247e-07, 
       -2.49032801125e-07,         2.53511873607e-07,         1.37928012239e-07,        -5.77034104318e-08,        -3.74121269892e-08, 
       -2.60422518203e-08,         1.64292475312e-08,         5.84496745219e-08,        -1.35909846848e-08,        -2.25440859791e-08, 
        1.23206433559e-08,        -9.48344495847e-09,         1.36337971797e-08,         1.89832551333e-08,        -4.49416146896e-08, 
       -6.35612782886e-10,         6.40267128917e-08,        -2.21842996467e-08,        -5.74393089510e-08,         3.09312992552e-08, 
        3.23465039838e-08,        -2.01349541547e-08,        -4.93022971694e-09,        -3.13720363128e-10,        -1.06171753187e-08, 
        1.64392649483e-08,         1.14334425114e-08,        -2.02312363387e-08,        -4.33348804978e-09,         1.34310045653e-08, 
       -1.49095829662e-09,        -3.55103164227e-09,         1.35326300159e-09,        -2.74997643354e-09,         3.49146318283e-09, 
        3.69487538003e-09,        -9.03989372370e-09,        -1.70321874313e-09,         1.25432716689e-08,        -8.58538726933e-11, 
       -1.40104971501e-08,         6.22609291314e-10,         1.48751248047e-08,        -1.09099836256e-09,        -1.58744202016e-08, 
        3.01189331656e-09, 
},
{
       -1.85311429600e-06,         2.62052751914e-06,         2.37286099015e-06,        -7.82818036951e-07,        -2.44080887215e-06, 
       -1.80723827485e-06,        -2.07792578426e-06,        -4.97929532982e-06,        -1.55882170726e-06,        -6.18022432754e-07, 
       -1.13311144991e-06,         3.29964811594e-07,        -1.67169153768e-06,         1.04344337685e-06,        -4.76798701669e-08, 
       -4.10928762020e-07,         2.56651906377e-07,        -2.12378173616e-07,        -4.84943251479e-07,        -1.52663807759e-07, 
       -1.21763016068e-07,         1.64188996978e-07,         3.10609587407e-08,        -2.64535898164e-07,        -4.54756801966e-07, 
        3.26658814610e-07,         3.45357477521e-07,        -4.00802289293e-07,        -2.59426892317e-07,         3.81900585117e-07, 
       -1.55138490259e-08,        -3.33736593848e-07,         2.16177644374e-07,         2.27218373779e-07,        -3.08857937646e-07, 
       -1.14914107630e-07,         2.61615163811e-07,         2.55177122523e-08,        -1.44000960097e-07,         1.47158368171e-08, 
        2.94508836203e-08,        -1.01518749121e-08,         3.25139727718e-08,        -1.69031816537e-08,        -3.90259512653e-08, 
        4.12182144426e-08,         1.78154708226e-08,        -4.94135447603e-08,         6.69688654899e-10,         4.35248972600e-08, 
       -2.79807840846e-09,        -3.33839690759e-08,        -5.97902407970e-09,         2.67722404969e-08,         1.25395246963e-08, 
       -2.43270357697e-08,        -8.82215244568e-09,         2.17280524075e-08,        -3.09467846860e-09,        -1.51006343489e-08, 
        1.49766157601e-08,         4.69503856111e-09,        -1.98661977494e-08,         5.70794307396e-09,         1.66944398651e-08, 
       -1.21354516944e-08,        -9.52115504470e-09,         1.33045068699e-08,         3.43609736134e-09,        -1.09381199371e-08, 
       -9.43971181435e-10, 
},
{
       -3.52672247641e-08,        -8.76440540677e-07,         1.03448610858e-07,         6.43178805290e-08,        -5.15474936507e-06, 
        8.10699410895e-07,         4.67699442523e-07,        -4.08078374394e-06,        -2.78874228709e-06,        -4.82044050240e-06, 
        8.60278569072e-07,        -2.20938197457e-06,        -7.67885897635e-07,         5.75834651299e-07,         1.33133327433e-06, 
       -4.53355807986e-07,         1.43911274822e-06,        -5.50423346970e-07,        -7.95598471286e-07,        -3.64793374347e-07, 
        1.16282600509e-06,        -3.24112384626e-07,        -3.88865169162e-07,         9.95844083969e-08,        -3.30189092436e-08, 
       -1.18071431879e-08,         2.11510457086e-07,        -2.09650114261e-07,        -1.34075109048e-07,         1.65687847940e-07, 
       -6.17858003642e-08,        -5.07707392304e-08,         1.78389116160e-07,        -1.14273363099e-07,        -1.86334274716e-07, 
        1.92284046405e-07,         1.06130957116e-07,        -1.83408606673e-07,        -2.07560431264e-08,         1.14471603819e-07, 
       -2.60466426828e-08,        -4.92922304522e-08,         2.84064060815e-08,         2.09710070437e-08,        -1.35371040124e-08, 
       -2.94606391821e-08,         6.51441832008e-09,         4.91501175097e-08,        -1.49336306396e-08,        -5.59588878204e-08, 
        2.93058847841e-08,         4.22865949030e-08,        -3.64784120488e-08,        -1.73728182036e-08,         3.09595789259e-08, 
       -4.11363485054e-09,        -1.72635681148e-08,         1.33148796192e-08,         4.15129636628e-09,        -1.11627523405e-08, 
        2.52067436742e-09,         4.60674280437e-09,        -2.79705687887e-09,        -1.00539177977e-10,         5.77835800562e-10, 
       -3.85994876234e-10,         4.87200011309e-10,        -1.08071160969e-09,         4.24112205260e-10,         1.52881128317e-09, 
       -1.66353451544e-09, 
},
{
       -2.82898797801e-07,        -4.11715423887e-07,         3.07602739561e-06,         1.33743739226e-06,        -7.66777749531e-07, 
        1.51121214156e-06,         8.66823844486e-07,        -3.96605516700e-08,        -2.01459080199e-06,        -3.00158097882e-06, 
       -4.12019039792e-06,        -3.02047893346e-06,         1.41517196906e-06,        -1.39109107699e-06,        -3.72960752156e-07, 
       -2.37699334053e-07,        -1.04010125903e-09,        -1.64409315530e-07,         7.56022273373e-07,        -1.02186803946e-07, 
       -1.01885714480e-06,         5.87341869890e-07,         9.02197471458e-08,        -2.88774247735e-07,         2.21688312959e-07, 
        1.64002563769e-07,        -2.68279768374e-07,         8.79957991709e-08,         1.21822354955e-07,        -1.30138771779e-07, 
        2.98169534419e-08,         1.25155807935e-07,        -9.69760468536e-08,        -9.17973645727e-08,         9.95979397263e-08, 
        1.00445085392e-07,        -8.22238770449e-08,        -1.19034936028e-07,         6.79815545548e-08,         1.18204024952e-07, 
       -5.29649001163e-08,        -8.31684531436e-08,         2.42083900630e-08,         3.18539137900e-08,         1.62335389058e-08, 
        8.03567812736e-09,        -5.15464632949e-08,        -2.11866659987e-08,         6.34951477749e-08,         1.28429851386e-08, 
       -4.83785431481e-08,        -3.10247174926e-10,         1.90290526415e-08,        -2.53932376578e-09,         5.44393943609e-09, 
       -5.80958607794e-09,        -1.31833122976e-08,         1.66134462688e-08,         5.67711518647e-09,        -2.00718460078e-08, 
        6.25656175284e-09,         1.30197824249e-08,        -1.18659418151e-08,        -1.71310024134e-11,         7.57825098232e-09, 
       -1.14325828324e-08,         2.48673064593e-09,         1.66477151941e-08,        -1.13819504758e-08,        -1.61500510370e-08, 
        1.48811081216e-08, 
},
{
       -1.10715863213e-06,        -1.46933457454e-06,        -1.52076371288e-07,        -8.35905173830e-07,        -2.77951168390e-07, 
       -2.79925326197e-07,         5.72854823106e-08,         1.40142293525e-06,         1.06857239858e-07,        -1.40736169963e-06, 
       -2.72954457613e-06,        -1.69394248917e-06,         7.78868208374e-07,        -2.70164685869e-06,        -1.04321517038e-06, 
        8.76536541427e-08,        -1.70854706815e-07,         3.84617179358e-07,         1.06507205225e-07,         1.54474910951e-06, 
        3.08346281489e-07,        -1.06952592677e-07,         2.86570972151e-07,         8.35512201482e-08,        -3.77355674121e-07, 
        2.45303247862e-07,         4.15613176513e-07,        -9.49992611426e-08,        -2.99851534587e-07,        -1.68705830385e-08, 
        2.75066161687e-07,         1.26223297498e-07,        -2.15395783174e-07,        -9.67247815669e-08,         1.33751693319e-07, 
        3.27201934189e-08,        -3.62532872397e-09,         2.32410528664e-08,        -1.11608443097e-07,        -3.04777362212e-08, 
        1.74240855168e-07,         7.86830086540e-09,        -1.69650035396e-07,         1.88411340119e-08,         1.23063351636e-07, 
       -3.05441248023e-08,        -6.87259301204e-08,         2.92819845474e-08,         3.01585892322e-08,        -2.53363312010e-08, 
       -1.08300371857e-08,         2.57326808407e-08,         1.78782109353e-09,        -2.87104615195e-08,         6.04347308539e-09, 
        2.85453481030e-08,        -1.47544668851e-08,        -2.24042998701e-08,         2.08398350121e-08,         1.32636787836e-08, 
       -2.09858151359e-08,        -7.01966986799e-09,         1.60463780641e-08,         7.41497799332e-09,        -1.04151906834e-08, 
       -1.32809294113e-08,         8.34637196197e-09,         1.99221672630e-08,        -1.08841567043e-08,        -2.28792095516e-08, 
        1.57076830572e-08, 
},
{
       -1.23555282736e-07,         3.55536727479e-07,        -7.05143492300e-07,         7.90715869888e-08,         1.25537015423e-06, 
       -1.09864570213e-07,         3.09864117360e-08,        -3.04825712771e-08,         4.25062547392e-07,         1.22369323902e-07, 
       -4.72121940547e-07,        -1.35148133543e-06,         5.88025915670e-08,         1.85242122696e-06,         9.69189340340e-07, 
        5.30080820045e-07,         2.77961871106e-07,         9.03888872383e-08,        -8.36806497901e-07,         4.60758684761e-07, 
        2.75798963954e-07,         1.74864910642e-07,         6.22645273286e-07,        -4.44858674385e-07,        -4.31522154988e-07, 
        5.67058683508e-07,         2.83778755281e-07,        -7.18129769414e-07,        -8.41439936960e-08,         5.52731586908e-07, 
        2.38888901847e-08,        -3.25197829317e-07,        -6.77808819294e-08,         7.96747311139e-08,         1.42357272601e-07, 
        5.52409434159e-08,        -1.69591477987e-07,        -8.46981003790e-08,         1.26910183135e-07,         4.02533585230e-08, 
       -4.36912435092e-08,         1.77484971694e-08,        -2.95596514472e-08,        -5.11905613334e-08,         5.94716260071e-08, 
        5.06012202493e-08,        -4.52635195115e-08,        -3.04793802993e-08,         1.20396338264e-08,         1.06035351730e-08, 
        1.21542292529e-08,        -1.51831718689e-09,        -1.43071880081e-08,         1.26611846853e-09,         5.72769200547e-10, 
       -2.03291870222e-09,         1.32660551625e-08,        -1.06260337596e-09,        -1.50545075201e-08,         6.34514205921e-09, 
        3.95614730767e-09,        -8.46973238412e-09,         1.13052326937e-08,         4.02111637575e-09,        -2.03034518383e-08, 
        5.30150986691e-09,         1.83130956150e-08,        -1.41044001745e-08,        -8.37419422228e-09,         1.75488724292e-08, 
       -2.23490539481e-09, 
},
{
        3.31042982444e-07,         1.19201927257e-06,         1.18829817287e-07,        -1.36280430511e-06,        -2.30227798066e-07, 
       -9.67494571145e-07,        -2.48615860825e-06,        -7.42485308196e-07,         7.15600148171e-07,        -2.17393883692e-07, 
       -1.04909636510e-06,        -2.07838984496e-06,        -1.66552805204e-06,        -8.18791702715e-07,         1.05154420415e-07, 
        9.16277818524e-07,        -1.22587550077e-06,        -3.39567239459e-07,        -5.79689393829e-07,        -7.16642392626e-07, 
       -4.97345465373e-08,        -5.67611689887e-08,        -3.18301604122e-07,         1.85345611457e-07,        -3.12514666401e-08, 
       -2.67032184589e-07,        -4.01048234942e-08,        -3.47421711840e-09,         1.42590992552e-08,         6.08186201660e-08, 
       -7.75725235742e-08,        -1.65429593460e-07,        -2.50423131095e-08,         2.15551592479e-07,         1.37164742493e-07, 
       -2.99552947899e-07,        -2.32261672411e-07,         3.39226082371e-07,         2.17694497881e-07,        -3.16581675438e-07, 
       -1.23893768060e-07,         2.14349316107e-07,         4.08410014781e-09,        -7.28169356836e-08,         7.50747996551e-08, 
       -5.43215675008e-08,        -8.74467785496e-08,         1.20869563852e-07,         4.76767515461e-08,        -1.16853756842e-07, 
        4.18733608884e-09,         6.64585410766e-08,        -3.26599370793e-08,        -1.02989570418e-08,         2.61885090816e-08, 
       -1.98440831091e-08,         1.74236087850e-09,         1.58363074878e-08,        -2.72845415681e-08,         8.19187473391e-09, 
        3.41148266891e-08,        -2.98925823314e-08,        -2.24423668991e-08,         3.43841019296e-08,         5.15698356691e-09, 
       -2.18263822426e-08,         3.70896886636e-09,         3.86577108723e-09,         1.10945214535e-09,         6.49570197414e-09, 
       -1.41857816328e-08, 
},
{
       -1.07942540399e-07,        -7.90788994526e-07,         1.08421919978e-06,        -3.76552798708e-07,        -1.21721450278e-06, 
       -2.98451577637e-07,        -6.15164366855e-07,         1.65079746757e-06,         1.41722024799e-06,        -1.66804136711e-07, 
       -4.41725663401e-07,        -1.27320506412e-06,        -1.64014958901e-06,         1.05280890197e-08,         1.21348829789e-06, 
       -1.71017081384e-07,        -1.11074710301e-06,        -5.56193223233e-08,        -6.45032706375e-07,         1.08815138178e-07, 
        4.10759486256e-07,        -1.66409557478e-07,         4.18635995913e-07,         3.05454684003e-07,        -4.09031056520e-07, 
       -1.86168233286e-07,         4.51792588895e-07,         2.75996639167e-08,        -2.66171998882e-07,         1.72009327208e-07, 
        5.49791831988e-08,        -2.59839855219e-07,         1.37585800451e-07,         2.74854948056e-07,        -2.25582681504e-07, 
       -2.66690905317e-07,         2.35723075072e-07,         2.53349610026e-07,        -2.10179784455e-07,        -2.27643376221e-07, 
        1.76006088160e-07,         1.66051484756e-07,        -1.39272355681e-07,        -7.65184210181e-08,         9.53433510605e-08, 
       -9.82943457521e-09,        -4.73525513100e-08,         5.77899198657e-08,         7.30260741047e-09,        -5.56831581738e-08, 
        1.15952623666e-08,         1.97563641038e-08,        -6.98436764680e-09,         1.90981041624e-08,        -1.03367296493e-08, 
       -3.66450028257e-08,         2.34179791840e-08,         2.80707681895e-08,        -2.04520240441e-08,        -6.30344977349e-09, 
        1.46943457356e-09,        -1.02113984454e-08,         2.32999233978e-08,         1.03148904434e-08,        -4.11954431002e-08, 
        4.55374768283e-09,         4.50402453848e-08,        -2.41096777720e-08,        -3.62903082205e-08,         3.75634377323e-08, 
        2.24088292969e-08, 
},
{
        3.99696928800e-07,         5.16002582029e-07,         7.27357528133e-07,        -1.52061923137e-06,         1.04469328900e-06, 
        1.10133708021e-06,        -1.61992541886e-07,        -2.48147441083e-07,         3.46550179747e-07,        -8.02446090724e-07, 
        3.35011614871e-07,         5.32428926831e-07,        -1.55134040748e-06,        -2.92775160576e-07,        -1.17485629063e-06, 
       -8.24145012331e-07,        -9.95671717104e-08,         1.80494239538e-06,        -3.10699845449e-07,        -1.27774635189e-06, 
       -6.04560605220e-07,         3.83744404997e-07,        -5.67704071731e-08,        -3.55929860748e-07,         2.65411738611e-07, 
       -3.45726557828e-07,        -2.91963309744e-07,         4.29047235771e-07,         1.21007053004e-08,        -3.46157772593e-07, 
        1.06532074137e-07,         1.88518227282e-07,        -7.00554346336e-08,        -7.91330453239e-08,        -1.52649777087e-08, 
        6.30614732002e-08,         8.94006485259e-08,        -6.87188168172e-08,        -1.09084014939e-07,         6.26121186426e-08, 
        1.01520467470e-07,        -2.49536571265e-08,        -8.94623767931e-08,        -2.04686868535e-08,         8.55688094325e-08, 
        5.20231940990e-08,        -8.27559290639e-08,        -5.76365594505e-08,         7.29912625921e-08,         4.34733469849e-08, 
       -5.51046517729e-08,        -2.20525010920e-08,         3.51712174567e-08,         3.87617901358e-09,        -1.94592515358e-08, 
        6.90592506988e-09,         9.44251873302e-09,        -1.04043731864e-08,        -2.20689227965e-09,         7.91325190415e-09, 
       -5.52424905896e-09,        -5.51876655222e-10,         1.40950510585e-08,        -1.01124950732e-08,        -2.09433262197e-08, 
        2.14584707470e-08,         2.31990005748e-08,        -3.04731416813e-08,        -2.01872119689e-08,         3.52533162679e-08, 
        1.38212187355e-08, 
},
{
       -6.46025385309e-07,         1.02689019808e-06,        -4.96266672282e-08,         6.34648075435e-07,         1.03694102964e-06, 
       -3.33378561241e-07,         1.51439567981e-07,        -9.62559558160e-07,        -5.04304320045e-08,         4.94231565400e-07, 
        3.70166874563e-07,         8.42705677551e-07,         4.24433644218e-08,         1.30174506299e-07,         6.11886346377e-07, 
        4.39985513793e-07,         3.32578571312e-07,        -1.10161470065e-06,        -6.31096333270e-07,        -5.83659096735e-07, 
       -2.98279273623e-07,        -8.63291594113e-07,         5.61303547430e-07,        -9.23989394718e-08,        -3.65307054360e-07, 
        5.82891104841e-08,         5.51311958885e-08,        -3.05306085678e-07,         1.61106892953e-07,         9.50053121684e-09, 
       -1.36038669867e-07,         4.09540261162e-08,         5.55015427711e-08,        -5.68278662212e-08,        -8.05252536724e-09, 
        1.82640746290e-08,         1.90045869330e-08,        -8.66138747003e-10,        -4.84705209420e-08,         6.75343995378e-09, 
        6.58884035579e-08,        -2.17166038004e-08,        -5.72792886545e-08,         2.89282123713e-08,         3.40524650703e-08, 
       -2.23272431277e-08,        -1.02399216377e-08,         7.18242029679e-09,        -3.92514603513e-09,         8.61071403953e-09, 
        7.41028568472e-09,        -1.91454931292e-08,        -3.13266579296e-09,         2.27082298137e-08,        -4.60865961321e-09, 
       -2.01330242735e-08,         1.23746300723e-08,         1.34323422158e-08,        -1.76987323889e-08,        -5.00014147327e-09, 
        1.94089702610e-08,        -2.70285258512e-09,        -1.78518448050e-08,         7.77117706935e-09,         1.47119467949e-08, 
       -9.59209038322e-09,        -1.20123934263e-08,         9.06779723752e-09,         1.09107950854e-08,        -7.93286085881e-09, 
       -1.11544467619e-08, 
},
{
       -4.14736066116e-07,         7.29426396349e-08,        -1.11254081166e-06,        -5.34243507129e-08,        -6.50405718419e-07, 
       -6.02335371402e-08,        -1.39871055285e-06,         9.04112799198e-09,         4.45416588490e-07,         6.29826374796e-07, 
        4.03804893802e-07,         3.62672128101e-07,         7.76415907327e-07,        -6.30475237389e-07,        -4.06093996782e-08, 
       -1.21751772777e-07,         5.47897257889e-07,         6.74938817160e-07,         3.01059605190e-07,         6.13367594598e-07, 
        1.17939299138e-06,         9.80682522509e-08,         4.34398916994e-07,        -9.48456502967e-08,        -1.98427167483e-07, 
        1.48923750899e-07,         1.15596211040e-07,        -1.51053500950e-07,        -3.09724070727e-08,         1.49373317737e-07, 
       -5.11898445940e-08,        -8.29648139087e-08,         3.38705887243e-08,         4.86481275144e-08,        -1.76790731160e-08, 
       -3.28562023058e-08,        -2.77284377901e-09,         3.56697083948e-08,         1.25820412624e-09,        -2.50350517432e-08, 
        4.72592822383e-09,        -7.82183763807e-09,        -1.23571566429e-08,         5.64177137859e-08,         1.09645916932e-08, 
       -1.00306104085e-07,         1.96024211078e-09,         1.19243384209e-07,        -2.43947857468e-08,        -1.04370393255e-07, 
        4.59557864020e-08,         6.22728797366e-08,        -5.45261317758e-08,        -1.14051326673e-08,         4.33446595529e-08, 
       -2.70688835928e-08,        -1.61541333261e-08,         3.93136190715e-08,        -1.43958654405e-08,        -2.48051000745e-08, 
        3.37470750544e-08,        -4.71342244113e-09,        -3.34858659574e-08,         3.23670987662e-08,         1.54779095193e-08, 
       -4.51281373371e-08,         1.01034957965e-08,         3.96373739843e-08,        -3.11549237130e-08,        -2.21106206438e-08, 
        4.02373435629e-08, 
},
{
        1.22294953666e-07,        -6.53633334102e-07,         8.20874899385e-07,        -4.64844437097e-07,        -3.33295870179e-07, 
       -2.95618243152e-07,        -1.41670676100e-07,         1.10055255792e-06,         1.07365164006e-06,         3.17606091838e-07, 
       -1.04207066215e-06,        -1.40654734201e-07,         2.08554470753e-07,         5.66965631235e-07,        -4.56735809072e-07, 
        1.10526981350e-07,         4.59804567991e-07,        -8.80153918561e-07,         1.52318543161e-06,         3.72086270876e-07, 
       -5.29673186694e-07,         1.65705435569e-06,        -2.22213589042e-07,         5.98371947782e-07,        -2.66398795550e-07, 
       -3.48086795391e-07,         3.28821415403e-07,        -4.75860538511e-08,        -1.93766196331e-07,         1.33586882338e-07, 
        8.64245519334e-08,        -9.65330097217e-08,        -2.11810485278e-08,         1.30219611013e-08,         4.44427626793e-08, 
        5.59329885323e-10,        -6.03322216602e-08,         7.79500288718e-09,         8.68051927070e-08,        -1.89405822230e-08, 
       -1.01300746798e-07,         1.16281028993e-08,         1.13116248281e-07,         1.01023307739e-09,        -1.16495428407e-07, 
       -9.62318976193e-09,         1.09243437167e-07,         9.25075038694e-09,        -9.06011531301e-08,        -3.97562900831e-09, 
        6.39683997669e-08,        -1.36428602240e-09,        -3.58061716984e-08,         3.76519545488e-09,         1.26737013810e-08, 
       -2.75288843513e-09,         6.65031509907e-10,        -7.79440117428e-10,        -2.81101340958e-09,         5.01717658084e-09, 
       -4.27654070511e-09,        -7.57777038277e-09,         1.60192612687e-08,         6.37987659933e-09,        -2.69748262473e-08, 
       -8.18086927076e-10,         3.29462104705e-08,        -7.66839501223e-09,        -3.25923723229e-08,         1.63172284037e-08, 
        2.75588839061e-08, 
},
{
        3.04970530387e-07,        -7.45056052545e-08,         6.76185865488e-07,        -2.81617963938e-07,         5.43341778675e-07, 
        1.92665073562e-07,        -4.37162157598e-08,        -4.19884823747e-07,         4.05446155517e-07,        -4.96095185350e-07, 
        3.37422514882e-07,         3.08950436146e-07,         7.24294522496e-08,         6.38937319509e-07,        -7.12343635524e-08, 
        1.37133946731e-07,         8.77682547756e-07,         3.66167555010e-07,         6.46556563157e-07,        -5.32379537073e-07, 
       -2.97947319648e-07,         3.63376873488e-07,         4.56321252794e-07,         2.78706909003e-07,        -1.70298537159e-07, 
        1.91235332490e-07,        -3.69382456132e-08,         5.02528373419e-09,        -2.06895997458e-07,         1.04871397427e-07, 
        1.77391966115e-08,        -4.18027655229e-08,         1.91410824352e-08,        -2.57196527090e-08,        -6.29657414364e-08, 
        5.01682247212e-08,         3.10339985213e-08,        -3.75463684721e-08,        -2.26152293047e-09,         4.46434408959e-09, 
       -1.92354184689e-08,         3.00786495439e-08,         3.25609732616e-08,        -6.47334442616e-08,        -4.73632056663e-08, 
        9.82392529881e-08,         6.11006961176e-08,        -1.29786809704e-07,        -6.50449872655e-08,         1.51214895545e-07, 
        5.14992131593e-08,        -1.54890680531e-07,        -2.11693441229e-08,         1.36827740380e-07,        -1.60436556039e-08, 
       -1.00851590239e-07,         4.64672802664e-08,         5.72599954614e-08,        -5.95703878032e-08,        -1.93715288612e-08, 
        5.28882159568e-08,        -1.92285516651e-09,        -3.27574128807e-08,         2.54948348888e-09,         1.08351222650e-08, 
        1.30934976061e-08,         1.90826760468e-09,        -3.43609415025e-08,        -5.96579741552e-10,         4.95819597261e-08, 
       -1.15760581005e-08, 
},
{
       -1.11635352796e-07,        -9.77565813311e-08,        -6.06416400449e-07,         5.54707198846e-07,        -1.81035971697e-07, 
        2.53484171523e-07,        -2.90350147829e-07,        -3.86865273874e-07,        -6.36514439951e-07,        -3.07169781881e-07, 
        4.70330430546e-07,         3.31509783648e-08,        -1.15241723995e-08,        -3.01087223275e-07,         2.54895355975e-08, 
       -3.54704847190e-07,         5.44601602316e-07,         9.83327721901e-07,         7.85523756668e-08,         1.79108413642e-06, 
       -2.42206230693e-08,         1.32776427932e-07,         7.14029416013e-07,        -4.82026222416e-07,         3.80582763941e-07, 
       -3.37871222409e-07,         2.29340523356e-07,         3.90380828606e-07,        -1.32933801920e-07,        -1.53960657447e-07, 
        2.55928708409e-07,        -3.85189138741e-08,        -1.51780599827e-08,         4.14247628589e-08,        -7.15467677227e-08, 
        1.93511210552e-08,         7.02161992236e-08,        -5.91820881671e-08,        -3.42172472778e-08,         6.12531225701e-08, 
        2.02877542925e-08,        -4.99749429326e-08,        -2.32106700580e-08,         4.19394988777e-08,         2.51175430365e-08, 
       -3.57189444421e-08,        -1.82879615095e-08,         2.15459610027e-08,         7.31182318659e-09,         1.89673134103e-09, 
       -2.13366724584e-09,        -2.71531340875e-08,         7.01076234729e-09,         4.33389421445e-08,        -1.92957386475e-08, 
       -4.37265220748e-08,         3.21612316860e-08,         2.89971111908e-08,        -3.92900251964e-08,        -6.10625062883e-09, 
        3.74767135926e-08,        -1.54768019247e-08,        -2.75706311286e-08,         2.77640933814e-08,         1.37603248735e-08, 
       -2.71799610481e-08,        -1.79307447315e-09,         1.55970873911e-08,        -3.56062753863e-09,         8.58934709979e-10, 
        8.32265530689e-10, 
},
{
       -6.76992677690e-08,         1.72011379658e-07,        -4.55938229151e-07,        -8.32877770934e-08,        -2.59710414962e-08, 
        1.22428751048e-07,        -1.94332667791e-07,         4.93239776974e-08,         8.12797478005e-08,         7.61650449380e-07, 
        8.54048136876e-08,        -1.50887343598e-07,        -6.06201232110e-07,        -1.87983982671e-07,        -6.18874878932e-07, 
       -4.71839922543e-07,        -4.76460055532e-07,        -1.00571507799e-07,         3.31368365337e-07,        -6.20238473742e-07, 
        4.18977510546e-07,        -6.05707347140e-07,        -4.23705142100e-07,        -1.07578118458e-07,        -4.50288598885e-07, 
       -7.34074195950e-08,        -1.78114805207e-07,        -2.49444634122e-08,         3.66912593612e-07,         1.60236437405e-08, 
       -8.88466092369e-08,         1.65490837282e-07,         3.90653645788e-08,         4.01983860311e-08,        -5.18170237368e-09, 
       -3.61146644942e-08,         6.26640678699e-08,         3.06967185359e-09,        -3.93118526071e-08,         4.54605333944e-08, 
        8.24214374654e-09,        -4.56762876757e-08,         2.40575249463e-08,         3.32575494993e-08,        -3.18837136045e-08, 
       -2.02081569123e-08,         3.08523455439e-08,         1.23586241968e-08,        -2.81240360384e-08,        -1.84775609000e-09, 
        2.58892122589e-08,        -1.30229927182e-08,        -1.97779633387e-08,         2.69532627242e-08,         9.20191325699e-09, 
       -3.21718303958e-08,         1.63184418406e-09,         2.62344912120e-08,        -6.82645841266e-09,        -1.36294915481e-08, 
        3.87009243014e-09,         2.24516926211e-09,         4.70740004792e-09,         1.86639747337e-09,        -1.32997894613e-08, 
        2.48248528270e-09,         1.68321116028e-08,        -1.20060575080e-08,        -1.33968551773e-08,         2.15923033692e-08, 
        4.67416706141e-09, 
},
{
       -8.73231838678e-08,         2.59039723992e-07,         5.35593723910e-07,        -3.30894669092e-07,         3.30116942264e-07, 
       -3.41880782072e-07,         2.61718454453e-07,         2.48467562293e-08,         7.34308261146e-07,         5.31724024499e-07, 
       -4.16955167883e-07,         1.77980052725e-07,         8.27095584164e-08,        -1.52970644679e-08,         3.86733933546e-07, 
       -6.15732947534e-08,        -2.48197177314e-08,        -5.63274054476e-07,        -1.02348290167e-07,         2.30632892638e-08, 
        8.31052166288e-08,        -4.84882236752e-07,        -6.47780447159e-07,        -4.21424501723e-07,        -7.16804077107e-07, 
        7.81769045150e-08,        -1.64414828527e-07,        -1.44296877752e-07,        -8.00420042647e-08,         1.29780323018e-07, 
        1.11860828681e-08,        -7.28043333738e-08,         6.64209179649e-08,         4.28286393599e-08,         8.88911582988e-09, 
       -2.15186459980e-08,        -8.04352505559e-09,         2.34874926070e-08,        -9.51018542980e-10,        -1.61413820046e-08, 
        6.26487233983e-09,         1.35205699864e-08,         3.61835346620e-09,        -1.79262013278e-08,        -1.07116116452e-08, 
        3.04468801051e-08,         1.07363437530e-08,        -4.19752756606e-08,        -2.17058499393e-09,         4.69571845314e-08, 
       -1.02963032079e-08,        -4.29973394554e-08,         2.46676260470e-08,         3.06506053572e-08,        -3.81624576864e-08, 
       -1.17841024097e-08,         4.73117376482e-08,        -9.70769363181e-09,        -4.76380571814e-08,         2.78669665571e-08, 
        3.74210197581e-08,        -3.64806233692e-08,        -1.98445488118e-08,         3.23180071581e-08,         2.32184995791e-09, 
       -1.73924383326e-08,         7.44129953786e-09,        -1.62175464993e-09,        -5.69131195712e-09,         1.66871617397e-08, 
       -5.51053101339e-09, 
},
{
       -5.75090281126e-09,         1.28274980015e-08,         1.30928980116e-07,        -1.53448323797e-07,        -1.61904345251e-07, 
        2.86030644182e-08,         4.20095551170e-08,        -1.15706347922e-07,         7.48093397457e-08,        -4.25631365120e-07, 
        9.96607136641e-08,         1.78178899890e-07,         6.89916422135e-07,         1.56226464305e-07,         2.42786455896e-07, 
        6.18777671250e-08,         8.84301043548e-08,         2.94174283237e-07,        -5.04086904432e-07,         1.45845694307e-07, 
        1.75906016065e-07,        -1.34995944673e-08,         8.62079004526e-08,         1.16437014759e-07,         6.14350551215e-07, 
        2.70282385608e-07,        -1.91270752378e-07,         4.90869057278e-07,        -2.52260649440e-07,         9.31205015865e-08, 
       -1.05195057841e-08,        -4.27303233360e-08,         8.66943186720e-09,         4.94337833677e-08,        -1.59624830076e-08, 
       -2.43626542439e-08,         1.89752253419e-08,         1.05114977547e-08,        -2.51297591696e-08,        -1.99470378421e-09, 
        1.41833284650e-08,         3.27055932623e-10,        -1.10818133738e-08,        -4.62347120709e-09,         1.54542085670e-08, 
        6.35137409010e-09,        -2.45923809158e-08,        -2.08566608371e-09,         3.10019969814e-08,        -6.15396503018e-09, 
       -3.12749679467e-08,         1.39852383491e-08,         2.59725067026e-08,        -1.84551910131e-08,        -1.75991290966e-08, 
        1.92933873071e-08,         8.36560397782e-09,        -1.76582005352e-08,         3.66380238421e-10,         1.48030907940e-08, 
       -7.48522250591e-09,        -1.11738275340e-08,         1.17380205964e-08,         6.91649936003e-09,        -1.20573991333e-08, 
       -2.56422942415e-09,         8.30092868717e-09,        -6.50871750310e-10,        -1.70546210870e-09,         1.30724570838e-09, 
       -5.40432381902e-09, 
},
{
        6.75629629611e-08,        -1.89575745316e-07,        -3.76610396151e-07,         1.27687550364e-07,        -2.75954608884e-07, 
        3.33718366703e-07,        -1.74144449786e-07,         6.52712886039e-08,        -4.01525582302e-07,        -9.93379049713e-08, 
        2.03221713182e-07,        -1.90961294023e-07,         5.33141521128e-09,         1.19032815446e-07,        -3.71163923391e-07, 
       -1.48776658182e-07,        -8.78356680226e-08,         1.07821267091e-07,        -1.23515968473e-07,        -3.97870246025e-07, 
        7.51080816745e-08,        -1.08485698959e-07,        -1.50294262354e-07,         5.35456850251e-07,         7.04416783149e-07, 
       -4.03683836573e-08,         4.49550641535e-07,        -3.06176989567e-07,         6.18567796362e-07,        -1.61921490660e-07, 
        6.29105352546e-08,        -1.75104371556e-08,        -1.74186017322e-08,         8.55611510584e-08,         6.59882819506e-09, 
        1.20526627737e-09,        -2.23318487365e-08,         3.20868288851e-08,         1.47752641092e-08,        -1.41324518633e-08, 
       -6.72632504580e-09,         7.08564805458e-09,         1.13570536702e-08,         5.32639968975e-09,        -2.01385846005e-08, 
       -4.45638506981e-09,         2.45345898458e-08,         6.83439541290e-09,        -2.28947943013e-08,        -1.44027984098e-08, 
        2.08365249670e-08,         2.64709391854e-08,        -2.21006592120e-08,        -3.54453852762e-08,         2.51370599391e-08, 
        3.71258691789e-08,        -2.64028662395e-08,        -3.16620925023e-08,         2.40258906575e-08,         2.21573552295e-08, 
       -1.90735711477e-08,        -1.17225620060e-08,         1.39121806910e-08,         2.38103670735e-09,        -1.01347284520e-08, 
        4.59612330829e-09,         7.87767160105e-09,        -8.29883421701e-09,        -6.50145479657e-09,         8.37714270853e-09, 
        5.55790589011e-09, 
},
{
       -5.14181922051e-08,        -1.17074845689e-07,         7.09423484031e-08,         1.88716302968e-07,         2.57658945625e-07, 
        2.70987173186e-08,        -1.75121547460e-07,        -7.36832549744e-09,        -7.44520843335e-08,         3.19932994239e-07, 
        4.68668032227e-08,        -8.02351012744e-08,        -6.09933608282e-07,        -1.58849436321e-08,        -2.49141801537e-07, 
       -5.17421681873e-08,         1.85281073634e-08,        -9.36814352204e-08,         1.21323960933e-07,        -1.90736317756e-07, 
       -1.44755225338e-07,        -3.05995095636e-07,        -3.96833614433e-07,         3.49647133538e-08,        -2.57382909418e-07, 
        1.83519515023e-07,        -1.08222025315e-07,        -1.64603821909e-07,         2.32280049421e-07,         1.04522226379e-07, 
        1.79262446620e-08,        -5.43729228217e-08,        -3.08654416788e-08,         1.18842262971e-08,         4.43249425226e-08, 
       -2.26034124965e-08,         1.41158021256e-08,        -2.81334222109e-08,         2.70648112682e-08,         1.24608770781e-08, 
       -2.36895314313e-08,        -2.69650259576e-09,         1.69346708826e-08,         1.69702748195e-09,        -1.04592334723e-08, 
       -3.49166615991e-09,         1.50464211517e-08,         5.70336510696e-10,        -1.79461857985e-08,         5.69741451882e-09, 
        1.72263256545e-08,        -8.71123361336e-09,        -1.56912668538e-08,         6.86012381265e-09,         1.82247348051e-08, 
       -2.93914629050e-09,        -2.44793861479e-08,         4.72800608688e-10,         3.03109476475e-08,        -3.26422236377e-10, 
       -3.17308260144e-08,         1.28148353060e-09,         2.76402170977e-08,        -2.13442767652e-09,        -1.94604999345e-08, 
        2.80843816482e-09,         9.40561870642e-09,        -3.66351618710e-09,         6.18597948325e-10,         4.45351589541e-09, 
       -9.07779431211e-09, 
},
{
        6.73977519124e-08,         9.27570159111e-08,         1.99372530910e-07,        -2.76482123179e-08,         1.42629899010e-07, 
       -2.98157527328e-07,         1.18139206455e-07,         4.47754796506e-08,         1.53805395815e-07,        -1.66632891918e-07, 
       -9.99087788346e-09,         1.58627527390e-07,         6.16972691466e-08,        -9.50632678134e-08,         3.04378553243e-07, 
        3.55398809549e-08,        -6.01720980288e-08,         9.00847907376e-08,         2.61255114855e-08,         1.59273185626e-07, 
        1.50282290694e-07,        -1.49589558797e-08,         8.73004465895e-08,         6.05650948282e-08,         4.79610198269e-07, 
       -5.79052860303e-07,        -3.33948095483e-07,        -1.97982336306e-07,        -9.32816727143e-08,         3.34854478198e-07, 
       -2.08993594549e-07,         1.65782786360e-07,        -4.30189727950e-08,        -1.04734367593e-08,         8.11047064572e-09, 
        2.46465418619e-08,         1.74779085155e-09,        -1.54809437651e-08,        -2.29896164035e-08,         3.72205304162e-08, 
        3.47836926812e-09,        -3.26261547463e-08,         4.22205675548e-09,         1.77690733384e-08,        -3.39869297819e-09, 
       -1.37511099554e-08,         1.15663021258e-10,         1.48300501356e-08,        -1.08194375637e-09,        -1.55406098780e-08, 
        4.02978366433e-09,         1.23669124834e-08,        -6.09655070516e-09,        -8.59946383767e-09,         8.28252515657e-09, 
        5.23463551029e-09,        -1.25789152422e-08,        -6.02157752150e-10,         1.89176738627e-08,        -7.48821597074e-09, 
       -2.43048272839e-08,         1.81314207856e-08,         2.53650668185e-08,        -2.74749877049e-08,        -2.09575265240e-08, 
        3.12052934407e-08,         1.27197989493e-08,        -2.71922962992e-08,        -3.75459195802e-09,         1.63799856635e-08, 
       -3.04272165716e-09, 
},
{
        9.11494963754e-08,         1.20228660708e-07,        -1.82113141623e-07,        -1.93323025639e-07,        -2.47093802659e-07, 
       -3.26515306374e-08,         2.10510234356e-07,        -3.32249851875e-08,         1.31897778521e-07,        -1.17143449231e-07, 
        1.41306724723e-09,         2.09761391371e-08,         3.78224115604e-07,         8.22185846641e-08,         1.27080095841e-07, 
       -1.24273713130e-07,        -2.01185735286e-07,        -3.52924783240e-08,         9.79710365142e-09,        -1.23435204691e-08, 
        1.43172428352e-07,        -9.74035698237e-08,        -8.07768923925e-08,         3.26063691158e-07,         1.51561182821e-07, 
        4.77502328344e-07,         9.79127710362e-08,        -3.13574294806e-07,         1.18155930791e-07,        -1.33340498166e-08, 
       -4.34818146160e-08,        -2.51953736358e-07,         2.10082925387e-07,        -3.57389328863e-08,        -2.08732744198e-08, 
        3.70785155258e-09,         3.36839659796e-08,         1.59081456195e-08,        -4.71852424270e-08,         5.52086194645e-09, 
        3.20489050096e-08,        -4.18775608836e-09,        -2.09787783258e-08,         7.67350450149e-09,         9.76283549787e-09, 
       -2.06074050716e-09,        -9.68205334230e-09,         2.56659207728e-09,         7.88277433825e-09,        -2.33444356295e-09, 
       -5.18906714031e-09,         8.27920994218e-10,         2.65658502826e-09,         2.89143351422e-09,        -3.62578941600e-09, 
       -5.62160232858e-09,         7.47291244621e-09,         5.92730958032e-09,        -1.20146902713e-08,        -4.27156520970e-09, 
        1.57127112022e-08,         2.37923104102e-09,        -1.87384368887e-08,        -1.07374836314e-09,         2.15985494691e-08, 
       -1.39682055548e-10,        -2.37809317497e-08,         2.03448341201e-09,         2.37659023255e-08,        -4.50683782333e-09, 
       -2.02912456421e-08, 
},
{
       -2.21463314187e-07,        -8.78960783061e-08,        -1.95786540315e-08,        -5.84903061144e-10,        -6.17570873322e-08, 
        2.32594534679e-07,        -1.17069327884e-07,        -1.02604774630e-07,         2.41279343476e-08,         3.18270600955e-07, 
       -1.04023458246e-07,        -6.09013242688e-08,        -5.27659976169e-08,         2.03246858012e-08,        -2.02653428860e-07, 
       -8.73956721516e-08,         1.22195184806e-07,        -1.08355931306e-07,        -1.19105917179e-07,        -8.11352686602e-08, 
       -7.89014969725e-08,         8.68221161897e-08,        -3.61677523597e-07,        -6.64901598919e-08,         7.37376009385e-08, 
       -4.00224307145e-08,         8.44077887926e-08,         1.32497001623e-07,        -1.16045704113e-07,        -1.00393790283e-07, 
        6.55463926883e-07,        -8.77276655186e-09,         1.10003347756e-07,         1.90223192867e-07,         4.46207231247e-08, 
       -4.67094619707e-08,         3.09046213223e-08,         1.79259657116e-08,         4.81513060810e-09,        -4.82458387638e-08, 
        1.08435520037e-08,         1.63583192461e-08,        -7.87693085318e-09,        -1.48549588513e-08,         6.28138864610e-09, 
        7.01244934358e-09,        -5.24628099308e-09,        -8.29880659179e-09,         7.11525821668e-09,         4.75125144429e-09, 
       -8.86768817708e-09,        -1.67989846268e-09,         8.44726283499e-09,        -2.48845157303e-10,        -7.71772138816e-09, 
       -1.66715174572e-10,         8.31373977980e-09,         5.18029018580e-10,        -1.03759384501e-08,         1.15749066128e-09, 
        1.18912551719e-08,        -5.06524042002e-09,        -1.09678794071e-08,         9.61544973757e-09,         7.28549658277e-09, 
       -1.30491528142e-08,        -2.11007117978e-09,         1.44887121951e-08,        -2.83682474416e-09,        -1.39817354261e-08, 
        6.32389633965e-09, 
},
{
       -6.19951634548e-08,         1.17286440278e-08,         2.03777210287e-07,         4.36286090219e-08,         1.69245920652e-07, 
        1.00767323544e-07,        -1.72802901224e-07,         2.70714741003e-08,        -1.16197788018e-07,         4.90037513014e-08, 
        3.04208702980e-08,         1.30263137116e-08,        -1.90079093038e-07,        -6.54225772439e-09,        -1.02458843020e-07, 
        9.63071172915e-08,         1.88060131704e-07,         1.64747755296e-07,         2.77909416096e-08,        -5.33369891189e-08, 
       -2.07102910977e-08,        -8.76202552407e-08,         1.46935091390e-07,        -2.04418057643e-07,        -1.25096367671e-07, 
       -1.02663069238e-07,         3.91890573982e-08,        -1.01075220313e-07,         7.28965916736e-08,         1.47225777818e-07, 
       -1.36003787178e-07,         6.19364528066e-09,         5.87959322372e-08,         1.02521988437e-07,         7.71410458303e-08, 
        5.70948903352e-08,        -2.28085435716e-08,         3.23206415321e-08,         1.37362354638e-08,         7.66608621335e-09, 
       -2.17971084740e-08,        -5.68461563464e-11,         1.99867848886e-08,        -3.39855025292e-09,        -1.11958709690e-08, 
        6.64163088626e-09,         6.14050746577e-09,        -4.21590802414e-09,        -2.00758843060e-09,         2.08054919791e-09, 
        7.79722622941e-10,        -2.14025175839e-10,         4.04721553742e-10,        -1.94347970277e-09,        -4.55047932204e-10, 
        4.70391823186e-09,        -4.32984661615e-10,        -7.30980520130e-09,         1.92994685762e-09,         9.07357299161e-09, 
       -3.53450779843e-09,        -9.97508958940e-09,         5.31802924606e-09,         9.95747816801e-09,        -7.56571995567e-09, 
       -8.59433327579e-09,         1.00744054635e-08,         5.43184085977e-09,        -1.19374064043e-08,        -7.33580732771e-10, 
        1.20249715821e-08, 
},
{
        2.70449373010e-07,         1.22202093992e-07,        -1.02474887534e-07,         7.65927616550e-09,         4.07444946940e-08, 
       -1.68808311617e-07,         1.40002324649e-07,         7.39452294129e-08,        -7.64163912960e-08,        -2.46031969229e-07, 
        1.11101144280e-07,        -1.68998082603e-08,         2.32023745581e-08,         4.55982058658e-08,         1.73931894551e-07, 
        3.61170828400e-10,        -1.64030619814e-07,         1.32170608814e-07,         9.05655409495e-08,         3.40514029181e-08, 
        4.31743585312e-08,        -5.40367063449e-08,         3.34987088807e-08,         2.66431710062e-07,         5.22576114844e-08, 
       -4.62498065117e-08,        -7.74312568174e-08,         8.79100873812e-08,         2.36462292106e-08,         7.54045681028e-09, 
        6.64430337672e-08,         1.24863348734e-07,        -1.33170968860e-08,        -3.37577799413e-08,        -6.58958707980e-08, 
       -4.97986357479e-08,        -2.85632284690e-08,        -1.04087070414e-08,        -1.89558975451e-08,        -1.65458098396e-09, 
       -5.14986247018e-09,        -8.79821696553e-09,        -1.38583413664e-08,         1.22857309365e-08,        -8.36259371767e-10, 
       -5.07112538079e-09,        -3.25053847390e-10,         1.25865427984e-09,         1.52952028376e-09,         5.03128943976e-10, 
       -4.17312319779e-09,         9.51359536621e-10,         3.95958753381e-09,        -1.55451395395e-09,        -3.08136256950e-09, 
        1.29367031227e-09,         2.98552049609e-09,        -5.32836487344e-10,        -3.72059691923e-09,        -7.63448168192e-11, 
        4.86495064485e-09,         4.57007454704e-10,        -6.05885331905e-09,        -6.34422790333e-10,         7.21509356573e-09, 
        6.07819012017e-10,        -8.10793546927e-09,        -4.44732804407e-10,         8.45614856788e-09,         4.06007300625e-10, 
       -8.11852823845e-09, 
},
{
       -1.24483329218e-08,        -1.61706910591e-07,        -1.56043276346e-07,         1.12559763528e-07,        -7.49161539381e-08, 
       -1.30432445770e-07,         6.43898607547e-08,        -4.77169532993e-08,         9.17615739805e-08,        -1.57278860532e-08, 
       -4.22855686906e-08,        -4.83240909550e-08,         5.27731905882e-08,        -4.03526937518e-08,         4.59824985760e-08, 
       -7.77768102147e-08,        -1.90759184276e-07,        -1.90568279567e-07,        -1.47085178858e-09,         2.47570244192e-08, 
       -2.19880334169e-08,         2.65864835388e-08,        -1.46469636204e-07,         5.44139878156e-08,         1.22278418928e-07, 
        8.36703048926e-08,         6.69199028948e-08,        -9.05234163889e-08,         7.49334352732e-08,         1.41240776729e-07, 
       -1.52518051760e-07,         1.33584769903e-07,        -1.36892322211e-07,         2.35326118896e-07,         2.40498075566e-07, 
       -1.74172181581e-08,         4.21506965868e-08,         2.33652968355e-09,         3.70616449387e-08,         9.74091593847e-10, 
        1.35280326731e-09,         7.10246669698e-10,         9.67847429320e-09,        -6.29114889375e-09,         1.65758802295e-09, 
        4.59330584251e-09,        -7.19615098655e-10,        -3.37291936753e-09,         6.72109937868e-11,         4.02695056480e-09, 
       -1.38226646233e-09,        -4.43264379800e-09,         2.81284332849e-09,         2.22627677607e-09,        -3.39483576739e-09, 
        3.73548572914e-10,         2.05780860346e-09,        -2.76592716043e-09,        -2.22330257617e-10,         4.78695506111e-09, 
       -1.71197425072e-09,        -7.16826356952e-09,         3.70538740328e-09,         1.00271543842e-08,        -6.23382933496e-09, 
       -1.29571055681e-08,         9.36792882078e-09,         1.51659420518e-08,        -1.27859370554e-08,        -1.58933267047e-08, 
        1.58146789116e-08, 
},
{
       -2.04080107591e-07,        -1.14117184557e-07,         1.42137274635e-07,        -3.08707065194e-08,        -6.26241385997e-08, 
        1.24919570169e-07,        -1.30623416954e-07,         4.61891618626e-09,         4.54395735849e-08,         1.00052115348e-07, 
        5.86498024147e-09,         7.75485841783e-08,        -3.63771377583e-09,        -7.56353288588e-08,        -1.18716847249e-07, 
        4.22434614326e-08,         9.66176929222e-08,        -8.86748628113e-08,        -7.11473262381e-08,        -4.84281860891e-08, 
        1.44706186480e-08,         2.62963743275e-08,        -1.55051290045e-08,        -1.15971814481e-07,        -4.79277303347e-09, 
       -2.37841253225e-08,         3.43223286542e-08,         2.41177634123e-08,        -7.53574553429e-08,        -5.08175697833e-08, 
       -6.74690254031e-08,        -1.32642117635e-07,        -2.78708608373e-07,         1.70781968755e-07,        -1.10448823062e-07, 
        1.33938872198e-07,         3.41194422981e-08,        -1.15305457620e-08,         3.94808978284e-08,         7.28679565927e-09, 
        2.21218877815e-08,        -7.48348475084e-09,        -1.33713715704e-09,         1.36713773305e-08,         1.64765022584e-09, 
        3.12170686306e-09,        -7.95722326254e-10,        -3.11216086830e-09,         3.90432477204e-09,         2.29304908810e-09, 
       -1.73554394237e-09,        -1.99045256045e-09,        -7.08258955590e-11,         3.40533676615e-09,        -2.87006533457e-10, 
       -3.77500837914e-09,         6.79629286060e-10,         2.67174236538e-09,        -4.78074961939e-11,        -1.57258606736e-09, 
       -2.00159579388e-09,         1.62306268685e-09,         4.47250476004e-09,        -2.95657666555e-09,        -6.81255378561e-09, 
        5.12155511368e-09,         8.78380504433e-09,        -7.80438058373e-09,        -1.03232304512e-08,         1.08644937136e-08, 
        1.11076602252e-08, 
},
{
        6.53842772597e-08,         2.39099208234e-07,         7.22841809013e-08,        -2.19973568243e-07,         3.59022613094e-09, 
        1.44891644657e-07,         4.78197616129e-08,         4.69900225658e-08,        -8.92182855427e-08,         3.81588913749e-08, 
        7.69791794705e-08,         7.78726632338e-08,        -1.44025107079e-08,         8.09168264521e-08,         5.44601653842e-09, 
        2.41617259374e-08,         1.37158711312e-07,         1.98164891006e-07,         3.76981487122e-08,        -3.01536240796e-08, 
        5.58390203302e-08,        -4.25547383434e-08,         5.98862713154e-08,         3.18446676206e-09,        -5.37636965633e-08, 
       -2.02389026166e-08,        -7.07859538590e-09,         4.01266238824e-08,         1.86499554271e-08,         4.94190629722e-08, 
       -8.72526585934e-08,        -2.23371466497e-08,        -9.38521743574e-08,        -1.81218622430e-07,         2.22307844739e-08, 
       -2.06088117182e-08,        -2.80681827668e-08,         7.48394491156e-08,        -2.31332385892e-08,         1.44752796156e-08, 
       -3.77328709080e-09,         1.16948453637e-08,        -1.07058608323e-09,        -1.59810580196e-08,         4.50744434671e-09, 
        5.87394282964e-09,         4.79170015842e-09,        -1.10503730500e-08,        -3.81969130976e-09,         8.37694948462e-09, 
        2.16871525017e-09,        -6.47822256913e-09,        -1.89312026287e-09,         3.89642023008e-09,         2.66450285120e-09, 
       -3.76663928923e-09,        -2.84437252441e-09,         3.64712360443e-09,         1.88201522962e-09,        -3.24058767477e-09, 
       -7.57678862303e-10,         2.24394382231e-09,         5.87133009810e-11,        -1.52008061820e-09,         4.26822839869e-10, 
        1.34672160767e-09,        -1.22147509788e-09,        -1.57961479546e-09,         2.63336292292e-09,         1.76139172532e-09, 
       -4.53237255602e-09, 
},
{
        9.05488706074e-08,         4.10182887528e-08,        -1.18458444174e-07,         6.28781088391e-08,         8.83271203938e-08, 
       -9.88626376041e-08,         9.52385503315e-08,        -6.54722689962e-08,         4.20374460279e-09,         2.60680129893e-08, 
       -1.42602551087e-07,        -1.14974334169e-07,         7.81478722457e-09,         5.94221859045e-08,         6.54366232641e-08, 
       -6.58818433272e-08,        -1.43517826122e-08,         3.12154880155e-08,         1.91438320508e-08,         8.99493513704e-08, 
       -4.13122765483e-08,         1.53587726083e-08,        -3.64249992781e-08,         5.77941538312e-08,         2.38081149363e-08, 
       -6.24670490118e-09,         1.19472240711e-10,         1.47593911222e-08,         4.11330648923e-08,         2.15568826158e-08, 
        1.15168294684e-08,         6.31129991104e-08,        -5.50363733303e-08,         6.57778999489e-08,         2.11213090164e-07, 
       -1.00234981625e-07,         2.47988918013e-07,        -7.11768070363e-08,         2.03952931634e-08,         3.28705404262e-08, 
       -5.11340572152e-08,         2.14925950468e-08,        -1.03546888233e-08,         1.10087656479e-08,        -2.25636253369e-08, 
        3.95515899469e-09,         5.35991279383e-09,        -2.95533475354e-10,        -9.50933860427e-09,         1.24626987710e-09, 
        3.06279429719e-09,         1.79077715767e-09,        -4.40861887921e-09,        -1.66352535909e-09,         3.87156638959e-09, 
        1.49039078449e-09,        -3.67226763857e-09,        -1.14171364833e-09,         2.89358100617e-09,         1.25304651670e-09, 
       -2.58495732121e-09,        -1.42637833038e-09,         2.53401635341e-09,         1.65351202737e-09,        -2.85531386611e-09, 
       -1.95536881806e-09,         3.59396264961e-09,         2.37362243267e-09,        -4.80744947767e-09,        -2.75984719461e-09, 
        6.35855282741e-09, 
},
{
       -6.82273119596e-08,        -2.04687439198e-07,         1.22189349463e-08,         2.36096067702e-07,         1.59396598227e-08, 
       -1.29728159102e-07,        -1.03311015214e-07,        -5.10991669937e-08,         1.03932996908e-07,        -6.49022556361e-08, 
       -7.62608431450e-08,        -7.52993719235e-08,         1.81704194799e-08,        -7.49961257622e-08,        -3.82584448125e-08, 
        1.34734236841e-08,        -8.86029173334e-08,        -1.82811537331e-07,        -4.94160752076e-08,        -1.32296414746e-08, 
       -5.53382941217e-08,         2.34540673449e-08,        -2.53208714496e-08,        -1.87579754798e-08,         1.97937546465e-08, 
        1.93637752388e-08,        -1.14741095190e-08,        -3.10334092163e-09,        -1.28246089405e-08,         1.88048461695e-08, 
       -2.85508247048e-08,        -2.54907755829e-11,         5.51790043134e-08,        -2.51577270499e-08,         9.97584818450e-08, 
        7.98123360829e-08,         7.06975801402e-09,        -1.10330783204e-08,         8.63257783647e-08,        -8.13099019517e-08, 
        6.61494614879e-08,        -6.09136564827e-08,         4.36731129932e-08,        -1.64150901924e-08,         5.18432181377e-09, 
       -5.37268849922e-09,         9.87796142544e-09,        -3.11901129546e-10,        -4.29610320060e-09,         8.12551628801e-10, 
        3.66669724248e-09,        -1.23793848435e-09,         3.35504598924e-10,        -2.69463935868e-10,         1.19932780602e-10, 
        1.52021316127e-09,        -3.43734398797e-10,        -7.81629837672e-10,         5.66691136841e-10,         1.47046376656e-10, 
       -2.07429240474e-11,         3.38328902796e-10,        -2.79576331721e-10,        -6.31378741831e-10,         1.01819120771e-10, 
        1.43959104140e-09,         3.23205851282e-10,        -2.85932024072e-09,        -6.25884765257e-10,         4.79484526286e-09, 
        6.56801181485e-10, 
},
{
       -4.56727621802e-09,         5.59813841332e-08,         6.98771938880e-08,        -8.94764381381e-08,        -9.93776307670e-08, 
        7.98868189455e-08,        -5.27214375096e-08,         8.64099288384e-08,        -3.82220694740e-08,        -7.33762626227e-08, 
        2.21225805555e-07,         1.34724995529e-07,        -2.58292120059e-08,        -2.40406427424e-08,        -1.21091504458e-08, 
        4.81309225633e-08,        -6.14293088712e-08,         4.78897192213e-08,         4.52243740160e-08,        -1.38388355524e-07, 
        3.96137805501e-08,        -1.48940550792e-08,         1.93936294310e-08,        -1.23102038151e-08,        -1.60664562102e-09, 
       -9.25109786194e-09,         1.90030424677e-08,        -1.98121581140e-08,         5.04060471440e-09,        -4.51556179624e-08, 
       -3.68246692077e-08,        -2.86367268705e-08,        -3.14630704140e-08,        -3.44846237353e-08,         1.53431247508e-08, 
        2.61380214582e-08,        -2.43463291310e-07,         1.68395998426e-07,        -9.49188103251e-08,        -6.08990938316e-09, 
       -1.77103284470e-08,        -7.16196608980e-08,         3.94580202931e-09,        -2.96883284653e-09,        -9.87447316312e-09, 
       -2.32199159560e-08,         9.25801685640e-09,         5.09858994613e-09,        -7.96990704082e-09,        -5.71341357082e-09, 
        3.80640932898e-09,         2.57245778710e-09,        -2.17225589277e-09,        -2.37149862014e-09,         1.23207199953e-09, 
        2.23011901797e-09,        -1.02612471240e-09,        -1.24730981548e-09,         1.02528460376e-09,         7.09102364136e-10, 
       -6.90231406012e-10,         3.50855013083e-11,         2.01596291456e-10,        -3.41212265209e-10,         4.69718234710e-10, 
        4.53840714750e-10,        -1.13828948236e-09,        -3.87665423214e-10,         1.89854718007e-09,         3.46309375835e-10, 
       -2.89303503613e-09, 
},
{
        3.48941719441e-08,         9.94145377155e-08,        -6.48321032808e-08,        -1.90689097519e-07,         1.81464323227e-09, 
        1.00091313349e-07,         9.77277553827e-08,         5.52622701546e-08,        -1.17503232911e-07,         7.78110291545e-08, 
        5.27283551355e-08,         2.80959308548e-08,        -3.57140806516e-08,         5.06152745865e-08,         3.82827992877e-08, 
       -3.53510709884e-08,         4.62271152235e-08,         1.70059028295e-07,         4.81361690195e-08,         5.55180615278e-08, 
        5.29115555599e-08,        -3.50218722096e-08,         1.72228461446e-08,         8.71405084466e-09,        -1.47375462871e-08, 
       -8.66090690239e-09,         8.96832251892e-09,         2.00815151412e-08,         3.86862296189e-09,         4.00651003907e-08, 
       -3.21343307940e-08,        -1.02584626984e-08,        -1.19054828847e-08,        -1.04483482792e-08,        -1.54492799811e-08, 
       -6.99619925930e-08,         3.29079764570e-08,        -1.50389426974e-07,        -1.49906448536e-07,         6.11212297165e-08, 
        1.72352970110e-08,         6.65153779014e-08,        -5.92440645534e-08,         3.34432600684e-08,         3.27454118901e-09, 
       -2.37701326786e-09,        -1.06899173226e-08,         6.36358477366e-09,         7.26586976167e-09,        -6.16856195084e-09, 
       -3.66541424244e-09,         2.38442133754e-09,         2.86901108962e-09,        -2.26907402782e-09,        -2.49268887078e-09, 
        1.16132057514e-09,         2.19660567419e-09,        -1.64843321662e-09,        -1.28208725737e-09,         1.30104515357e-09, 
        5.24948486529e-10,        -9.78093484828e-10,        -7.21630411719e-11,         4.50645847522e-10,        -1.14819018619e-11, 
       -2.39536908004e-10,        -8.66079996313e-12,         2.83100003342e-10,        -7.85139981902e-11,        -5.31897635448e-10, 
        3.38832806462e-10, 
},
{
       -2.54534718456e-08,        -1.18696225202e-07,        -2.65499987062e-08,         1.00742691179e-07,         9.00260808359e-08, 
       -6.06916121299e-08,         2.99067643642e-08,        -7.87811053633e-08,         4.45845800133e-08,         5.50027925190e-08, 
       -1.97069068865e-07,        -1.28865786682e-07,         3.17277313280e-08,        -1.49521739448e-08,        -1.08082920575e-08, 
       -8.08982575351e-09,         8.93892608020e-08,        -1.22058382662e-07,        -9.68421899146e-08,         1.55195895081e-07, 
       -3.99784259787e-08,         1.39310414030e-08,        -2.40781196883e-08,         4.66356344944e-09,        -7.18663516958e-09, 
        1.11967261997e-08,        -1.10636607433e-08,         9.05709082568e-09,        -4.56788061136e-10,         1.40293772843e-08, 
        1.97455603626e-08,         1.03867765445e-08,        -1.26980144261e-09,        -5.79159286981e-09,         1.18603353272e-08, 
        1.99409655567e-08,        -1.25108396163e-07,         5.52407127199e-08,        -4.76379854956e-09,        -2.15463260715e-08, 
       -2.23727343180e-09,        -1.40583499998e-08,         3.63762521649e-08,        -3.25288226391e-08,         1.14523627761e-08, 
       -1.42102771876e-08,         4.11947046075e-09,        -7.83036705942e-09,        -2.08104005046e-10,        -4.92841113747e-11, 
        9.99969411512e-10,        -5.16181332569e-09,         1.84299845802e-09,         6.20575264837e-10,        -1.14465660283e-09, 
       -1.08433311353e-09,         6.13676583233e-10,         8.72317378792e-10,        -8.55264587609e-10,        -9.72160232602e-10, 
        1.09619151793e-09,         2.93710088862e-10,        -8.76899472689e-10,         1.65806170104e-12,         3.39510247253e-10, 
        1.58152739684e-10,        -1.53243538045e-10,        -4.66158556728e-10,         3.54302409194e-10,         5.88384497349e-10, 
       -6.64352582758e-10, 
},
{
       -1.78375492513e-09,         7.89063106612e-09,         7.70913162696e-08,         1.24969882323e-07,        -2.85113611686e-08, 
       -6.27405042721e-08,        -6.13038442751e-08,        -6.03581940939e-08,         1.07662108174e-07,        -6.41741021693e-08, 
       -1.75446339709e-08,         4.55835768250e-08,         3.28240597247e-08,        -2.49508221736e-08,        -1.85448095994e-08, 
        3.25481815795e-08,        -2.92342984332e-08,        -1.52645829557e-07,        -1.05874379654e-08,        -9.17645997343e-08, 
       -5.83696345523e-08,         3.58883154819e-08,        -2.47282118652e-08,        -1.01415663204e-08,         2.49740970879e-08, 
        4.56510788451e-09,        -2.18393210565e-09,        -1.51449905383e-09,        -4.74842747722e-09,        -1.66205667440e-08, 
       -1.54052486551e-09,        -1.80956527510e-10,         7.07282354051e-09,        -1.18284140192e-08,         8.68882838494e-09, 
       -2.47029400928e-08,         3.63759346870e-08,        -2.92787368470e-08,        -1.68032974263e-09,        -7.31704669877e-09, 
       -7.00990996515e-08,         4.31668338148e-08,         2.80837688958e-08,         1.33139410943e-08,         1.37236813369e-08, 
        3.66645953169e-09,        -1.00370101392e-08,         2.80755490246e-09,        -2.26743260024e-09,        -1.81951730928e-09, 
       -3.15778265969e-09,         1.15224420307e-09,        -2.14687638308e-09,        -3.83649399332e-10,        -6.63887885183e-10, 
        2.14479106135e-11,        -8.38431158406e-10,         2.64967082741e-10,         5.06043553197e-10,        -9.48322675562e-10, 
       -4.98637859326e-10,         9.72534872573e-10,        -1.64720327143e-10,        -6.05168778588e-10,         1.98112251339e-10, 
        1.17967789296e-10,        -2.30327433319e-11,         2.31926898728e-11,        -1.39704744351e-10,         1.44123777421e-11, 
        3.76057014473e-11, 
},
{
        1.81337718701e-08,         1.21145513567e-07,         2.03315329701e-10,        -9.78196414980e-08,        -6.93951950131e-08, 
        4.02017161215e-08,        -3.08445054710e-08,         6.63810462373e-08,        -3.43066366690e-08,        -1.36078727151e-08, 
        1.03662657571e-07,         9.85126702132e-08,        -1.73340336793e-08,         3.92828639408e-08,         5.41417196538e-09, 
       -3.13394367691e-08,        -7.23773850457e-08,         1.73796208347e-07,         1.14234004047e-07,        -1.34519149133e-07, 
        4.03845792094e-08,        -1.51940698670e-08,         1.89965981655e-08,         4.41463987514e-09,         1.57787899969e-08, 
       -1.81998820732e-08,         4.30741286800e-09,        -3.12834434271e-09,         1.30690621834e-08,        -3.85819041929e-09, 
       -1.77153338995e-08,        -4.25268638094e-09,         6.64776698095e-09,        -1.59993970839e-08,        -5.97049817251e-09, 
       -3.87149592788e-09,        -4.28678694454e-08,         1.23068742894e-08,        -6.14094496672e-11,         8.90029237855e-09, 
        5.07447527535e-08,         8.62938271934e-09,        -1.18546374734e-07,        -8.28679845813e-09,        -6.07162164543e-08, 
        4.02890839827e-09,        -9.72192794285e-09,        -9.03999938075e-10,        -6.40551910108e-09,         1.86381266613e-09, 
        2.12774569886e-09,         7.73775069037e-12,        -3.27864757622e-11,         1.44773878159e-09,         1.50770795529e-11, 
        1.43054713241e-09,         5.81567934087e-10,        -1.34634964878e-09,         1.65618260790e-09,         8.93851136048e-10, 
       -1.11346684443e-09,        -5.01829659220e-11,         8.61574922149e-10,        -3.89629011675e-11,        -2.86533010920e-10, 
       -1.62527158646e-10,         3.57613634289e-10,         2.63636490618e-10,        -4.60596127790e-10,        -2.06768072025e-10, 
        5.39633865148e-10, 
},
{
       -1.06630780185e-08,        -6.79608526479e-08,        -5.87089732264e-08,        -7.08664454094e-08,         3.83563046839e-08, 
        2.91287865314e-08,         3.48309708169e-08,         5.82063316374e-08,        -7.63284739343e-08,         3.22875139442e-08, 
       -8.41112164540e-10,        -1.05110395038e-07,        -1.19344239762e-08,         1.16800125741e-08,         2.39641055867e-09, 
       -1.39168768185e-08,         3.15880955622e-08,         1.24680386528e-07,        -4.07853380850e-08,         9.83403562925e-08, 
        7.16541712065e-08,        -3.41170013321e-08,         2.87694215670e-08,         1.33941525084e-08,        -3.82929089605e-08, 
       -1.73776262798e-09,         1.60869945861e-09,        -5.71418761354e-09,        -2.38573532142e-09,         1.63185972958e-08, 
        3.37082477088e-09,        -8.28963028047e-09,        -2.04087218807e-09,         1.77942628805e-08,         1.17828239990e-09, 
       -1.79601349473e-09,         7.83556221463e-10,         2.52096638660e-09,        -2.47219100838e-09,        -2.03215323693e-08, 
       -7.50555122381e-08,         3.57054027063e-08,         4.28962908501e-08,        -7.12034348848e-08,        -1.20024262091e-08, 
       -6.43588966058e-08,        -6.19611046448e-09,        -1.86651255413e-08,         1.23897826652e-09,        -1.21227499259e-08, 
       -3.00461889538e-09,         2.90088401076e-10,         1.12266828643e-10,        -2.16085855962e-09,        -1.43503554192e-09, 
        5.42337641591e-10,         2.04215444452e-09,        -1.26562734080e-09,        -1.62853208181e-09,         2.07720407515e-09, 
        5.03340372442e-10,        -9.44839708756e-10,        -1.99613570383e-10,         5.15067891528e-10,         4.92247622179e-10, 
       -3.95771345685e-10,        -5.83108150167e-10,         7.05230854163e-10,         3.83949515550e-10,        -6.96323705757e-10, 
       -1.36856096984e-10, 
},
{
       -5.91842666879e-09,        -7.96680951839e-08,         1.07913487988e-08,         8.64592123958e-08,         4.93394542277e-08, 
       -2.17458676507e-08,         4.39807413172e-08,        -5.96448429001e-08,         1.77854658602e-08,        -1.39001689523e-08, 
       -3.01814552576e-09,        -5.17296127609e-08,        -1.01647624995e-08,        -4.87473260401e-08,         1.33112654978e-08, 
        4.95117873719e-08,         2.23885767292e-08,        -1.92885484744e-07,        -9.07608978953e-08,         9.12031689732e-08, 
       -5.00781350988e-08,         2.68285119585e-08,        -1.25369319365e-08,        -1.83492469532e-08,        -1.48470420798e-08, 
        2.59368507130e-08,         1.92762760295e-09,         9.81912335200e-09,        -9.95535654766e-09,        -6.86974293917e-09, 
        1.96026001663e-09,         7.29749163873e-09,        -1.23545440639e-08,        -9.61296392031e-09,         6.95948818019e-09, 
        1.00623877406e-08,        -8.60001741675e-10,         1.21279379842e-09,         5.38001396511e-09,         5.44756976509e-09, 
        1.87725288890e-08,        -8.59411315285e-08,         4.66824213547e-08,         1.73952369406e-08,        -5.25426967068e-08, 
       -6.60567229449e-09,        -2.63079391868e-09,         2.36614995837e-09,         4.25426787580e-09,         4.02954109454e-09, 
        3.73440822271e-09,        -2.76731128845e-09,         2.59093501843e-09,         6.49439974599e-10,         6.49852884345e-11, 
       -2.46367505776e-09,         1.24851882700e-09,         1.10888026900e-09,        -1.73324891205e-09,        -5.85762298041e-10, 
        1.07447242675e-09,         2.27994377705e-11,        -5.90882786777e-10,        -3.30189764326e-10,         4.06832005178e-10, 
        5.12596743262e-10,        -7.21148556042e-10,        -3.53711019972e-10,         7.84444395519e-10,         8.23611625431e-11, 
       -6.15934558888e-10, 
},
{
        7.20746786399e-09,         7.46552530106e-08,         2.91972564675e-08,         3.66006184872e-08,        -2.69343697329e-08, 
       -6.11892981757e-09,        -3.57361429902e-08,        -4.69530430037e-08,         3.85623004614e-08,         1.25540557405e-09, 
       -4.70218058456e-09,         1.21206099283e-07,        -1.47501840823e-08,        -8.09607214131e-09,        -3.48309549044e-09, 
       -6.86281898404e-09,        -4.14381418467e-08,        -8.25565223774e-08,         8.12915256314e-08,        -7.83124803986e-08, 
       -7.56122157005e-08,         2.30606409020e-08,        -3.11292891647e-08,        -1.66505319913e-08,         4.75231086259e-08, 
        5.25933694559e-09,        -6.80113340879e-09,         9.17154201377e-09,         1.10376250783e-08,        -3.36488041518e-09, 
       -2.66244737286e-09,        -1.05844323582e-09,         9.98766335731e-09,        -1.74439903061e-08,        -4.84344769392e-09, 
       -1.44188447752e-08,         7.95922862032e-09,         1.08678518110e-08,         2.18716970452e-09,        -1.06744341452e-08, 
       -1.59047700355e-08,         9.82035438097e-09,        -1.03897811530e-09,        -3.45127242788e-08,         2.10527109531e-08, 
       -6.43292469123e-08,        -1.91089395939e-08,         1.93645974100e-08,         6.98762050682e-09,         1.57172256071e-08, 
        5.53015818908e-09,         9.48284616052e-09,         2.78018510857e-09,         3.16572939607e-09,         1.33852074762e-09, 
        1.45030584335e-09,         1.18930330596e-10,         1.11652439642e-09,        -1.85863491580e-10,        -3.98766122469e-10, 
        4.97642313118e-10,         7.43219115663e-11,        -1.89659564316e-10,        -3.27757039295e-10,        -2.61583699794e-11, 
        4.18800182711e-10,        -6.25182979029e-11,        -5.26172904790e-10,         1.37346081555e-10,         3.83774337798e-10, 
       -1.73680632893e-10, 
},
{
        5.80849742310e-09,         3.02047209712e-08,        -1.22728314003e-08,        -7.14288432471e-08,        -3.82603439172e-08, 
        8.05242055405e-09,        -5.13517066708e-08,         5.60132052304e-08,        -2.30618666216e-09,         1.43453489313e-08, 
       -5.29909870901e-08,         7.11068712198e-09,         3.43203592380e-08,         4.63547838395e-08,        -2.24820126992e-08, 
       -3.69117240296e-08,         3.37024593085e-08,         1.78439117771e-07,         4.04709598154e-08,        -4.86228684210e-08, 
        5.94452291387e-08,        -3.77680165819e-08,         1.83586217387e-10,         3.39857852613e-08,         1.53468911088e-08, 
       -3.88989261075e-08,         1.15218405268e-10,        -1.65441228004e-08,         2.75734207378e-09,         9.62803534010e-09, 
        3.73399161821e-09,         4.09004003765e-10,         6.73202942778e-09,         8.97824736734e-09,        -7.34216654538e-09, 
       -7.91941798971e-10,        -1.53048073546e-08,         1.80302233753e-09,         2.92952321609e-09,        -3.66908146986e-09, 
        2.44737837887e-09,        -1.92130454046e-08,         3.10935078371e-08,         2.43354391329e-08,         1.79731157187e-08, 
        1.51267099334e-08,        -3.19427694347e-08,        -2.75144424583e-08,        -1.01157393626e-08,        -9.54609827345e-09, 
        4.02779549309e-09,        -5.87168318718e-09,        -3.36340374109e-10,        -1.67044238024e-10,         9.38226416078e-10, 
       -1.39992682620e-09,        -1.45334116586e-10,         8.35239413333e-10,         8.76917488808e-10,        -1.21830013626e-09, 
        4.38032731666e-10,         6.02670232291e-10,        -7.56647928537e-11,        -2.07465090967e-10,        -1.80098483133e-10, 
        2.91160619058e-10,         2.37417258900e-10,        -2.95008533309e-10,        -1.88642319221e-11,         1.41541585142e-10, 
        1.33652928103e-11, 
},
{
       -5.08092488016e-09,        -5.20706824993e-08,        -4.12154508899e-09,        -1.74357566652e-08,         6.27220729418e-09, 
       -3.39780301487e-09,         5.58847324353e-08,         3.09249766038e-08,        -1.24909331386e-08,        -2.18277328825e-08, 
        2.43669490296e-08,        -9.28769751492e-08,         3.14680681281e-08,         6.39237655421e-09,         1.82308923620e-08, 
        1.53050000626e-08,         4.47493731213e-08,         3.28305563267e-08,        -8.95126987795e-08,         4.40765364509e-08, 
        6.06034945967e-08,        -1.01190121618e-08,         3.39995214192e-08,         1.46497774204e-08,        -5.22777061779e-08, 
       -7.21998046122e-09,         8.38154795119e-09,        -1.17809291867e-09,        -9.99143511819e-09,        -3.20703837776e-09, 
       -2.99340331954e-09,         2.28656976708e-09,        -5.03764404563e-09,         5.76416857513e-09,         7.33125449625e-09, 
        1.84206592493e-09,        -5.91714360479e-10,        -1.43096371328e-09,         6.13959353845e-09,        -5.67166374814e-09, 
       -1.21991865286e-08,        -4.94489891666e-09,         1.38060743759e-08,         4.89131158109e-09,         2.44357147367e-08, 
        7.29311424608e-08,        -4.08300388261e-08,         3.65283969828e-08,         6.14130923407e-08,        -2.99499985811e-08, 
        1.48915067971e-08,        -9.77785075929e-09,        -1.24573076326e-10,        -8.42427242698e-09,        -7.67794480151e-10, 
       -1.56793125961e-09,        -1.68658129072e-09,        -2.29405168570e-09,         4.64023234870e-11,         3.46282924733e-10, 
       -1.16023067051e-09,         1.27184545547e-11,        -6.18278928440e-11,         1.00984005555e-10,        -1.04340630755e-10, 
       -2.25143420940e-10,         1.51824977430e-10,         8.35868275322e-11,        -7.41088722624e-11,         1.22013223471e-10, 
       -1.76193934758e-10, 
},
{
       -1.31850512180e-08,         1.07350097295e-09,         8.53218969105e-09,         5.47067487484e-08,         3.67990198987e-08, 
        6.61209859331e-10,         4.33934294389e-08,        -4.90085338106e-08,        -9.83183689659e-09,         3.16049240625e-09, 
        5.37776257278e-08,         2.01242031306e-08,        -4.38250958527e-08,        -3.89442571319e-08,         1.28003380979e-08, 
        2.67482108716e-09,        -7.27528145143e-08,        -1.37852583005e-07,         1.30087230779e-08,         2.14025002434e-08, 
       -6.26895794403e-08,         4.41869482651e-08,         9.80911876525e-09,        -4.54164882748e-08,        -1.64583251035e-08, 
        5.41025846525e-08,        -2.54910219486e-09,         1.56928566539e-08,         7.05755775939e-09,        -5.45629987129e-09, 
       -4.11224532080e-09,        -7.22048912259e-09,        -2.42286284371e-09,        -9.72461213414e-09,        -9.82033845423e-10, 
        3.18318003304e-09,         4.19076151868e-09,        -3.29877557921e-09,        -2.53380006793e-09,         2.05626819177e-09, 
        1.89278791265e-09,        -1.57201056090e-08,         1.35570240983e-08,         4.95135647532e-09,         1.02055591791e-08, 
        2.03984290631e-08,         3.10038562478e-08,         6.35515117086e-08,        -6.09666738776e-08,         3.27763407108e-08, 
       -2.48071269520e-08,         5.77219088248e-10,        -1.90227167217e-09,        -4.51989119167e-09,         1.19989701144e-09, 
       -3.94489600499e-09,         2.35662117065e-09,        -1.48475990048e-09,         4.08027540259e-10,        -8.46589711444e-10, 
        8.17822861318e-10,        -2.92486842497e-10,         2.35977233012e-10,        -5.04858602682e-10,         3.53957213040e-10, 
        1.87581520610e-10,        -2.12784888409e-10,        -5.40726521941e-11,         1.85076657553e-10,         1.19041891575e-10, 
       -7.44365939286e-11, 
},
{
        1.39360438172e-08,         2.82008167985e-08,        -9.83912480574e-09,         6.53790592545e-09,         7.56760245313e-09, 
        2.15758136857e-09,        -7.43660140524e-08,        -1.77034403531e-08,         5.00150287157e-09,         2.43870701732e-08, 
       -3.91649210514e-08,         4.51029299421e-08,        -3.36490246119e-08,        -3.55279705543e-10,        -3.12341550492e-08, 
       -4.77655693653e-09,        -3.52373688089e-08,         1.03088805204e-08,         6.51986800144e-08,        -1.42776668500e-08, 
       -2.74606123513e-08,        -3.14694726052e-09,        -3.66547433480e-08,        -9.65267771938e-09,         5.25366263720e-08, 
        5.98656495084e-09,        -8.66935978355e-09,        -4.81016613037e-09,         2.21356976194e-10,         4.50592316243e-09, 
        7.79962988782e-09,         1.02896347240e-09,        -6.85700635448e-10,        -4.08898548296e-09,        -5.97483140296e-09, 
       -5.05619678502e-09,         1.98137267333e-09,         5.59537677799e-09,         1.44530480686e-09,        -4.98698475994e-09, 
        5.47103523414e-11,         9.59793475921e-10,         1.62556383177e-09,         7.61191328326e-09,        -3.11250922676e-09, 
        2.04406115876e-08,        -1.14421578886e-08,        -4.51376402249e-08,         1.74403201060e-08,         2.49121290767e-08, 
       -4.77756067702e-09,         9.71958277562e-09,        -5.21208823702e-09,         4.24395331781e-09,        -1.03229953064e-09, 
        2.25316047890e-09,        -9.71658447223e-10,         3.07717192203e-10,         4.04442794160e-10,         9.91739252850e-11, 
       -2.26667458588e-10,        -5.65017028321e-10,         4.36645395779e-10,        -1.47887135340e-10,        -3.22302504838e-10, 
       -4.35602253149e-11,         1.77466731334e-10,        -2.02344759077e-10,        -1.16922900976e-10,         1.24282334613e-10, 
        9.13991384487e-11, 
},
{
        1.51433008455e-08,        -9.90274524315e-09,        -1.59726146842e-09,        -3.76028691909e-08,        -4.01112141224e-08, 
       -5.88230405438e-09,        -2.26868904979e-08,         3.75709019703e-08,         1.74202283714e-08,        -2.18667865233e-08, 
       -2.28584715224e-08,        -2.55676879266e-08,         3.76466258089e-08,         2.95411791467e-08,         9.06677005545e-09, 
        3.36151830995e-08,         8.16888672997e-08,         8.43755544744e-08,        -4.81655944428e-08,        -9.60937109660e-09, 
        5.31218404670e-08,        -4.38235264050e-08,        -1.52839733321e-08,         4.90948714417e-08,         1.93693801179e-08, 
       -6.55907369118e-08,         1.28094572018e-09,        -1.17307018168e-08,        -8.75523825225e-09,         9.89459713377e-10, 
       -9.65436069731e-10,         8.75073159812e-09,         6.22321666313e-09,         3.03408696514e-09,        -2.02693477777e-10, 
       -3.42244717281e-09,        -3.60458517065e-09,         8.17365902845e-10,         1.31873876728e-09,        -6.29446276626e-10, 
        8.17135186415e-11,        -6.11775014297e-10,         1.16498213235e-08,         5.05179232738e-09,         1.48732364056e-09, 
        4.83581571568e-09,         1.21406470551e-08,        -1.99544880752e-08,         1.82710905138e-08,        -1.00010381664e-09, 
       -2.15998470727e-08,         1.22359380864e-08,         3.10746946916e-09,         9.20391417924e-09,         4.99496614259e-09, 
        7.74768893394e-09,         2.97674939546e-09,         4.21944122431e-09,         2.10976670263e-09,         1.84701718465e-09, 
        1.27522046954e-09,         9.59597696562e-10,         7.76402867581e-11,         5.93509946526e-10,         6.44005999000e-11, 
        2.73244131577e-10,         5.23769178409e-11,        -1.64405535093e-10,         1.57894296007e-10,        -5.32146070146e-11, 
       -3.52598823682e-11, 
},
{
       -2.89977530218e-08,        -1.60327679024e-08,         1.40437981293e-08,        -8.02197692435e-10,        -7.24099799716e-09, 
        4.06403097807e-09,         7.65942805144e-08,         1.16689361592e-08,        -1.09087452454e-08,        -1.40201689117e-08, 
        3.85902856403e-08,        -7.06199792689e-09,         2.59661876461e-08,        -1.05519120183e-08,         2.98510792334e-08, 
       -1.92414877329e-08,         1.64882181383e-08,        -3.38062321435e-08,        -2.37908567724e-08,        -2.81754255511e-10, 
       -1.09228585702e-08,         1.59526229212e-08,         3.59910900638e-08,         2.86094005429e-09,        -4.85680776191e-08, 
       -6.26674418617e-10,         9.23853892935e-09,         6.69958763007e-09,         9.77966443243e-09,         1.41967053676e-11, 
       -7.58499212875e-09,        -5.73890218310e-09,         8.62225639588e-10,         5.66254551022e-09,         3.13062579964e-09, 
        3.50756305888e-09,        -3.25477146959e-09,        -4.56304160408e-11,         2.75738618860e-09,        -3.13715484235e-09, 
       -2.86375420472e-09,        -1.54819200251e-09,         3.36414899704e-09,         7.15772652668e-09,         3.84231795120e-09, 
        2.33954217604e-09,         8.90248464905e-10,        -7.59168872384e-09,        -1.72880091706e-08,        -9.96387668324e-09, 
        5.52738260557e-08,         5.50219345241e-08,        -6.19879338931e-09,         2.84590154188e-09,        -2.93400180017e-09, 
       -2.31965833276e-09,        -1.25350870622e-10,        -2.87846929510e-09,         8.55921435345e-10,        -4.77436546837e-10, 
       -1.77720687409e-10,        -4.84553660202e-10,         5.15824231200e-10,        -2.14594452155e-10,         2.51811432144e-10, 
       -4.99888620210e-10,         6.17999434777e-10,        -3.83511322276e-12,        -3.59825537596e-10,         2.62194619133e-10, 
        5.13487272712e-11, 
},
{
       -5.83465805647e-09,         6.71185562589e-09,        -6.81713219973e-09,         2.26383142071e-08,         4.20552253652e-08, 
        8.69076686354e-09,        -2.77401525084e-10,        -2.61174133030e-08,        -1.97294115400e-08,         2.99330328101e-08, 
       -6.83051084114e-09,         1.73291667283e-08,        -2.30067205919e-08,        -1.89728671493e-08,        -2.75364682815e-08, 
       -5.22908898104e-08,        -6.24559985991e-08,        -3.43302640521e-08,         5.53481129346e-08,         4.83816533810e-09, 
       -3.22434803588e-08,         3.82358859624e-08,         1.59464323880e-08,        -4.51204672956e-08,        -2.13655557532e-08, 
        6.85461894817e-08,         3.16924152432e-09,         9.59255037983e-09,         4.24026648418e-09,        -1.47278325291e-09, 
        4.33182813406e-09,        -6.09997679284e-09,        -7.80344526198e-09,        -3.42661116670e-09,         1.15644112153e-09, 
        2.63406629946e-09,         2.91550194937e-09,        -3.03960369789e-09,        -1.89892482698e-11,         1.96041907179e-09, 
       -1.43931548006e-09,        -4.40956922283e-09,         3.51846259634e-09,        -1.42831090949e-09,        -9.91475145396e-10, 
        1.73862700582e-09,         4.65356050197e-09,        -1.43478859426e-08,         1.94540480472e-08,         3.68542752960e-09, 
        1.75665891426e-08,         1.09724359426e-08,         6.15554190955e-08,         2.24557882875e-08,         4.31602441837e-09, 
        8.36600821165e-09,        -2.35286907735e-09,         2.16938806260e-09,        -2.24907351320e-09,         3.84600910948e-10, 
       -8.39178596013e-10,        -4.60148481175e-10,        -5.62419605739e-10,        -3.72388196592e-10,        -1.84233239066e-10, 
        1.18564034356e-11,        -5.55690996416e-10,         2.86543719996e-10,        -1.05628541657e-10,        -2.36978381895e-10, 
        1.57802797151e-10, 
},
{
        3.83468543840e-08,         1.23058511170e-08,        -1.27790886348e-08,        -4.44113776244e-10,        -3.47903406305e-09, 
       -9.72886383380e-09,        -6.22779401962e-08,        -1.14471319997e-08,         1.89568431157e-08,         5.07401412909e-10, 
       -2.57297082127e-08,        -6.59622565076e-09,        -1.72349462482e-08,         2.22872888920e-08,        -1.35263605921e-08, 
        4.29401185723e-08,         2.15918618228e-09,         3.32017375368e-08,        -1.39754829354e-08,        -1.71637629981e-10, 
        4.01879852610e-08,        -2.93385155733e-08,        -3.06888367022e-08,         3.85446217650e-09,         3.99928115599e-08, 
       -5.80252280901e-09,        -1.16874932788e-08,        -7.88491992232e-09,        -1.37007832188e-08,        -5.50397965262e-09, 
        4.45252564327e-09,         5.52912988799e-09,         2.51613850605e-09,        -6.48444648359e-09,        -3.37178094104e-09, 
       -2.51491256739e-09,         3.30730870422e-09,         7.99695434893e-10,        -1.19311872658e-09,        -1.12263378785e-09, 
        1.86338438000e-09,         7.13763055752e-10,        -6.16185253025e-10,         4.57802636661e-09,        -4.22553632206e-09, 
       -9.36025250389e-10,        -1.90353818035e-09,         1.06932865634e-09,        -1.10739594206e-08,        -6.05749531037e-09, 
        1.92237834357e-08,        -3.59644128698e-08,         4.29382803304e-08,         1.61600340957e-08,         4.07593634548e-09, 
        1.60630458955e-09,        -2.64002222782e-10,         1.48591524735e-10,        -4.67921032664e-10,        -1.75303546758e-10, 
       -1.20019767821e-09,         8.79998577449e-11,        -2.59426978921e-10,         2.47442191778e-10,        -8.59011852880e-10, 
       -6.27362412079e-11,         2.12852281836e-10,        -1.86517425153e-10,        -1.11268327767e-10,        -2.04957061704e-10, 
        1.70805183689e-10, 
},
{
       -9.24761851413e-09,        -2.48259887582e-09,         1.42995701530e-08,        -1.27829654147e-08,        -3.90609187337e-08, 
       -9.13672205250e-09,         1.55977669468e-08,         1.93081652319e-08,         1.70823362302e-08,        -2.55564655787e-08, 
        1.69379042872e-08,        -7.82081481322e-09,         8.78317396751e-09,         6.76511547193e-09,         3.09071059283e-08, 
        4.59916264761e-08,         2.81997115537e-08,         9.65321112652e-10,        -3.84763541574e-08,         1.05672368084e-09, 
        6.11292606053e-09,        -2.80045350901e-08,        -1.36423764886e-08,         3.41296746280e-08,         2.18066507585e-08, 
       -6.12468581745e-08,        -7.66515360867e-09,        -9.97317009013e-09,         1.04869590885e-09,         7.11284150749e-09, 
       -4.49355038637e-09,         3.89528202481e-09,         5.76023093103e-09,         4.24693646211e-09,        -2.36600819614e-09, 
       -2.56431693173e-09,        -2.42338451456e-09,         3.76500965244e-09,         4.70977954611e-10,        -1.39961701900e-09, 
       -3.62357083727e-10,         2.95491639663e-10,         3.84401474511e-09,         1.41665781305e-09,         8.80320047984e-11, 
       -1.84006766149e-09,         2.45020805507e-09,        -9.44462845472e-09,         9.88551105956e-09,         3.94189445138e-09, 
        6.40476258760e-09,         7.12898711863e-09,        -3.98545086209e-08,         5.45524572635e-09,        -2.78059012497e-08, 
        2.29286358387e-09,        -2.24646448622e-09,         7.65298392052e-11,         1.86185380215e-09,         1.64161477289e-09, 
        7.70744234990e-10,         1.39845372450e-10,         1.33527559025e-09,         6.35138281071e-10,         8.29616493909e-10, 
       -4.92519203605e-10,         3.85692556866e-10,         3.67833620025e-10,         1.16329453279e-10,        -2.31924215578e-10, 
       -3.70592536575e-11, 
},
{
       -3.48303595090e-08,        -8.28561730774e-09,         9.37892957188e-09,        -1.52301353527e-09,         1.54357567878e-08, 
        1.20584485059e-08,         4.15777183204e-08,         1.22907037275e-08,        -2.07000442795e-08,         7.81712146908e-09, 
        1.18326414144e-08,         1.14874123513e-09,         1.31734859753e-08,        -2.98776382475e-08,        -7.29535578356e-09, 
       -5.28653965731e-08,        -1.21416688527e-08,        -1.56693873424e-08,         3.37811413124e-08,         6.99558664214e-09, 
       -5.16324450471e-08,         4.23650915584e-08,         2.27812320602e-08,        -9.14269080607e-09,        -2.83182707663e-08, 
        1.13985087163e-08,         1.32252514706e-08,         1.29049914153e-08,         1.24469767589e-08,         7.63049194276e-09, 
       -8.50717521621e-10,        -2.66354077020e-09,        -4.68577710794e-09,         4.04608257391e-09,         3.76036402560e-09, 
        6.22070971275e-10,        -3.01099583384e-09,        -9.22718340456e-10,         2.87593578713e-09,         6.26234826644e-10, 
       -3.78387402445e-10,        -3.89818456059e-10,         5.24148764643e-10,         2.15184051783e-09,         1.51788562411e-09, 
       -2.05808499417e-09,         1.53769470531e-09,         1.98882607080e-09,        -5.37492472322e-09,        -4.75905646983e-09, 
        1.03593976979e-08,        -1.52388865387e-08,         6.98360926032e-09,        -1.00680446676e-08,         1.08166287193e-09, 
        4.17395018850e-09,        -7.92650143452e-09,        -2.13996177200e-09,        -3.40280733999e-09,        -1.28289442341e-09, 
       -3.48612860345e-10,        -1.34039001702e-09,         1.44137560359e-10,         1.72864297717e-10,         3.99242332673e-10, 
       -3.12861930529e-11,        -1.22714375476e-10,         4.11551282643e-10,         1.35071322951e-10,        -5.49136404571e-11, 
       -3.50092226279e-12, 
},
{
        2.00878597558e-08,         5.78705753441e-10,        -1.85067901353e-08,         9.27333240954e-09,         3.12448553891e-08, 
        7.03812057081e-09,        -1.96699233019e-08,        -1.75547181193e-08,        -1.16959077871e-08,         1.40638989641e-08, 
       -1.02243710304e-08,         4.94255126035e-09,        -2.85654713394e-10,         6.14220068995e-09,        -1.86070431628e-08, 
       -2.24910590032e-08,         4.62570136384e-09,         1.08422793142e-08,         1.01013798194e-08,        -1.00761863115e-08, 
        1.71384871252e-08,         1.36393740253e-08,         9.09223743835e-09,        -1.78216108247e-08,        -2.07659441638e-08, 
        4.50407546985e-08,         1.09942490687e-08,         8.71532182934e-09,        -3.46203941366e-09,        -1.30732818884e-08, 
        1.86073145388e-09,        -5.50472191525e-09,        -1.79127927150e-09,        -3.69078155648e-09,         1.03038095696e-09, 
        3.56844555671e-09,         1.82029260337e-09,        -3.59012958387e-09,        -5.99477172909e-10,         1.78955808568e-10, 
       -1.50534163443e-10,        -2.71582627528e-10,         3.65673405777e-11,         4.31201739486e-10,        -1.41498095097e-09, 
        1.71986679199e-10,         2.20202323032e-10,        -1.86316026706e-09,         4.65474243208e-09,         7.50003295623e-11, 
        2.01791569593e-09,         6.61613722374e-09,        -1.64691093941e-08,         3.35868299895e-09,         2.06841401869e-08, 
       -1.27140720914e-08,         2.28207067508e-08,         1.88889399323e-08,        -1.56871563253e-09,         1.06044756714e-08, 
       -1.98797122634e-09,         3.19664361135e-09,        -8.85100006065e-10,         1.35907870757e-09,        -3.53632265641e-10, 
        1.68025483444e-10,        -3.22734106535e-10,         3.59803763783e-11,         1.44015426729e-10,        -2.46354566899e-10, 
       -1.56958618069e-10, 
},
{
        2.13606415283e-08,         2.61104837571e-10,        -5.12640964088e-09,         3.92157769260e-09,        -2.17922134054e-08, 
       -1.12234786626e-08,        -2.52284820211e-08,        -1.05653125289e-08,         1.47534078437e-08,        -7.81251692295e-09, 
       -5.52756778600e-09,         7.81567587771e-09,        -1.38628796358e-08,         3.06293244026e-08,         2.00531648633e-08, 
        4.44388809195e-08,         1.07565299177e-08,        -4.98079814694e-09,        -3.26693257363e-08,        -1.04717456630e-08, 
        4.55703207346e-08,        -5.18646701035e-08,        -1.53753426503e-08,         1.10233680368e-08,         1.65127034577e-08, 
       -1.46943871915e-08,        -1.18371663166e-08,        -2.11678925625e-08,        -9.36883772104e-09,        -6.18846300385e-09, 
       -7.17295954366e-10,         7.07375488366e-10,         4.04005054363e-09,        -1.89006086348e-09,        -2.98274248987e-09, 
       -2.72373419635e-10,         2.99413181501e-09,         1.71867494791e-09,        -1.67491092780e-09,        -2.24837510102e-10, 
       -1.27647418191e-10,        -4.43718126965e-10,         1.28888371152e-10,         6.08175641967e-12,        -4.47281867867e-10, 
       -1.13917505176e-09,         2.49804821858e-11,         1.58804545423e-09,        -6.38565600396e-10,        -2.19463899874e-09, 
        4.82641539339e-10,        -4.13972947143e-09,        -1.52684956968e-09,        -4.03747208472e-09,         2.03399713493e-09, 
       -6.85456264387e-11,         3.21923040981e-08,         1.77496594607e-08,        -6.57036070417e-09,         1.67362841165e-09, 
        6.51900050392e-10,         3.20592956656e-10,        -6.22506473132e-10,         6.89492916750e-10,        -1.10305423926e-10, 
       -2.73201999265e-11,        -3.69148022589e-10,        -3.36900310119e-11,         6.23444805991e-11,        -2.40379245711e-10, 
       -1.40575182556e-10, 
},
{
       -2.11449840380e-08,         1.70364768865e-09,         1.84077999426e-08,        -1.04470279880e-08,        -2.11090759700e-08, 
       -3.08538765888e-09,         1.55870093739e-08,         1.74842296040e-08,         6.78102393195e-09,        -2.39351089134e-09, 
        9.16827792396e-10,        -8.12271877178e-09,        -2.09713626469e-09,        -1.70980954319e-08,        -3.36481838662e-10, 
       -1.63477011844e-09,        -2.45698621871e-08,        -6.46345038277e-09,         1.58685469411e-08,         1.87738461899e-08, 
       -3.17753249790e-08,         3.20586586632e-09,        -1.88602807343e-09,        -7.06147798384e-10,         1.88911795861e-08, 
       -2.35715975994e-08,        -1.36207968508e-08,        -2.96974709258e-09,         4.11807680678e-09,         1.55726745042e-08, 
        1.42813083983e-09,         9.45562127443e-09,        -5.50342060454e-12,         9.47060579036e-10,        -1.31636610340e-11, 
       -4.13355767901e-09,        -1.36517698125e-09,         2.59893820006e-09,         7.87263135947e-10,        -1.63293421790e-10, 
        4.57479869353e-10,         2.23821428857e-10,         8.68938802406e-10,         1.04731345857e-09,        -8.88393526925e-10, 
       -7.67245094752e-10,         7.95412928134e-10,        -1.26703654182e-09,         1.20267105565e-09,         1.68246742004e-09, 
       -2.90734166212e-10,         1.29073373189e-09,        -5.17123347508e-09,        -1.98414383258e-09,         8.68379626731e-09, 
       -5.55111481536e-10,        -1.42450682976e-08,        -6.09756555318e-09,         1.95526540421e-08,        -1.74756143020e-08, 
        5.67113678251e-09,        -3.02850580306e-09,         9.55171463901e-10,         2.05130658339e-10,         4.10541577157e-10, 
        6.09613872334e-10,        -1.51721752923e-10,         2.52110771024e-10,        -7.71243981023e-11,         2.50861840377e-10, 
       -3.15301286631e-10, 
},
{
       -6.97389928353e-09,         8.19223238937e-09,         3.86344515845e-10,        -4.09161503816e-09,         2.15086188979e-08, 
        8.84026143790e-09,         1.75168187123e-08,         6.38223060821e-09,        -5.40790774953e-09,         1.27613649234e-09, 
        6.83605981772e-09,        -8.16838146397e-09,         1.53932319037e-08,        -2.54951948049e-08,        -1.88478069897e-08, 
       -2.40402119684e-08,        -1.57441972513e-09,         1.68067815097e-08,         1.72676580119e-08,         5.59152703074e-09, 
       -2.86492870300e-08,         5.43943690979e-08,         1.00301990250e-08,        -7.98678971821e-09,        -7.76011457570e-09, 
        1.50421464647e-08,         7.24859393702e-09,         2.84302064807e-08,         6.19305964914e-09,         3.46421645468e-09, 
        7.29457788187e-10,        -2.03953367164e-09,        -3.49216937250e-09,         2.22948860492e-09,         1.00046457313e-09, 
        3.91009209354e-10,        -2.81616802007e-09,        -1.32948307220e-09,         1.60681265696e-09,        -3.85150601073e-10, 
       -2.99647052856e-12,         2.30331633006e-10,        -2.95515237938e-10,         1.16555696414e-09,         1.29093291786e-09, 
       -1.18559304611e-09,         7.69319605545e-10,         8.45218895725e-10,         9.97660148753e-11,        -2.49125691361e-09, 
        1.71887060157e-09,        -2.08134294997e-09,        -2.05353064105e-09,        -1.40943197870e-09,        -7.95029420133e-10, 
        4.57500812172e-10,         2.66176741122e-09,        -8.45284547878e-09,        -1.72464654244e-08,         4.37460502973e-09, 
       -2.14133621071e-08,         2.07568873488e-09,        -7.26104375204e-09,        -1.00391687349e-09,        -1.27803313752e-09, 
       -3.12499906038e-10,         1.64566201647e-10,        -2.64003823478e-10,         2.19152155708e-10,        -6.08065671246e-11, 
        2.91241024346e-10, 
},
{
        1.45794705923e-08,        -6.94095426478e-09,        -1.46516426574e-08,         1.27999419612e-08,         1.13371333384e-08, 
       -1.03827899425e-09,        -9.33691928804e-09,        -1.56655527338e-08,        -4.64901999538e-09,        -5.02200187982e-09, 
       -1.61253633916e-10,         1.14250004735e-08,         1.04897928578e-09,         2.30677458047e-08,         1.48376980403e-08, 
        1.24575355375e-08,         2.94278017824e-08,        -2.35138638356e-09,        -3.02352635207e-08,        -2.21871588978e-08, 
        3.62066897739e-08,        -1.87676412194e-08,        -7.88879658574e-09,         1.67284159383e-08,        -1.64511196293e-08, 
        1.80470308334e-09,         1.61610500011e-08,        -6.32653153379e-09,        -5.63611461470e-09,        -1.36492140425e-08, 
       -3.98357606044e-09,        -1.31843974940e-08,        -2.95094932604e-10,         1.22155865277e-09,        -8.18724201623e-11, 
        4.32917593662e-09,         1.47665150069e-09,        -2.37895691002e-09,        -4.46232861533e-10,         6.88295714513e-10, 
       -5.16533548211e-10,        -2.98098315208e-10,        -1.66170840740e-11,        -9.83328433322e-10,        -7.49386973573e-12, 
        5.53742029850e-10,        -5.25670682024e-10,         7.91640382371e-10,         1.56418885572e-10,         1.10581093815e-10, 
       -6.58164390753e-10,         2.30281727430e-09,        -1.76985292705e-09,        -2.52104117406e-10,         4.35105127337e-09, 
        9.50631225651e-10,        -4.16420007408e-09,         1.63319225742e-09,        -5.76274479456e-09,        -2.40732625030e-08, 
       -1.75497836789e-09,         3.14073233839e-09,         2.06722446971e-10,         6.15654876818e-10,        -1.83828602443e-09, 
        8.91863923782e-11,        -7.32038530145e-10,         2.51398038991e-11,        -5.99491504304e-10,        -3.00206456167e-10, 
       -1.44764173317e-10, 
},
{
       -1.00927201516e-09,        -1.12563225853e-08,         4.10303019429e-09,         1.35766313602e-09,        -1.76706321663e-08, 
       -6.33133114865e-09,        -1.58256959526e-08,        -2.55099860358e-09,        -1.98845843393e-09,         7.65034355330e-09, 
       -9.27705153693e-09,        -1.12335401560e-09,        -1.37466579848e-08,         1.81825220106e-08,         7.10241485975e-09, 
        4.02492709578e-09,        -8.85893307270e-09,        -1.64410211668e-08,         1.78037716913e-09,         6.18310989134e-09, 
        9.43092892687e-09,        -4.91212309718e-08,        -5.94616656009e-09,         2.33776843993e-10,         3.45909605385e-09, 
       -1.20461763038e-08,        -1.48929964636e-09,        -3.07186780451e-08,        -1.74514675311e-09,        -1.64983037457e-09, 
       -4.88349722145e-10,         5.95799091373e-09,         5.34371799946e-09,        -4.42890035526e-09,         8.18041681434e-10, 
       -3.42699121533e-10,         1.98716387810e-09,         1.05287143166e-09,        -1.60118518183e-09,         3.74560237002e-11, 
        4.30510987147e-10,        -1.24458057644e-11,         1.59298040132e-10,         2.00727548762e-10,        -1.05550872839e-09, 
       -3.79150789581e-10,         2.15163073993e-10,         2.42405320272e-10,         8.26461350104e-10,        -8.26908402082e-10, 
       -1.17580504463e-09,         3.06856103731e-10,        -6.50137429525e-10,        -4.41067319666e-10,         3.60517999804e-10, 
        2.26943480374e-09,        -2.26777465383e-09,        -3.17192620821e-09,         4.71765023928e-09,        -7.17064247007e-10, 
        3.35428016384e-09,        -1.44568214037e-08,        -5.22457366234e-09,         1.66336809178e-09,        -2.90377600076e-09, 
        1.29805032593e-09,        -1.26377599560e-09,         8.82845779504e-10,        -6.06325346278e-10,         3.29167345622e-10, 
       -4.86992603184e-10, 
},
{
       -6.69418934559e-09,         1.37435079582e-08,         8.94449713304e-09,        -1.32744929284e-08,        -3.42298694969e-09, 
        3.54398491125e-09,         5.41087439588e-09,         1.16315397812e-08,         5.43049206781e-09,         7.22548391687e-09, 
        8.32969829895e-09,        -9.70264834211e-09,         3.29194286418e-10,        -2.28934282804e-08,        -1.89158895377e-08, 
       -6.72268640472e-09,        -2.48998062198e-08,         4.79948920577e-09,         3.10375158695e-08,         1.77194169673e-08, 
       -3.27461093495e-08,         2.87291124640e-08,         1.81341906851e-08,        -2.57036574630e-08,         1.34667359216e-08, 
        1.50282473055e-08,        -1.80083366432e-08,         1.53807741706e-08,         8.50923569455e-09,         8.86580779537e-09, 
        5.84357892792e-09,         1.49568961283e-08,         3.13933300357e-10,        -1.62265639742e-09,        -2.71750283689e-10, 
       -4.74162485418e-09,        -1.54027414516e-09,         2.24627776389e-09,         3.94494521611e-10,        -8.65434389556e-10, 
        4.06876544197e-11,         9.49246337038e-12,        -2.78745762708e-12,         8.14659896763e-10,         1.37581908244e-10, 
       -6.67013079352e-10,         1.56043412131e-10,        -3.73668539490e-10,         2.91997675159e-10,         1.36693993016e-10, 
       -6.54604986830e-10,        -4.32787058746e-10,        -2.01900650248e-10,        -3.73732959376e-10,         1.17593236664e-09, 
        1.25019917856e-09,        -4.06772621813e-10,         2.62941827055e-11,        -5.01539023844e-09,         2.20264695507e-09, 
       -7.99873798337e-10,        -1.38864997977e-08,         1.89113029865e-08,        -4.92473759669e-09,         2.25495141463e-09, 
       -1.35202491794e-09,        -5.52433178573e-10,         4.56700535217e-10,        -1.08453563811e-09,         2.08149936094e-10, 
       -4.86562348007e-10, 
},
{
        1.59085456722e-09,         6.85654361068e-09,        -7.00213176823e-09,         2.79886914366e-09,         1.36185239856e-08, 
        4.24316810801e-09,         1.49823015248e-08,         1.51536368020e-09,         4.80800283884e-09,        -1.52852113046e-08, 
        6.74059315380e-09,         1.23818423361e-08,         7.62534791021e-09,        -1.29189255105e-08,         6.46776186884e-09, 
        5.58814345523e-09,         1.55272537517e-08,         9.48025159749e-09,        -1.54515305642e-08,        -1.91586342541e-08, 
        5.52510603346e-09,         3.89921759522e-08,         1.53884873748e-09,         9.70010840954e-09,        -2.58450974073e-09, 
        6.10659317534e-09,        -3.31863577927e-09,         2.69829689940e-08,        -5.18633689714e-09,         9.54655424483e-10, 
        1.10257212072e-09,        -1.07470301370e-08,        -9.24795507126e-09,         6.58015068292e-09,        -2.17176395097e-09, 
        4.58057899632e-11,        -5.89852579301e-10,        -1.08696369595e-09,         1.76961875507e-09,         5.17900582391e-10, 
       -1.75057287352e-10,         9.25197440469e-11,        -2.50129797052e-10,        -1.43863124411e-10,         6.48452762605e-10, 
        1.45821843504e-11,         5.08022663181e-11,         5.20944349354e-10,        -2.22466576817e-10,         1.63223932220e-10, 
       -2.20187746478e-10,        -5.59612363290e-10,        -1.09644198188e-09,        -5.74016479148e-10,        -7.05032877139e-10, 
        5.41139538173e-10,        -1.75672098198e-09,        -1.39148153573e-09,         3.56205131993e-09,        -2.28402116324e-09, 
       -2.11996734058e-09,         1.02158234487e-08,        -9.03145945015e-09,         6.74519699673e-09,         3.96553936564e-09, 
       -1.86201203791e-09,         1.73115198830e-09,        -1.12586930874e-09,         1.28015712134e-09,        -8.52016665284e-10, 
        5.40048216622e-10, 
},
{
        2.24175058608e-09,        -1.80048981260e-08,        -3.12262338200e-09,         1.09213638844e-08,        -2.34739424622e-09, 
       -3.62775941980e-09,        -4.72779164751e-09,        -7.66510607358e-09,        -7.45356749638e-09,        -5.54737271723e-09, 
       -1.76715282283e-08,         2.75602799923e-09,        -1.69571242151e-10,         1.83399878315e-08,         1.39575510189e-08, 
       -8.15182488640e-09,         1.93564815821e-08,         2.83230967494e-09,        -2.25648470537e-08,        -6.50553576800e-09, 
        2.58000298455e-08,        -3.08437147362e-08,        -2.52355002310e-08,         2.54847866850e-08,        -1.02547784600e-08, 
       -2.31156904634e-08,         1.80490908182e-08,        -2.07339288116e-08,        -1.07661683238e-08,        -3.01535335850e-09, 
       -7.68257372138e-09,        -1.48069892580e-08,         2.01027999042e-09,         9.99760108276e-10,         1.08354054196e-10, 
        6.14660785311e-09,         1.28564079633e-09,        -2.09336319693e-09,        -4.20298737144e-10,         4.25415144354e-10, 
        1.62528459950e-10,         2.90532826722e-10,         1.71910528123e-10,        -3.11025751145e-10,        -1.33103059435e-10, 
       -2.06229535968e-11,        -1.01864391838e-12,         1.83968184450e-10,         1.10503393703e-10,        -4.39744108374e-10, 
        3.62026687979e-10,         9.91374141987e-10,        -2.29073818924e-10,        -1.96476557739e-10,         7.12970504798e-10, 
       -1.13766011583e-11,        -4.20193970730e-10,         1.55084508263e-10,        -2.07311873846e-09,         4.97170801127e-09, 
       -1.43546676298e-09,        -2.83355589064e-09,        -1.10252637774e-08,         6.05940550331e-09,         3.99966738205e-09, 
       -3.01245801005e-09,         1.55767716903e-09,        -1.76576057070e-09,         3.24168922891e-10,        -8.31542602205e-10, 
       -2.66216857326e-10, 
},
{
        1.21344979026e-09,         1.68143601041e-09,         7.17496475619e-09,        -6.16676682096e-09,        -1.04790581097e-08, 
       -2.56884025730e-09,        -1.18466261093e-08,        -3.15812555176e-09,        -3.91966926052e-09,         1.98141486988e-08, 
        1.38635734908e-09,        -1.72189441012e-08,         1.21817663345e-09,         1.20962952507e-08,        -1.44544310671e-08, 
       -2.77157289913e-09,        -1.75345910354e-08,        -5.18677919528e-09,         1.96931354877e-08,         2.73445632999e-08, 
       -1.34090850563e-08,        -2.91542768122e-08,         3.47163703476e-09,        -1.81277447713e-08,         2.57977232786e-09, 
        1.21386503899e-09,         6.03819112764e-09,        -1.88672498499e-08,         1.37103726997e-08,        -6.05432824782e-10, 
       -2.47228554945e-09,         1.51962491621e-08,         1.28967139517e-08,        -7.79862332166e-09,         3.72113464741e-09, 
       -5.38537837973e-11,        -1.03429249993e-09,         1.21836002449e-09,        -1.72650481394e-09,        -6.69140718344e-10, 
       -5.92693703795e-11,        -3.48986528238e-10,         1.82729205358e-10,         3.35052327159e-11,        -3.17087715155e-10, 
       -3.18884567204e-11,        -1.74124747914e-10,         1.60221499212e-11,         2.19818583586e-10,        -3.08005487788e-10, 
       -1.03924693386e-09,         3.57735906206e-10,         6.24759383836e-10,         2.58905514291e-11,        -3.33189198035e-11, 
        1.43853723366e-09,        -1.18717189407e-09,        -1.16785259494e-09,         1.30875298480e-09,        -3.78313075871e-10, 
       -1.78834939405e-10,         3.24780504992e-09,         1.24913737581e-09,        -5.81598399155e-09,        -5.59411857348e-09, 
        3.64395539681e-09,        -9.24453436136e-09,         4.47771250493e-09,        -3.05561484511e-09,         1.53031532077e-09, 
       -9.51455754573e-10, 
},
{
       -1.61257071335e-09,         1.68031788414e-08,        -1.43997406035e-09,        -6.83561667038e-09,         6.15771494785e-09, 
        1.84940649677e-09,         5.49679635644e-09,         6.20449352999e-09,         8.77780225000e-09,         1.91932825931e-09, 
        2.04574128095e-08,         5.19466027259e-09,        -1.88619886636e-09,        -1.31444429831e-08,        -5.85108099202e-09, 
        2.09595981294e-08,        -1.83338336882e-08,        -1.60809659162e-08,         1.19420715359e-08,        -7.60290585686e-09, 
       -1.97440959288e-08,         2.65440680521e-08,         2.62764003085e-08,        -1.76095202898e-08,         7.69655874383e-09, 
        2.17420856840e-08,        -1.59211533715e-08,         2.10941126151e-08,         1.00347683971e-08,        -2.82700831911e-09, 
        9.79010172615e-09,         1.32374028962e-08,        -6.53911495403e-09,        -6.71157080417e-10,         6.27463962363e-10, 
       -8.41681000768e-09,        -6.50691861698e-10,         1.80206276690e-09,         3.28044031100e-10,         1.26977268325e-10, 
       -2.54312208966e-11,        -2.56570788259e-10,        -3.16186003614e-10,         3.13409798507e-10,        -1.39154279098e-10, 
       -9.91205300457e-11,         7.97413093587e-11,         3.18151554298e-11,        -8.67175546766e-12,         1.29389498219e-10, 
       -3.82517042874e-10,        -6.96497252306e-10,        -1.08737728177e-10,         1.95151740370e-10,        -2.53439925487e-11, 
        2.73172720705e-10,         5.09532834145e-10,         1.93167149595e-10,        -1.38705464346e-09,         2.14706830868e-09, 
       -7.75118796324e-10,        -7.08477809193e-10,        -5.26704198158e-09,         7.86915905747e-10,        -7.75139277566e-10, 
       -1.20771857120e-08,         1.10859044541e-08,        -3.95758423759e-09,         1.34095213821e-09,        -1.34774070616e-09, 
       -7.61028957422e-10, 
},
{
       -2.96330186809e-09,        -8.71149348588e-09,        -4.60581541687e-09,         7.40575286139e-09,         7.44427299195e-09, 
        1.32944756262e-09,         6.87892449696e-09,         5.15044360164e-09,         1.90289786864e-09,        -2.11902568522e-08, 
       -1.05243784571e-08,         1.30339553907e-08,        -9.66749886830e-09,        -1.51416397807e-08,         1.49339683264e-08, 
       -6.82997662729e-09,         1.75555049363e-08,         9.59735518941e-09,        -1.58346427741e-08,        -2.76563449765e-08, 
        1.50880592410e-08,         2.39022843994e-08,        -7.37257898393e-09,         2.22732746313e-08,        -1.17540644799e-09, 
       -7.53547384971e-09,        -6.64423555359e-09,         9.12090678773e-09,        -2.09321921609e-08,         1.70475472984e-10, 
        3.79115400196e-09,        -1.88788984892e-08,        -1.43560043433e-08,         8.65768583432e-09,        -5.99190485019e-09, 
        8.17674867883e-10,         2.73534197941e-09,        -1.25076986525e-09,         1.67202914589e-09,         5.38584710639e-10, 
        7.28488991987e-11,         5.00399117393e-10,        -1.32050184562e-10,         5.70007114236e-11,         4.50980702398e-10, 
       -1.56092855782e-10,         1.35047155440e-10,         1.07981501130e-10,         2.27727777403e-10,         1.57523084783e-10, 
        1.57627629059e-11,        -3.91971581800e-11,        -3.59534418376e-10,        -2.24171747145e-10,        -3.51830575481e-10, 
       -3.94769416474e-12,        -6.98182270206e-10,        -6.24143725439e-10,         2.24921539767e-10,         4.58873858784e-11, 
       -4.27906778891e-10,         4.31613914969e-10,         3.72857523939e-10,        -1.25973273764e-09,        -1.69208698001e-09, 
        2.33635314165e-09,        -4.42170646311e-09,        -6.19241416117e-09,         9.57410804045e-09,        -1.33994837833e-09, 
        2.88559203153e-09, 
},
{
        2.21550985669e-09,        -1.08761816211e-08,         3.99558715112e-09,         2.80967719716e-09,        -8.07395617813e-09, 
        4.11836655926e-10,        -5.55902337458e-09,        -7.54663094226e-09,        -8.54155684450e-09,         2.14224952506e-09, 
       -1.50822754051e-08,        -9.30776848934e-09,         5.22644258492e-09,         1.06959375179e-08,         1.26727744506e-10, 
       -2.46734591905e-08,         2.19813202139e-08,         2.64661896592e-08,        -5.22296293593e-09,         2.01841811322e-08, 
        1.72582868296e-08,        -2.00405571642e-08,        -2.11365797124e-08,         6.41809565115e-09,        -6.96084052606e-09, 
       -1.38132027540e-08,         1.25764147746e-08,        -1.73410662925e-08,        -5.68224389296e-09,         7.98392406763e-09, 
       -1.16472489045e-08,        -1.04992999450e-08,         1.16960724160e-08,         9.97517270904e-10,        -1.22590003544e-09, 
        1.11175301645e-08,        -1.73197435760e-10,        -1.82655975945e-09,        -2.85372103230e-11,        -5.80272816411e-10, 
       -1.51859295715e-10,         1.78144573239e-10,         3.29967634362e-10,        -3.37955219608e-10,         9.36559133320e-11, 
        2.33806363781e-10,        -1.51548821385e-10,         4.81759953479e-11,        -1.72420290404e-10,         9.47514511758e-11, 
        1.41313143488e-10,         2.31219324962e-10,        -9.80104226215e-12,         1.32559055195e-10,         1.32926417186e-10, 
       -1.26521232005e-10,         8.61719149356e-11,        -9.48465985425e-11,        -5.77480997781e-10,         7.10513625031e-10, 
        3.33751162131e-10,         2.25371668939e-10,        -2.00075224075e-09,         1.73726953932e-11,        -9.63102951506e-10, 
        8.84973354032e-10,        -6.33880206612e-09,         1.19509756676e-08,        -1.23867938181e-08,        -1.75986333183e-10, 
        1.84540681643e-10, 
},
{
        2.20442379643e-09,         1.06093937266e-08,         5.81796543037e-10,        -6.60337505868e-09,        -3.59769155787e-09, 
       -7.55323791305e-10,        -2.54234204970e-09,        -5.10796215516e-09,        -7.35791508185e-10,         2.02470561513e-08, 
        1.53105079460e-08,        -3.72826745422e-09,         1.53145652375e-08,         1.91950503512e-08,        -1.10427184949e-08, 
        1.50966245383e-08,        -1.90346122846e-08,        -2.18266453303e-08,         8.61634959673e-09,         2.09670477211e-08, 
       -1.37921382065e-08,        -2.42891321570e-08,         7.73130482497e-09,        -2.18363474252e-08,        -2.26257052459e-09, 
        1.08690160771e-08,         5.53484955795e-09,        -2.99714708994e-10,         2.40946929088e-08,        -1.33983112472e-10, 
       -4.28574475422e-09,         2.14242335876e-08,         1.30684968748e-08,        -9.90857264266e-09,         8.67733041238e-09, 
       -2.35733305812e-09,        -4.63161788342e-09,         1.29473183636e-09,        -1.89553669618e-09,        -4.59427030149e-10, 
        2.42144507923e-10,        -4.16586371567e-10,         5.38525815614e-11,         5.06420740293e-11,        -4.40904585190e-10, 
       -3.55439652437e-11,         7.16666210844e-11,        -7.43945978181e-11,        -4.48707161615e-14,        -3.89688215573e-10, 
       -1.06242523918e-10,         2.58081212737e-10,         2.52957727574e-10,        -1.12206058665e-10,         1.25359001376e-10, 
        4.65196191034e-10,        -3.84400493669e-10,        -6.94703241869e-12,         1.75765649012e-11,         3.03025174825e-10, 
       -2.82783049945e-10,         4.01315468369e-10,         4.12953298196e-10,         1.37755017855e-10,         5.35879583749e-10, 
       -8.89554972906e-10,         1.41230617370e-09,         2.88496074264e-09,        -2.02211120012e-09,        -2.92678679069e-09, 
       -1.32779519370e-09, 
},
{
       -1.69569410995e-09,         3.77467926402e-09,        -4.40886381673e-09,         5.56561236783e-12,         8.04130055199e-09, 
       -1.90922413675e-09,         4.18907340180e-09,         9.74986312086e-09,         7.18728523315e-09,        -5.73698783796e-09, 
        6.06903756728e-09,         7.70692837255e-09,        -8.92450330286e-09,        -1.20579461837e-08,         1.26981560245e-09, 
        1.99690369449e-08,        -2.63673049887e-08,        -2.75950087868e-08,         4.74665266398e-09,        -2.81816047823e-08, 
       -1.85668098120e-08,         1.56223186060e-08,         1.28147211368e-08,         3.34653784487e-09,         8.79001162101e-09, 
        4.50962616109e-09,        -9.56902172086e-09,         1.14759498363e-08,        -8.18718838424e-10,        -1.14394926675e-08, 
        1.23760861896e-08,         6.59916767131e-09,        -1.58790837950e-08,        -1.32687746449e-09,         1.11379702979e-09, 
       -1.37354625393e-08,         1.17885842231e-09,         2.28721038519e-09,        -3.20208571924e-10,         1.04170297942e-09, 
        1.74197420838e-10,        -1.96936677639e-10,        -2.94873231363e-10,         3.00772971236e-10,         7.16908377668e-11, 
       -2.13019149835e-10,         4.71796946470e-12,         6.73287421264e-11,         9.47282497585e-11,         1.13969785333e-11, 
       -4.95692387042e-10,        -2.10176301163e-10,         2.43056656361e-10,         2.10050730783e-10,        -1.63920325709e-10, 
        1.78416340149e-10,         2.59832317274e-10,        -8.67728743695e-11,        -1.90486726272e-10,         5.11031840045e-10, 
        2.07429494545e-10,         6.01916895915e-11,        -4.51043991631e-10,        -2.84725619369e-10,        -9.00425677585e-10, 
        1.75637381929e-09,        -3.05343133956e-09,        -1.13949038607e-09,         8.67471841981e-09,        -1.20836362716e-09, 
       -5.82228201413e-09, 
},
{
       -4.34132009302e-10,        -7.75087414667e-09,         3.01558977171e-09,         4.71154415918e-09,        -7.49216376905e-10, 
        1.00803559832e-09,         6.80502757781e-10,         2.50968615141e-09,         7.14673791173e-10,        -1.78834414010e-08, 
       -1.38544814310e-08,        -4.40014569836e-09,        -1.75390888813e-08,        -2.10958577770e-08,         7.38357845578e-09, 
       -1.72079653582e-08,         2.34071727534e-08,         3.55064969669e-08,        -3.12925741902e-09,        -1.09886854618e-08, 
        1.32228680167e-08,         2.79905923067e-08,        -3.42423512307e-09,         1.89423576650e-08,         6.58278299345e-09, 
       -1.08357346680e-08,        -3.15797692173e-09,        -5.73724002933e-09,        -2.24237395776e-08,         1.17095687862e-09, 
        3.75272223363e-09,        -2.21189349932e-08,        -9.53898222289e-09,         1.14738610249e-08,        -1.08852230671e-08, 
        4.51323937412e-09,         6.82128992015e-09,        -1.67701269395e-09,         2.40414388291e-09,         6.07774899516e-10, 
       -6.60019627118e-10,         2.99040532453e-10,        -3.14559979196e-11,        -1.63470895581e-10,         2.87515654594e-10, 
        1.57999301195e-10,        -6.51836138921e-11,         9.33740041861e-11,         1.35397279380e-12,         3.63241143567e-10, 
        9.72202754669e-12,        -2.95205422364e-10,        -4.00353827993e-10,         8.22864495969e-11,        -7.72712046552e-11, 
       -1.61785125842e-10,        -5.45149880852e-11,        -1.14869657613e-10,        -2.35508461951e-10,        -4.36494291268e-11, 
        8.89943225886e-11,        -1.75440273458e-10,        -3.12772031677e-10,         5.01611321824e-10,         2.89832673869e-10, 
       -1.26304954251e-09,         9.96948042221e-10,         1.64595272692e-09,        -1.73160029442e-09,         2.54702483266e-09, 
       -7.50678984290e-10, 
},
} ;

gal_gm_t gal_gmglgm1 = {
GAL_SSB_MO,
"GLGM-1",
4.9028026273352e+12,
1.7380e+06,
70,
70,
1,
(double *) &gal_gmglgm1_terms
} ;

__END_DECLS  
  
#endif /* !_GAL_GMGLGM1_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
