/*  
 *  - - - - - - - - - - - - - - 
 *   g a l _ g m g l g m 2 . h  
 *  - - - - - - - - - - - - - - 
 *  
 *  This file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This file defines the external variables for the GLGM-2 Lunar gravity model.
 *  
 *  Status: 
 *  
 *     Support file gravity model sub-system  
 *
 *  Defines:  
 *
 *     gal_gmglgm2    gal_gm_t      GLGM-2 gravity model structure
 *
 *  Notes:  
 *
 *  1) The field was derived using the 1992 IAU Model for the Moon.
 *     Note that the reference for this model has typographical errors for two of
 *     the quantities describing the angular librations.
 * 
 *  2) Report of the IAU/IAG/COSPAR Working Group on Cartographic
 *     Coordinates and Rotational Elements of the Planets and Satellites
 *     1991, by M E Davies, V K Abalakin, A. Brahic, M. Bursa, B H Chovitz,
 *     J H Lieske, P K Seidelmann, A T Sinclair, and Y S Tjuflin,
 *     Cel. Mechanics and Dynamical Astronomy, 53, 377-397, 1992.
 * 
 *     Table II lists the IAU model for the orientation for the lunar pole
 *     and prime meridian.
 * 
 *     The quantities which read E3 = 260.008 - 13.012001*d
 * 	            E5 = 357.529 -  0.985600*d
 *     should instead read   E3 = 260.008 + 13.012001*d
 *              E5 = 357.529 +  0.985600*d
 * 
 *  3) The Reference radius for this model is 1738.0 km.
 * 
 *  4) The following list gives the Planet GM in meters**3/seconds**2,
 *     and the Spherical Harmonic Coefficients (GCOEFC for the C terms
 *     and GCOEFS for the S terms).  All the C and S terms are normalized.
 * 
 *  5) LUNAR GRAVITY MODEL,  70x70 lgm0309a (1995), GLGM-2: gm=4902.80295 ;dgm = .00224
 *
 *  References:	
 *
 *     J. Geophys. Res, GLGM-2, A 70th Degree and Order Lunar Gravity 
 *     Model from Clementine and Historical Data, Submitted, November 1995.
 *     by F. G. Lemoine, D. E. Smith, M.T. Zuber, G. A. Neumann, and D. D. Rowlands.
 *				
 *     High Degree and Order Spherical Harmonic Models for the Moon
 *     from Clementine and Historic S-Band Doppler Data, 1995 XXI
 *     General Assembly, IUGG, Boulder, Colorado, July 12, 1995.
 *     by F. G. Lemoine, D. E. Smith, M. T. Zuber, and G. A. Neumann.
 * 
 *  This revision:  
 * 
 *     2008 September 20 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_GMGLGM2_H_  
#define _GAL_GMGLGM2_H_ 1  

#include "gal_gm.h"
#include "gal_const.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

double gal_gmglgm2_terms[71][71] = {
{
                    0e+00,                     0e+00,         9.86743378399e-08,         5.13243605486e-06,         1.33451819207e-06, 
       -4.42787205061e-06,        -2.94952849013e-06,         2.61997039665e-07,         1.51869440033e-06,         8.72824063578e-07, 
       -2.58986017284e-07,         8.05335393073e-07,         1.81524590410e-06,        -3.81813940597e-07,        -1.01487892351e-06, 
        6.59995428577e-08,         5.93852530821e-07,        -1.08906191899e-07,         1.30349509491e-07,        -1.22099266610e-07, 
       -4.62020237765e-07,         2.59183392304e-07,         3.39066830632e-07,        -3.67805131169e-07,        -3.65142755162e-08, 
        2.85383103153e-07,        -1.95188404523e-07,        -1.22714043295e-07,         2.51585813967e-07,        -2.34525822515e-08, 
       -1.87337112332e-07,         8.61774190741e-08,         9.87443791310e-08,        -7.97072244271e-08,        -4.78682346907e-08, 
        4.91148110103e-08,         3.76795841442e-08,        -2.96673044163e-08,        -3.98410890124e-08,         2.74826089568e-08, 
        3.03748405933e-08,        -3.02071314851e-08,        -7.54005074376e-09,         2.64152669822e-08,        -1.46208387836e-08, 
       -1.57565857389e-08,         2.31015723640e-08,         5.94684025880e-09,        -1.65097609815e-08,        -3.60714078864e-09, 
        3.44749074336e-09,         8.58500690876e-09,         6.19035179209e-09,        -1.52310159326e-08,        -8.30661456314e-09, 
        1.77616847231e-08,         5.41480307051e-09,        -1.44535584725e-08,        -2.54720123832e-09,         7.84806950720e-09, 
        2.75057185291e-09,        -1.88789459343e-09,        -5.50624858418e-09,        -1.09163595421e-09,         8.24332093389e-09, 
        1.35526199786e-09,        -8.85234106254e-09,        -6.78146729798e-10,         7.07940443625e-09,         6.01130205365e-10, 
       -4.17582824976e-09, 
},
{
                    0e+00,                     0e+00,        -6.43069492547e-08,         4.84975411610e-06,        -6.11981534584e-06, 
        1.35513945731e-06,        -1.87767277439e-06,         2.68902745406e-06,         1.27646452754e-06,        -1.75924924406e-06, 
       -1.20306682174e-06,        -2.69307050789e-06,         6.75216072175e-07,        -3.32197218659e-07,         1.33271552356e-07, 
        4.56925439155e-07,         3.95069517803e-07,        -5.04260612352e-07,        -9.05555086554e-08,         2.02181794693e-07, 
        1.27091744770e-08,        -3.89536320970e-08,         6.59372410511e-10,        -1.43459873951e-07,         1.78015724182e-07, 
        1.50183296244e-07,        -3.65981262599e-07,        -4.77493100358e-08,         4.25423088815e-07,        -8.96610007890e-08, 
       -3.27055635942e-07,         1.59166454439e-07,         1.51533465255e-07,        -1.42979246130e-07,        -1.31864762456e-08, 
        7.75150542782e-08,        -3.29652125929e-08,        -1.87862948259e-08,         6.05933516163e-09,        -4.62816145984e-09, 
        3.67406126200e-08,        -8.33833325743e-10,        -5.30359184945e-08,         1.05490254344e-08,         3.79702782179e-08, 
       -7.33580925916e-09,        -1.34899665513e-08,        -7.67274322146e-09,         1.77759834243e-09,         2.16649290309e-08, 
       -7.78696716025e-09,        -2.41922027945e-08,         2.05302819043e-08,         1.54077176491e-08,        -2.63004334271e-08, 
       -3.78798035882e-09,         2.01160457305e-08,        -2.12064176357e-09,        -7.24802974139e-09,         1.49100701065e-11, 
       -3.46585444783e-09,         6.08511699786e-09,         7.10277606614e-09,        -1.04253040081e-08,        -5.05781761914e-09, 
        1.01234103828e-08,         2.03457987639e-09,        -6.38205435480e-09,        -1.48459937969e-09,         2.36601903865e-09, 
        3.41038031307e-09, 
},
{
       -9.12253528209e-05,        -1.82240528303e-07,         3.44344414316e-05,        -1.93716576925e-06,        -1.35021727446e-05, 
        8.61861247337e-06,        -3.83541279004e-06,         2.38285407909e-06,         5.87478102993e-07,         1.83802276926e-06, 
        1.27230999930e-06,         4.52371542090e-07,        -2.80439356937e-06,        -6.69356216529e-07,         6.37209384553e-07, 
        5.29447478797e-07,         2.43128123092e-07,        -1.41926633573e-07,        -1.01258878338e-07,         5.35007783419e-07, 
       -2.74244664387e-07,        -6.31835013008e-07,         7.46838595023e-07,         5.72704513588e-07,        -8.42239718097e-07, 
       -2.82301865563e-07,         6.29118655233e-07,         1.34381715789e-09,        -2.99364817654e-07,         1.49198648786e-07, 
        6.80475693698e-08,        -1.47996569246e-07,         8.18370936057e-09,         7.41261049480e-08,         1.49030574321e-08, 
       -1.14028939680e-08,        -5.22347254154e-08,        -7.66903594368e-09,         5.88268883568e-08,        -4.39153442571e-10, 
       -4.03308248353e-08,         5.95239574199e-09,         2.40818752722e-08,         3.21923551722e-09,        -2.72127681690e-08, 
       -1.76269694641e-08,         4.47895297559e-08,         2.15452694107e-08,        -5.98760018842e-08,        -9.55368502211e-09, 
        5.99015360643e-08,        -9.93927685858e-09,        -4.52906670645e-08,         2.34738693224e-08,         2.61073503596e-08, 
       -2.36883024209e-08,        -1.26662041863e-08,         1.34436595153e-08,         8.51935676362e-09,        -1.44730361354e-09, 
       -1.01505434721e-08,        -5.27413515542e-09,         1.16531613122e-08,         5.64533661772e-09,        -9.64063520892e-09, 
       -3.28301001546e-09,         4.83171936614e-09,         2.19937263177e-09,        -1.57587337077e-10,        -3.57052065221e-09, 
       -2.19753736871e-09, 
},
{
       -3.77939697352e-06,         2.61915153494e-05,         1.43057885073e-05,         1.25935654319e-05,         4.37262677981e-06, 
       -7.30823169690e-08,        -4.23417476295e-06,         1.30070562025e-06,        -1.21841445262e-06,        -1.10134181280e-06, 
        1.57744068463e-06,         1.82810693991e-06,         5.12642939508e-07,        -1.13080657635e-06,        -2.09047351059e-06, 
       -1.57987969072e-06,        -8.21683239361e-08,         1.51394647514e-06,         7.18581708438e-07,        -1.36835081357e-06, 
       -4.38501751185e-07,         8.33851664309e-07,         1.39387576177e-07,        -2.97456565332e-07,         4.32251277109e-08, 
       -8.11459048792e-09,         3.47405780087e-08,         6.18422101880e-08,        -1.46152876979e-07,         4.28834106206e-08, 
        1.94417255152e-07,        -1.54736900497e-07,        -1.44068036768e-07,         1.94735698651e-07,         6.89824313998e-08, 
       -1.61156084627e-07,        -3.08133643001e-08,         1.02824475347e-07,         4.55467491922e-08,        -6.36581060995e-08, 
       -8.14485839696e-08,         5.51748749279e-08,         1.01239035837e-07,        -6.06145809478e-08,        -9.10752309710e-08, 
        5.86858399402e-08,         6.40863315467e-08,        -4.20146830053e-08,        -4.17733200850e-08,         1.88439914056e-08, 
        3.50086108433e-08,        -2.00248009629e-09,        -3.87801873428e-08,        -2.58455421269e-09,         4.07282315311e-08, 
       -1.11773709177e-09,        -3.29260571457e-08,         4.72258669111e-09,         1.70332323344e-08,        -2.88266735626e-09, 
       -7.60701519892e-10,        -3.49520531529e-09,        -9.27717070412e-09,         9.60830998233e-09,         1.19409947629e-08, 
       -1.14465553080e-08,        -1.06818728660e-08,         8.65677745129e-09,         9.57044621210e-09,        -3.90932973518e-09, 
       -1.01292610182e-08, 
},
{
        3.11112907684e-06,        -5.72303554125e-06,        -6.81619538984e-06,        -1.40064423773e-06,        -6.49828295587e-06, 
       -3.26284491225e-06,        -1.00841388475e-05,         1.58503903212e-06,         2.28960089967e-06,        -3.06520199402e-06, 
       -9.87999085470e-07,         2.04926002029e-06,         8.18258443705e-07,         5.18506538237e-07,        -1.18334410103e-07, 
       -9.70755240115e-07,        -5.40979024943e-07,        -1.02198150810e-06,         4.06399883742e-07,         7.12202637361e-07, 
       -5.11600547248e-09,        -4.91037691490e-07,        -4.17323452928e-07,         4.51036605303e-08,         5.59762991636e-07, 
        1.46229306624e-07,        -4.53533642595e-07,        -2.03460708347e-07,         2.22020545556e-07,         1.80227450659e-07, 
       -2.87611384920e-08,        -1.49756751855e-07,        -4.98335575825e-08,         1.29082201263e-07,         3.80221709193e-08, 
       -1.09862576703e-07,        -2.01070682125e-09,         8.56366106610e-08,        -7.51892091222e-09,        -5.98488654507e-08, 
       -1.52648736984e-08,         4.15239512299e-08,         4.66125880762e-08,        -3.33014438613e-08,        -6.12251094460e-08, 
        2.99437564035e-08,         5.21991718323e-08,        -2.35528115805e-08,        -3.02586120329e-08,         1.10927690575e-08, 
        1.09092915645e-08,         3.69198805146e-09,        -2.16748522942e-09,        -1.41285600262e-08,         1.70738679395e-09, 
        1.62997745345e-08,        -2.34507563750e-09,        -1.15685119208e-08,        -7.00338441879e-10,         4.68187440086e-09, 
        6.71939786507e-09,         1.91027150739e-10,        -1.16351111692e-08,        -2.01873799093e-09,         1.22069973952e-08, 
        2.48342201365e-09,        -8.50925769256e-09,        -3.64981708181e-09,         3.23865601938e-09,         6.01809440947e-09, 
        7.96539201855e-10, 
},
{
       -3.63618554613e-07,        -1.31754076117e-06,         3.96665747937e-06,        -4.50495273691e-07,         2.97233919665e-06, 
        3.69497496672e-06,         7.69194948228e-06,         8.62856415928e-07,        -2.70355566466e-06,        -2.58161233490e-06, 
       -2.32325985580e-06,        -1.14536258382e-06,         7.80555969278e-07,         1.38453087581e-06,         1.86877542315e-06, 
        3.28903389513e-08,        -1.15323551436e-06,        -9.12908645441e-07,         2.86178605267e-07,         4.74575505972e-07, 
       -3.81328431035e-08,        -3.31063101586e-07,        -1.57048164608e-07,         1.46118107134e-07,         4.89174538699e-08, 
       -1.69233421648e-07,         4.01262067590e-08,         1.68084368315e-07,        -1.35245982395e-07,        -1.66699204912e-07, 
        1.69865856876e-07,         1.09621031980e-07,        -1.71818857551e-07,        -3.31224342173e-08,         1.46196226340e-07, 
       -3.66112007743e-08,        -1.11984740260e-07,         7.46047157313e-08,         7.87510000050e-08,        -8.19109140968e-08, 
       -5.37422093325e-08,         7.23611760781e-08,         3.72725390800e-08,        -6.09256754269e-08,        -2.58146246046e-08, 
        5.43401304081e-08,         1.57187266653e-08,        -5.13121565186e-08,        -6.15034153070e-09,         4.79046368316e-08, 
       -1.23264685214e-09,        -4.23347864064e-08,         4.71962559650e-09,         3.58910133056e-08,        -4.51882505211e-09, 
       -3.06479512674e-08,         2.67341320645e-09,         2.70943468313e-08,        -1.33255888021e-09,        -2.37937760520e-08, 
        1.17139155458e-09,         1.89565839948e-08,        -1.25749553818e-09,        -1.21537593429e-08,         2.53397692953e-10, 
        4.68491413353e-09,         2.24591921754e-09,         1.49319524047e-09,        -5.33393084893e-09,        -5.18699041848e-09, 
        7.52001531985e-09, 
},
{
        3.94555398815e-06,         1.97408921936e-06,        -4.23264260849e-06,        -2.95363112702e-06,         1.25983657031e-06, 
        1.36249095808e-06,        -5.23706709573e-06,        -2.10578976419e-06,         3.37180237659e-06,         3.69386590615e-07, 
       -1.59851964850e-06,        -2.86242487920e-06,        -1.33769946851e-06,        -6.71639961824e-07,         7.86359537906e-07, 
        1.80233223103e-06,        -1.92643142616e-07,        -1.31156322082e-06,        -7.73256609654e-08,         4.88303409234e-07, 
       -4.61163045183e-07,         5.85796730968e-07,         2.99651833544e-07,        -9.05291747800e-07,        -3.77547625233e-08, 
        7.16807305553e-07,        -1.84896963277e-07,        -3.12271783608e-07,         2.30558852705e-07,         1.48870020095e-08, 
       -1.64375121522e-07,         7.02019926474e-08,         7.18254941678e-08,        -2.08196665043e-08,        -2.09398063141e-08, 
       -5.60894424744e-08,         1.76529114747e-08,         9.14166030602e-08,        -3.83034553895e-08,        -8.29916922709e-08, 
        5.62688567995e-08,         5.60562603043e-08,        -6.18589477095e-08,        -3.38841010458e-08,         5.73741914998e-08, 
        2.14004454190e-08,        -4.79045588017e-08,        -1.31377609205e-08,         3.56443699019e-08,         4.39821121653e-09, 
       -2.13481957873e-08,         3.65183761981e-09,         7.29524735625e-09,        -7.57209881274e-09,         2.46872867085e-09, 
        6.77220832443e-09,        -4.96776465867e-09,        -4.68221744290e-09,         8.95524645109e-10,         5.46123083785e-09, 
        5.72994853990e-09,        -1.02068835806e-08,        -1.05581276172e-08,         1.62368085612e-08,         1.18467539698e-08, 
       -1.96689553153e-08,        -1.09960226706e-08,         1.86266631927e-08,         1.06228462407e-08,        -1.43446414510e-08, 
       -1.21165337681e-08, 
},
{
        6.40420831081e-06,         7.67978860395e-06,        -1.39668593413e-06,         4.09047354853e-07,        -1.03103965984e-06, 
       -1.20571997679e-06,        -1.02746944981e-06,        -1.39340328516e-06,         2.65815924901e-06,        -2.11442635194e-06, 
        2.31145155260e-06,         3.29098389274e-07,        -2.36854058216e-06,        -1.58666383523e-06,         5.38125501132e-07, 
        1.47666903236e-06,         1.89365998950e-07,        -6.59152571203e-07,         2.61282451465e-08,         6.17320634550e-07, 
        1.79382355900e-07,         5.36390160566e-08,        -2.95875321492e-08,        -3.04807301805e-07,         1.44979476316e-07, 
        4.81878457069e-07,        -1.35222158910e-07,        -3.47011959774e-07,         1.35793040257e-07,         1.59730194649e-07, 
       -7.54034372130e-08,         3.71170320301e-08,         3.64838561107e-08,        -1.53786059893e-07,        -2.80889481787e-08, 
        2.01347901166e-07,         3.90253860391e-08,        -1.95924848643e-07,        -3.63715086215e-08,         1.60761699358e-07, 
        9.41724990449e-09,        -1.07676282075e-07,         2.61724131133e-08,         4.84625562719e-08,        -4.44177594204e-08, 
        1.13702885712e-09,         3.20671184379e-08,        -2.62699711574e-08,         1.36836762706e-09,         2.26209436532e-08, 
       -3.30647197872e-08,        -2.88332613372e-10,         4.48215460611e-08,        -2.27086295046e-08,        -3.49109083878e-08, 
        3.21170170132e-08,         1.59741944937e-08,        -2.54653376841e-08,        -3.27458627053e-09,         1.09792429612e-08, 
        3.62791055615e-09,         4.09727180733e-10,        -1.28207098537e-08,        -3.14522305222e-09,         2.14276335796e-08, 
       -5.14182278377e-10,        -2.29155844146e-08,         4.20990496642e-09,         1.76281386875e-08,        -3.29713922106e-09, 
       -1.07331927394e-08, 
},
{
        2.58622330507e-06,        -3.21207284866e-07,         3.05223379083e-06,        -1.38268368353e-06,         3.52864223577e-06, 
       -1.28381087027e-06,        -6.02870465997e-07,        -1.36717830282e-06,        -2.90832070040e-06,         1.98626530827e-06, 
       -2.86837547346e-07,         5.11488392620e-07,         3.12366873953e-07,         1.03750706261e-06,        -7.23093780107e-07, 
       -1.17796440639e-06,         3.41749794276e-07,         1.01238642011e-06,        -2.68700403965e-07,        -3.79848860651e-07, 
        1.90052421140e-07,        -9.76194775640e-08,         2.99252643107e-07,         2.74536358272e-07,        -2.78330870625e-07, 
       -2.24830502591e-07,         2.09255365068e-07,         1.27902511980e-07,        -3.84782909315e-08,        -4.01511181096e-08, 
       -5.58365665045e-08,         3.10595319250e-08,         8.84423520611e-08,        -3.61558423763e-08,        -5.58577131561e-08, 
        3.09581595246e-08,         1.14979785627e-08,         2.46936618913e-09,         1.65945240839e-08,        -4.03678980407e-08, 
       -1.60826539369e-08,         5.93006706452e-08,         2.19086941403e-10,        -4.84440610740e-08,         1.31281629787e-08, 
        1.93491784996e-08,        -1.32808616194e-08,         8.06292454580e-09,         2.50507684950e-09,        -2.01884521653e-08, 
        9.77511800691e-09,         1.73339903746e-08,        -1.56458730298e-08,        -9.09328753490e-09,         1.39102717578e-08, 
        4.64402918990e-09,        -8.81756429566e-09,        -6.27134173980e-09,         5.17195071356e-09,         1.01488848313e-08, 
       -4.51951894913e-09,        -1.16309919110e-08,         5.10202080625e-09,         9.59489227710e-09,        -4.58647624537e-09, 
       -6.55468309756e-09,         2.55493294213e-09,         5.52475096158e-09,        -6.42314647147e-10,        -7.07317553309e-09, 
        6.70627049542e-10, 
},
{
       -2.05442497698e-06,         2.51603364952e-06,         2.20871793036e-06,        -1.47945069566e-06,        -2.52837257364e-06, 
       -1.76697484584e-06,        -1.79025055934e-06,        -4.58700724332e-06,        -1.39787167313e-06,        -6.02691221749e-07, 
       -1.38486746033e-06,         6.06068703094e-08,        -1.15606815403e-06,         1.17582066304e-06,        -2.18909696934e-07, 
       -4.19495054914e-07,         1.48232741146e-07,        -2.37887378210e-07,        -4.08407495187e-07,        -1.60533695335e-07, 
        7.66015774812e-11,         1.43720315719e-07,         1.32746742105e-07,        -2.79581018250e-07,        -4.05530438077e-07, 
        3.27503776310e-07,         3.83439476066e-07,        -3.67239328424e-07,        -2.56044864126e-07,         3.41517204662e-07, 
        2.86668444483e-09,        -2.89760334363e-07,         2.06160381004e-07,         2.03009125458e-07,        -2.95146950115e-07, 
       -1.05805395520e-07,         2.48360852170e-07,         2.70681790073e-08,        -1.28698472107e-07,         1.00808275170e-08, 
        1.48676178896e-08,        -3.67346352791e-09,         4.39275920152e-08,        -2.61101252534e-08,        -4.61013327111e-08, 
        5.32336214725e-08,         2.20476262669e-08,        -6.15636404008e-08,        -3.58507906871e-09,         5.19813450940e-08, 
        3.52025661022e-09,        -3.57678090244e-08,        -1.43494288634e-08,         2.34699057563e-08,         2.13958933513e-08, 
       -1.78048270380e-08,        -1.65356318483e-08,         1.48113618990e-08,         2.80196637155e-09,        -9.70459986509e-09, 
        1.07727577127e-08,         1.58558018149e-09,        -1.73661397382e-08,         6.47041587975e-09,         1.67005692279e-08, 
       -1.07678342879e-08,        -1.33466130203e-08,         1.01905691315e-08,         1.19273365962e-08,        -6.66150777217e-09, 
       -1.36605345830e-08, 
},
{
       -2.42114840885e-07,        -5.14019261109e-07,         5.18885416978e-07,        -5.02808583352e-09,        -4.17314771481e-06, 
        9.88529664981e-07,         4.54684972814e-07,        -4.32903153170e-06,        -3.05870619354e-06,        -5.04120352646e-06, 
        7.37466561810e-07,        -1.90279535794e-06,        -4.46227225340e-07,        -1.09981556412e-08,         1.19122229350e-06, 
       -4.30281229787e-07,         1.25605170872e-06,        -3.44512106509e-07,        -9.29831357158e-07,        -4.16744761393e-07, 
        1.02335975373e-06,        -2.70845248997e-07,        -4.18443480376e-07,         1.24084691723e-07,        -6.59510181537e-11, 
       -4.54002507377e-08,         1.89447729962e-07,        -1.84291934537e-07,        -1.09447818115e-07,         1.92279309087e-07, 
       -6.61724723144e-08,        -1.01999076114e-07,         1.75700931387e-07,        -5.73194405477e-08,        -1.64878186411e-07, 
        1.59400133040e-07,         7.15656558289e-08,        -1.77226006121e-07,         2.39117787037e-08,         1.26646976162e-07, 
       -7.11252583145e-08,        -6.26817425874e-08,         6.69551481120e-08,         2.46667572121e-08,        -4.04511081384e-08, 
       -2.17583929133e-08,         2.06468092743e-08,         3.68157923532e-08,        -1.78197670282e-08,        -4.77789925755e-08, 
        2.42564780241e-08,         4.38115883240e-08,        -2.71644869971e-08,        -2.85878639932e-08,         2.04369163324e-08, 
        1.25679774071e-08,        -7.44658348135e-09,        -3.28711484832e-09,        -4.11739007906e-09,         9.01343971743e-10, 
        9.09990713689e-09,        -4.07061289730e-10,        -7.92395028910e-09,        -3.04737105359e-09,         4.75732634466e-09, 
        1.04569469297e-08,        -3.49918564377e-09,        -1.90676337864e-08,         5.06339688832e-09,         2.52097206390e-08, 
       -7.54037729864e-09, 
},
{
       -4.64909026845e-07,         2.25119202775e-07,         2.47492797103e-06,         7.30461120904e-07,        -1.01048322545e-06, 
        7.12083318513e-07,         8.05242095166e-07,        -2.76121966112e-07,        -1.89568325107e-06,        -2.81158621831e-06, 
       -4.09862651032e-06,        -2.83821095276e-06,         1.12121095608e-06,        -1.56587024557e-06,         1.66877614261e-08, 
       -1.33727199467e-07,        -2.80435114904e-08,        -2.66200429342e-08,         6.65884964131e-07,        -1.49621238807e-07, 
       -8.79793189228e-07,         4.27087463361e-07,         9.09940212963e-08,        -3.81403584001e-07,         2.65215357196e-07, 
        1.46624912111e-07,        -3.32540568469e-07,         7.13436595092e-08,         1.47647452277e-07,        -1.43296038895e-07, 
        4.19702528499e-08,         1.14079429075e-07,        -1.35044082090e-07,        -7.55389436268e-08,         1.33715753591e-07, 
        7.72296304618e-08,        -9.86642837837e-08,        -9.96559196453e-08,         6.95647862575e-08,         1.02532301455e-07, 
       -5.11484788161e-08,        -7.05114295791e-08,         2.79825003363e-08,         2.16049026087e-08,         6.23791086143e-09, 
        1.39736550945e-08,        -4.09958972393e-08,        -2.03829363992e-08,         5.90864449462e-08,         4.79499160083e-09, 
       -5.30389676316e-08,         1.27196273917e-08,         3.08175626543e-08,        -1.65546177717e-08,        -8.58434298751e-09, 
        5.43466544393e-09,        -1.72346206177e-09,         1.03310046108e-08,        -5.16005252805e-10,        -1.91943559041e-08, 
        6.92338026725e-09,         1.69558292892e-08,        -8.26358740735e-09,        -7.94019069654e-09,         1.31555244633e-09, 
       -2.27244564114e-10,         1.01512404076e-08,         2.88890729681e-09,        -1.96662743528e-08,        -8.95759697970e-10, 
        2.33337139627e-08, 
},
{
       -1.16274972432e-06,        -1.34120717523e-06,        -2.31686614739e-07,        -6.39964033500e-07,         3.42203886448e-07, 
        1.08348694649e-07,         4.33629050336e-07,         1.54045001314e-06,         4.94509088155e-07,        -1.29156468800e-06, 
       -2.67057854934e-06,        -1.51354827343e-06,         5.01462873463e-07,        -2.45572481675e-06,        -9.39299060865e-07, 
       -7.23058003113e-08,        -1.87308262593e-07,         1.43822855775e-07,        -6.71599474659e-08,         1.27452883283e-06, 
        2.08453269254e-07,        -2.66789415736e-07,         3.09782270789e-07,         5.66946861130e-08,        -4.52467153881e-07, 
        2.35756600422e-07,         4.55898550221e-07,        -1.34887357738e-07,        -3.41873261853e-07,        -4.90986547789e-09, 
        2.84906602083e-07,         1.17081257505e-07,        -2.12122146691e-07,        -1.07779575851e-07,         1.13031006220e-07, 
        4.49494362568e-08,         1.81754277904e-08,         1.19411354496e-08,        -1.26562883437e-07,        -2.72649850900e-08, 
        1.75970472438e-07,         1.26933577074e-08,        -1.62635884737e-07,         5.84526187648e-09,         1.16084864705e-07, 
       -1.22863563801e-08,        -6.97411822614e-08,         9.02473180418e-09,         4.07281118586e-08,        -6.41368311639e-09, 
       -2.62684093752e-08,         9.89798122169e-09,         1.51011500070e-08,        -1.59515359963e-08,        -4.27305040689e-10, 
        1.75344305446e-08,        -1.55024236275e-08,        -1.16599291353e-08,         2.59223779865e-08,         2.01459717269e-09, 
       -2.68789012633e-08,         4.59561121763e-09,         2.06468464134e-08,        -3.94685338344e-09,        -1.34152777951e-08, 
       -2.71291898072e-09,         1.02813391741e-08,         1.03483917334e-08,        -1.19701729491e-08,        -1.43067891543e-08, 
        1.53820868705e-08, 
},
{
       -1.38912069530e-07,         8.37933375488e-07,        -1.28415968925e-06,         1.29475945905e-07,         1.32592953954e-06, 
       -7.48432691390e-07,        -3.05237274026e-07,        -2.10466519827e-07,         2.34680636200e-07,        -6.57101713326e-09, 
       -7.12866700120e-07,        -1.50409091323e-06,        -2.40179313166e-07,         2.10769529972e-06,         8.98382107227e-07, 
        5.27707765025e-07,         1.65010065209e-07,         2.32125897883e-08,        -8.15596990776e-07,         3.88342227420e-07, 
        3.00980169662e-07,         1.50407459434e-07,         4.96473189174e-07,        -3.79734214487e-07,        -4.64836654513e-07, 
        6.44779433206e-07,         3.08826215311e-07,        -6.98235748502e-07,        -8.71072446541e-08,         5.55228686542e-07, 
        1.34008606943e-08,        -3.05128856199e-07,        -5.06996466503e-08,         8.48482481522e-08,         1.34082766456e-07, 
        3.18926778297e-08,        -1.69659996897e-07,        -4.34148868000e-08,         1.31815401152e-07,        -1.56072499859e-09, 
       -4.73001051120e-08,         4.76513604859e-08,        -2.96046167954e-08,        -6.35695273355e-08,         6.22569643708e-08, 
        4.93458522195e-08,        -4.84517718251e-08,        -2.37663197079e-08,         1.39029109638e-08,         5.30649193124e-09, 
        1.16836669579e-08,        -1.42940690410e-10,        -1.39894747206e-08,         2.38988510240e-09,        -1.21159597559e-09, 
       -2.75794638226e-09,         1.75839766326e-08,        -2.91054435432e-09,        -2.20124758674e-08,         1.13354293238e-08, 
        1.27822459067e-08,        -1.59168904380e-08,         1.83260164608e-09,         1.27385344498e-08,        -1.13362069843e-08, 
       -3.53245142350e-09,         1.05173497978e-08,        -6.09987944343e-09,        -1.76517802985e-09,         1.10816533911e-08, 
       -8.17089814937e-09, 
},
{
        3.66106718940e-07,         9.81039551499e-07,        -7.98360646159e-08,        -7.61659005361e-07,        -4.04614233788e-07, 
       -1.01029223161e-06,        -1.87034932650e-06,        -4.26964214114e-07,         8.30933166583e-07,         9.87359036145e-10, 
       -9.55434467225e-07,        -2.01158416268e-06,        -1.36567916072e-06,        -4.11012692873e-07,        -9.95923031514e-08, 
        8.66453492245e-07,        -1.22270591318e-06,        -1.35663943904e-09,        -4.77950172677e-07,        -6.59020400247e-07, 
        6.84049865150e-08,        -3.74087035561e-08,        -2.39724263000e-07,         1.73309337259e-07,        -1.98818679875e-08, 
       -2.36463326605e-07,         1.54864016869e-08,         1.20575091424e-08,         4.96812338350e-08,         8.37483936874e-08, 
       -9.75924363292e-08,        -1.61686658526e-07,         1.74733424478e-08,         2.15669535344e-07,         1.11280890207e-07, 
       -2.89436688248e-07,        -2.06833363015e-07,         3.39465108966e-07,         2.00903576974e-07,        -3.28221968149e-07, 
       -1.12445592106e-07,         2.39309494116e-07,         1.54083394047e-10,        -1.03164301530e-07,         7.39595084972e-08, 
       -2.61282215455e-08,        -8.45771108082e-08,         1.01648190459e-07,         4.69131801455e-08,        -1.09079717772e-07, 
        1.25011542282e-09,         6.89701952042e-08,        -2.72083458865e-08,        -1.93233152919e-08,         2.11404545770e-08, 
       -8.52913225461e-09,         3.79615007194e-09,         5.37922009418e-09,        -2.54827376242e-08,         1.63844097147e-08, 
        2.92891002803e-08,        -3.57919644035e-08,        -1.60319770849e-08,         3.84798151339e-08,        -1.91046947537e-09, 
       -2.43500489207e-08,         1.13641235699e-08,         4.52122032714e-09,        -7.45948197704e-09,         8.27232487333e-09, 
       -4.69908700716e-09, 
},
{
        3.11425907628e-08,        -9.44574909191e-07,         6.99727106315e-07,        -1.36019536974e-07,        -1.15465280277e-06, 
       -2.05191760429e-07,        -7.31607824651e-07,         1.33828032363e-06,         8.75364199001e-07,        -1.79216538225e-07, 
       -4.45228945579e-07,        -1.13581888417e-06,        -1.46875761530e-06,        -1.97142078056e-07,         9.05313023860e-07, 
       -6.60781269128e-08,        -9.19255005838e-07,        -2.01315685395e-08,        -9.71947263373e-07,         7.88364859957e-08, 
        2.25617544894e-07,        -2.22264097952e-07,         2.60555078201e-07,         2.63700983764e-07,        -4.27733399638e-07, 
       -1.97956688989e-07,         4.21814010005e-07,        -1.26264205911e-09,        -2.99545689939e-07,         1.97313395898e-07, 
        6.88570989546e-08,        -2.75716178837e-07,         1.23932791065e-07,         2.64958414582e-07,        -2.14577374873e-07, 
       -2.42722084027e-07,         2.19742836209e-07,         2.34530879743e-07,        -1.93452700477e-07,        -2.24048539491e-07, 
        1.68489780951e-07,         1.76623205726e-07,        -1.45949819972e-07,        -9.30148914571e-08,         1.13489294896e-07, 
        6.11525019372e-09,        -6.91031209736e-08,         4.44171796046e-08,         2.65721151732e-08,        -4.35171269708e-08, 
       -3.66349988687e-09,         7.72459927625e-09,         6.57077929812e-09,         3.01461349060e-08,        -2.49825776121e-08, 
       -4.46809180699e-08,         4.01044677885e-08,         3.17787697677e-08,        -3.80034260467e-08,        -6.00886177832e-09, 
        1.79499626662e-08,        -1.31609229777e-08,         9.18049000066e-09,         1.48915367879e-08,        -2.96351767729e-08, 
       -1.73314693056e-09,         3.56666193652e-08,        -1.52348613121e-08,        -2.89030557057e-08,         2.54176124649e-08, 
        1.72663598098e-08, 
},
{
        3.69032499220e-07,         2.10252366085e-07,         8.39451439224e-07,        -8.23198805738e-07,         7.82470611901e-07, 
        9.75774061752e-07,         4.14931455796e-07,        -1.93223255014e-07,         2.68734195684e-07,        -5.16659516276e-07, 
        1.86522482886e-07,         2.96345031264e-07,        -1.49962095886e-06,        -4.66732516348e-07,        -1.06461615811e-06, 
       -5.87470214956e-07,        -2.02115636162e-07,         1.57659306461e-06,        -4.26350743484e-07,        -1.09311153985e-06, 
       -7.91358869871e-07,         5.09055669546e-07,        -1.40945384633e-07,        -2.70608265085e-07,         1.91205205361e-07, 
       -2.67299283254e-07,        -2.93101070003e-07,         4.05050685124e-07,        -1.12842987012e-08,        -3.20481181024e-07, 
        8.61824084225e-08,         1.38388445315e-07,        -5.08974360258e-08,        -3.29760717702e-08,        -6.05040875352e-08, 
        3.09326875199e-08,         1.30732266438e-07,        -6.80741655291e-08,        -1.43457130701e-07,         7.96800774187e-08, 
        1.24790409572e-07,        -4.67951519505e-08,        -1.11118468203e-07,        -5.48471615453e-09,         1.12072977722e-07, 
        4.40186852684e-08,        -1.15031728540e-07,        -5.26925787405e-08,         1.05168733509e-07,         3.75171953011e-08, 
       -7.99101210023e-08,        -1.43005200101e-08,         4.85534024005e-08,        -4.39255544249e-09,        -2.21628761849e-08, 
        1.43110601549e-08,         5.29450115831e-09,        -1.67995805310e-08,         4.68856667339e-09,         1.41952966562e-08, 
       -1.25749754272e-08,        -7.82524131434e-09,         2.04291110223e-08,        -1.14918853626e-09,        -2.66983338813e-08, 
        1.05699505433e-08,         2.88401434614e-08,        -1.76830824039e-08,        -2.62402062553e-08,         2.07647659820e-08, 
        2.08429838806e-08, 
},
{
       -5.54559945549e-07,         9.64623121715e-07,        -2.55904913701e-07,         5.65918868665e-07,         1.02677850221e-06, 
       -7.67941728450e-09,         1.96687054935e-07,        -1.33158342607e-06,        -4.00697091527e-07,         3.77397230401e-07, 
        5.28736005114e-07,         1.00522656583e-06,         2.27640129364e-07,         9.71458188922e-08,         6.87522776454e-07, 
        4.55096016870e-07,         1.24137579671e-07,        -1.01043594904e-06,        -4.40854669277e-07,        -4.53120462649e-07, 
       -3.53055488860e-07,        -7.54246952147e-07,         4.14158484143e-07,         7.12024547502e-08,        -4.01535112871e-07, 
        1.66732967375e-07,         2.29185838821e-08,        -2.36854065666e-07,         1.94351582729e-07,         1.41288610372e-08, 
       -1.55690800976e-07,         5.50561624750e-08,         6.20009986936e-08,        -5.20413338137e-08,        -6.20374694526e-09, 
        1.29102985775e-08,         1.48316994264e-08,         3.28670923778e-09,        -4.78834193363e-08,         1.02905461487e-08, 
        6.60473090963e-08,        -3.45612873991e-08,        -5.86993138951e-08,         5.02665966144e-08,         3.66303769834e-08, 
       -5.02629473643e-08,        -1.61827654788e-08,         3.93168109757e-08,         5.27184592607e-09,        -2.54475768621e-08, 
       -2.90870452100e-09,         1.42897325469e-08,         4.11229482359e-09,        -7.50239441612e-09,        -4.99591126875e-09, 
        4.51113339547e-09,         4.24843251073e-09,        -4.07551106166e-09,        -2.27155005524e-09,         4.80223820516e-09, 
       -7.46369220073e-11,        -5.17823516057e-09,         1.92762886760e-09,         3.99061744167e-09,        -2.47739097388e-09, 
       -1.03731689004e-09,         1.21417613339e-09,        -2.62761061473e-09,         1.64108471284e-09,         5.36865117543e-09, 
       -5.04437004793e-09, 
},
{
       -4.63480844436e-07,         6.37156922673e-08,        -8.36413545501e-07,         1.55428731137e-07,        -6.20287123366e-07, 
       -7.40153307856e-08,        -9.64033343873e-07,        -1.10515506606e-08,         1.96077587846e-07,         7.79528929753e-07, 
        1.83208128738e-07,        -1.09931761361e-08,         6.73611561707e-07,        -8.11536037782e-07,         8.92240238608e-09, 
       -2.92978528049e-08,         4.47712630547e-07,         8.66432279245e-07,         2.75046882768e-07,         4.43419108259e-07, 
        1.01280889070e-06,         1.01929947870e-07,         3.69916270039e-07,        -5.15073255423e-08,        -1.54032318410e-07, 
        1.29319458069e-07,         1.96053007732e-07,        -1.81947473300e-07,         1.17551378616e-08,         1.52913028818e-07, 
       -4.57950621642e-08,        -8.09769981420e-08,         5.08636189554e-08,         4.06515472799e-08,        -1.04513205144e-08, 
       -2.12080687689e-08,        -1.16658559280e-08,         2.24679843003e-08,         2.44678591450e-08,        -1.38563688964e-08, 
       -2.21116193350e-08,        -1.37436765140e-08,         1.25769455063e-08,         5.95350452021e-08,        -4.98448095534e-09, 
       -1.06092810372e-07,         9.25714844445e-09,         1.33229003201e-07,        -2.78579412058e-08,        -1.27837101993e-07, 
        5.20486910843e-08,         9.17635433529e-08,        -6.73089752327e-08,        -4.06829118935e-08,         6.27668978213e-08, 
       -3.94433000315e-09,        -3.87300480133e-08,         2.58069557149e-08,         6.46407637554e-09,        -2.12376337316e-08, 
        1.87865251614e-08,        -5.49243816862e-10,        -2.67753616398e-08,         2.39526011068e-08,         1.73845523363e-08, 
       -3.59240725713e-08,         6.72602121060e-10,         3.21339969898e-08,        -1.60028078171e-08,        -1.74288470923e-08, 
        2.12088403521e-08, 
},
{
        2.86365582813e-07,        -4.27597820972e-07,         5.37184940905e-07,        -5.92105557060e-07,        -3.20991471733e-07, 
       -2.39401868927e-07,        -6.85195593716e-08,         8.98135949262e-07,         8.79476295352e-07,         3.19159440241e-07, 
       -8.71600423129e-07,        -6.69020149464e-08,         2.61923258321e-07,         5.85893197526e-07,        -3.55408814916e-07, 
        1.80880524531e-07,         2.53269229139e-07,        -7.93073292214e-07,         1.24491143825e-06,         2.91447243695e-07, 
       -3.50211945180e-07,         1.72315060538e-06,        -2.95362025564e-07,         5.36449771515e-07,        -2.90110318312e-07, 
       -3.52894600301e-07,         3.26149537139e-07,        -6.11312912965e-08,        -2.26730882507e-07,         1.39295255449e-07, 
        5.19456224577e-08,        -9.14692991525e-08,        -5.99427005408e-09,        -1.37759787327e-09,         2.55560365231e-08, 
        9.98873182391e-09,        -4.77363860159e-08,         3.41191664164e-09,         7.03582692160e-08,        -1.61433304859e-08, 
       -8.51652425215e-08,         9.33059474145e-09,         1.03830932917e-07,         1.17317167525e-09,        -1.18279561542e-07, 
       -6.98110451912e-09,         1.22686039650e-07,         6.19736273440e-09,        -1.12581915506e-07,        -3.93422762216e-09, 
        9.11187203827e-08,         3.17328548493e-09,        -6.49276524276e-08,        -3.85115017738e-09,         4.11444859638e-08, 
        4.64998828838e-09,        -2.47838616325e-08,        -5.14975250584e-09,         1.78822749847e-08,         5.50202889023e-09, 
       -1.93462263515e-08,        -5.26104723535e-09,         2.53794282482e-08,         3.28546696391e-09,        -3.08960921289e-08, 
        1.05609684973e-09,         3.17923779559e-08,        -6.78596728637e-09,        -2.69707240469e-08,         1.16639968277e-08, 
        1.86831637791e-08, 
},
{
        2.26931185803e-07,        -2.28840089254e-07,         7.12364369193e-07,        -2.11654412670e-07,         4.09612375051e-07, 
        1.15529786801e-07,         1.62963476477e-07,        -3.71662575494e-07,         2.02552743834e-07,        -5.28388358389e-07, 
        1.24561920754e-07,         5.75239484954e-08,         9.79495915358e-08,         5.63379259769e-07,         7.51052112097e-08, 
        2.28748330344e-07,         8.14156232774e-07,         4.16133703079e-07,         6.12768206347e-07,        -2.82696005310e-07, 
       -1.11423671190e-07,         2.38672846361e-07,         3.08340581087e-07,         2.17398558188e-07,        -2.14250228121e-07, 
        6.59461725153e-08,        -9.20737819253e-09,        -1.96694015317e-09,        -2.11522243203e-07,         7.63017585485e-08, 
        2.76505724629e-08,        -4.55319866675e-08,         3.47506558043e-08,        -3.17686952739e-08,        -7.90925676849e-08, 
        6.59655328091e-08,         3.56786661768e-08,        -5.62039789825e-08,         7.87246116623e-10,         1.81949001930e-08, 
       -2.36214490173e-08,         2.33459831009e-08,         3.44423160366e-08,        -6.33613363635e-08,        -4.98037136631e-08, 
        1.02166015526e-07,         6.82074263271e-08,        -1.39945957067e-07,        -7.85041723425e-08,         1.68325585258e-07, 
        7.00379347510e-08,        -1.77117481318e-07,        -4.25146441071e-08,         1.60558088396e-07,         6.21905178851e-09, 
       -1.22325234290e-07,         2.46475978216e-08,         7.42298492040e-08,        -3.94277588112e-08,        -3.14158368294e-08, 
        3.55844698288e-08,         6.09538020092e-09,        -1.89720655918e-08,        -2.87216757695e-09,         4.71011226640e-10, 
        1.72572507364e-08,         9.49854538172e-09,        -3.80725078846e-08,        -6.08132859012e-09,         5.28621023219e-08, 
       -7.81702641666e-09, 
},
{
       -1.49440245887e-07,        -1.62457720133e-08,        -5.73781359505e-07,         4.85924065177e-07,        -1.28285415544e-07, 
        2.84043062684e-07,        -2.25646252454e-07,        -3.79176800574e-07,        -8.14847402480e-07,        -3.58927038196e-07, 
        5.83850971076e-07,         5.74017854499e-08,         3.85864400349e-08,        -2.74951562458e-07,         8.76151977337e-08, 
       -3.04153369448e-07,         4.32046582795e-07,         9.21300590184e-07,         1.19521238058e-07,         1.79637171313e-06, 
       -2.21043423495e-07,        -2.62788336251e-08,         8.44919939563e-07,        -4.27968781689e-07,         3.90257988212e-07, 
       -3.10116433135e-07,         1.46491287913e-07,         3.76207625621e-07,        -2.08643037643e-07,        -1.31572286570e-07, 
        2.36694103253e-07,        -5.54219673080e-08,        -9.64308829898e-09,         4.90210547336e-08,        -9.31369712355e-08, 
        2.83268420713e-08,         8.28121424650e-08,        -7.67257200258e-08,        -4.00620833238e-08,         7.48301560870e-08, 
        1.95461718662e-08,        -5.12189390724e-08,        -2.56040201892e-08,         3.18670381962e-08,         3.31246426245e-08, 
       -1.95619141833e-08,        -3.09922902398e-08,         3.96907855470e-09,         2.10415576806e-08,         1.99094773822e-08, 
       -1.44718025314e-08,        -4.69200275897e-08,         1.73983146683e-08,         6.63230066904e-08,        -2.85770069793e-08, 
       -7.02275364198e-08,         4.15342788843e-08,         5.80850409000e-08,        -4.97847314063e-08,        -3.59528926646e-08, 
        4.97953630951e-08,         1.26886619399e-08,        -4.18602095255e-08,         3.93629126789e-09,         2.93544710510e-08, 
       -9.82537050062e-09,        -1.72690439179e-08,         5.51092314475e-09,         1.02203860465e-08,         4.52115867136e-09, 
       -1.03608951826e-08, 
},
{
       -2.53906864097e-09,         2.78204897726e-07,        -4.91950512705e-07,         1.67813112717e-08,        -3.39966155039e-08, 
        4.00785715066e-08,        -1.07063014481e-07,         9.16892742069e-08,         2.44354084188e-08,         7.01783145950e-07, 
        3.55640128034e-09,        -2.15861685586e-07,        -6.37616267912e-07,        -2.32006058759e-07,        -5.43571526161e-07, 
       -3.80673198924e-07,        -4.90138947391e-07,        -7.76572138254e-08,         3.97207267105e-07,        -5.34410554109e-07, 
        3.49782278028e-07,        -4.56615066412e-07,        -3.44507244025e-07,        -1.27643325982e-07,        -4.64015839736e-07, 
       -1.09136279262e-07,        -1.96717966030e-07,        -4.51633710091e-08,         2.99671131893e-07,        -6.42496996854e-08, 
       -8.36528274602e-08,         1.62048710078e-07,        -4.29477017641e-09,         2.98185014658e-08,        -8.25967610673e-09, 
       -4.96818200467e-08,         7.69611890579e-08,         1.84375291871e-09,        -6.22958117345e-08,         4.81804110430e-08, 
        2.30695859522e-08,        -5.19940982663e-08,         1.46342746564e-08,         3.48919445164e-08,        -2.40780427354e-08, 
       -2.07275469956e-08,         2.02654156113e-08,         1.36730905718e-08,        -1.46347147640e-08,        -5.07969480852e-09, 
        1.05810240037e-08,        -1.01570293004e-08,        -3.43356317850e-09,         2.67088161163e-08,        -8.63943127036e-09, 
       -3.53008973552e-08,         2.15087664843e-08,         3.14689114885e-08,        -2.84857074008e-08,        -1.89105822670e-08, 
        2.61627772903e-08,         5.86878076862e-09,        -1.68554012581e-08,         8.20762208644e-10,         6.50264810173e-09, 
        5.42269036690e-10,        -5.34700008080e-10,        -6.84637282554e-09,         8.97968621024e-10,         1.31367631399e-08, 
       -5.79392853936e-09, 
},
{
       -2.69247867036e-08,         1.55383152487e-07,         5.53300111954e-07,        -2.25364615336e-07,         3.24885590689e-07, 
       -3.14971090874e-07,         2.50463958541e-07,        -1.05047893716e-08,         6.81162816260e-07,         4.62280447605e-07, 
       -3.85295968443e-07,         1.43055205451e-07,        -3.89803682472e-10,        -9.23779643964e-09,         3.58607251516e-07, 
        8.30388376966e-08,        -1.16324101714e-08,        -5.82171305907e-07,         4.61613620137e-08,         1.18612800318e-07, 
       -4.52841602833e-08,        -4.47699604077e-07,        -6.23655164494e-07,        -3.67365706672e-07,        -6.53781702314e-07, 
        1.37214668536e-07,        -1.84220718099e-07,        -9.38527898790e-08,        -1.05954808778e-07,         1.50430500247e-07, 
       -8.24556223962e-11,        -5.71564525008e-08,         6.52414530027e-08,         3.32122575576e-08,        -1.92924310300e-09, 
       -1.47179540275e-08,        -5.36610298340e-09,         2.63587587474e-08,         2.10868187285e-09,        -1.87442261804e-08, 
       -1.50018287257e-09,         1.56312434225e-08,         1.43294976145e-08,        -1.82446026180e-08,        -2.32096888897e-08, 
        2.93338163226e-08,         2.27345476931e-08,        -3.92054607436e-08,        -1.17015448554e-08,         4.27416307733e-08, 
       -5.25756986495e-09,        -3.79708388165e-08,         2.54025863581e-08,         2.55732276208e-08,        -4.53645390389e-08, 
       -6.88841178070e-09,         6.03050094778e-08,        -1.50250133811e-08,        -6.43061272000e-08,         3.46170527242e-08, 
        5.45431168326e-08,        -4.53161089710e-08,        -3.42823499658e-08,         4.30563936054e-08,         1.21967747472e-08, 
       -2.92060894656e-08,         2.19727275013e-09,         1.04197128558e-08,        -3.79369969820e-09,         4.76160057281e-09, 
       -5.61100338250e-09, 
},
{
       -2.59538577484e-08,        -9.64664465812e-08,         2.28995465881e-07,        -1.12270656437e-07,        -1.98206548469e-07, 
        7.11034492984e-08,         5.94276296360e-08,        -8.70176438780e-08,         2.63307723378e-08,        -4.13992415161e-07, 
        3.31271877097e-08,         1.56828726245e-07,         7.18758341924e-07,         6.12101769577e-08,         3.25162458330e-07, 
        1.57014238974e-07,         1.71613026095e-07,         3.10121963696e-07,        -4.91356068110e-07,         2.35024858538e-07, 
        3.06058380205e-08,         9.55852763702e-08,         1.01506699704e-07,         1.32094255502e-07,         5.20820262204e-07, 
        2.52755109148e-07,        -2.69174854545e-07,         5.10908558316e-07,        -3.12108047276e-07,         8.20731494832e-08, 
       -4.13533280256e-08,        -2.73780231746e-08,        -3.80941331894e-09,         4.10514196424e-08,        -2.12967263282e-08, 
       -2.35495777751e-08,         1.67679353228e-08,         1.21200602361e-08,        -2.20185426415e-08,         3.89631568083e-09, 
        4.67748752124e-09,        -2.29321870547e-09,         2.55579005686e-09,        -5.60600795665e-09,         2.60429611318e-09, 
        1.05319751550e-08,        -1.51030643067e-08,        -4.58245258233e-09,         2.38067474752e-08,        -7.29401787368e-09, 
       -2.39831656968e-08,         1.87444366257e-08,         1.76926247456e-08,        -2.56378169779e-08,        -9.45272099538e-09, 
        2.84353692269e-08,         2.35206575603e-09,        -2.92068813871e-08,         2.93580145117e-09,         2.93088104569e-08, 
       -6.69561805627e-09,        -2.84386793475e-08,         8.87363697911e-09,         2.57282436726e-08,        -8.88074824831e-09, 
       -2.11143243396e-08,         6.37305469117e-09,         1.58868808566e-08,        -1.98680288464e-09,        -1.20355272833e-08, 
       -2.64495810086e-09, 
},
{
        2.93316267569e-08,        -1.30952271788e-07,        -3.80427542658e-07,         2.05102984976e-08,        -2.94350288334e-07, 
        3.38199915968e-07,        -1.69749961951e-07,         5.59475053559e-08,        -4.17444205738e-07,        -1.26544578057e-07, 
        2.12924881258e-07,        -1.81211478706e-07,        -1.76686365004e-08,         1.42224615668e-07,        -3.69901716373e-07, 
       -1.27675438449e-07,        -4.58176881211e-08,         5.24468845340e-08,        -1.32301241613e-08,        -3.70184136268e-07, 
        1.36659986884e-08,        -1.01407156516e-07,        -1.13514245627e-07,         4.68706708066e-07,         5.98308214830e-07, 
       -4.85575443382e-08,         4.29341525636e-07,        -2.91291241440e-07,         5.82480969334e-07,        -1.91613799989e-07, 
        7.34101518403e-08,        -9.54063517967e-08,        -2.75706531678e-08,         6.48982696892e-08,        -2.58852490186e-09, 
       -1.98985258227e-08,        -1.96828226799e-08,         2.11857053379e-08,         1.03744288992e-08,        -9.37172550035e-09, 
       -4.18568063806e-09,        -8.08659883614e-09,         1.27131728452e-08,         1.82506056222e-08,        -2.44220614383e-08, 
       -1.49270432248e-08,         2.74497308829e-08,         1.38206658042e-08,        -2.20073742773e-08,        -2.19802907839e-08, 
        1.80990643690e-08,         3.63556606671e-08,        -2.10333278336e-08,        -4.69348563209e-08,         2.81915690951e-08, 
        4.79025808302e-08,        -3.34496733871e-08,        -4.01830638055e-08,         3.33995181057e-08,         2.86032947630e-08, 
       -2.90548003415e-08,        -1.74723906689e-08,         2.36247598947e-08,         8.84762258227e-09,        -1.94975283731e-08, 
       -3.20505857912e-09,         1.71635695426e-08,         5.35330071658e-10,        -1.59878319055e-08,        -5.65098285573e-10, 
        1.53917239190e-08, 
},
{
       -5.74947514085e-08,        -6.47481993291e-08,        -2.22191080290e-08,         1.54557814824e-07,         2.94085136244e-07, 
       -3.85366759891e-08,        -1.41533138172e-07,        -1.37431368323e-09,        -7.91702444511e-08,         2.96125118526e-07, 
        4.01432131639e-08,        -9.10450727350e-08,        -6.15225412560e-07,        -6.12813007243e-08,        -2.14573278391e-07, 
       -3.60991329720e-08,         1.89961480525e-08,        -1.11457439075e-07,         9.28476755064e-08,        -1.05509138552e-07, 
       -2.33245554027e-07,        -2.22609682330e-07,        -3.33362722839e-07,         6.54056738831e-08,        -2.00923783139e-07, 
        2.37429645641e-07,        -8.28172283789e-08,        -8.13017215275e-08,         1.88412173252e-07,         9.82195737565e-08, 
        2.57770125218e-08,        -2.43625170762e-08,        -7.51533410616e-08,         3.38724027394e-08,         3.41504316159e-08, 
       -2.10998130669e-08,         3.28526596930e-09,        -2.70229112538e-08,         2.79289033807e-08,         1.42510601363e-08, 
       -2.58640795320e-08,        -4.61933659135e-09,         1.41714612017e-08,         5.07425783069e-09,        -8.57169544663e-09, 
       -7.09264436980e-09,         1.40166573949e-08,         9.20259903466e-10,        -1.76766089701e-08,         8.77393190773e-09, 
        1.60036968318e-08,        -1.32129464824e-08,        -1.41458963002e-08,         1.07844568711e-08,         1.80199190070e-08, 
       -6.30232884134e-09,        -2.68990631916e-08,         4.64399703375e-09,         3.51046162423e-08,        -6.36377819366e-09, 
       -3.77868346485e-08,         8.98857215586e-09,         3.42069142721e-08,        -1.04338925380e-08,        -2.68117099807e-08, 
        1.07187774804e-08,         1.84427980610e-08,        -1.09140945122e-08,        -1.07420892340e-08,         1.13964319574e-08, 
        4.38342303629e-09, 
},
{
        5.59288060453e-08,         9.44848717219e-08,         1.45891965519e-07,         5.03390151264e-08,         1.55713568537e-07, 
       -3.23712018131e-07,         9.65738439690e-08,         2.29673864171e-08,         1.46298176988e-07,        -1.30469598464e-07, 
       -1.81723707417e-08,         1.56706999356e-07,         8.93900391908e-08,        -1.06249504034e-07,         2.97775987124e-07, 
        8.89973522737e-08,        -2.05056225742e-08,         1.15971691304e-07,         3.18807057885e-08,         1.79841583041e-07, 
        1.53594101191e-07,         1.62054756540e-08,         1.32939886354e-07,         1.06311091774e-08,         4.79878184799e-07, 
       -5.27942035644e-07,        -3.40705515758e-07,        -2.03407796332e-07,        -2.10285167303e-07,         2.61093588363e-07, 
       -2.13331533473e-07,         1.24554545646e-07,        -7.62152245158e-08,        -1.04849929730e-08,         4.31924270405e-08, 
        1.00178784557e-08,        -2.09145616063e-09,        -1.27091442920e-08,        -2.26199927797e-08,         4.68444303835e-08, 
        6.29889629471e-09,        -3.79725122749e-08,         1.87994055768e-09,         2.08791778886e-08,         1.29042848293e-09, 
       -1.22031636994e-08,        -5.05801104273e-09,         1.09679527149e-08,         2.76783395484e-09,        -8.64030531085e-09, 
        1.40499988221e-09,         3.34849915212e-09,        -3.36818162401e-09,         9.11768542180e-10,         4.85772965312e-09, 
       -2.73982156043e-09,        -9.39838099115e-09,         5.06001651207e-09,         1.73319799115e-08,        -1.14168371537e-08, 
       -2.48389014701e-08,         2.15162314700e-08,         2.74714319976e-08,        -3.12661973069e-08,        -2.36225220042e-08, 
        3.59333365011e-08,         1.50996168881e-08,        -3.32510686108e-08,        -5.30012102451e-09,         2.41769476145e-08, 
       -2.78663377862e-09, 
},
{
        1.15841750675e-07,         1.07355110982e-07,        -9.71864710052e-08,        -1.54965388610e-07,        -2.59050714221e-07, 
       -2.76819217046e-08,         1.79377585276e-07,        -2.39797408894e-08,         1.34627688462e-07,        -1.30039889311e-07, 
       -2.24889543010e-08,         3.46750766049e-08,         3.93204918072e-07,         8.25544871347e-08,         1.02423908197e-07, 
       -8.24969796078e-08,        -1.51241702357e-07,        -4.15859467363e-08,        -1.91623932810e-08,         2.00571570592e-08, 
        5.43782213236e-08,        -3.29826501337e-08,        -2.37911217021e-08,         2.93313622078e-07,         1.46431596016e-07, 
        4.51491496932e-07,         6.76929414547e-08,        -3.52788308066e-07,         5.66532429157e-08,         2.18051107258e-08, 
       -5.84471029457e-08,        -1.81588455230e-07,         1.46736165722e-07,        -7.18566904619e-08,        -5.47637504097e-10, 
        2.22197922260e-09,         1.82407464893e-08,         1.19943048279e-08,        -4.37686078123e-08,        -3.99402768232e-10, 
        3.36819942439e-08,        -4.47017874708e-09,        -1.93228020481e-08,         1.70012920268e-09,         7.99122269075e-09, 
        3.77911145591e-09,        -7.26630791343e-09,        -2.79309238011e-09,         4.74286708931e-09,         2.69783622414e-10, 
       -4.87505130627e-10,        -3.42217395027e-10,        -2.55469079747e-09,         3.12019776510e-09,         7.07141376317e-10, 
       -4.62117901875e-09,         4.52143161787e-09,         2.93630386269e-09,        -9.54681722970e-09,         5.23462391425e-10, 
        1.24077688028e-08,        -2.88285883965e-09,        -1.39404168807e-08,         2.96244269417e-09,         1.57063196161e-08, 
       -1.87809957821e-09,        -1.77711351473e-08,         1.38416635317e-09,         1.85381431966e-08,        -2.02439268826e-09, 
       -1.63731427736e-08, 
},
{
       -1.41610566866e-07,        -1.05628012678e-07,         6.02691888168e-08,        -4.21803938363e-08,        -2.84028382030e-08, 
        2.84683079393e-07,        -7.60898944554e-08,        -8.25557298877e-08,         1.19633237690e-08,         2.65963908774e-07, 
       -8.72121294753e-08,        -6.97068332864e-08,        -6.84293154148e-08,         1.12181010678e-08,        -1.97700795367e-07, 
       -7.08586751766e-08,         1.24659072746e-07,        -1.33424643780e-07,        -9.34701609587e-08,        -1.02043479980e-07, 
       -6.16346925940e-08,         3.56311138289e-08,        -3.05914881932e-07,        -1.01046859895e-07,         5.03851201357e-08, 
       -4.31438951571e-08,         3.73288354275e-08,         1.60378126024e-07,        -6.54051641519e-08,        -3.59459486287e-08, 
        5.36397156887e-07,        -3.41633309732e-08,         8.30385600267e-08,         1.79947413606e-07,         2.90757885430e-08, 
       -1.82405371817e-08,         8.51238388740e-11,         1.40292801996e-08,         2.11814576942e-08,        -3.89554419885e-08, 
       -2.16387103214e-09,         1.11111066302e-08,        -1.51489175685e-09,        -6.90951370881e-09,         6.89168196207e-11, 
        7.36592939252e-10,        -1.10642431943e-09,        -3.80700113501e-09,         5.17404379001e-09,         7.00389545071e-10, 
       -8.80439143700e-09,         2.30765784452e-09,         8.95892211518e-09,        -3.42392341245e-09,        -8.58408409459e-09, 
        1.19392019140e-09,         1.01390708029e-08,         8.95201160163e-10,        -1.35274256974e-08,        -1.32394955113e-10, 
        1.57340470286e-08,        -3.41743931934e-09,        -1.42638174247e-08,         7.25057882634e-09,         9.13985347918e-09, 
       -8.95913638032e-09,        -2.59194448395e-09,         7.82652641802e-09,        -2.84694583799e-09,        -4.63794220159e-09, 
        5.73974758025e-09, 
},
{
       -9.57246500303e-08,        -1.51823061201e-08,         1.35268083950e-07,         5.24089546676e-08,         1.51577837129e-07, 
        1.32517636085e-07,        -1.47159815411e-07,         2.92024608348e-08,        -1.48801250120e-07,         5.78727089523e-08, 
        5.15032502911e-08,        -9.84204857883e-09,        -2.05185589647e-07,        -4.60127971003e-08,        -6.91754474526e-08, 
        9.75943509045e-08,         1.65081146480e-07,         1.81740445861e-07,         1.99899786338e-08,        -2.81879277334e-08, 
       -4.09813388498e-08,        -6.58847025359e-08,         1.77125479766e-07,        -1.98564931831e-07,        -1.23937900662e-07, 
       -8.97860620101e-08,        -8.80429059972e-09,        -9.55555263034e-08,         7.02711594022e-08,         1.37909787516e-07, 
       -1.06772404441e-07,        -4.21916776651e-09,         2.05095096805e-08,         5.77146908785e-08,         8.86401576111e-08, 
        5.61452544399e-08,        -1.01474825611e-08,         1.76056799606e-08,         7.63135555510e-09,         2.97052241493e-08, 
       -1.08954429713e-08,        -1.34150005961e-08,         1.83111242326e-08,         4.46314857656e-09,        -6.95881153368e-09, 
        4.93074522745e-09,         5.79187787661e-10,        -2.85562969552e-09,         3.70645045253e-09,         7.09183153347e-10, 
       -3.81477903314e-09,         1.08122397864e-09,         3.80673942443e-09,        -2.88967531562e-09,        -3.08089304237e-09, 
        5.37594368505e-09,         1.76579088128e-09,        -8.01261633288e-09,        -2.40215552673e-10,         1.01607507750e-08, 
       -1.01352174630e-09,        -1.18895417776e-08,         2.31981758801e-09,         1.29297523373e-08,        -4.32265049486e-09, 
       -1.23613492001e-08,         6.88023263575e-09,         9.20706624408e-09,        -8.71604173579e-09,        -3.64944995622e-09, 
        8.18038764919e-09, 
},
{
        1.48197275124e-07,         1.26147330194e-07,        -1.64024803575e-07,         2.38753671975e-08,        -3.12851874132e-08, 
       -2.24107478111e-07,         9.52985600267e-08,         5.30402084666e-08,        -6.79967027351e-08,        -2.12946511750e-07, 
        9.02650867584e-08,        -2.43221532659e-08,         5.52698397209e-09,         6.45292035695e-08,         1.62136228598e-07, 
       -1.77450509977e-08,        -1.52853142129e-07,         1.37147188197e-07,         8.73786519593e-08,         4.36262726882e-08, 
        2.77992445844e-08,        -4.92655324077e-08,         2.74855057023e-08,         2.74191169672e-07,         3.52069424251e-08, 
       -2.89015307545e-08,        -8.31774889444e-08,         8.87388998440e-08,         4.63559476217e-08,        -4.03386359201e-09, 
        5.78320605313e-08,         9.24113087276e-08,         5.28748042462e-08,         7.84146140403e-09,        -4.21590586274e-08, 
       -5.45564240377e-08,        -3.42915668781e-08,        -5.49679851561e-09,        -2.91890204930e-09,        -7.18301582546e-09, 
        2.02434062978e-10,        -6.54554606280e-09,        -1.36682589869e-08,         1.85697088003e-08,        -1.53183125054e-10, 
       -6.68651307380e-09,         1.85204816491e-09,        -1.08747839223e-10,         3.47035043686e-09,         3.79827129328e-09, 
       -7.26193424390e-09,        -9.91319215056e-10,         6.98019296068e-09,        -4.80915777127e-10,        -4.36956722804e-09, 
        7.23386166406e-10,         2.84487468701e-09,        -1.50864431679e-10,        -2.54760104713e-09,         1.56161990501e-10, 
        2.91895716843e-09,        -7.81704508758e-10,        -3.30436455938e-09,         1.87556930089e-09,         3.59263759884e-09, 
       -3.27724043991e-09,        -3.59821250891e-09,         4.80411743743e-09,         3.10168330450e-09,        -6.05276645074e-09, 
       -2.09827182603e-09, 
},
{
        2.83143394886e-08,        -1.09164022052e-07,        -1.12254642034e-07,         7.47408632526e-08,        -4.25769444219e-08, 
       -1.86667932420e-07,         6.49937262608e-08,        -3.36212728132e-08,         1.34542237081e-07,        -3.01211789234e-08, 
       -7.78140413764e-08,        -1.23285043318e-08,         7.84633015910e-08,        -1.46429598300e-08,         2.33635941196e-08, 
       -7.02999798537e-08,        -1.64110232267e-07,        -2.22481098715e-07,        -2.92690235052e-09,         3.45559878177e-08, 
       -2.25649425571e-08,         4.14942123196e-08,        -1.39606701938e-07,         2.64175354503e-08,         1.24725905434e-07, 
        6.29237713443e-08,         4.93210277998e-08,        -1.13289842886e-07,         8.79638751610e-08,         7.07166459215e-08, 
       -1.39027456517e-07,         1.10951289917e-07,        -7.44283478126e-08,         2.35978656958e-07,         2.17489682980e-07, 
       -1.35723702217e-08,        -2.06886013361e-08,        -3.84356789991e-08,         2.50634436053e-08,         1.28714052013e-08, 
       -7.23542044201e-09,        -1.87072036572e-08,        -2.35201424708e-10,        -1.46547792542e-09,         8.86979544541e-09, 
       -2.27557751962e-09,        -6.55263803838e-09,        -1.25665372776e-09,         1.83487180270e-09,         5.43265452196e-09, 
       -1.17747089636e-09,        -7.42772486611e-09,         2.18674789791e-09,         4.78025707857e-09,        -2.04088370409e-09, 
       -5.12990798197e-10,        -5.47036102706e-11,        -3.22408743804e-09,         2.47086521234e-09,         6.33572907037e-09, 
       -4.24076534363e-09,        -9.63514154626e-09,         5.58235092544e-09,         1.34472594502e-08,        -7.28566064851e-09, 
       -1.71576953693e-08,         9.79251892747e-09,         1.97579116673e-08,        -1.29389255290e-08,        -2.03282754811e-08, 
        1.61006461163e-08, 
},
{
       -8.44760742311e-08,        -1.13576227855e-07,         1.63378124961e-07,        -3.26939983762e-08,         1.62143357440e-08, 
        1.67727867426e-07,        -1.09527016164e-07,         2.01358704078e-08,         4.49864109298e-08,         8.22604431016e-08, 
        2.06239451668e-08,         1.04720631336e-07,         4.37074640533e-08,        -8.66566004655e-08,        -1.27500576996e-07, 
        7.47496942645e-08,         1.01356226102e-07,        -9.47230293313e-08,        -7.39096311340e-08,        -3.89977474527e-08, 
        4.97471250504e-08,         1.91538666059e-08,         2.43279808987e-08,        -1.25554955262e-07,        -1.34114071752e-08, 
       -1.71555976851e-09,         2.09676190035e-08,         2.56553020855e-08,        -8.25125675435e-08,        -4.04663331959e-08, 
       -8.60953780685e-08,        -1.00964004883e-07,        -2.11698939003e-07,         1.19315167983e-07,        -1.07178396946e-07, 
        1.60194305522e-07,         7.02197170226e-09,        -2.85440915749e-08,         1.59483765046e-08,         9.68293508120e-09, 
        3.80274271765e-08,        -1.45420091831e-08,        -1.28553621888e-08,         7.98287822085e-09,         6.12175890861e-09, 
        6.20172927266e-09,        -5.44829200427e-09,        -7.93487546023e-09,         7.37931215539e-09,         2.99897664152e-09, 
       -2.06174048067e-09,        -1.83946205534e-09,        -1.54327960760e-09,         2.67575758710e-09,         1.60217225721e-09, 
       -2.73214243796e-09,        -4.43527966050e-10,         7.24930080866e-10,         7.01361888905e-10,         1.13427893667e-09, 
       -2.85240890990e-09,        -1.30824005405e-09,         5.70247167767e-09,        -3.00120703289e-10,        -8.36096619130e-09, 
        2.85429775351e-09,         1.06475273815e-08,        -5.76075934310e-09,        -1.26365908301e-08,         8.89945790326e-09, 
        1.40342583680e-08, 
},
{
        2.75374126970e-08,         1.73203367323e-07,         5.76013471167e-08,        -1.65469305298e-07,        -1.98895278677e-08, 
        1.82443048749e-07,         1.99119384791e-08,         1.94347947910e-08,        -1.25664850173e-07,         5.17842140060e-08, 
        1.07596763993e-07,         3.89176580092e-08,        -3.12233512623e-08,         4.57097765640e-08,         2.01915190348e-08, 
        2.79899307683e-08,         1.29222340027e-07,         2.22976908727e-07,         1.76309489277e-08,        -2.18754799602e-08, 
        4.48146348814e-08,        -4.41974375304e-08,         5.19943133193e-08,         2.08987391385e-08,        -5.56268611920e-08, 
       -1.81740075148e-08,         7.31589623935e-09,         3.88209735451e-08,         3.19296606837e-08,         2.47478997448e-08, 
       -8.10076547237e-08,         8.66210270590e-09,        -6.51723869464e-08,        -1.80432127031e-07,         7.71302300190e-08, 
        2.04171932184e-08,        -5.74854456388e-08,         6.81343356732e-08,        -5.36495951804e-08,         3.24773678963e-08, 
       -1.01654452531e-08,         2.37152374104e-08,        -1.70967729752e-08,        -1.12595719597e-08,         6.91558478824e-09, 
        8.95656686231e-09,        -8.78659735259e-11,        -1.25282830900e-08,        -2.18930352451e-09,         1.18836581554e-08, 
        1.25769886066e-10,        -8.38680289948e-09,        -6.94680377747e-10,         4.68755018924e-09,         2.42674487076e-09, 
       -3.99444700793e-09,        -3.27479397362e-09,         3.92975102566e-09,         2.43409852957e-09,        -3.48441567649e-09, 
       -1.28998117986e-09,         2.24398411559e-09,         8.69714758702e-10,        -1.34053935675e-09,        -1.03553827768e-09, 
        1.33630231539e-09,         1.00983923064e-09,        -2.09294778461e-09,        -2.54032801901e-10,         2.97887971449e-09, 
       -1.14699897251e-09, 
},
{
        5.94064998677e-09,         5.87938948174e-08,        -1.03308110850e-07,         5.70833233872e-08,         3.82996870578e-08, 
       -1.20386343934e-07,         1.03784419331e-07,        -8.35602174008e-08,        -2.72268611074e-09,         3.03550862306e-08, 
       -1.54320332650e-07,        -1.56875263072e-07,        -4.85766473795e-08,         5.89101418220e-08,         8.89763894413e-08, 
       -8.91591861042e-08,        -1.18002520645e-08,         3.17743250612e-08,         2.23540973406e-08,         7.19169033964e-08, 
       -6.50262715418e-08,         1.20820450705e-08,        -5.73148947722e-08,         4.82280918441e-08,         2.07646546978e-08, 
       -9.98354085799e-09,        -8.14480960707e-10,         1.57265272007e-08,         4.56939163703e-08,         2.76735309868e-08, 
        1.29749934307e-08,         6.77538236691e-08,        -2.19791513307e-09,         3.98694540610e-08,         1.86549111958e-07, 
       -1.45166558159e-07,         2.65294602468e-07,        -6.16205922155e-08,         4.12785025564e-08,         2.80331328597e-08, 
       -1.26126407599e-08,         2.91666969377e-08,        -1.41960737540e-08,         4.55565029081e-09,        -1.30884865671e-08, 
        1.24400353665e-08,         8.69925180234e-09,        -8.70425523470e-09,        -1.03016857593e-08,         7.53274561630e-09, 
        5.72283451748e-09,        -6.08145694235e-10,        -8.15706795544e-09,        -8.92382978593e-10,         7.98713597875e-09, 
        1.51056785708e-09,        -6.95764988977e-09,        -1.97189202135e-09,         5.04487435682e-09,         2.87338309135e-09, 
       -4.04662825909e-09,        -3.47921802543e-09,         3.65927923002e-09,         3.59823729662e-09,        -3.81785758324e-09, 
       -3.50165557258e-09,         4.47485708919e-09,         3.32677835925e-09,        -5.73206170509e-09,        -2.94451685397e-09, 
        7.37548375918e-09, 
},
{
       -4.09855008842e-08,        -1.43739267846e-07,        -9.67213976295e-10,         1.82976565724e-07,         2.25485228092e-08, 
       -1.32709966832e-07,        -6.44489332496e-08,        -1.41870675480e-08,         1.21921765832e-07,        -8.51476613419e-08, 
       -9.96099321004e-08,        -4.26091082727e-08,         2.71935642592e-08,        -3.61354547137e-08,        -4.21713493907e-08, 
        5.51510022883e-09,        -9.55973214527e-08,        -2.00692037388e-07,        -3.16086350313e-08,        -2.14681671676e-08, 
       -5.27618175108e-08,         2.79077566849e-08,        -6.44242523308e-09,        -2.16189376684e-08,         1.69225183323e-08, 
        2.13024894118e-08,        -2.43254931029e-08,        -2.79682450569e-09,        -1.10979029191e-08,         8.23898343694e-09, 
       -2.54899977334e-08,         1.46035323716e-08,         7.19988548396e-08,        -3.01726246428e-08,         6.38482857093e-08, 
        1.03612702810e-07,         4.22008335114e-08,        -3.48857604260e-08,         3.96860811694e-08,        -8.16137114261e-08, 
        5.85873871887e-08,        -3.81014862367e-08,         3.94126195904e-08,        -2.89771805967e-08,         3.63604153500e-09, 
       -3.27981905774e-10,         1.36924676853e-08,         1.49287612200e-09,        -1.01307570223e-08,        -9.49327478054e-10, 
        8.07494411816e-09,         2.28066984186e-09,        -1.27623735183e-09,        -5.53755754609e-09,         7.41893730046e-10, 
        7.24131851136e-09,        -6.01937533156e-10,        -5.29714826073e-09,        -1.08937797648e-10,         3.16318157081e-09, 
        1.82132750100e-09,        -1.71286706017e-09,        -2.83954068037e-09,         8.44551654347e-10,         2.73559745765e-09, 
        5.53304418654e-10,        -2.08872178651e-09,        -2.69420624923e-09,         1.62385392988e-09,         5.28695976449e-09, 
       -1.59221728853e-09, 
},
{
        3.61826144862e-08,         1.00013872430e-08,         3.73099803467e-08,        -7.41630266558e-08,        -9.14461895739e-08, 
        8.21755743857e-08,        -8.17948040725e-08,         1.08794431282e-07,        -3.18695450922e-08,        -6.85485179604e-08, 
        2.31264328764e-07,         1.76175030996e-07,         2.19275781635e-08,        -1.39119741401e-08,        -4.89886097818e-08, 
        5.72190649858e-08,        -6.25153412728e-08,         5.58587392901e-08,         3.92310610656e-08,        -1.28376320806e-07, 
        6.30182569836e-08,        -9.80750307734e-09,         2.94331436322e-08,        -1.77870755010e-09,         1.01435982756e-08, 
       -2.43795721729e-09,         2.18649649310e-08,        -2.87881405064e-08,         3.86382492798e-09,        -3.83225823804e-08, 
       -3.67115341996e-08,        -2.66216108051e-08,        -6.28116259930e-09,        -1.92764741246e-08,         1.94127956537e-08, 
        8.84591474479e-10,        -1.81223918160e-07,         1.50479996828e-07,        -4.73715919863e-08,        -1.96708076667e-08, 
       -3.04744575064e-08,        -5.03367034817e-08,         5.86831163191e-09,        -1.18051137247e-08,        -1.31500830613e-08, 
       -2.18125914831e-08,         8.86689656910e-09,         3.77351187475e-09,        -7.73689284376e-09,        -7.34498845874e-09, 
        1.68532649031e-09,         3.35309569796e-09,         1.35591211800e-09,        -4.13399678998e-09,        -2.76425178216e-09, 
        3.33868160865e-09,         2.72541643780e-09,        -1.99056902796e-09,        -2.12646662624e-09,         3.87975573471e-10, 
        1.90644028121e-09,         1.14568729017e-09,        -1.99427269458e-09,        -1.94213299173e-09,         2.24473144471e-09, 
        2.17047881292e-09,        -2.32415353475e-09,        -2.08377627143e-09,         2.35671516817e-09,         2.04986241099e-09, 
       -2.66504930240e-09, 
},
{
        2.19463153262e-08,         5.68605040504e-08,        -3.50318577207e-08,        -1.44731980363e-07,         1.06419315465e-08, 
        7.44400754349e-08,         6.57795645712e-08,         2.57820485435e-08,        -1.16123217117e-07,         1.04296183641e-07, 
        6.22393801828e-08,         9.36853289553e-09,        -3.56645842056e-08,         2.91889075589e-09,         2.68537568102e-08, 
       -1.68337943353e-08,         7.41706371734e-08,         1.79832812828e-07,         2.74893307482e-08,         7.36646063833e-08, 
        4.92995065200e-08,        -3.15139208015e-08,         6.44946647152e-09,        -4.82038928365e-09,        -1.34979300925e-08, 
       -8.04372252696e-09,         1.69743785476e-08,         1.76949624832e-08,         1.40748223817e-09,         2.75924313129e-08, 
       -3.33855357583e-08,        -6.60768104871e-09,        -1.93313796964e-08,        -1.28763744507e-08,        -4.01468227562e-08, 
       -4.93191513876e-08,         5.37646263795e-08,        -1.21147376321e-07,        -1.51023507429e-07,         3.28338945158e-08, 
        1.24256557757e-08,         5.70283532153e-08,        -5.27764866200e-08,         3.05792084753e-08,        -5.76893662253e-09, 
        7.31822806291e-09,        -8.80279870358e-09,         4.19747243406e-09,         4.63124030565e-09,        -5.19479078601e-09, 
       -3.05061132487e-09,         2.65107431940e-09,         2.24612754311e-09,        -1.54676467269e-09,        -3.36533689413e-09, 
        2.75422610130e-10,         3.50495710422e-09,        -7.27921461640e-10,        -2.54055590612e-09,         2.68748591183e-10, 
        1.23291048921e-09,         3.14089214439e-10,        -2.32196671438e-10,        -1.09828890995e-09,        -2.26501246192e-10, 
        1.33721972395e-09,         4.17633066892e-10,        -1.02921815581e-09,        -6.46139663548e-10,         3.46758471957e-10, 
        1.01833190816e-09, 
},
{
       -3.06415794248e-08,        -5.81483099404e-08,         4.84776127854e-09,         7.24059519256e-08,         1.14627581189e-07, 
       -4.92998957081e-08,         6.17763621256e-08,        -1.03668287264e-07,         4.60776749544e-08,         4.19444269780e-08, 
       -2.08879143902e-07,        -1.58999564404e-07,         3.88202748723e-09,        -2.40863158664e-08,         3.10227622144e-08, 
       -2.58372056348e-09,         9.18661965112e-08,        -1.35423927310e-07,        -9.59455364135e-08,         1.56967990622e-07, 
       -4.73446376062e-08,         2.86382106898e-09,        -2.34330125150e-08,         5.66702339251e-10,        -2.76323655221e-08, 
        8.67018006764e-09,        -1.44844307648e-08,         1.06914324484e-08,         8.65809895632e-10,         1.19895803689e-08, 
        2.01768759350e-08,         9.36177686458e-09,         1.08560416097e-08,        -1.27749303652e-08,         9.52467380587e-09, 
       -2.21837906169e-08,        -1.15328584050e-07,         6.67173782934e-08,        -4.25449590789e-08,        -2.44250366375e-08, 
       -3.40122831669e-08,        -1.72522257775e-08,         2.65606455101e-08,        -4.18178531805e-08,         1.43384207018e-09, 
       -9.23220702093e-09,         7.05952899882e-09,        -4.73306662915e-10,        -3.64701198886e-09,         1.59462611818e-10, 
        5.21085659325e-11,        -2.41855280686e-09,         4.11604933472e-09,         1.47704458427e-10,        -2.98288460419e-09, 
       -8.16252202751e-10,         1.39060861611e-09,         2.32876641763e-09,        -1.16176481582e-09,        -2.79337240592e-09, 
        1.13687647163e-09,         1.89924302792e-09,        -4.14598911421e-10,        -1.00119493972e-09,        -6.38821870129e-10, 
        6.80204815676e-10,         1.05675027296e-09,        -5.94012766855e-10,        -6.66656468740e-10,         2.58276387528e-10, 
       -5.66507048025e-11, 
},
{
        3.88573615461e-10,         2.90913541574e-08,         4.40391877278e-08,         8.81727554509e-08,        -4.52444040411e-08, 
       -3.17940574539e-08,        -4.62089827417e-08,        -4.90449196941e-08,         9.53606342961e-08,        -9.39190609817e-08, 
       -1.66646445653e-08,         4.95894947043e-08,         3.27273141583e-08,         2.52177058085e-08,         7.59587008332e-09, 
        6.29220592107e-09,        -7.29874848008e-08,        -1.58213645747e-07,         1.44146762924e-08,        -1.10606651159e-07, 
       -5.75627711530e-08,         3.34263006132e-08,        -1.94337209089e-08,         6.85549002861e-09,         2.84732701293e-08, 
        2.54297532767e-09,        -2.86897952345e-09,        -1.70905811170e-09,        -6.81989304747e-09,        -1.37444702281e-08, 
       -6.12251971991e-09,         1.32387381098e-08,         1.62112981948e-08,         2.56753897574e-09,         7.37014725735e-09, 
       -1.85937468610e-08,         1.61712083817e-08,        -2.49464163075e-08,        -2.28516669548e-08,         1.09532561551e-08, 
       -5.07333278913e-08,         4.42464620092e-08,         1.25241711037e-08,         5.49662209662e-10,         3.76529964309e-10, 
       -4.74454279786e-09,        -5.32633195061e-09,        -1.75370862931e-09,         1.32235315825e-09,        -1.37428489264e-09, 
       -2.33266098836e-09,        -1.50058806181e-09,        -5.14623724647e-10,         1.67926064751e-09,        -8.52733586869e-11, 
       -1.24887210520e-09,        -1.62970583865e-09,         7.49800479570e-10,         2.25450088884e-09,        -8.88529486198e-10, 
       -2.07535095648e-09,         5.09597526351e-10,         1.09039111525e-09,         3.92005506338e-10,        -5.88966186439e-10, 
       -1.16433268246e-09,         4.23860275784e-10,         1.28574929247e-09,        -2.28671674343e-10,        -9.74005471841e-10, 
       -2.53959118212e-10, 
},
{
        4.35048034542e-10,         6.92465569317e-08,        -1.98913126874e-08,        -5.79670699198e-08,        -1.05241372907e-07, 
        2.15603605397e-08,        -5.32029094168e-08,         8.74377433147e-08,        -4.45777652370e-08,         6.02150525866e-09, 
        1.15318880588e-07,         1.12365744979e-07,        -9.87286091776e-09,         4.04825316393e-08,        -3.84701144184e-08, 
       -4.70295990881e-08,        -7.29151502372e-08,         1.91045501189e-07,         1.20596542115e-07,        -1.47003692077e-07, 
        3.76181313990e-08,        -3.69946015566e-09,         1.75050996893e-08,         2.58264463416e-09,         3.39794903490e-08, 
       -1.29973869160e-08,         2.83934613879e-09,        -3.08161017638e-11,         1.36788449770e-08,        -3.69339745748e-10, 
       -2.03851733533e-08,        -7.17706294328e-09,         1.91057585332e-08,        -9.75335832317e-09,         1.52653836474e-08, 
        1.17934851888e-08,        -4.21512461303e-08,         1.87788562768e-08,         1.64325298611e-09,         1.00613680649e-09, 
        6.24195647956e-08,         5.42308671447e-09,        -8.57430271493e-08,         1.29531128947e-08,        -4.98295943588e-08, 
        1.69330968893e-08,         3.35657250201e-10,         2.38878717311e-09,        -7.38849977210e-09,        -1.16325024493e-09, 
        7.13991860520e-09,         2.04404815471e-09,        -1.89727238981e-09,        -1.12994286365e-09,        -1.20991212925e-11, 
        3.81550404672e-09,         9.25084867262e-10,        -3.86137678041e-09,         6.96379879666e-10,         2.16596406904e-09, 
        1.61702965045e-10,        -6.16953605383e-10,        -1.03577428111e-09,         7.47767959719e-11,         1.62162177004e-09, 
       -6.52148405622e-11,        -1.25771099628e-09,        -1.15568901400e-10,         6.62991245420e-10,         4.86931399812e-10, 
       -1.72167887053e-10, 
},
{
       -7.20537027663e-09,        -7.56114158859e-08,        -3.29407605181e-08,        -4.31366364217e-08,         5.71875856102e-08, 
        1.11811799253e-08,         3.39467774194e-08,         6.61480215286e-08,        -6.22177970399e-08,         5.90680679702e-08, 
       -8.01556644807e-09,        -9.80712380723e-08,        -1.68558292302e-08,        -3.55825311115e-08,        -3.19910886508e-08, 
        1.81579566646e-08,         8.36246092373e-08,         1.29159478234e-07,        -7.57911790606e-08,         1.11531895018e-07, 
        7.49886246467e-08,        -3.19760614542e-08,         2.66263180356e-08,        -1.95714747573e-09,        -4.48702943759e-08, 
       -2.07057052421e-09,         3.66035159750e-09,        -1.28376803655e-08,        -2.44635910978e-10,         1.23448447136e-08, 
        1.10062505829e-08,        -2.03638410387e-08,        -3.04518030985e-09,         1.56825039519e-08,        -1.40253252410e-08, 
        1.59377080469e-08,         1.62373064667e-08,        -5.00933909224e-09,        -4.31818823137e-09,        -2.42817794230e-09, 
       -3.54496684075e-08,         2.55203676023e-08,         6.52158746932e-08,        -8.00462782849e-08,        -2.85402957750e-08, 
       -4.56418302710e-08,        -5.18606611899e-09,         2.60204041246e-09,         1.71844405232e-10,        -9.23214371976e-09, 
       -8.97747909369e-09,         6.44197158664e-09,         4.54513684130e-09,        -1.31222977182e-09,        -5.73774267017e-09, 
       -8.85862168613e-10,         5.91104186197e-09,         5.18915410207e-10,        -3.73977184509e-09,        -2.13463120194e-10, 
        1.02170665223e-09,         1.67081994102e-09,         7.80204882388e-11,        -2.23308070223e-09,        -2.73004498288e-11, 
        1.67297585551e-09,         1.94096329499e-10,        -6.38128916502e-10,        -6.91737533413e-10,         4.57017814379e-11, 
        1.08160190389e-09, 
},
{
        2.44914316242e-08,        -5.18342287259e-08,         1.87849698621e-08,         4.38912119995e-08,         7.89073544689e-08, 
       -9.78536505659e-10,         5.33153949973e-08,        -7.21971565964e-08,         3.29527204463e-08,        -3.60510224703e-08, 
       -1.17323171092e-08,        -5.28962570640e-08,        -2.20656089000e-09,        -3.85732128169e-08,         5.52265637176e-08, 
        6.96037372409e-08,         2.34615732962e-08,        -2.12097726751e-07,        -1.06162171673e-07,         1.08107869333e-07, 
       -3.96478759783e-08,         1.88278307033e-08,        -1.28624050617e-08,        -1.73617958219e-08,        -2.95690515440e-08, 
        2.23162629610e-08,         6.12377183153e-09,         9.01954569072e-09,        -1.48202211865e-08,        -1.24420792483e-08, 
        2.09973049083e-10,         1.37067803796e-08,        -2.07914952675e-08,        -8.97691143987e-09,        -4.95702526502e-09, 
       -6.19575857895e-09,         5.75663725839e-09,         1.05252635537e-08,        -3.92360822931e-09,         7.07576936756e-09, 
        1.55990403335e-08,        -4.74755402242e-08,         5.09948147594e-08,        -8.85158669856e-09,        -4.21850058786e-08, 
       -1.73259049878e-08,        -1.01117351572e-08,        -1.55011486716e-09,         8.67252244491e-09,         7.26292676050e-09, 
       -2.73459048707e-09,        -6.81431876721e-09,         3.20590357536e-09,         5.72910834565e-09,         1.00118888251e-09, 
       -6.30048604899e-09,        -1.28627927737e-09,         4.51769179111e-09,         8.27337329902e-10,        -1.86949420679e-09, 
       -1.85857274680e-09,         2.09293233812e-10,         2.40383882657e-09,         5.93546111529e-11,        -2.04110614896e-09, 
       -1.90356130788e-10,         8.99901150867e-10,         6.91063438532e-10,        -1.17148095348e-10,        -1.18378939022e-09, 
       -1.72951412828e-10, 
},
{
        9.95140372866e-10,         7.99830919541e-08,         1.43814983701e-08,         1.75210157800e-08,        -4.38101950867e-08, 
       -4.80924736361e-09,        -4.05437237316e-08,        -6.55267565268e-08,         2.84606296475e-08,        -1.74144381319e-08, 
        3.63235681227e-09,         1.08586186006e-07,        -2.69033870610e-09,         3.13589662372e-08,         2.82964411052e-08, 
       -4.19595658315e-08,        -9.17825372243e-08,        -8.67607916724e-08,         1.22789244652e-07,        -7.84894967312e-08, 
       -8.36112845481e-08,         2.03511623274e-08,        -2.99653034770e-08,        -3.74595641243e-09,         5.35240082338e-08, 
        8.36781594920e-09,        -9.12366092735e-09,         1.53740649175e-08,         1.14298346581e-08,         4.35664531370e-10, 
       -1.17882727193e-08,         4.26915642633e-09,         1.45094609203e-08,        -1.28266879087e-08,        -3.13946362012e-09, 
       -2.96220501207e-08,        -3.83343982409e-10,         1.13147584485e-08,        -6.04496977638e-09,        -9.26845996037e-09, 
       -3.82976842741e-09,        -4.40262551989e-09,         4.34231119765e-09,         1.49896058779e-08,         1.82734377572e-09, 
       -5.65763008718e-08,        -1.19049187450e-08,         1.78369009106e-09,         1.38156978238e-09,         1.34552461318e-08, 
        7.93126676721e-09,         2.11468117703e-09,        -3.45092048126e-09,         1.81142974057e-09,         5.50062907198e-09, 
        2.79121010526e-09,        -4.32491534709e-09,        -1.41225374556e-09,         2.25233019388e-09,         2.69307733034e-09, 
       -7.91692320727e-10,        -2.87014477408e-09,         1.27530690761e-10,         2.24446441323e-09,         4.27017242762e-10, 
       -1.41386392067e-09,        -1.03883524874e-09,         7.35183042097e-10,         1.33876490851e-09,        -3.00504991348e-10, 
       -1.31670774860e-09, 
},
{
       -3.00370413460e-08,         2.65856190682e-08,        -1.29346974132e-08,        -3.78269421518e-08,        -5.50630619590e-08, 
       -1.08387866073e-08,        -5.14112121378e-08,         5.89448865249e-08,        -1.72175471065e-08,         3.40307831283e-08, 
       -4.92969240059e-08,         2.78140015823e-09,         1.82132516508e-08,         2.76916737733e-08,        -5.82900771420e-08, 
       -5.70153534382e-08,         3.03800990821e-08,         2.00126752530e-07,         6.31685763148e-08,        -6.78280621367e-08, 
        4.80759625277e-08,        -3.52155722667e-08,         2.67606594770e-09,         3.74690353382e-08,         2.56118694115e-08, 
       -3.73575898221e-08,        -4.52994430583e-09,        -1.97049950556e-08,         4.29188493309e-09,         1.46731360273e-08, 
        8.74354013921e-09,        -3.97679733482e-09,         1.27844167083e-08,         1.26146694602e-08,         6.41257140070e-09, 
        6.54530331285e-09,        -2.75424611108e-08,         2.75083381996e-09,         3.10682842809e-09,        -9.80705038585e-09, 
        1.58396435355e-09,        -2.08094711477e-08,         1.75508729183e-08,         2.13612344945e-08,         2.04294413951e-08, 
        7.04346771121e-09,        -2.05577143671e-08,        -1.95367726729e-08,        -1.19007137371e-08,        -6.95705662316e-09, 
        6.56470188669e-09,         4.17595048058e-10,        -3.43281559652e-09,        -5.85710048813e-09,        -6.84425695318e-10, 
        4.65242107831e-09,         1.27578693413e-09,        -3.74752805596e-09,        -1.92920341025e-09,         1.10772055610e-09, 
        3.63128529889e-09,        -6.92045513454e-10,        -3.05920420174e-09,        -5.40561714275e-11,         2.01287445853e-09, 
        1.15495454745e-09,        -1.39343325177e-09,        -1.70813637588e-09,         1.09517452736e-09,         1.53019910385e-09, 
       -4.85564701182e-10, 
},
{
        4.03434420847e-09,        -6.20644195800e-08,         1.64443256650e-09,        -4.54821135993e-09,         1.82537660532e-08, 
        3.06625304686e-09,         5.86610963725e-08,         4.93862956529e-08,        -7.30877931091e-09,        -1.35982025278e-08, 
        1.72767914307e-08,        -7.96404656226e-08,         1.53008873601e-08,        -2.38040567667e-08,        -2.66049903624e-09, 
        5.12792953489e-08,         8.66653846723e-08,         3.55905752400e-08,        -1.29666308077e-07,         3.01417907092e-08, 
        6.88189180604e-08,        -3.65313741504e-09,         3.66370952159e-08,         2.06911974240e-09,        -5.71973500047e-08, 
       -1.31472046914e-08,         1.11248441582e-08,        -2.69598654894e-09,        -1.13299455417e-08,        -8.51743989673e-09, 
        5.37210946160e-10,         6.16355646993e-10,        -3.86885973639e-09,         3.86865071954e-09,         7.15764931779e-09, 
        1.53181586486e-08,         2.92875678763e-09,        -6.39577280769e-09,         5.03604466547e-09,        -1.29349648501e-09, 
       -2.53330275490e-09,        -6.53425764710e-09,        -1.13886505965e-08,         6.87204153662e-09,         2.24611565851e-08, 
        5.87242633239e-08,        -3.00771043374e-08,         4.68237465153e-09,         3.09494428881e-08,        -2.30811165477e-08, 
        9.48666560163e-09,         1.03894437239e-09,         4.66907194797e-09,        -6.42919685824e-09,        -5.65364555939e-09, 
       -7.59805520464e-10,         4.61956851345e-09,         3.07512542713e-10,        -3.41350339536e-09,        -2.37689729831e-09, 
        1.04840370114e-09,         3.46352521650e-09,        -8.31106406213e-10,        -2.70668404802e-09,        -4.49278875401e-10, 
        1.90820789675e-09,         1.48103931649e-09,        -1.51519735079e-09,        -1.72639501679e-09,         1.09812066641e-09, 
        1.34766523573e-09, 
},
{
        2.16757476078e-08,        -1.00308998385e-08,         7.90915218196e-09,         3.78405875374e-08,         4.36019378907e-08, 
        1.49901543013e-08,         4.00360122755e-08,        -4.49292633382e-08,         2.25312902593e-09,        -1.03896477651e-08, 
        5.41468030808e-08,         2.27158506035e-08,        -2.60311375047e-08,        -1.73165651066e-08,         3.78871387653e-08, 
        1.92513830428e-08,        -6.62873304119e-08,        -1.60696246025e-07,        -1.48801837230e-08,         4.17113622943e-08, 
       -5.20094864595e-08,         4.56182452734e-08,         7.13322350021e-09,        -5.38875648656e-08,        -2.42315080991e-08, 
        5.49346913809e-08,         2.26120660096e-09,         1.86875701333e-08,         9.91755214824e-09,        -7.27758307893e-09, 
       -8.32985204004e-09,        -9.04822722382e-09,        -5.15922002999e-09,        -7.38172798500e-09,        -1.02046298117e-08, 
        3.21684324442e-09,         1.40365792792e-08,        -3.47517806653e-09,        -3.03250131717e-09,         2.24566687492e-09, 
        6.47537927269e-09,         1.09634827817e-09,         9.00051416357e-09,        -5.82709405899e-09,         4.35291633066e-09, 
        1.12850815971e-08,         2.36942141268e-08,         3.23782668125e-08,        -4.07400709080e-08,         2.20706674250e-08, 
       -1.90177756117e-08,         2.98133775509e-09,         4.53041057981e-09,         2.45717923956e-09,        -1.44918705496e-09, 
       -6.16433832836e-09,         1.40948115328e-09,         3.60888261469e-09,         1.84057401273e-09,        -2.89524025099e-09, 
       -2.40377187069e-09,         1.30557802395e-09,         3.26200773070e-09,        -7.00307375390e-10,        -2.29243808889e-09, 
       -5.83284286667e-10,         1.76311874905e-09,         1.41215489012e-09,        -1.27865375401e-09,        -1.52112602597e-09, 
        7.16868278611e-10, 
},
{
        1.85092333924e-09,         4.27970695999e-08,        -1.12053744163e-08,        -4.33120529724e-09,         3.12532903632e-09, 
       -1.50261076818e-09,        -7.21873564273e-08,        -2.95696512380e-08,         3.12214335681e-09,         2.59954447360e-08, 
       -3.35903854687e-08,         3.46708402289e-08,        -1.72944952143e-08,         2.09612259744e-08,        -2.35780634912e-08, 
       -3.87616074306e-08,        -6.66626910342e-08,         1.08895149054e-08,         9.64344599155e-08,         9.70703726339e-09, 
       -3.10536608012e-08,        -1.33749210178e-08,        -4.72178128035e-08,         3.81668653915e-09,         5.72472069840e-08, 
        1.28503863637e-08,        -9.93914152709e-09,        -7.60532943936e-09,        -2.92241560622e-09,         8.49083178689e-09, 
        8.49029476025e-09,         3.61050379229e-09,        -5.95878774138e-09,        -1.10253804277e-09,        -7.09537212861e-09, 
       -1.62248776229e-08,         2.58947378018e-09,         1.17731456702e-08,        -6.51099903663e-10,        -5.49299230809e-09, 
        4.87147547403e-10,         5.60589698906e-09,         5.81890691838e-09,         5.55146315679e-09,        -5.15985386807e-09, 
        1.77264855056e-08,        -7.44431038490e-09,        -1.30780622058e-08,         2.28847828648e-08,         2.40072181781e-09, 
        2.66454846685e-09,         1.89749042032e-09,        -1.57606822673e-10,         7.12563004990e-09,         3.81621206947e-09, 
       -1.14246979512e-10,        -3.90822800676e-09,         9.51459663546e-11,         3.85410996332e-09,         2.08318156563e-09, 
       -2.18546379718e-09,        -3.02988962203e-09,         1.43591611244e-09,         2.71905791266e-09,        -1.40325029834e-10, 
       -2.35115575975e-09,        -8.07517222322e-10,         1.68867560796e-09,         1.31549116484e-09,        -1.06607093058e-09, 
       -1.44776687852e-09, 
},
{
       -1.29147031228e-08,         6.46896502191e-09,        -4.15580890393e-09,        -3.72937157739e-08,        -4.21073735837e-08, 
       -1.44025675307e-08,        -2.04160373813e-08,         3.05528069682e-08,         7.64032601011e-09,        -1.54283872959e-08, 
       -2.44955223116e-08,        -2.26589090015e-08,         2.26770436191e-08,         1.09926072541e-08,        -3.17277807980e-09, 
        2.20578889104e-08,         7.41670530992e-08,         1.05149094155e-07,        -1.79008818767e-08,        -3.00592809093e-08, 
        4.23363052441e-08,        -4.78821035507e-08,        -1.27888301402e-08,         6.15628948539e-08,         2.44147088652e-08, 
       -6.75273300743e-08,        -4.17416502164e-09,        -1.21292424146e-08,        -1.28985427101e-08,        -3.87484696715e-10, 
       -5.99595348464e-10,         1.27421365000e-08,         1.08587452131e-08,        -3.42149039795e-10,         6.92698357043e-09, 
       -6.82581295332e-09,        -1.30104679909e-08,         2.40839580496e-09,         2.89094738565e-09,        -3.90008390245e-10, 
       -3.29481268436e-09,        -2.67702249990e-09,         1.36250399244e-08,         7.36167053411e-09,        -1.36056061425e-09, 
       -6.39200141270e-09,         7.35542115589e-09,        -9.05424709906e-09,         1.21945638499e-08,         2.13454703153e-08, 
       -1.09181701102e-08,         8.87697981293e-10,        -9.67389644513e-10,         4.68926409572e-09,         5.68188685819e-09, 
        7.10565130363e-09,         2.46768494389e-11,        -1.46456943851e-09,         5.91124313075e-10,         3.85085464955e-09, 
        2.85333770271e-09,        -1.49843344332e-09,        -2.72017917027e-09,         1.39412179681e-09,         2.31785449532e-09, 
        6.48764812835e-10,        -2.15163141023e-09,        -1.28647280862e-09,         1.83483654809e-09,         1.32531632698e-09, 
       -9.51772640327e-10, 
},
{
       -1.62517955499e-08,        -3.10297699852e-08,         1.52931471864e-08,         1.16652374435e-08,        -1.17311907695e-08, 
        8.68600507954e-10,         7.03315735387e-08,         1.65512087082e-08,        -1.04224093373e-08,        -2.30795449495e-08, 
        3.31383002393e-08,        -1.15883412895e-09,         1.18029513134e-08,        -2.40061378620e-08,         3.19083845504e-08, 
        8.90077592751e-09,         3.91934540971e-08,        -3.78799322670e-08,        -4.40407573165e-08,        -2.75954067659e-08, 
       -1.42571636919e-08,         2.79163072259e-08,         5.61751656583e-08,        -1.06879144034e-08,        -5.38965747739e-08, 
       -7.44782552270e-09,         9.71140775093e-09,         1.07141325156e-08,         1.78059951758e-08,         1.05422133934e-10, 
       -9.42787883250e-09,        -1.07096239752e-08,         6.38094372559e-09,         6.71336778212e-09,         4.62938437597e-09, 
        1.14906498090e-08,        -7.82094642924e-09,        -5.09515569068e-09,         3.45958729422e-09,        -2.85979660504e-09, 
       -2.03065319823e-09,        -7.09706009389e-09,        -3.25578188915e-09,         1.03446045931e-08,         5.66802933326e-09, 
        2.90805047003e-09,        -9.21596028099e-09,        -5.23699620528e-10,        -6.74654487421e-09,        -4.56462154308e-09, 
        3.57181133763e-08,         3.28815614625e-08,        -1.04321423852e-08,        -2.85134307388e-09,        -2.45748806927e-09, 
        1.63306962857e-09,         1.72854469361e-09,        -2.59673970375e-09,        -3.03352178215e-09,        -1.84963901333e-10, 
        1.44056045545e-09,         2.03459861258e-09,        -1.47601748903e-09,        -2.46320153192e-09,         9.35288318520e-10, 
        1.41814323274e-09,         1.02158257724e-09,        -1.74615040854e-09,        -1.46141845511e-09,         1.60750179640e-09, 
        1.19894794120e-09, 
},
{
        1.18911832480e-08,        -1.06169571731e-08,         6.38636996402e-10,         3.20167757738e-08,         4.16666105544e-08, 
        1.16519371787e-08,         5.40613867851e-10,        -1.96331995654e-08,        -1.05490106823e-08,         2.96096629549e-08, 
       -6.60564347004e-09,         9.11060980237e-09,        -1.26840134345e-08,        -7.30302147728e-09,        -2.68049510039e-08, 
       -4.51467413323e-08,        -5.73163431384e-08,        -4.87567840182e-08,         2.63549718313e-08,         2.30130204210e-08, 
       -1.92671818785e-08,         4.53048317509e-08,         1.34511766729e-08,        -6.12348729046e-08,        -2.35193214946e-08, 
        7.03648931855e-08,         8.94907429094e-09,         8.95233550566e-09,         6.19516783257e-09,         4.78555964790e-11, 
        7.09552019411e-09,        -8.69348886500e-09,        -1.35918070092e-08,        -7.61167259246e-11,        -1.72839177419e-09, 
        8.00748576341e-09,         9.51138802726e-09,        -6.43534721831e-09,        -1.41530550722e-09,         3.48636927377e-09, 
        2.38760173186e-09,        -3.52357122511e-09,        -4.25947960842e-09,        -3.19044172841e-09,         4.11263871489e-09, 
        2.44327279344e-09,         2.92465924775e-09,        -1.25142610233e-08,         1.24654092763e-08,         5.56296758078e-09, 
       -1.73829816793e-09,        -6.88425372320e-10,         4.19278915548e-08,         5.31648260840e-09,        -1.52277223581e-09, 
        2.18561663003e-09,         6.40861784211e-10,         1.60885463102e-09,        -2.22382713106e-09,        -2.07617550038e-09, 
       -2.56843450625e-10,         3.52921834335e-10,         1.11244749289e-09,        -1.30414748423e-09,        -1.44933439554e-09, 
        3.79909640680e-10,         6.61718639958e-10,         7.49369873555e-10,        -1.22263315629e-09,        -9.45617726298e-10, 
        1.02551616837e-09, 
},
{
        2.89582900894e-08,         2.41288067331e-08,        -1.62651688255e-08,        -1.50905913909e-08,         9.28910159341e-09, 
       -2.88759907293e-09,        -5.39507677933e-08,        -1.22407010453e-08,         1.91600379443e-08,         1.40209947418e-08, 
       -1.89920662387e-08,        -8.01833186125e-09,        -4.86444650603e-09,         2.88938478766e-08,        -1.93541093191e-08, 
        2.41172958160e-08,        -1.47415051731e-08,         3.88939312016e-08,        -1.76448020760e-09,         2.48254935813e-08, 
        4.89551955834e-08,        -4.06538902166e-08,        -5.82986156459e-08,         1.59700346900e-08,         4.54934511283e-08, 
       -2.91418533891e-10,        -1.17415530857e-08,        -1.17766655152e-08,        -2.41610387348e-08,        -8.80325437895e-09, 
        4.89867433895e-09,         9.59201374259e-09,        -8.35443114610e-11,        -8.37827823180e-09,        -5.53839151333e-09, 
       -7.23709234604e-09,         8.97004918404e-09,         4.81272341255e-09,        -3.32669862570e-09,        -2.60961420126e-09, 
        3.76862740541e-09,         6.99047867688e-09,        -2.07874800206e-09,        -1.73887186538e-09,        -3.90664563556e-09, 
        4.76036499182e-09,        -1.10356239367e-09,         1.23101268101e-09,        -6.68890004049e-09,         1.53063015512e-10, 
        1.26564182545e-08,        -3.37869702682e-08,         1.07409154247e-08,         7.75100558628e-09,         5.00255637236e-09, 
       -3.64108990017e-10,         5.24261305875e-10,         8.43999696983e-10,         8.54853418849e-10,        -1.61740502409e-10, 
       -1.10297271856e-09,         6.29715137654e-10,         2.00165899843e-11,         5.87647213207e-10,        -9.87273775377e-10, 
       -7.74503004056e-11,         2.04776895189e-10,         1.49547505472e-10,         1.58442413959e-10,        -6.42172945750e-10, 
       -4.40537839819e-11, 
},
{
       -1.66509018479e-08,         1.51067699995e-08,         2.78997066969e-09,        -2.32628024547e-08,        -3.53512016537e-08, 
       -7.79761307187e-09,         1.16094139633e-08,         1.49816445675e-08,         7.98784803484e-09,        -2.98041863584e-08, 
        1.90589314246e-08,         2.66719887561e-09,         2.36329196141e-09,         2.78983200177e-09,         3.76933563110e-08, 
        4.06475063185e-08,         2.81466525264e-08,         6.76044426890e-09,        -1.50711813568e-08,        -1.28721105292e-08, 
       -9.64075161294e-09,        -3.96174608481e-08,        -1.09616675640e-08,         5.39974521600e-08,         2.12947615994e-08, 
       -6.16797115588e-08,        -1.23887515105e-08,        -1.09910685711e-08,         1.47961467712e-09,         8.11284376457e-09, 
       -7.43851158390e-09,         4.80495888593e-09,         9.56287664484e-09,         2.92712136068e-09,        -1.57602718412e-09, 
       -8.22722858600e-09,        -6.95718718702e-09,         8.20760439491e-09,         2.43457617083e-09,        -2.51018137363e-09, 
       -3.72245225465e-09,         2.86213436914e-09,         7.52953231759e-09,        -3.07471603203e-10,        -2.75129563241e-09, 
       -2.69316166389e-09,         5.57720958524e-09,        -5.81855902933e-09,         3.76735085485e-09,         4.34663971769e-09, 
        4.32293266799e-09,         6.93441079167e-10,        -3.69820142330e-08,         2.61669907227e-09,        -1.04338520867e-08, 
        6.18235247598e-10,         4.26161171718e-10,        -1.74880027260e-09,        -3.35383372897e-10,         2.95762205534e-10, 
        5.51900278806e-10,         4.81833063803e-10,         1.15027635339e-09,        -1.35044135143e-10,         5.35877262030e-11, 
       -4.26391812452e-10,         9.32249737532e-10,         4.52571304294e-10,        -3.98939273961e-10,        -3.87492824373e-10, 
        2.22169056701e-11, 
},
{
       -3.16834947843e-08,        -1.62987600699e-08,         1.53401468346e-08,         1.25896046359e-08,        -3.13671181219e-09, 
        6.95585808880e-09,         3.24385825310e-08,         1.12971923918e-08,        -2.21560854510e-08,        -7.09834565378e-09, 
        3.42644538923e-09,        -3.85107989008e-10,         9.70471296775e-10,        -3.07475958708e-08,        -2.55471055867e-09, 
       -4.45666109511e-08,         8.78784948089e-10,        -2.00185485182e-08,         2.52377901315e-08,        -1.28897105727e-08, 
       -6.23828169679e-08,         5.22441967368e-08,         5.32534945469e-08,        -1.85585738594e-08,        -3.29942911053e-08, 
        7.66268357944e-09,         1.27899830022e-08,         1.75347269700e-08,         2.28802390000e-08,         1.12172738239e-08, 
       -1.33695950360e-10,        -3.63661181821e-09,        -4.13426032691e-09,         5.13308982764e-09,         6.39695041709e-09, 
        2.27561264202e-09,        -9.09295291220e-09,        -4.16317909469e-09,         5.13466605087e-09,         2.28030395864e-09, 
       -2.47708157059e-09,        -4.33789792198e-09,         3.37795575726e-09,         3.84328278011e-09,        -5.24610715188e-10, 
       -3.67411230150e-09,        -9.01301477607e-10,         4.88209865114e-09,        -3.27189667575e-09,        -4.26942966026e-09, 
        1.15642806809e-08,        -5.70631341013e-09,        -1.24799967591e-09,        -9.36123009120e-09,        -6.91895256189e-09, 
        8.76270882295e-09,         2.36723737814e-09,         7.48989389247e-10,        -5.63514814825e-10,        -2.79164593120e-09, 
       -7.89624700483e-10,        -2.73468512542e-10,         1.77011066364e-09,         6.23038078567e-10,        -5.83843226561e-10, 
       -8.71286097211e-10,         3.21002881528e-11,         1.39875443177e-09,         5.07922911766e-10,        -9.05852375443e-10, 
       -6.69582571274e-10, 
},
{
        1.98752021759e-08,        -1.61766459905e-08,        -5.25836143866e-09,         1.53386905173e-08,         2.26968619575e-08, 
        2.99799264570e-09,        -1.34638205450e-08,        -1.51100517898e-08,        -4.06292522403e-09,         2.16955587032e-08, 
       -1.39087935622e-08,        -4.16736384865e-09,         4.51686496560e-09,         4.30580275758e-09,        -2.85095077480e-08, 
       -1.57496022067e-08,        -7.70595366861e-10,         1.24751533915e-08,        -3.90098660693e-09,        -5.89966129225e-10, 
        3.42251671390e-08,         3.03996623136e-08,         6.60666410723e-09,        -4.09529689054e-08,        -1.92273872316e-08, 
        4.29944962353e-08,         1.30383722337e-08,         1.24588359953e-08,        -4.45099553264e-09,        -1.68554961957e-08, 
        2.85294594022e-09,        -6.90249416004e-09,        -2.77458749464e-09,        -2.53882043747e-09,         1.28317620532e-09, 
        9.11531352123e-09,         3.51501258900e-09,        -8.00834942299e-09,        -2.53958259317e-09,         1.38429835552e-09, 
        2.14315526202e-09,        -3.98057501638e-09,        -3.49780777989e-09,         4.14966930515e-09,         1.37977668278e-09, 
       -6.09440947267e-10,        -2.45724528589e-09,        -2.42786751313e-09,         4.36154664038e-09,        -3.54855743659e-10, 
       -1.42305444282e-09,         1.00024599716e-08,        -7.57527453838e-09,        -1.15309113395e-09,         7.26515964575e-09, 
       -3.11312134607e-09,         1.69902900942e-08,         8.23337205407e-09,         5.50572167244e-10,         3.91961166498e-09, 
       -2.72490459953e-09,        -1.17346770601e-09,        -3.47033991327e-11,         1.96983249134e-09,         7.83295798222e-10, 
       -1.07127604123e-09,        -1.35369821833e-09,         1.67208143779e-10,         1.44444851373e-09,         3.31026917245e-10, 
       -1.07591550179e-09, 
},
{
        2.41599874755e-08,         5.57938308038e-09,        -1.24364581038e-08,        -5.78757202329e-09,        -5.33236750864e-10, 
       -1.02447330741e-08,        -1.56176567089e-08,        -7.77727637915e-09,         1.86848631934e-08,         5.65565450896e-09, 
        3.48178719141e-09,         9.94693369798e-09,        -1.09813234312e-09,         2.70452054169e-08,         1.84676281924e-08, 
        4.47088984301e-08,         1.21692743182e-09,        -4.01220131359e-09,        -2.56218407816e-08,         3.89085628958e-09, 
        5.51266703556e-08,        -6.10756541340e-08,        -4.43458489651e-08,         1.72410746167e-08,         1.98501541761e-08, 
       -1.25251047357e-08,        -9.63554985827e-09,        -2.75012662086e-08,        -1.99767880167e-08,        -7.17678108807e-09, 
       -8.03634366140e-10,        -1.24589481392e-09,         3.67152575399e-09,        -1.25802746504e-09,        -4.82578085922e-09, 
        6.30880542077e-11,         8.43599086582e-09,         3.31187579028e-09,        -3.99749779249e-09,        -1.30889983620e-09, 
        2.09995972464e-09,         1.72898416734e-09,        -4.56997427312e-09,        -2.64292922087e-09,         2.54665864620e-09, 
        1.96566610442e-09,        -1.93498263173e-10,        -7.07090958224e-10,        -1.86355894530e-10,        -1.05241474523e-09, 
       -1.07091126953e-09,        -2.98659480621e-09,         5.08047580137e-09,         7.32642732894e-10,        -1.62960902241e-09, 
       -4.13641130512e-09,         9.68693678467e-09,         1.98035273971e-08,        -1.18685291789e-09,         2.90469478096e-09, 
        2.42987554435e-09,        -9.94709876884e-10,        -1.91959160891e-09,        -3.78496969977e-11,         1.04458467503e-09, 
        1.14806206857e-09,        -1.21145980519e-09,        -1.39829852399e-09,        -2.63507975654e-11,         1.03171903222e-09, 
        4.09875612057e-10, 
},
{
       -1.64822346234e-08,         1.44550151705e-08,         5.82687740841e-09,        -1.12956402141e-08,        -8.31544736064e-09, 
        2.18158062104e-09,         8.49173762717e-09,         1.54674125684e-08,         2.70187123675e-09,        -1.23626381280e-08, 
        4.85299418606e-09,        -2.80583707324e-09,        -7.44725454916e-09,        -1.25977970703e-08,         9.60396433144e-09, 
       -1.19515702511e-08,        -1.54709625882e-08,        -1.14977127190e-08,         1.87990813652e-08,         1.21580146553e-08, 
       -4.75484133031e-08,        -1.72020032948e-08,         1.62227807058e-10,         2.40318699561e-08,         1.86563181409e-08, 
       -1.82378542679e-08,        -1.24166236395e-08,        -8.65140478835e-09,         4.58528999543e-09,         2.03423035869e-08, 
        2.42848654152e-09,         1.30082612011e-08,        -1.81452198282e-10,        -1.22959694028e-09,        -7.10186979739e-10, 
       -8.83415631899e-09,        -9.24721843609e-10,         6.52430491435e-09,         1.87000607912e-09,        -1.74069810477e-09, 
       -2.16024804314e-10,         4.48767823686e-09,         1.78833421118e-09,        -2.86368175890e-09,        -2.38014161373e-09, 
        1.33474796327e-09,         2.52626412522e-09,        -1.14235535308e-09,        -5.28895599390e-10,         3.15415005928e-09, 
       -1.28528327458e-09,        -2.96709280013e-09,        -2.17734312332e-09,         2.64463360538e-09,         5.56711636438e-09, 
       -2.09739327442e-09,        -9.20544214897e-09,        -1.59169644935e-10,         8.73198903821e-09,        -9.32289186153e-09, 
        3.85374641096e-09,         6.21853612141e-10,         6.07943896691e-10,        -1.11587403831e-09,        -1.37666933823e-10, 
        1.08005328140e-09,         1.50448905687e-09,        -4.89597099335e-10,        -1.07662153254e-09,        -1.84467417863e-10, 
        8.73554427792e-10, 
},
{
       -1.27401204913e-08,         5.16165824712e-09,         7.51428602813e-09,        -1.10760324343e-09,         2.96425102994e-10, 
        1.01694802868e-08,         7.56654478366e-09,         5.10795202929e-10,        -1.28532295314e-08,        -8.40455552125e-09, 
       -7.46922071122e-10,        -8.62130495409e-09,         3.36704987516e-09,        -1.86290309841e-08,        -2.00946991569e-08, 
       -2.88331375411e-08,         4.04612203291e-09,         1.90864915141e-08,         1.27000660657e-08,        -3.72302902607e-09, 
       -3.53685710999e-08,         6.40280009842e-08,         3.48346886857e-08,        -1.10372174737e-08,        -1.03017394034e-08, 
        1.30749185761e-08,         1.91715110330e-09,         3.59483647655e-08,         1.82534808592e-08,         1.03958262215e-09, 
       -1.16409011708e-09,         1.03894537516e-09,        -3.15770700139e-09,         9.88535012083e-10,         1.48115942450e-09, 
       -1.22885425774e-09,        -7.72436785031e-09,        -1.03821464859e-09,         4.18022744438e-09,        -1.28067907648e-10, 
       -2.86044796881e-09,        -5.42602025657e-11,         4.37238166481e-09,         1.13072594809e-09,        -1.52592493097e-09, 
       -2.29207337792e-09,         1.78385961867e-09,         1.48445640098e-09,        -7.36076411621e-10,        -2.47605537994e-09, 
        4.20140589651e-09,        -2.32569815446e-09,        -4.60708394373e-09,         1.88793679773e-09,         2.55409909749e-09, 
        5.69800025818e-10,        -6.36286139371e-10,        -7.28755597522e-09,        -5.15914245299e-09,         5.71826843351e-09, 
       -1.17418836778e-08,         2.14565428270e-09,        -1.70343269839e-09,        -4.74591447248e-10,        -1.63619821455e-09, 
       -1.30066557061e-09,         8.47839624938e-10,         9.77047947013e-10,        -1.06730535971e-10,        -1.18107204121e-09, 
       -2.75990318847e-10, 
},
{
        7.40393483778e-09,        -1.22718922654e-08,        -4.23468484569e-09,         1.06782999598e-08,        -2.72833621184e-09, 
       -6.29394825768e-09,        -2.60785340292e-09,        -1.25253311726e-08,        -5.17470377799e-09,         5.76630746686e-09, 
       -3.78782883611e-09,         1.02953038435e-08,         7.67666746281e-09,         1.87012445096e-08,         6.18285841963e-09, 
        2.65412480942e-08,         1.90311477250e-08,         1.68218219032e-09,        -2.34087288086e-08,        -1.68996763472e-08, 
        4.81029996204e-08,         2.23516977369e-09,        -9.96708057156e-09,        -7.41037281626e-09,        -1.94925754074e-08, 
       -6.73861880527e-09,         1.25417420055e-08,         3.76630331677e-10,        -6.19745329232e-09,        -1.75377197183e-08, 
       -5.53602385570e-09,        -1.88322523009e-08,        -1.08257270832e-09,         4.58902171664e-09,         1.28148464756e-09, 
        7.76254098089e-09,        -3.82308109093e-10,        -6.23042963495e-09,        -4.88696275753e-10,         3.10472119752e-09, 
       -7.77796520018e-10,        -4.44554397839e-09,         4.26914311606e-10,         2.61131412435e-09,         1.38785561053e-10, 
       -1.14271736077e-09,        -1.62306926013e-09,         1.68200092298e-09,         4.89067718099e-10,        -8.44705975869e-10, 
       -7.19318953367e-10,         3.29632119749e-09,        -2.93618688201e-09,        -2.93068764883e-09,         4.64191184387e-09, 
        1.74094772922e-09,        -2.55202252522e-09,         7.38402638070e-10,         1.95484765775e-09,        -8.12393121883e-09, 
       -5.07795279015e-09,        -4.45746192545e-10,         6.43379904282e-10,         1.58202653261e-09,        -1.95933950063e-10, 
       -7.60303108756e-10,        -1.13439670108e-09,         6.62241355984e-10,         9.87992988768e-10,        -1.43560165655e-10, 
       -9.55748964698e-10, 
},
{
        4.38664041931e-09,        -1.17536817048e-08,        -1.63758892476e-09,         4.65823709701e-09,         1.43887807780e-09, 
       -6.53709005602e-09,        -5.93205236001e-09,         6.90453768824e-09,         9.13668687461e-09,         1.21791315145e-08, 
       -5.15269678602e-09,        -3.86778811750e-09,        -5.06832387687e-09,         8.80629263707e-09,         9.83937060104e-09, 
        9.31932869300e-09,        -1.02167497610e-08,        -1.97291075515e-08,         1.36097293893e-09,         1.07910061324e-08, 
        1.31492303714e-08,        -5.93996408260e-08,        -2.55936007633e-08,         6.57747896695e-10,         6.49158977464e-09, 
       -8.19020229394e-09,         7.74005812187e-09,        -3.77473799985e-08,        -1.56992978789e-08,         3.45116942702e-09, 
        3.27379378683e-09,         3.10485749745e-09,         6.47129538451e-09,        -3.23560407241e-09,         1.61850800851e-09, 
        2.21218976826e-09,         5.90142578728e-09,        -5.94089575893e-10,        -4.52269253079e-09,         1.49677177703e-10, 
        3.36038332485e-09,        -8.57548171968e-10,        -4.02146408942e-09,         1.26868090563e-09,         1.32458188809e-09, 
       -6.25068401046e-11,        -1.01269674489e-09,        -7.48375194622e-10,         1.58727809537e-09,        -3.55890276786e-10, 
       -1.21015141064e-09,         1.55960133597e-09,         7.23023520962e-10,        -2.55791439043e-09,        -1.04652093951e-09, 
        3.15898383805e-09,        -8.73645574148e-10,        -5.14277019591e-09,         3.61093875817e-09,         2.85641167733e-10, 
        3.40446750909e-09,        -6.38219185060e-09,        -5.38094501392e-09,         1.12782397385e-09,        -8.39488243478e-10, 
        1.08521214448e-09,        -1.11478385894e-09,        -6.72530429535e-10,        -1.18117417163e-10,         9.26220173904e-10, 
       -9.30232850167e-12, 
},
{
        2.29089712878e-09,         1.08408421524e-08,         1.04999443261e-09,        -1.06165231649e-08,         8.49993043338e-09, 
        7.77568144802e-09,        -1.57556874099e-10,         6.66556724307e-09,         9.76413048972e-09,        -2.26851006669e-09, 
        1.22570701663e-08,        -1.15499576899e-08,        -6.70547872600e-09,        -1.99535069065e-08,        -1.17463312070e-08, 
       -2.31119934999e-08,        -1.48238196383e-08,         4.19021481216e-09,         1.82075083975e-08,         1.39685594597e-08, 
       -3.90571360404e-08,         1.01554826602e-08,         2.13587929319e-08,        -3.81845634785e-09,         2.04203330415e-08, 
        2.54080856481e-08,        -1.39052890983e-08,         7.56018239251e-09,         1.03669929201e-08,         1.11163576767e-08, 
        6.39391430799e-09,         2.16267314935e-08,         2.57326795691e-09,        -5.47694971524e-09,        -2.26261910304e-09, 
       -6.97184138590e-09,         1.00842411588e-09,         5.97848637751e-09,        -2.59568616650e-10,        -3.49679035932e-09, 
        8.47395693815e-10,         3.35761989880e-09,        -1.66835231259e-09,        -2.42389860422e-09,         1.29045594108e-09, 
        1.17873733003e-09,         3.87280057116e-10,        -1.33081020819e-09,        -8.03104765932e-11,         8.72586676622e-10, 
       -9.41430860214e-10,        -6.85219009779e-10,         2.44970372976e-09,        -7.93306195223e-11,        -1.53700851161e-09, 
       -4.15893772621e-10,         1.02785056340e-09,        -1.81759449110e-09,        -3.41870210021e-09,         2.83516381071e-09, 
        4.79476679518e-09,        -7.31855912268e-09,         6.07205397989e-09,        -3.52988375013e-09,         1.49869776539e-10, 
        3.58033912543e-10,         5.85423037020e-10,         4.90922885604e-10,        -1.38238499521e-09,        -1.33940122757e-10, 
        1.43749712933e-10, 
},
{
       -1.73581985668e-09,         1.24584542650e-08,        -3.24496696847e-09,        -4.41945970177e-09,        -1.80967750327e-09, 
        1.56181429956e-09,         5.66273189345e-09,        -1.02220988238e-08,        -8.95094866362e-09,        -1.45715820608e-08, 
        7.16487992162e-09,         1.89424403072e-08,         4.47882911543e-09,        -1.46747132195e-09,         3.44301893860e-09, 
        2.08732382621e-09,         1.27797940823e-08,         1.07507787832e-08,        -8.43277894842e-09,        -1.93644583563e-08, 
        3.98781540528e-09,         4.90212955552e-08,         1.59027078172e-08,         1.06990069887e-08,        -7.41812055197e-09, 
       -1.61572871160e-09,        -1.61381763485e-08,         3.21942151435e-08,         9.55251157949e-09,        -5.67525689603e-09, 
       -3.17249475282e-09,        -8.40098076022e-09,        -1.32939512273e-08,         5.10818818300e-09,        -3.70198695005e-09, 
       -3.15752181112e-09,        -3.25855368016e-09,         1.16674003775e-09,         4.83109396940e-09,         9.13236098569e-11, 
       -2.78281924383e-09,         1.80958894727e-09,         2.96280750771e-09,        -2.11370335183e-09,        -1.58179400303e-09, 
        7.46192122880e-10,         1.27834270693e-09,         6.06472136158e-10,        -1.34390044508e-09,         5.16011896194e-10, 
        3.67904967907e-10,        -1.65492794744e-09,        -6.99879322345e-10,         2.32964419565e-09,        -3.61434578005e-10, 
       -9.30529133379e-10,        -3.45512325939e-10,        -1.15020793696e-09,        -1.81139481846e-11,        -3.64421612832e-09, 
        1.12176538701e-09,         6.77721654913e-09,        -2.44833504770e-09,         4.42943526302e-09,        -1.53745014946e-09, 
       -1.78823678191e-09,         6.59051181672e-10,         5.69373254316e-10,         9.03632456301e-10,        -1.40173240718e-09, 
       -5.42159629820e-10, 
},
{
       -7.96465350923e-09,        -9.52439458732e-09,         2.58633910702e-09,         8.58956063721e-09,        -1.04538818180e-08, 
       -6.13721217280e-09,        -4.15673000823e-10,        -1.43042191432e-09,        -1.36159550692e-08,         5.94740558852e-10, 
       -2.31410287191e-08,         5.78015433538e-09,         5.76944931075e-09,         1.64892073847e-08,         8.14816734204e-09, 
        8.59225356011e-09,         9.98497625743e-09,         4.56138703124e-10,        -8.23806015893e-09,        -6.49943161483e-09, 
        2.58002435917e-08,        -1.64175155758e-08,        -3.05767063624e-08,         6.42955827022e-09,        -2.01731205733e-08, 
       -3.28102239565e-08,         1.57539603815e-08,        -1.09215864225e-08,        -1.41464020563e-08,        -3.77132422365e-09, 
       -6.47695618809e-09,        -2.15764931912e-08,        -9.02644884322e-10,         5.08830582293e-09,         2.31621979907e-09, 
        7.67422037722e-09,        -1.56543520398e-09,        -5.20675092788e-09,         6.05741283472e-10,         2.77199781536e-09, 
       -1.09322800897e-09,        -2.09748236100e-09,         2.41511376282e-09,         2.15937964838e-09,        -1.55294625799e-09, 
       -1.50004803254e-09,         4.34108090275e-10,         8.97972189051e-10,         2.36650997822e-10,        -1.43188015382e-09, 
        9.76527890534e-10,         5.70063323758e-10,        -1.60687744505e-09,         9.67547306982e-11,         2.42697848375e-09, 
       -6.76362381225e-10,        -6.94352166832e-10,         6.15868246020e-10,        -4.49258830683e-10,         1.21550880028e-09, 
       -6.08150364520e-10,         7.19935063611e-10,        -2.27194445699e-09,         1.08049908349e-09,        -2.78455148955e-10, 
       -4.03804997299e-09,        -2.30426868747e-10,        -3.48713570725e-10,         2.05711424708e-09,         5.93107948738e-10, 
       -6.36908048589e-10, 
},
{
        2.63152940689e-09,        -8.92601410711e-09,         5.49637491316e-09,         2.45829222501e-09,         8.47144676793e-11, 
        1.93008330117e-09,        -3.37121670181e-09,         8.48339476231e-09,         1.04034781991e-08,         1.48806311283e-08, 
       -3.32136651381e-09,        -2.76514665029e-08,        -1.59047596851e-09,        -9.12125294157e-10,        -1.17436410939e-08, 
       -1.37978246207e-09,        -1.12103878549e-08,        -2.20515216297e-09,         6.70072730551e-09,         2.40625426919e-08, 
       -1.26075058873e-08,        -3.75072194049e-08,        -5.72134026746e-09,        -1.85878915745e-08,         9.95039480850e-09, 
        1.35360155421e-08,         2.11758385885e-08,        -2.22794729644e-08,        -2.51454396366e-10,         6.78575014064e-09, 
        6.42545144708e-10,         1.30411304747e-08,         2.01259081345e-08,        -5.29068985244e-09,         5.64133626762e-09, 
        3.32751024670e-09,         2.74275224384e-10,        -1.41235387050e-09,        -4.40237774893e-09,         2.69611072256e-10, 
        1.84441943775e-09,        -2.61416400351e-09,        -1.81502512959e-09,         2.06891490312e-09,         1.17098293160e-09, 
       -8.41021424006e-10,        -1.22783814413e-09,         3.02756160758e-10,         7.69191897064e-10,        -2.61493527471e-10, 
       -1.21013027459e-09,         7.47458852712e-10,        -2.30374556584e-10,        -1.18840522584e-09,         8.83382975896e-10, 
        2.16319201313e-09,        -9.01844640114e-10,        -9.14834900449e-10,         1.36116563364e-09,        -3.97507128677e-10, 
       -9.73975935313e-10,         4.40437444569e-10,         2.54610623181e-09,        -3.22933140157e-09,        -2.49018583749e-09, 
        1.93040089306e-10,        -1.07210941655e-08,         8.67385342818e-10,        -2.86246121169e-09,         2.41560986575e-09, 
       -9.59273491876e-11, 
},
{
        8.51597170113e-09,         7.03509864265e-09,        -5.38257442836e-09,        -4.28494880239e-09,         1.11639407340e-08, 
        2.41918911099e-09,         1.93130787428e-09,         2.08191206169e-10,         1.50427925172e-08,         2.38089289811e-10, 
        2.84161414239e-08,         2.48080546008e-09,        -5.86740610631e-09,        -1.11998556618e-08,        -1.31105542561e-09, 
        5.21075908021e-09,        -9.38410343841e-09,        -1.31739882092e-08,        -3.87123542965e-10,        -1.05227280833e-09, 
       -1.36379268682e-08,         1.63865168252e-08,         3.38097072268e-08,        -1.25820133082e-09,         1.84909052894e-08, 
        2.79214314988e-08,        -1.74097729361e-08,         8.69560352481e-09,         1.39213267452e-08,        -3.36069539796e-09, 
        6.98130739382e-09,         1.98241139213e-08,        -4.03947621370e-09,        -5.46781945752e-09,        -1.40971342350e-09, 
       -9.80997916967e-09,         2.20419055879e-09,         3.88699148453e-09,        -1.05478043838e-09,        -1.69151076262e-09, 
        1.72299677178e-09,         1.19176902674e-09,        -2.81088516253e-09,        -1.09020952930e-09,         1.30826759132e-09, 
        7.65089659737e-10,        -5.19475473951e-10,        -6.76764667216e-10,         2.53466345549e-10,         7.44675870747e-10, 
       -2.75238804457e-10,        -5.64639744760e-11,         2.74801924605e-10,        -1.12939471069e-09,        -9.68869025588e-10, 
        9.12602833606e-10,         7.62639143359e-10,        -7.06526220624e-10,        -2.05367334067e-10,         1.78206953149e-09, 
       -3.09788236331e-10,        -1.55229552594e-09,        -2.83101734348e-09,         1.33680342189e-09,         1.43290518481e-09, 
       -1.14970548077e-08,         2.89694266568e-09,        -3.13518951522e-09,        -5.78690655449e-10,        -5.09508943853e-10, 
        9.99352256905e-10, 
},
{
       -3.27237518776e-09,         4.43853025917e-09,        -4.87163036123e-09,        -1.17214983794e-09,         2.26102509268e-09, 
       -2.45292428392e-09,        -8.39888657590e-10,        -4.51028252463e-09,        -1.05849520769e-08,        -1.35774200532e-08, 
       -2.87402332582e-09,         2.72461292508e-08,        -2.27894014213e-09,        -1.52072907787e-09,         1.26284831961e-08, 
       -6.80956356672e-09,         8.26093718430e-09,         1.86691883161e-09,         6.42691209712e-10,        -2.27093142582e-08, 
        1.31666011271e-08,         2.93461305169e-08,        -3.09864519799e-09,         1.99265602102e-08,        -1.10477469913e-08, 
       -2.33137504815e-08,        -2.21365446166e-08,         1.19317051447e-08,        -8.49448580078e-09,        -7.33182234258e-09, 
        3.13782539608e-09,        -1.67139870494e-08,        -2.40360136231e-08,         4.84296322829e-09,        -8.19264783374e-09, 
       -2.17378170557e-09,         2.61902802325e-09,         1.88174659775e-09,         3.76765377831e-09,        -1.03583876803e-09, 
       -1.25264544570e-09,         2.97428212102e-09,         7.69431230259e-10,        -1.95596255102e-09,        -1.55698022488e-10, 
        7.76353580091e-10,         7.48195071456e-10,        -5.55602389320e-10,        -3.10348076750e-10,         2.27912639163e-10, 
        2.60572023290e-10,         6.35940422297e-11,         9.37481190226e-10,         1.99714520585e-10,        -1.42752373506e-09, 
       -5.38471223676e-10,         3.71774675063e-10,        -7.75522776066e-10,        -7.32342481787e-10,         4.01459614375e-10, 
        8.75008879968e-10,        -8.64777774169e-10,        -1.42591178570e-09,        -2.31412973830e-09,         8.38231540988e-11, 
        1.83868211546e-09,        -2.20384449997e-09,        -6.02377870180e-09,         3.66436455043e-09,        -1.70581284725e-09, 
        9.01961596212e-10, 
},
{
       -6.11497807219e-09,        -2.97086926479e-09,         6.37337640382e-09,        -6.62945429412e-10,        -1.19740104189e-08, 
        1.48651180064e-09,        -2.04535676225e-09,        -3.42744602541e-09,        -1.44513672260e-08,        -3.79724333252e-10, 
       -2.55813596411e-08,        -7.72647314055e-09,         7.64226778954e-09,         7.69799854952e-09,        -3.28135351891e-09, 
       -1.03340975860e-08,         1.33576313606e-08,         2.57673154685e-08,         3.57504467100e-09,         5.53583120510e-09, 
        6.19728537973e-09,        -1.31907492239e-08,        -2.99482228616e-08,        -7.23900786884e-09,        -1.62012775422e-08, 
       -1.44838460470e-08,         1.89052958562e-08,        -2.71964555076e-09,        -8.76786418863e-09,         9.87990830005e-09, 
       -7.95455553978e-09,        -1.70169733811e-08,         1.01701235576e-08,         7.14713919486e-09,         6.02612137241e-10, 
        1.27180311246e-08,        -2.67429434690e-09,        -2.91822777588e-09,         1.73101700156e-09,         8.07838683612e-10, 
       -2.23246643612e-09,        -5.45627449719e-10,         2.77744479822e-09,         6.48460661102e-11,        -1.37482528896e-09, 
        1.55817547540e-10,         5.64135381227e-10,         5.68452405185e-10,        -7.17601388927e-10,        -2.51326559779e-10, 
        5.71406766825e-11,        -3.82822469571e-10,         1.14177047130e-10,         1.34945037717e-09,         2.98181481296e-10, 
       -1.18454773423e-09,         1.32368715558e-10,         1.59002680471e-10,        -8.63052176107e-10,        -3.67961260217e-10, 
        9.46954034990e-10,         1.32800186332e-09,        -1.69876636604e-09,        -1.16384044557e-09,        -5.67880954727e-10, 
        4.77879860110e-10,        -2.54296515202e-09,         4.16483446182e-09,        -5.72920790611e-09,         1.45244569321e-09, 
       -4.52619460949e-10, 
},
{
        1.62596736836e-09,        -1.49622585363e-09,         2.60919247612e-09,         1.49172686724e-09,        -3.33642449852e-09, 
        5.37524642165e-10,         4.62992696453e-09,         2.17345692265e-09,         8.07264447263e-09,         1.13577524675e-08, 
        6.40176794335e-09,        -2.16127959871e-08,         5.48794169254e-09,         6.23472067231e-09,        -8.99797600770e-09, 
        1.41789625240e-08,        -7.32976742460e-09,        -1.05049505531e-08,        -8.43557024277e-09,         1.66182747533e-08, 
       -8.89395805178e-09,        -2.61821134855e-08,         7.82160534457e-09,        -1.49978997267e-08,         9.45640489721e-09, 
        2.73327776411e-08,         1.91428172678e-08,        -4.01047838598e-09,         1.27615973631e-08,         6.47725818291e-09, 
       -6.79275133793e-09,         1.93707150635e-08,         2.41892680435e-08,        -5.22047092849e-09,         1.10407108040e-08, 
       -1.98824586445e-10,        -5.56290282495e-09,        -2.38954438292e-09,        -3.47607694255e-09,         1.58375447723e-09, 
        1.09208358889e-09,        -2.75467660366e-09,         2.26812455269e-11,         1.91598835199e-09,        -5.43185966767e-10, 
       -1.14553791821e-09,        -3.70897553624e-11,         5.49531840837e-10,         4.02048905710e-10,        -6.99419556740e-10, 
       -7.10944397203e-11,        -3.97417090200e-11,        -7.03871722677e-10,         8.14519990224e-11,         1.26113697337e-09, 
        2.50691876175e-10,        -8.50319609008e-10,         4.93916932292e-10,         1.02226783503e-10,        -3.58563647806e-10, 
       -5.47763034272e-10,         1.14574813518e-09,         9.99767478825e-10,        -1.02913339346e-09,        -3.56948901971e-10, 
       -2.01271217180e-10,         7.12880998446e-11,         1.76246896084e-09,         9.16095813300e-10,        -2.91838999073e-09, 
       -7.26003979083e-10, 
},
{
        3.69727728288e-09,        -1.69664793330e-09,        -5.32890170011e-09,         4.31625903902e-09,         1.23944472972e-08, 
       -4.05287213036e-09,         3.30581679957e-10,         8.46506196956e-09,         1.34504272386e-08,        -3.04758226112e-10, 
        1.83090034549e-08,         7.56450413196e-09,        -1.10354932803e-08,        -7.87276491407e-09,         3.89812022200e-09, 
        6.91858592688e-09,        -1.85574927050e-08,        -3.06682021771e-08,        -7.73252034687e-10,        -6.16204351175e-09, 
       -4.60865021638e-09,         1.07359616343e-08,         2.15954703009e-08,         1.37251161271e-08,         1.44883134831e-08, 
       -6.39121934769e-10,        -2.04582116321e-08,        -4.16058499605e-09,         9.70033686013e-10,        -1.46819420591e-08, 
        8.77155279860e-09,         1.32162741317e-08,        -1.55147590017e-08,        -9.02369802565e-09,        -7.65052065292e-10, 
       -1.56215979354e-08,         3.00482513093e-09,         2.68402875854e-09,        -2.24568025543e-09,         5.12537583711e-11, 
        2.29672703877e-09,        -8.04157407717e-11,        -2.43093739180e-09,         5.57867298974e-10,         1.49523837522e-09, 
       -5.59982471250e-10,        -7.91879794689e-10,        -2.29484267950e-10,         6.46032577230e-10,         3.12476449818e-10, 
       -4.59399134868e-10,         1.14382411042e-10,        -2.27826377425e-10,        -6.54823721919e-10,         2.21820221902e-10, 
        1.00670723423e-09,        -2.75677376479e-11,        -4.06721740336e-10,         5.00719542170e-10,         2.93795721299e-10, 
       -4.34812896658e-10,        -1.67327271303e-10,         9.92224819614e-10,         5.57830334669e-10,        -8.08969856346e-10, 
        1.22119352598e-09,        -8.91848824164e-10,        -1.98030770987e-09,         2.64121305357e-09,        -6.34279834292e-10, 
       -3.96057983028e-09, 
},
{
        1.52806478495e-09,         6.34789056617e-10,        -5.21852017415e-10,        -2.70331978694e-09,         2.57624058017e-09, 
        2.06665118291e-09,        -5.98494107621e-09,        -3.22545831315e-09,        -3.71930617847e-09,        -8.64996914539e-09, 
       -4.99961280072e-09,         1.68336097823e-08,        -7.02858831969e-09,        -9.92163217561e-09,         5.44794004300e-09, 
       -1.52073838859e-08,         9.86466388359e-09,         2.25636434125e-08,         1.25275965738e-08,        -9.03928589254e-09, 
        4.15735029396e-09,         2.63204543343e-08,        -6.99775938241e-09,         7.31297233401e-09,        -5.99961491778e-09, 
       -2.46702553188e-08,        -1.29055536797e-08,        -8.96060345925e-11,        -1.12662672307e-08,        -3.22399485107e-09, 
        9.56795364478e-09,        -2.04240415400e-08,        -2.12736996740e-08,         6.65665590113e-09,        -1.30856502829e-08, 
        3.39784549547e-09,         8.79896076064e-09,         2.37630113950e-09,         3.62235906453e-09,        -1.61916177275e-09, 
       -1.06520286135e-09,         2.27325775559e-09,        -6.25468208312e-10,        -1.70157522395e-09,         7.23512477343e-10, 
        1.27980826435e-09,        -2.58318532755e-10,        -4.64485951746e-10,        -3.18919543359e-10,         6.95262772944e-10, 
        2.45992752874e-10,         6.40154458791e-11,        -1.79062185282e-11,        -5.71785186933e-10,        -7.39478461467e-10, 
        2.94324914707e-10,         5.11195664453e-10,        -3.81945021027e-10,        -1.89887208531e-10,         5.44035108533e-10, 
        1.01609824632e-11,        -8.94292584320e-10,        -3.80958688030e-10,         8.02741776352e-10,         5.12272670985e-10, 
       -6.97360854629e-10,         6.58950762952e-10,         1.61155222236e-09,        -1.92145271366e-09,         1.03758629856e-09, 
       -4.63212812993e-10, 
},
} ;

gal_gm_t gal_gmglgm2 = {
GAL_SSB_MO,
"GLGM-2",
4.9028029535968e+12,
1.7380e+06,
70,
70,
1,
(double *) &gal_gmglgm2_terms
} ;

__END_DECLS  
  
#endif /* !_GAL_GMGLGM2_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
