/*  
 *  - - - - - - - - - - - -
 *   g a l _ g m o p v 0 0  
 *  - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Moon position and velocity, with respect to the Geocentric Celestial 
 *  Reference Frame (GCRF).  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     epoch1              d        TDB epoch part A (Note 1)  
 *     epoch2              d        TDB epoch part B (Note 1) 
 *     icor                i        correction type
 *                                  icor=0, the constants are fitted to LLR observations provided 
 *                                  from 1970 to 2001; it is the default value;
 *                                  icor=1, the constants are fitted to DE405 ephemeris over one 
 *                                  century (1950-2060); the lunar angles W1, W2, W3 receive 
 *                                  also additive corrections to the secular coefficients.
 *  
 *  Returned:
 *  
 *     pv               d[2][3]     Geocentric Moon position & velocity ( m, m/s )  
 *     gal_gmopv00         i        status: 
 *                                    0 = Success  
 *                                    1 = warning: date outside 1940-2060 CE  
 *  
 *  Notes:  
 *  
 *  1) The epoch epoch1+epoch2 is a Julian Date, apportioned in  
 *     any convenient way between the two arguments.  For example,  
 *     JD(TDB)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            epoch1       epoch2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *     However, the accuracy of the result is more likely to be  
 *     limited by the algorithm itself than the way the epoch has been  
 *     expressed.  
 * 
 *  References:
 *
 *     LUNAR SOLUTION ELP version ELP/MPP02 
 *     Jean CHAPRONT and G´erard FRANCOU 
 *     Observatoire de Paris -SYRTE department - UMR 8630/CNRS 
 *     October 2002  
 *
 *  This revision:
 *  
 *     2008 June 7  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_GMOPV02_H_  
#define _GAL_GMOPV02_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
int  
gal_gmopv02  
 (  
    double epoch1,  
    double epoch2, 
    int icor, 
    double pv[2][3] 
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_GMOPV02_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
