/*  
 *  - - - - - - - - - - -  
 *   g a l _ g s t 0 0 b  
 *  - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Greenwich Apparent Sidereal Time (consistent with IAU 2000  
 *  resolutions but using the truncated nutation model IAU 2000B).  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     uta,utb             d        UT1 as a 2-part Julian Date (Notes 1,2)  
 *  
 *  Returned:
 *  
 *     gal_gst00b          d        The result is the Greenwich Apparent Sidereal  
 *                                  Time (radians), in the range 0 to 2pi.  
 *  Notes:  
 *  
 *  1) The UT1 date uta+utb is a Julian Date, apportioned in any  
 *     convenient way between the argument pair.  For example,  
 *     JD=2450123.7 could be expressed in any of these ways, among  
 *     others:  
 *  
 *             uta            utb  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in cases  
 *     where the loss of several decimal digits of resolution is  
 *     acceptable.  The J2000 and MJD methods are good compromises  
 *     between resolution and convenience.  For UT, the date & time  
 *     method is best matched to the algorithm that is used by the Earth  
 *     Rotation Angle routine, called internally:  maximum accuracy (or,  
 *     at least, minimum noise) is delivered when the uta argument is for  
 *     0hrs UT1 on the day in question and the utb argument lies in the  
 *     range 0 to 1, or vice versa.  
 *  
 *  2) The result is compatible with the IAU 2000 resolutions, except  
 *     that accuracy has been compromised for the sake of speed and  
 *     convenience in two respects:  
 *  
 *     . UT is used instead of TDB (or TT) to compute the precession  
 *       component of GMST and the equation of the equinoxes.  This  
 *       results in errors of order 0.1 mas at present.  
 *  
 *     . The IAU 2000B abridged nutation model (McCarthy & Luzum, 2001)  
 *       is used, introducing errors of up to 1 mas.  
 *  
 *  3) This GAST is compatible with the IAU 2000 resolutions and must be  
 *     used only in conjunction with other IAU 2000 compatible components  
 *     such as precession-nutation.  
 *  
 *  4) The algorithm is from Capitaine et al. (2003) and IERS Conventions  
 *     2003.  
 *  
 *  Called:
 *  
 *     gal_gmst00         Greenwich mean sidereal time, IAU 2000  
 *     gal_ee00b          equation of the equinoxes, IAU 2000B  
 *     gal_anp            normalize angle into range 0 to 2pi  
 *  
 *  References:  
 *  
 *     Capitaine, N., Wallace, P.T. and McCarthy, D.D., "Expressions to  
 *     implement the IAU 2000 definition of UT1", Astronomy &  
 *     Astrophysics, 406, 1135-1149 (2003)  
 *  
 *     McCarthy, D.D. & Luzum, B.J., "An abridged model of the  
 *     precession-nutation of the celestial pole", Celestial Mechanics &  
 *     Dynamical Astronomy, 85, 37-49 (2003)  
 *  
 *     McCarthy, D. D., Petit, G. (eds.), IERS Conventions (2003),  
 *     IERS Technical Note No. 32, BKG (2004)  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 January 19 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_GST00B_H_  
#define _GAL_GST00B_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
double  
gal_gst00b  
 (  
    double uta,  
    double utb  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_GST00B_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
