/*  
 *  - - - - - - - - - - -  
 *   g a l _ g s t 0 6 a  
 *  - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Greenwich apparent sidereal time (consistent with IAU 2000 and 2006  
 *  resolutions).  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     canonical model.  
 *  
 *  Given:
 *  
 *     uta,utb             d        UT1 as a 2-part Julian Date (Notes 1,2)  
 *     tta,ttb             d        TT as a 2-part Julian Date (Notes 1,2)  
 *  
 *  Returned:
 *  
 *     gal_gst06a          d        Greenwich apparent sidereal time (radians)  
 *  
 *  Notes:  
 *  
 *  1) The UT1 and TT dates uta+utb and tta+ttb respectively, are both  
 *     Julian Dates, apportioned in any convenient way between the  
 *     argument pairs.  For example, JD=2450123.7 could be expressed in  
 *     any of these ways, among others:  
 *  
 *            Part A       Part B  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable (in the case of UT;  the TT is not at all critical  
 *     in this respect).  The J2000 and MJD methods are good compromises  
 *     between resolution and convenience.  For UT, the date & time  
 *     method is best matched to the algorithm that is used by the Earth  
 *     rotation angle routine, called internally:  maximum accuracy (or,  
 *     at least, minimum noise) is delivered when the uta argument is for  
 *     0hrs UT1 on the day in question and the utb argument lies in the  
 *     range 0 to 1, or vice versa.  
 *  
 *  2) Both UT1 and TT are required, UT1 to predict the Earth rotation  
 *     and TT to predict the effects of precession-nutation.  If UT1 is  
 *     used for both purposes, errors of order 100 microarcseconds  
 *     result.  
 *  
 *  3) This GAST is compatible with the IAU 2000/2006 resolutions and must  
 *     be used only in conjunction with IAU 2006 precession and IAU 2000A  
 *     nutation.  
 *  
 *  4) The result is returned in the range 0 to 2pi.  
 *  
 *  Called:
 *  
 *     gal_pnm06a         classical NPB matrix, IAU 2006/2000A  
 *     gal_gst06          Greenwich apparent ST, IAU 2006, given NPB matrix  
 *  
 *  References:  
 *  
 *     Wallace, P.T. & Capitaine, N., 2006, Astron.Astrophys. 459, 981  
 *  
 *  This revision:
 *  
 *     2006 December 5 ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_GST06A_H_  
#define _GAL_GST06A_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
double  
gal_gst06a  
 (  
    double uta,  
    double utb,  
    double tta,  
    double ttb  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_GST06A_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
