/*  
 *  - - - - - - - - - -  
 *   g a l _ g s t 9 4  
 *  - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Greenwich Apparent Sidereal Time (consistent with IAU 1982/94  
 *  resolutions).  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     uta,utb             d        UT1 as a 2-part Julian Date (Notes 1,2)  
 *  
 *  Returned:
 *  
 *     gal_gst94           d        The result is the Greenwich Apparent Sidereal  
 *                                  Time (radians), in the range 0 to 2pi.  
 *  
 *  Notes:  
 *  
 *  1) The UT1 date uta+utb is a Julian Date, apportioned in any  
 *     convenient way between the argument pair.  For example,  
 *     JD=2450123.7 could be expressed in any of these ways, among  
 *     others:  
 *  
 *             uta            utb  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in cases  
 *     where the loss of several decimal digits of resolution is  
 *     acceptable.  The J2000 and MJD methods are good compromises  
 *     between resolution and convenience.  For UT, the date & time  
 *     method is best matched to the algorithm that is used by the Earth  
 *     Rotation Angle routine, called internally:  maximum accuracy (or,  
 *     at least, minimum noise) is delivered when the uta argument is for  
 *     0hrs UT1 on the day in question and the utb argument lies in the  
 *     range 0 to 1, or vice versa.  
 *  
 *  2) The result is compatible with the IAU 1982 and 1994 resolutions,  
 *     except that accuracy has been compromised for the sake of  
 *     convenience in that UT is used instead of TDB (or TT) to compute  
 *     the equation of the equinoxes.  
 *  
 *  3) This GAST must be used only in conjunction with contemporaneous  
 *     IAU standards such as 1976 precession, 1980 obliquity and 1982  
 *     nutation.  It is not compatible with the IAU 2000 resolutions.  
 *  
 *  Called:
 *  
 *     gal_gmst82         Greenwich mean sidereal time, IAU 1982  
 *     gal_eqeq94         equation of the equinoxes, IAU 1994  
 *     gal_anp            normalize angle into range 0 to 2pi  
 *  
 *  References:  
 *  
 *     Explanatory Supplement to the Astronomical Almanac,  
 *     P. Kenneth Seidelmann (ed), University Science Books (1992)  
 *  
 *     IAU Resolution C7, Recommendation 3 (1994)  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 January 19 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_GST94_H_  
#define _GAL_GST94_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
double  
gal_gst94  
 (  
    double uta,  
    double utb  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_GST94_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
