/*  
 *  - - - - - - - - - -  
 *   g a l _ h 2 f k 5  
 *  - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Transform Hipparcos star data into the FK5 (J2000) system.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given (all Hipparcos, epoch J2000):  
 *     rh                  d        RA (radians)  
 *     dh                  d        Dec (radians)  
 *     drh                 d        proper motion in RA (dRA/dt, rad/Jyear)  
 *     ddh                 d        proper motion in Dec (dDec/dt, rad/Jyear)  
 *     pxh                 d        parallax (arcsec)  
 *     rvh                 d        radial velocity (positive = receding)  
 *  
 *  Returned (all FK5, equinox J2000, epoch J2000):  
 *     *r5                 d        RA (radians)  
 *     *d5                 d        Dec (radians)  
 *     *dr5                d        proper motion in RA (dRA/dt, rad/Jyear)  
 *     *dd5                d        proper motion in Dec (dDec/dt, rad/Jyear)  
 *     *px5                d        parallax (arcsec)  
 *     *rv5                d        radial velocity (positive = receding)  
 *  
 *  Notes:  
 *  
 *  1) This routine transforms Hipparcos star positions and proper  
 *     motions into FK5 J2000.  
 *  
 *  2) The proper motions in RA are dRA/dt rather than  
 *     cos(Dec)*dRA/dt, and are per year rather than per century.  
 *  
 *  3) The FK5 to Hipparcos transformation is modeled as a pure  
 *     rotation and spin;  zonal errors in the FK5 catalogue are  
 *     not taken into account.  
 *  
 *  4) See also gal_fk52h, gal_fk5hz, gal_hfk5z.  
 *  
 *  Called:
 *  
 *     gal_starpv         star catalog data to space motion pv-vector  
 *     gal_fk5hip         FK5 to Hipparcos rotation and spin  
 *     gal_rv2m           r-vector to r-matrix  
 *     gal_rxp            product of r-matrix and p-vector  
 *     gal_trxp           product of transpose of r-matrix and p-vector  
 *     gal_pxp            vector product of two p-vectors  
 *     gal_pmp            p-vector minus p-vector  
 *     gal_pvstar         space motion pv-vector to star catalog data  
 *  
 *   References:  
 *  
 *     F.Mignard & M.Froeschle, Astron. Astrophys. 354, 732-739 (2000).  
 *  
 *  This revision:
 *  
 *     2007 April 18 ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_H2FK5_H_  
#define _GAL_H2FK5_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_h2fk5  
 (  
    double rh,  
    double dh,  
    double drh,  
    double ddh,  
    double pxh,  
    double rvh,  
    double *r5,  
    double *d5,  
    double *dr5,  
    double *dd5,  
    double *px5,  
    double *rv5  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_H2FK5_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
