/*  
 *  - - - - - - - - - - - -
 *   g a l _ h p l p v 8 7 
 *  - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Pluto heliocentric position and velocity, with respect to the 
 *  FK5 Reference Frame.  
 *  
 *  Status:
 *  
 *     internal support routine.  
 *  
 *  Given:
 *  
 *     tdb1                d            TDB epoch part 1 (Note 1)  
 *     tdb2                d            TDB epoch part 2 (Note 1)  
 *     ref                 i            Reference frame
 *                                        0 = dynamical equinox and ecliptic J2000.
 *                                        1 = FK5 (VSOP87)
 *  
 *  Returned:
 *  
 *     pv               d[2][3]         position/velocity (AU, AU/Day)  
 *  
 *  Called:
 *
 *     gal_zpv                          Zero pv-vector
 *     gal_sxpv                         Scale pv-vector
 *     gal_rxpv                         Product of r-matrix and pv-vector
 *
 *  Notes:  
 *  
 *  1) The epoch tt1+tt2 is a Julian Date, apportioned in  
 *     any convenient way between the two arguments.  For example,  
 *     JD(TDB)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *              tdb1         tdb2
 *  
 *         2450123.7          0.0       (JD method)  
 *         2451545.0      -1421.3       (J2000 method)  
 *         2400000.5      50123.2       (MJD method)  
 *         2450123.5          0.2       (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *     However, the accuracy of the result is more likely to be  
 *     limited by the algorithm itself than the way the epoch has been  
 *     expressed.  
 *  
 *  2) On return, the arrays pvh and pvb contain the following:  
 *  
 *        pv[0][0]  x       }  
 *        pv[0][1]  y       } position, AU  
 *        pv[0][2]  z       }  
 *  
 *        pv[1][0]  xdot    }  
 *        pv[1][1]  ydot    } velocity, AU/day  
 *        pv[1][2]  zdot    }  
 *  
 *     The vectors are heliocentric with respect to the FK5 Reference Frame.  
 *     The time unit is one day in TT 
 *  
 *  3) Computation of heliocentric rectangular coordinates of Pluto.
 *     Source : DE200 (Jet Propulsion Laboratory).
 *     Frame : dynamical mean equinox and equator J2000 (DE200).
 *     The ephemerides are computed with a method of approximation
 *     using frequency analysis.
 *
 *  4) Valid date range is JD2341972.5  (Jan 01 1700 0h) to
 *     JD2488092.5  (Jan 01 2100 0h).
 *  
 *  References:
 *
 *     J. Chapront, 1995, Astron. Atrophys. Sup. Ser., 109, 181.
 *
 *  This revision:
 *  
 *     2008 July 5 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_HPLPV87_H_  
#define _GAL_HPLPV87_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

void 
gal_hplpv87  
 (  
    double tt1,  
    double tt2, 
    int ref, 
    double pv[2][3]
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_GAL_HPLPV87_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
