/*  
 *  - - - - - - - - - - - -
 *   g a l _ m a s u d a t  
 *  - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     This routine calculates a number of Sun data values
 *     for the planet Mars. 
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     mtc1               d        MTC date part 1 ( see Note 1 )  
 *     mtc2               d        MTC date part 2 ( see Note 1 ) 
 *     m                  d        Mars mean anomaly ( radians )
 *     ls                 d        Aerocentric solar longitude ( radians )
 *     eot                d        Equation of time ( radians )
 *     lon                d        Longitude of local observer ( radians ) ( see Note 3 )
 *     lat                d        Latitude of local observer ( radians )
 *  
 *  Returned:
 *
 *     *ssl               d        Subsolar longitude ( radians )
 *     *sdec              d        Solar declination ( planetographic ) ( radians )
 *     *mhd               d        Mars heliocentric distance ( AU )
 *     *mhlon             d        Mars heliocentric longitude ( radians )
 *     *mhlat             d        Mars heliocentric latitude ( radians )
 *     *sel               d        Local solar elevation ( radians )
 *     *saz               d        Local solar azimuth ( radians ) 
 *  
 *  Notes:
 *
 *  1) mtc1 contains the sol number, and mtc2 the fractional part of the 
 *     sol. A Mars "day" is called a "sol".
 *
 *  2) As defined, consistent with the terrestrial convention for Mean
 *     Solar Time, JD 2451549.5 (2000 January 6 00:00:00) corresponds to
 *     a near coincidence of the terrestrial Greenwich mean solar
 *     midnight and the Martian mean solar (prime meridian) midnight. The
 *     addition of the integer number 44796 assures a positive result
 *     for any date since JD 2405522 (1873 December 29.5).
 *
 *  3) Longitude is measured westwards from the prime meridian (0-2pi).
 *   
 *  Called:
 *
 *     gal_anp            Normalise angle in range 0 <= a < 2pi
 *
 *  References:
 *
 *     A post-Pathfinder evaluation of areocentric solar coordinates with 
 *     improved timing recipes for Mars seasonal/diurnal climate studies 
 *     by Michael Allison, Megan McEwen, 
 *     Planetary and Space Science 48 (2000) 215-235 
 *
 *     Mars24 URL: http://www.giss.nasa.gov/tools/mars24/help/algorithm.html
 *     The referenced URL contains corrections to the referenced article.
 *
 *  This revision:
 *  
 *     2009 January 6  
 *  
 *  Copyright (C) 2009 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_MASUDAT_H_  
#define _GAL_MASUDAT_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void 
gal_masudat  
 (  
   double mtc1,  
   double mtc2,   
   double m,    
   double ls,       
   double eot,             
   double lon,              
   double lat,              
   double *ssl,           
   double *sdec,             
   double *mhd,             
   double *mhlon,           
   double *mhlat,           
   double *sel,              
   double *saz               
  ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_MASUDAT_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
