/*  
 *  - - - - - - - - - - -  
 *   g a l _ n u t 0 6 a  
 *  - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  IAU 2000A nutation with adjustments to match the IAU 2006 precession.  
 *  
 *  Status: canonical model.  
 *  
 *  Given:
 *  
 *     date1,date2         d        TT as a 2-part Julian Date (Note 1)  
 *  
 *  Returned:
 *  
 *     *dpsi,*deps         d        nutation, luni-solar + planetary (Note 2)  
 *  
 *  Notes:  
 *  
 *  1) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  2) The nutation components in longitude and obliquity are in radians  
 *     and with respect to the mean equinox and ecliptic of date,  
 *     IAU 2006 precession model (Hilton et al. 2006, Capitaine et al.  
 *     2005).  
 *  
 *  3) The routine first computes the IAU 2000A nutation, then applies  
 *     adjustments for (i) the consequences of the change in obliquity  
 *     from the IAU 1980 ecliptic to the IAU 2006 ecliptic and (ii) the  
 *     secular variation in the Earth's dynamical flattening.  
 *  
 *  4) The present routine provides classical nutation, complementing  
 *     the IAU 2000 frame bias and IAU 2006 precession.  It delivers a  
 *     pole which is at current epochs accurate to a few tens of  
 *     microarcseconds, apart from the free core nutation.  
 *  
 *  Called:
 *  
 *     gal_nut00a         nutation, IAU 2000A  
 *  
 *  References:  
 *  
 *     Wallace, P.T. & Capitaine, N., 2006, Astron.Astrophys. 459, 981  
 *  
 *  This revision:
 *  
 *     2007 February 27 ( c version 2008 January 19 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_NUT06A_H_  
#define _GAL_NUT06A_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_nut06a  
 (  
    double date1,  
    double date2,  
    double *dpsi,  
    double *deps  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_NUT06A_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
