/*  
 *  - - - - - - - -  
 *   g a l _ p a p  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Position-angle from two p-vectors.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     vector/matrix support routine.  
 *  
 *  Given:
 *  
 *     a                  d[3]      direction of reference point  
 *     b                  d[3]      direction of point whose PA is required  
 *  
 *  Returned:
 *  
 *     gal_pap             d        position angle of b with respect to b (radians)  
 *  
 *  Notes:  
 *  
 *  1) The result is the position angle, in radians, of direction b with  
 *     respect to direction a.  It is in the range -pi to +pi.  The sense  
 *     is such that if b is a small distance "north" of a the position  
 *     angle is approximately zero, and if b is a small distance "east" of  
 *     a the position angle is approximately +pi/2.  
 *  
 *  2) a and b need not be unit vectors.  
 *  
 *  3) Zero is returned if the two directions are the same or if either  
 *     vector is null.  
 *  
 *  4) If a is at a pole, the result is ill-defined.  
 *  
 *  Called:
 *  
 *     gal_pn             decompose p-vector into modulus and direction  
 *     gal_pm             modulus of p-vector  
 *     gal_pxp            vector product of two p-vectors  
 *     gal_pmp            p-vector minus p-vector  
 *     gal_pdp            scalar product of two p-vectors  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 June 8 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_PAP_H_  
#define _GAL_PAP_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
double  
gal_pap  
 (  
    double a[3],  
    double b[3]  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_PAP_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
