/*  
 *  - - - - - - - - -  
 *   g a l _ p b 0 6  
 *  - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  This routine forms three Euler angles which implement general  
 *  precession from epoch J2000.0, using the IAU 2006 model.  Frame  
 *  bias (the offset between ICRS and mean J2000.0) is included.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     date1,date2         d        TT as a 2-part Julian Date (Note 1)  
 *  
 *  Returned:
 *  
 *     *bzeta              d        1st rotation: radians clockwise around z  
 *     *bz                 d        3rd rotation: radians clockwise around z  
 *     *btheta             d        2nd rotation: radians counterclockwise around y  
 *  
 *  Notes:  
 *  
 *  1) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  2) The traditional accumulated precession angles zeta_A, z_A, theta_A  
 *     cannot be obtained in the usual way, namely through polynomial  
 *     expressions, because of the frame bias.  The latter means that two  
 *     of the angles undergo rapid changes near this date.  They are  
 *     instead the results of decomposing the precession-bias matrix  
 *     obtained by using the Fukushima-Williams method, which does not  
 *     suffer from the problem.  The decomposition returns values which  
 *     can be used in the conventional formulation and which include  
 *     frame bias.  
 *  
 *  3) The three angles are returned in the conventional order, which  
 *     is not the same as the order of the corresponding Euler rotations.  
 *     The precession-bias matrix is R_3(-z) x R_2(+theta) x R_3(-zeta).  
 *  
 *  4) Should zeta_A, z_A, theta_A angles be required that do not contain  
 *     frame bias, they are available by calling the SOFA routine  
 *     gal_P06E.  
 *  
 *  Called:
 *  
 *     gal_pmat06         PB matrix, IAU 2006  
 *     gal_rz             rotate around Z-axis  
 *  
 *  This revision:
 *  
 *     2007 June 8 ( c version 2008 January 19 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_PB06_H_  
#define _GAL_PB06_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_pb06  
 (  
    double date1,  
    double date2,  
    double *bzeta,  
    double *bz,  
    double *btheta  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_PB06_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
