/*  
 *  - - - - - - - - - -  
 *   g a l _ p f w 0 6  
 *  - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Precession angles, IAU 2006 (Fukushima-Williams 4-angle formulation).  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     canonical model.  
 *  
 *  Given:
 *  
 *     date1,date2         d        TT as a 2-part Julian Date (Note 1)  
 *  
 *  Returned:
 *  
 *     gamb                d        F-W angle gamma_bar (radians)  
 *     phib                d        F-W angle phi_bar (radians)  
 *     psib                d        F-W angle psi_bar (radians)  
 *     epsa                d        F-W angle epsilon_A (radians)  
 *  
 *  Notes:  
 *  
 *  1) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  2) Naming the following points:  
 *  
 *           e = J2000 ecliptic pole,  
 *           p = GCRS pole,  
 *           E = mean ecliptic pole of date,  
 *     and   P = mean pole of date,  
 *  
 *     the four Fukushima-Williams angles are as follows:  
 *  
 *        gamb = gamma_bar = epE  
 *        phib = phi_bar = pE  
 *        psib = psi_bar = pEP  
 *        epsa = epsilon_A = EP  
 *  
 *  3) The matrix representing the combined effects of frame bias and  
 *     precession is:  
 *  
 *        PxB = R_1(-epsa).R_3(-psib).R_1(phib).R_3(gamb)  
 *  
 *  4) The matrix representing the combined effects of frame bias,  
 *     precession and nutation is simply:  
 *  
 *        NxPxB = R_1(-epsa-dE).R_3(-psib-dP).R_1(phib).R_3(gamb)  
 *  
 *     where dP and dE are the nutation components with respect to the  
 *     ecliptic of date.  
 *  
 *  References:  
 *  
 *     Hilton, J. et al., 2006, Celest.Mech.Dyn.Astron. 94, 351  
 *  
 *  Called:
 *  
 *     gal_obl06          mean obliquity, IAU 2006  
 *  
 *  This revision:
 *  
 *     2007 June 8 ( c version 2008 January 19 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_PFW06_H_  
#define _GAL_PFW06_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_pfw06  
 (  
    double date1,  
    double date2,  
    double *gamb,  
    double *phib,  
    double *psib,  
    double *epsa  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_PFW06_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
