/*  
 *  - - - - - - - - - - -  
 *   g a l _ p m a t 7 6  
 *  - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Precession matrix from J2000 to a specified date, IAU 1976 model.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     date1,date2         d        ending date, TDB (Note 1)  
 *  
 *  Returned:
 *  
 *     rmatp            d[3][3]     precession matrix, J2000 -> date1+date2  
 *  
 *  Notes:  
 *  
 *  1) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  2) The matrix operates in the sense V(date) = rmatp * V(J2000),  
 *     where the p-vector V(J2000) is with respect to the mean  
 *     equatorial triad of epoch J2000 and the p-vector V(date)  
 *     is with respect to the mean equatorial triad of the given  
 *     date.  
 *  
 *  3) Though the matrix method itself is rigorous, the precession  
 *     angles are expressed through canonical polynomials which are  
 *     valid only for a limited time span.  In addition, the IAU 1976  
 *     precession rate is known to be imperfect.  The absolute accuracy  
 *     of the present formulation is better than 0.1 arcsec from  
 *     1960AD to 2040AD, better than 1 arcsec from 1640AD to 2360AD,  
 *     and remains below 3 arcsec for the whole of the period  
 *     500BC to 3000AD.  The errors exceed 10 arcsec outside the  
 *     range 1200BC to 3900AD, exceed 100 arcsec outside 4200BC to  
 *     5600AD and exceed 1000 arcsec outside 6800BC to 8200AD.  
 *  
 *  Called:
 *  
 *     gal_prec76         accumulated precession angles, IAU 1976  
 *     gal_ir             initialize r-matrix to identity  
 *     gal_rz             rotate around Z-axis  
 *     gal_ry             rotate around Y-axis  
 *     gal_cr             copy r-matrix  
 *  
 *  References:  
 *  
 *     Lieske,J.H., 1979. Astron.Astrophys.,73,282.  
 *     equations (6) & (7), p283.  
 *  
 *     Kaplan,G.H., 1981. USNO circular no. 163, pA2.  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_PMAT76_H_  
#define _GAL_PMAT76_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_pmat76  
 (  
    double date1,  
    double date2,  
    double rmatp[3][3]  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_PMAT76_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
