/*  
 *  - - - - - - - - - - -  
 *   g a l _ p n m 0 0 a  
 *  - - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Form the matrix of precession-nutation for a given date (including  
 *  frame bias), equinox-based, IAU 2000A model.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     date1,date2         d        TT as a 2-part Julian Date (Note 1)  
 *  
 *  Returned:
 *  
 *     rbpn             d[3][3]     classical NPB matrix (Note 2)  
 *  
 *  Notes:  
 *  
 *  1) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  2) The matrix operates in the sense V(date) = rbpn * V(GCRS), where  
 *     the p-vector V(date) is with respect to the true equatorial triad  
 *     of date date1+date2 and the p-vector V(J2000) is with respect to  
 *     the mean equatorial triad of the Geocentric Celestial Reference  
 *     System (IAU, 2000).  
 *  
 *  3) A faster, but slightly less accurate result (about 1 mas), can be  
 *     obtained by using instead the gal_pnm00b routine.  
 *  
 *  Called:
 *  
 *     gal_pn00a          bias/precession/nutation, IAU 2000A  
 *  
 *  References:  
 *  
 *     IAU: Trans. International Astronomical Union, Vol. XXIVB;  Proc.  
 *     24th General Assembly, Manchester, UK.  Resolutions B1.3, B1.6.  
 *     (2000)  
 *  
 *  This revision:
 *  
 *     2006 November 13 ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_PNM00A_H_  
#define _GAL_PNM00A_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_pnm00a  
 (  
    double date1,  
    double date2,  
    double rbpn[3][3]  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_PNM00A_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
