/*  
 *  - - - - - - - - - -  
 *   g a l _ p o m 0 0  
 *  - - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Form the matrix of polar motion for a given date, IAU 2000.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     xp,yp               d        coordinates of the pole (radians, Note 1)  
 *     sp                  d        the TIO locator s' (radians, Note 2)  
 *  
 *  Returned:
 *  
 *     rpom             d[3][3]     polar-motion matrix (Note 3)  
 *  
 *  Notes:  
 *  
 *  1) xp and yp are the "coordinates of the pole", in radians, which  
 *     position the Celestial Intermediate Pole in the International  
 *     Terrestrial Reference System (see IERS Conventions 2003).  In a  
 *     geocentric right-handed triad u,v,w, where the w-axis points at  
 *     the north geographic pole, the v-axis points towards the origin  
 *     of longitudes and the u axis completes the system, xp = +u and  
 *     yp = -v.  
 *  
 *  2) sp is the TIO locator s', in radians, which positions the  
 *     Terrestrial Intermediate Origin on the equator.  It is obtained  
 *     from polar motion observations by numerical integration, and so is  
 *     in essence unpredictable.  However, it is dominated by a secular  
 *     drift of about 47 microarcseconds per century, and so can be taken  
 *     into account by using s' = -47*t, where t is centuries since  
 *     J2000.  The routine gal_sp00 implements this approximation.  
 *  
 *  3) The matrix operates in the sense V(TRS) = rpom * V(CIP), meaning  
 *     that it is the final rotation when computing the pointing  
 *     direction to a celestial source.  
 *  
 *  Called:
 *  
 *     gal_ir             initialize r-matrix to identity  
 *     gal_rz             rotate around Z-axis  
 *     gal_ry             rotate around Y-axis  
 *     gal_rx             rotate around X-axis  
 *  
 *  References:  
 *  
 *     McCarthy, D. D., Petit, G. (eds.), IERS Conventions (2003),  
 *     IERS Technical Note No. 32, BKG (2004)  
 *  
 *  This revision:
 *  
 *     2006 October 10 ( c version 2008 February 4 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_POM00_H_  
#define _GAL_POM00_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_pom00  
 (  
    double xp,  
    double yp,  
    double sp,  
    double rpom[3][3]  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_POM00_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
