/*  
 *  - - - - - - - - -  
 *   g a l _ p r 0 0  
 *  - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Precession-rate part of the IAU 2000 precession-nutation models  
 *  (part of MHB2000).  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     canonical model.  
 *  
 *  Given:
 *  
 *     date1,date2         d        TT as a 2-part Julian Date (Note 1)  
 *  
 *  Returned:
 *  
 *     *dpsipr,*deps       d        precession corrections (Notes 2,3)  
 *  
 *  Notes  
 *  
 *  1) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  2) The precession adjustments are expressed as "nutation components",  
 *     corrections in longitude and obliquity with respect to the J2000  
 *     equinox and ecliptic.  
 *  
 *  3) Although the precession adjustments are stated to be with respect  
 *     to Lieske et al. (1977), the MHB2000 model does not specify which  
 *     set of Euler angles are to be used and how the adjustments are to  
 *     be applied.  The most literal and straightforward procedure is to  
 *     adopt the 4-rotation epsilon_0, psi_A, omega_A, xi_A option, and  
 *     to add dpsipr to psi_A and depspr to both omega_A and eps_A  
 *     (Wallace 2002).  
 *  
 *  4) This is an implementation of one aspect of the IAU 2000A nutation  
 *     model, formally adopted by the IAU General Assembly in 2000,  
 *     namely MHB2000 (Mathews et al. 2002).  
 *  
 *  References  
 *  
 *     Lieske, J.H., Lederle, T., Fricke, W. & Morando, B., "Expressions  
 *     for the precession quantities based upon the IAU (1976) System of  
 *     Astronomical Constants", Astron.Astrophys., 58, 1-16 (1977)  
 *  
 *     Mathews, P.M., Herring, T.A., Buffet, B.A., "Modeling of nutation  
 *     and precession   New nutation series for nonrigid Earth and  
 *     insights into the Earth's interior", J.Geophys.Res., 107, B4,  
 *     2002.  The MHB2000 code itself was obtained on 9th September 2002  
 *     from ftp://maia.usno.navy.mil/conv2000/chapter5/IAU2000A.  
 *  
 *     Wallace, P.T., "Software for Implementing the IAU 2000  
 *     Resolutions", in IERS Workshop 5.1 (2002)  
 *  
 *  This revision:
 *  
 *     2005 August 24 ( c version 2008 January 19 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_PR00_H_  
#define _GAL_PR00_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_pr00  
 (  
    double date1,  
    double date2,  
    double *dpsipr,  
    double *depspr  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_PR00_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
