/*  
 *  - - - - - - - -  
 *   g a l _ s 0 0  
 *  - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  The CIO locator s, positioning the Celestial Intermediate Origin on  
 *  the equator of the Celestial Intermediate Pole, given the CIP's X,Y  
 *  coordinates.  Compatible with IAU 2000A precession-nutation.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     canonical model.  
 *  
 *  Given:
 *  
 *     date1,date2         d        TT as a 2-part Julian Date (Note 1)  
 *     x,y                 d        CIP coordinates (Note 3)  
 *  
 *  Returned:
 *  
 *     gal_s00             d        the CIO locator s in radians (Note 2)  
 *  
 *  Notes:  
 *  
 *  1) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  2) The CIO locator s is the difference between the right ascensions  
 *     of the same point in two systems:  the two systems are the GCRS  
 *     and the CIP,CIO, and the point is the ascending node of the  
 *     CIP equator.  The quantity s remains below 0.1 arcsecond  
 *     throughout 1900-2100.  
 *  
 *  3) The series used to compute s is in fact for s+xy/2, where x and y  
 *     are the x and y components of the CIP unit vector;  this series is  
 *     more compact than a direct series for s would be.  This routine  
 *     requires x,y to be supplied by the caller, who is responsible for  
 *     providing values that are consistent with the supplied date.  
 *  
 *  4) The model is consistent with the IAU 2000A precession-nutation.  
 *  
 *  Called:
 *  
 *     gal_fal03          mean anomaly of the Moon  
 *     gal_falp03         mean anomaly of the Sun  
 *     gal_faf03          mean argument of the latitude of the Moon  
 *     gal_fad03          mean elongation of the Moon from the Sun  
 *     gal_faom03         mean longitude of the Moon's ascending node  
 *     gal_fave03         mean longitude of Venus  
 *     gal_fae03          mean longitude of Earth  
 *     gal_fapa03         general accumulated precession in longitude  
 *  
 *  References:  
 *  
 *     Capitaine, N., Chapront, J., Lambert, S. and Wallace, P.,  
 *     "Expressions for the Celestial Intermediate Pole and Celestial  
 *     Ephemeris Origin consistent with the IAU 2000A precession-nutation  
 *     model", Astronomy & Astrophysics, 400, 1145-1154 (2003)  
 *  
 *     n.b. The celestial ephemeris origin (CEO) was renamed "celestial  
 *          intermediate origin" (CIO) by IAU 2006 Resolution 2.  
 *  
 *     McCarthy, D. D., Petit, G. (eds.), IERS Conventions (2003),  
 *     IERS Technical Note No. 32, BKG (2004)  
 *  
 *  This revision:
 *  
 *     2007 May 29 ( c version 2008 January 19 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_S00_H_  
#define _GAL_S00_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
double  
gal_s00  
 (  
    double date1,  
    double date2,  
    double x,  
    double y  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_S00_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
