/*  
 *  - - - - - - - - - - - - -
 *   g a l _ s g p 4 i n i t  
 *  - - - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This routine initializes the variables for gal_sgp4.
 *  
 *  Status: 
 *  
 *     SGP4 support routine.  
 *  
 *  Given:  
 *
 *     *gm           gal_gm_t       Gravity Model
 *     *tle          gal_tle_t      TLE parameters
 *  
 *  Returned:  
 *  
 *     *sgp4        gal_sgp4_t      Common values for subsequent calls
 *     gal_sgp4init     i           GAL_SUCCESS if OK
 *                                  1 = mean elements, ecc >= 1.0 or ecc < -0.001 or a < 0.95 er
 *                                  2 = mean motion less than 0.0
 *                                  3 = pert elements, ecc < 0.0  or  ecc > 1.0
 *                                  4 = semi-latus rectum < 0.0
 *                                  5 = epoch elements are sub-orbital
 *                                  6 = satellite has decayed
 *
 *  Notes:  
 *  
 *  1) This routine is based on a translation from c++ to c of David Vallado's SGP4UNIT.sgp4init 
 *     routine ( 2007 November 16 ). 
 *
 *  Called:
 *
 *     gal_sgp4gm       Get gravity model parameters for SGP4
 *     gal_initsgp4p    Initialize SGP4 propagator
 *     gal_dscom        
 *     gal_dpper        
 *     gal_dsinit    
 *     gal_sgp4         SGP4 orbit propagator
 *     gal_days2cal     Convert day of year to calendar date
 *     gal_cal2jd       Convert calendar date to Julian Date
 *
 *  References:
 *
 *     NORAD Spacetrack Report #3 1980
 *     Hoots, Roehrich 
 *
 *     NORAD Spacetrack Report #6 1986
 *     Hoots 
 *
 *     Hoots, Schumacher and Glover 2004
 *
 *     Revisting Spacetrack Report #3
 *     Vallado, David, Crawford, Paul, Hujsak, Richard, Kelso, T.S.
 *     AIAA 2006-6753
 *
 *  This revision:  
 * 
 *     2008 April 6 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_SGP4INIT_H_  
#define _GAL_SGP4INIT_H_ 1  

#include "gal_gm.h"
#include "gal_sgp4t.h"
#include "gal_tle.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
int 
gal_sgp4init
  (
    gal_gm_t *gm,
    gal_tle_t *tle,
    gal_sgp4_t *sgp4
  ) ; 
   
__END_DECLS  
  
#endif /* !_GAL_SGP4INIT_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
