/*  
 *  - - - - - - - - - - -
 *   g a l _ t 2 a z e l  
 *  - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     This routine converts a pv-vector in the ITRF reference
 *     frame to azimuth, elevation, range & range-rate  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     itrf              d[2][3]    ITRF position & velocity vector of target ( m / m s ^-1 )
 *     site              d[2][3]    ITRF position vector of observer ( m )
 *     lat                 d        Latitude of observer ( radians )
 *     lon                 d        Longitude of observer ( radians )
 *  
 *  Returned:
 *  
 *     *az                 d        Azimuth ( radians ) 
 *     *el                 d        Elevation ( radians ) 
 *     *range              d        Range ( m ) 
 *     *rdot               d        Range Rate ( m s^-2 )
 *  
 *  Called:
 *
 *     gal_pmp             p-vector minus p-vector
 *     gal_cp              copy p-vector
 *     gal_ir              Initialize r-matrix to identity
 *     gal_rz              Rotate r matrix about z axis
 *     gal_ry              Rotate r matrix about y axis
 *     gal_rxpv            Product of r-matrix and pv-vector
 *     gal_pdp             Dot product of two p-vectors
 *     gal_pm              Modulus of p-vector
 *
 *  References:
 *
 *     Fundamentals of Astrodynamics and Applications
 *     Vallado, David A. Second Edition 2004
 *     Pages 252-257
 *
 *  This revision:
 *  
 *     2008 May 24   
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_T2AZEL_H_  
#define _GAL_T2AZEL_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_t2azel  
 ( 
   double itrf[2][3],
   double site[3],
   double lat,
   double lon,
   double *az,
   double *el,
   double *range,
   double *rdot
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_T2AZEL_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
