/*  
 *  - - - - - - - - - - -
 *   g a l _ t t 2 m t c  
 *  - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     This routine converts a TT jd date to a Mars Coordinated 
 *     Time (MTC) date. Mars Coordinated Time is the Mean Solar 
 *     Time on the Mars prime meridian. 
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     tt1                 d        TT date part 1 ( see Note 1 )
 *     tt2                 d        TT date part 2 ( see Note 1 )  
 *  
 *  Returned:
 *  
 *     *mtc1               d        MTC date part 1 ( see Note 2 )  
 *     *mtc2               d        MTC date part 2 ( see Note 2 ) 
 *  
 *  Notes:
 *
 *  1) The Julian Date is apportioned in any convenient way between  
 *     the arguments tai1 and tai2.  For example, JD=2450123.7 could  
 *     be expressed in any of these ways, among others:  
 *  
 *               tt1          tt2  
 *  
 *         2450123.7          0.0   (JD method)  
 *         2451545.0      -1421.3   (J2000 method)  
 *         2400000.5      50123.2   (MJD method)  
 *         2450123.5          0.2   (date & time method)  
 *
 *  2) mtc1 contains the sol number, and mtc2 the fractional part of the 
 *     sol. A Mars "day" is called a "sol".
 *
 *  3) As defined, consistent with the terrestrial convention for Mean
 *     Solar Time, JD 2451549.5 (2000 January 6 00:00:00) corresponds to
 *     a near coincidence of the terrestrial Greenwich mean solar
 *     midnight and the Martian mean solar (prime meridian) midnight. The
 *     addition of the integer number 44796 assures a positive result
 *     for any date since JD 2405522 (1873 December 29.5).
 *   
 *  References:
 *
 *     A post-Pathfinder evaluation of areocentric solar coordinates with 
 *     improved timing recipes for Mars seasonal/diurnal climate studies 
 *     by Michael Allison, Megan McEwen, 
 *     Planetary and Space Science 48 (2000) 215-235 
 *
 *     Mars24 URL: http://www.giss.nasa.gov/tools/mars24/help/algorithm.html
 *     The referenced URL contains corrections to the referenced article.
 *
 *  This revision:
 *  
 *     2009 January 5  
 *  
 *  Copyright (C) 2009 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_TT2MTC_H_  
#define _GAL_TT2MTC_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void 
gal_tt2mtc  
 (  
    double tt1,
    double tt2,
    double *mtc1,
    double *mtc2
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_TT2MTC_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2009 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
