/*  
 *  - - - - - - - - - - -
 *   g a l _ u t c 2 t t 
 *  - - - - - - - - - - -
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *     This routine converts a UTC jd date to a TT jd date.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     utc1                d        UTC date part 1 ( see Note 1 )
 *     utc2                d        UTC date part 2 ( see Note 1 )  
 *  
 *  Returned:
 *  
 *     *tt1                d        TT date part 1 ( see Note 1 )  
 *     *tt2                d        TT date part 2 ( see Note 1 ) 
 *     gal_utc2tt          i        Status ( see Note 2 )
 *                                    1 = dubious year (Note 2)  
 *                                    0 = OK  
 *  Notes:
 *
 *  1) The Julian Date is apportioned in any convenient way between  
 *     the arguments utc1 and utc2.  For example, JD=2450123.7 could  
 *     be expressed in any of these ways, among others:  
 *  
 *              utc1         utc2  
 *  
 *         2450123.7          0.0   (JD method)  
 *         2451545.0      -1421.3   (J2000 method)  
 *         2400000.5      50123.2   (MJD method)  
 *         2450123.5          0.2   (date & time method)  
 *  
 *  2) TAI began at 1960 January 1.0 (JD 2436934.5) and it is improper  
 *     to call the routine with an earlier epoch.  If this is attempted,  
 *     zero is returned together with a warning status.  
 *  
 *     Because leap seconds cannot, in principle, be predicted in  
 *     advance, a reliable check for dates beyond the valid range is  
 *     impossible.  To guard against gross errors, a year five or more  
 *     after the release year of the present routine is considered dubious.  
 *     In this case a warning status is returned but the result is 
 *     computed in the normal way.  
 *  
 *  Called:
 *
 *     gal_dat                      Calculate delta(AT) = TAI-UTC      
 *     gal_utc2tai                  Convert UTC to TAI      
 *     gal_tai2tt                   Convert TAI to TT      
 *
 *  This revision:
 *  
 *     2008 April 13   
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_UTC2TT_H_  
#define _GAL_UTC2TT_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
int 
gal_utc2tt 
 (  
    double utc1,
    double utc2,
    double *tt1,
    double *tt2
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_UTC2TT_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
