/*  
 *  - - - - - - - - -  
 *   g a l _ x y 0 6  
 *  - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  X,Y coordinates of celestial intermediate pole from series based  
 *  on IAU 2006 precession and IAU 2000A nutation.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     canonical model.  
 *  
 *  Given:
 *  
 *     date1,date2         d        TT as a 2-part Julian Date (Note 1)  
 *  
 *  Returned:
 *  
 *     *x,*y               d        CIP X,Y coordinates (Note 2)  
 *  
 *  Notes:  
 *  
 *  1) The TT date date1+date2 is a Julian Date, apportioned in any  
 *     convenient way between the two arguments.  For example,  
 *     JD(TT)=2450123.7 could be expressed in any of these ways,  
 *     among others:  
 *  
 *            date1         date2  
 *  
 *         2450123.7          0.0        (JD method)  
 *         2451545.0      -1421.3        (J2000 method)  
 *         2400000.5      50123.2        (MJD method)  
 *         2450123.5          0.2        (date & time method)  
 *  
 *     The JD method is the most natural and convenient to use in  
 *     cases where the loss of several decimal digits of resolution  
 *     is acceptable.  The J2000 method is best matched to the way  
 *     the argument is handled internally and will deliver the  
 *     optimum resolution.  The MJD method and the date & time methods  
 *     are both good compromises between resolution and convenience.  
 *  
 *  2) The x,y coordinates are those of the unit vector towards the  
 *     celestial intermediate pole.  They represent the combined effects  
 *     of frame bias, precession and nutation.  
 *  
 *  3) The fundamental arguments used are as adopted in IERS Conventions  
 *     (2003) and are from Simon et al. (1994) and Souchay et al. (1999).  
 *  
 *  4) This is an alternative to the angles-based method, via the SOFA  
 *     routine gal_fw2xy and as used in gal_xys06a for example.  The  
 *     two methods agree at the 1 microarcsecond level (at present),  
 *     a negligible amount compared with the intrinsic accuracy of the  
 *     models.  However, it would be unwise to mix the two methods  
 *     (angles-based and series-based) in a single application.  
 *  
 *  Called:
 *  
 *     gal_fal03          mean anomaly of the Moon  
 *     gal_falp03         mean anomaly of the Sun  
 *     gal_faf03          mean argument of the latitude of the Moon  
 *     gal_fad03          mean elongation of the Moon from the Sun  
 *     gal_faom03         mean longitude of the Moon's ascending node  
 *     gal_fame03         mean longitude of Mercury  
 *     gal_fave03         mean longitude of Venus  
 *     gal_fae03          mean longitude of Earth  
 *     gal_fama03         mean longitude of Mars  
 *     gal_faju03         mean longitude of Jupiter  
 *     gal_fasa03         mean longitude of Saturn  
 *     gal_faur03         mean longitude of Uranus  
 *     gal_fane03         mean longitude of Neptune  
 *     gal_fapa03         general accumulated precession in longitude  
 *  
 *  References:  
 *  
 *     Capitaine, N., Wallace, P.T. & Chapront, J., 2003,  
 *     Astron.Astrophys., 412, 567  
 *  
 *     Capitaine, N. & Wallace, P.T., 2006, Astron.Astrophys. 450, 855  
 *  
 *     McCarthy, D. D., Petit, G. (eds.), 2004, IERS Conventions (2003),  
 *     IERS Technical Note No. 32, BKG  
 *  
 *     Simon, J.L., Bretagnon, P., Chapront, J., Chapront-Touze, M.,  
 *     Francou, G. & Laskar, J., Astron.Astrophys., 1994, 282, 663  
 *  
 *     Souchay, J., Loysel, B., Kinoshita, H., Folgueira, M., 1999,  
 *     Astron.Astrophys.Supp.Ser. 135, 111  
 *  
 *     Wallace, P.T. & Capitaine, N., 2006, Astron.Astrophys. 459, 981  
 *  
 *  This revision:
 *  
 *     2007 June 15 ( c version 2008 January 19 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#ifndef _GAL_XY06_H_  
#define _GAL_XY06_H_ 1  

#undef __BEGIN_DECLS  
#undef __END_DECLS  
#ifdef __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  
  
void  
gal_xy06  
 (  
    double date1,  
    double date2,  
    double *x,  
    double *y  
 ) ;  
  
__END_DECLS  
  
#endif /* !_GAL_XY06_H_ */  

/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
