/*  
 *  - - - - - - - - - - - - - - 
 *   g a l _ g m g m m 2 b . h  
 *  - - - - - - - - - - - - - - 
 *  
 *  This file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This file defines the external variables for the GMM-2B Mars gravity model.
 *  
 *  Status: 
 *  
 *     Support file gravity model sub-system  
 *
 *  Defines:  
 *
 *     gal_gmgmm2b    gal_gm_t      GMM-2B gravity model structure
 *
 *  Notes:
 *
 *  1) This model was derived from radio tracking of the Mars Global Surveyor 
 *     spacecraft; no Mariner 9 or Viking data are included.  Coordinate system 
 *     is IAU 1991 (Davies et al., Celestial Mechanics and Dynamical Astronomy, 
 *     53, 377-397, 1992).                                                                       
 *                                                                              
 *  2) The model was constructed from 955,115 observations, summarized              
 *     in the table below.  MGS data are limited to tracking from the               
 *     Aerobraking Hiatus and Science Phasing Orbit (SPO) subphases of the          
 *     Orbit Insertion phase of the mission and to February 1999 to                 
 *     February 2000 after the orbit was circularized.                              
 *                                                                              
 *            Time Periods                      Total                           
 *                                          Arcs  Observations                  
 *       -----------------------            ----  ------------                  
 *       Hiatus                               2       24119                     
 *       SPO-1                                8       31001                     
 *       SPO-2                               16      157972                     
 *       Feb-Mar 1999                         9       76813                     
 *       Apr 1999 - Feb 2000                 47      665210                     
 *       -----------------------            ----  ------------                  
 *       Total                                       955115                     
 *                                                                              
 * 3) Orbit reconstruction was improved using Mars Orbiter Laser Altimeter         
 *    (MOLA) data on 5 arcs between March and December 1999.  Inter-arc            
 *    and intra-arc crossovers at 21343 points were included in the orbit          
 *    solutions.                                                                   
 *                                                                              
 * 4) The gravity model was derived using a Kaula type constraint:                 
 *    sqrt(2)*13*10**(-5)/L**2 (Kaula, W.M., Theory of Satellite Geodesy,          
 *    Blaisdell, Waltham, MA, 1966).                                               
 *                                                                              
 * 5) The analysis and results were described by F.G. Lemoine,                     
 *    D.D. Rowlands, D.E. Smith, D.S. Chinn, G.A. Neumann, and M.T. Zuber          
 *    at the Spring Meeting of the American Geophysical Union, May 30 -            
 *    June 3, 2000, Washington. DC.                                                
 *                                                                              
 * 6) Further improvements to the model are expected as additional MGS             
 *    data are incorporated.                                                       
 *                                                                              
 * 7) This Mars gravity model was produced by F.G. Lemoine under the               
 *    direction of D.E. Smith of the MGS Radio Science Team."                      
 *
 *  This revision:  
 * 
 *     2008 September 20
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_GMGMM2B_H_  
#define _GAL_GMGMM2B_H_ 1  

#include "gal_gm.h"
#include "gal_const.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

double gal_gmgmm2b_terms[81][81] = {
{
                    0e+00,                     0e+00,       1.7044280642328e-10,       2.5139324037413e-05,       3.7413215027229e-06, 
      2.1179750719201e-06,      -1.5234122376020e-06,      -2.3256794873474e-07,       7.4942490031394e-07,      -4.9042273171693e-07, 
      2.1871853125251e-07,      -2.1751302948038e-07,      -4.6597501385512e-08,       2.2788663120969e-07,       3.0659939197390e-07, 
      2.5814277194372e-07,      -5.5301461123008e-07,      -6.3489366161239e-07,      -5.7769470567911e-07,       5.0606657054153e-07, 
      5.5166467757317e-07,      -4.2489275995068e-07,      -1.1826221354555e-07,       7.3494112778137e-08,       1.6690861715653e-07, 
     -1.7543650003502e-08,      -3.8315999458062e-07,      -4.2301208758475e-08,       1.0124148940443e-07,       2.0184784435221e-07, 
     -1.1060675702898e-09,      -8.2210099378317e-08,      -1.8450978973318e-07,      -9.5472951755738e-08,      -4.9939191989393e-08, 
      1.5644291900712e-07,      -3.0952448936566e-08,      -1.8632051812706e-07,      -9.1583448966180e-09,       1.1341140325641e-07, 
     -1.2315860111016e-08,      -6.6196153339956e-08,      -2.0747224762366e-08,      -4.6518061672390e-08,       1.5996922284384e-09, 
      6.6534684936877e-08,       2.7471214407566e-08,      -1.0388620820808e-07,      -7.1935622896234e-08,       6.9326640864387e-08, 
      3.5516031480898e-08,      -3.9502450870681e-08,       1.3193446981941e-08,       3.5566327968041e-08,       4.2223927127308e-08, 
     -3.4121066246252e-08,       3.8641681074456e-08,       1.9873894089603e-08,      -1.1569274748816e-08,      -2.3483280674137e-08, 
      1.3490441539497e-09,       3.2834716479108e-08,      -3.8890275894474e-08,       2.0596816742637e-08,      -1.6485777335695e-08, 
     -7.3607481231004e-09,      -3.9069590310602e-10,      -2.0242575809331e-08,      -7.1624936313843e-09,      -2.2996972065424e-11, 
     -2.3132840022126e-08,       1.9829175912853e-08,      -2.5170975454309e-08,       1.8926017985385e-08,      -1.9688685572870e-08, 
      1.4004550230924e-08,      -8.2180330560395e-09,       1.1039511430777e-08,      -1.1917359750881e-08,       1.0080122064768e-08, 
     -9.4305524346009e-09, 
},
{
                    0e+00,                     0e+00,       4.9605348841412e-05,       8.4857987158792e-06,      -8.9622951629187e-06, 
     -1.1283599363068e-06,       1.4592318487313e-06,      -6.5173659805381e-07,       4.9096335865113e-07,       3.7160680928004e-07, 
     -1.1128765713995e-06,      -9.8790735061237e-07,       5.3208625826598e-07,       8.4834357183257e-07,      -5.2539256378858e-07, 
     -7.7775370918244e-07,      -8.3798338110112e-08,       1.4769821786575e-07,       4.5344370424782e-08,       8.7643122788539e-08, 
     -2.3854889220810e-07,      -5.5509403173538e-07,       7.4421453554010e-08,       4.6791638769017e-07,      -1.3850302464474e-07, 
     -3.5958046277900e-07,       1.4205464154316e-08,       2.6901356144063e-07,       2.4849703134893e-07,       1.7215589308587e-09, 
     -4.2452925690369e-08,       1.3393507846428e-08,       1.8175786246894e-07,       2.0388444611357e-07,       4.8735766498621e-08, 
     -5.8861114697072e-08,      -1.2561437941774e-07,      -2.2446207229091e-08,       1.1561106188446e-07,       8.9367826520247e-08, 
     -9.2243360499731e-08,      -1.1013450301151e-07,       8.9574906805196e-08,       1.5472351168610e-07,      -1.1429095402858e-08, 
     -5.9366772604899e-08,       3.9340574054677e-08,       5.6639972735709e-08,      -3.6465683234284e-08,      -1.4485001510092e-08, 
      5.1659029521868e-08,      -2.4233504694116e-08,      -3.0872193571646e-08,       2.6854082131425e-08,       1.4556630222111e-08, 
     -5.2375271382275e-08,      -4.7810606698333e-08,       5.5426278662686e-08,      -1.1193037962724e-08,      -4.9375869395951e-08, 
      1.7868898713224e-08,      -5.1303556170471e-09,      -1.9842457978631e-08,      -1.7168373104858e-08,       1.3989217029388e-08, 
     -5.1984539933337e-09,      -1.6755231490103e-08,      -1.6341600634354e-08,      -1.0771461661548e-08,      -5.3598276115665e-09, 
     -4.1713719279456e-09,       1.4659266878295e-08,      -5.3083824684430e-09,       3.2789664716711e-09,      -1.0376476318903e-08, 
      1.2488378151696e-09,      -9.5117019631845e-09,       2.9688927761927e-09,      -1.3307175585157e-08,       2.0941879284064e-09, 
     -1.2000398675073e-08, 
},
{
     -8.7450547081842e-04,       1.3938449166781e-10,      -8.4177519807823e-05,       2.5113984262623e-05,      -2.7297790313232e-07, 
      2.3024139448590e-07,       3.2022418522316e-07,      -4.0675705536591e-07,      -1.3230871310064e-06,      -9.9277210221518e-07, 
      4.4574364384326e-07,       7.7876627497924e-07,       3.3094328849605e-07,       1.7831477048833e-07,      -3.1613141949168e-07, 
     -2.9119276531666e-07,       4.3179535117819e-07,       1.9182219078222e-07,      -4.5784264171330e-07,      -1.9930153462648e-07, 
      2.0444588490030e-07,       2.4876536599426e-07,       2.0395835626639e-08,      -1.3263849456797e-07,      -2.9176290248854e-07, 
     -1.4852699810844e-07,       1.2804480855376e-07,       3.1206623710872e-07,      -2.7948778667318e-07,      -3.0816637609179e-07, 
      8.3431426027651e-09,       5.3573643937370e-08,       3.8103547315773e-08,      -1.1722570873242e-07,      -1.6024833581982e-07, 
     -5.8377933040033e-08,       5.2985466285571e-08,       6.2856719350807e-08,      -1.0809767167288e-08,      -2.2416832893452e-08, 
     -1.0205576486770e-08,       6.8022061285030e-08,       2.4325083281381e-08,       1.6876664552560e-08,      -2.8057002814233e-08, 
      1.3994387397177e-09,       4.3105646467269e-08,      -1.3794245411363e-09,      -1.7251413095420e-08,       4.5842173279046e-08, 
      1.6146472722275e-08,      -3.4950981016614e-08,      -3.7915243521455e-08,       6.5728992936600e-09,       6.3753171488067e-08, 
      1.7671698679507e-08,      -7.7656091678671e-08,       1.9890550601184e-08,       4.1794160984964e-08,      -1.7057122867019e-08, 
     -4.7914590742039e-09,      -1.7658601641077e-08,      -1.6179649107591e-08,      -2.5481699502383e-08,      -8.4259339503889e-10, 
     -6.8179442273111e-09,       7.1007004943716e-09,       2.4396092798539e-10,      -1.3913162885903e-08,       2.6954410925303e-08, 
     -4.7557734681538e-08,       8.1143011875860e-09,      -2.7983538172296e-08,       1.5244645000584e-08,      -3.1434745408576e-08, 
      2.7167552255778e-08,      -3.5031302786458e-08,       2.6586603502873e-08,      -3.4654647377658e-08,       2.7808062591185e-08, 
     -3.3984412455783e-08, 
},
{
     -1.1886910646016e-05,       3.9053442315701e-06,      -1.5863411026265e-05,       3.5338541142774e-05,      -1.2861361694340e-05, 
     -3.2997722093047e-06,       2.6170003356585e-06,      -4.6224291975935e-07,       1.2166283194289e-07,       1.6143044902574e-06, 
     -4.9501526389811e-08,      -6.1657941677816e-07,       1.2477384606768e-07,       6.8437925412020e-07,      -9.6126046924894e-07, 
     -8.2291945418793e-07,      -4.1236194296459e-08,      -1.7248528799717e-08,       1.1649861097787e-07,       2.5044457390706e-07, 
      2.1259491309391e-07,      -1.3425496908503e-07,      -3.8145043638467e-07,       6.6478968884065e-08,       1.1739532630109e-07, 
      1.6531831359390e-07,       2.1670066344322e-07,       8.5273684327321e-08,       1.3956437835764e-08,       4.9832426947716e-08, 
      2.1727062750582e-07,       7.5885563450515e-09,       6.5322199228227e-08,       3.0724477493343e-08,       1.0118550795608e-07, 
      8.1282437672106e-08,      -1.9696456884033e-08,       2.0014500256916e-09,       5.9753324011347e-08,       3.7147422269355e-08, 
      5.2977246889948e-08,      -9.1090743411113e-09,       4.4277868919749e-08,       7.1322115880911e-08,       1.4930471391428e-08, 
     -1.3327022127011e-08,       2.6671432486938e-08,       6.6168165171316e-08,       1.4822951110727e-08,      -1.7169242814551e-08, 
     -9.5051567762535e-09,      -1.1510435654775e-08,      -1.0176165347589e-08,       3.4991411194197e-08,       2.4100147675497e-08, 
     -3.0768856418781e-08,      -5.6364326409147e-08,       1.0671273735475e-08,       2.9800174574788e-08,      -7.1577687868231e-09, 
     -1.4700802313101e-08,      -1.1442665281633e-08,       1.2432801385891e-08,      -3.2519014195806e-08,       1.2605373709994e-08, 
      2.1351986563289e-08,       2.7114090583256e-08,       3.4426038832712e-09,       5.6391931488592e-09,       3.4974030177432e-09, 
     -5.4607384716000e-09,      -2.6906149250308e-09,      -2.5543799442943e-10,      -5.3440071906493e-09,       3.8470563461167e-09, 
     -1.2452216208437e-08,       1.0792848761169e-09,      -7.6647813847473e-09,      -3.0856491033798e-09,      -1.0014623816837e-08, 
      2.2723162227291e-09, 
},
{
      5.1257987175466e-06,       4.2271575054702e-06,      -1.0253884110276e-06,       6.4461288728918e-06,       9.6384334824045e-08, 
      3.8656154098344e-06,       1.5853762547291e-06,      -1.3515575270663e-06,      -1.5681467772892e-06,      -1.4984195288745e-06, 
     -1.0683891523420e-06,       8.6845829243625e-07,       9.8313706759768e-07,      -4.0358226801550e-07,      -9.5209040368264e-07, 
     -4.5309344036893e-07,       5.9447709629049e-07,       2.9716758199904e-07,      -6.2249966128911e-07,      -4.3895607578845e-07, 
      1.1045333324554e-08,       1.5936242888489e-07,       3.0105913448951e-08,       1.9519929635274e-07,      -1.5733433810897e-07, 
     -3.2513243257401e-07,       2.2188350902353e-07,       2.8166455549002e-07,      -3.6928288502625e-08,      -1.6917412913967e-07, 
      1.4967249746880e-07,       1.7269202062704e-07,      -6.6707883167500e-08,       5.6365977329366e-08,      -5.5390063209572e-08, 
     -2.1312335468172e-07,       8.3350902398882e-09,       1.2268383979688e-07,      -3.4281153285803e-08,      -1.8968885023875e-07, 
     -1.2588819373651e-07,       8.5119144101047e-08,      -4.1939709906211e-08,      -9.2086521843099e-08,      -5.0239429063942e-08, 
      1.4549561383987e-08,       3.8338098547695e-09,      -3.0625354541469e-09,      -2.7758658523186e-08,      -6.1774980609957e-09, 
      1.7470830600593e-08,       1.8336636626905e-08,      -3.3221184222900e-08,      -1.0582243302835e-08,       3.1896528569288e-09, 
      8.3006511625411e-09,      -2.3067342111363e-08,      -8.4411285598917e-09,       3.0012350802429e-10,       9.6073912894567e-09, 
      5.4229768058368e-09,       5.1267789933401e-09,      -5.6766528212746e-09,      -1.8003473493274e-08,      -1.8065489002329e-08, 
     -2.7083970664320e-08,      -2.3271167086174e-08,      -8.7845956515856e-09,      -7.1190413465649e-09,      -1.2139007125138e-08, 
     -2.7250150441747e-09,      -2.0776583995093e-08,      -4.1843415452525e-09,      -2.5948452960462e-08,       3.8760204531147e-09, 
     -1.8021397424406e-08,       6.6173065051489e-09,      -2.1718342682825e-08,       1.1227343688026e-08,      -2.2324311550613e-08, 
      1.4311698457651e-08, 
},
{
     -1.7242068505339e-06,       4.9155252614410e-07,      -4.3015486989529e-06,       3.3106878341317e-06,      -4.6889658986048e-06, 
     -4.3640801168294e-06,       7.5170270469873e-07,      -1.8832018842058e-06,      -1.7626582142155e-06,       5.5634131644083e-07, 
      1.0970214333048e-06,       2.6287975442268e-08,      -1.6138324546285e-06,      -9.2963519094536e-07,      -8.1255730199729e-08, 
      6.3181043403390e-07,       2.1995105650213e-07,      -3.2424361898798e-07,      -6.8437607860474e-07,      -1.4472759335103e-07, 
      3.7356644384240e-07,       2.7488485498800e-07,      -5.2344037555341e-07,      -5.0612553610889e-07,       2.9276330519770e-08, 
      3.5398705137298e-07,       6.5494767739468e-08,      -3.2786198801970e-07,      -2.7356671662512e-07,       9.4101032299518e-09, 
      3.6547714193666e-07,       1.1345288369187e-07,      -2.0955403475299e-07,      -2.5737195557074e-07,       2.8211816113406e-08, 
      1.8345312607410e-07,       8.9199564709527e-09,      -1.1901884817943e-07,      -1.2193059030373e-07,      -5.3033608789881e-09, 
      7.8338895154592e-08,       4.0965479663068e-08,      -1.8241878220335e-08,      -5.2794268166107e-08,       5.6878315588006e-08, 
      4.4211678959369e-08,      -5.2784424123614e-08,      -1.7822421928175e-08,       6.3690413352122e-08,      -3.7779336068049e-08, 
     -3.3186764017648e-08,       1.8899193568129e-08,      -3.8084824156321e-09,      -3.9126633818856e-08,       2.6165267500894e-08, 
      2.7956920139482e-08,      -6.8608717175949e-09,      -8.3303307735297e-09,       9.3511389743938e-09,       1.6661748674528e-09, 
     -1.8300971074692e-08,      -3.7057223003806e-10,       5.9576260707114e-08,       1.7570149368159e-09,      -4.9286018744710e-09, 
      1.9039640424468e-08,      -5.4621151430622e-09,       7.3178114560709e-09,       2.2481835537070e-08,      -2.0870379336570e-09, 
      1.1661068420154e-08,       1.3581771673408e-08,       1.5684858688266e-08,       4.7565374325581e-09,       4.6548054931092e-09, 
     -3.1237499023377e-09,       7.2786983083775e-09,      -1.0553399144576e-09,       6.1357015388518e-09,       5.8662141671556e-09, 
      2.0349773484661e-10, 
},
{
      1.3448267510621e-06,       1.7926701548424e-06,       8.7185360387643e-07,       9.5816746766166e-07,       1.0503162831990e-06, 
      1.6880399538738e-06,       2.7768427868542e-06,      -1.7838625631807e-06,       1.6540404534479e-06,       8.8413812925585e-07, 
     -6.2740746269726e-07,      -8.8124580630581e-07,      -1.2420962147610e-07,       4.1816002573525e-07,       2.5344830630814e-07, 
      3.3367910077558e-07,       2.9924170216304e-07,      -2.4963319407555e-07,      -1.6356127281012e-07,       2.0107368970881e-07, 
      3.7898258389082e-08,      -3.0863895600893e-07,       5.6295008574610e-09,       2.9122642661273e-07,       5.1879797911087e-07, 
      2.5722461498610e-07,      -2.3553518937132e-07,      -1.1172236487931e-07,       2.0162811309387e-07,       1.7464531562867e-07, 
      3.0984720440641e-08,      -1.4083684406008e-07,      -1.7096554939387e-07,       2.9017505639064e-07,       2.3369066516505e-07, 
     -1.0628024552179e-07,      -1.2028864718113e-07,      -2.1457643848064e-08,       1.5558891893238e-07,      -1.4270267969448e-09, 
     -4.0624066538335e-08,       1.1381524181573e-07,      -1.9140139720980e-08,      -5.0671082746500e-08,       8.9155653753268e-09, 
      9.0555599872659e-08,       2.4809146636189e-08,      -1.1144131567664e-07,       4.1319260120171e-09,       7.0940107173856e-08, 
     -3.2168636180769e-08,      -3.9728889660761e-09,       1.8867550334227e-08,      -2.4112294204053e-08,      -4.9795966203032e-08, 
      5.5289281214080e-09,      -2.2723812623338e-09,      -2.5739017197925e-08,       3.2225289379238e-09,       3.8829937775706e-09, 
     -2.9258135055096e-09,      -1.3880826635213e-08,      -6.3333303134136e-09,       1.7467714563694e-08,      -3.4717499330703e-09, 
      1.1022507125668e-08,       3.6587875409956e-09,       1.1392386866222e-08,       7.0864787179928e-09,       1.0253608127095e-08, 
      1.1150701883847e-08,      -3.4454021587590e-10,       8.6955877876331e-09,       8.8992170377227e-09,      -1.1987991401492e-09, 
      8.3606665288044e-09,      -7.0126705605204e-09,       4.1402396035281e-09,      -2.2474940557800e-09,       6.1289679035865e-09, 
     -7.1629094284259e-09, 
},
{
      1.0566966079622e-06,       1.3714218129130e-06,       2.8033764459324e-06,       8.7336552189930e-07,       2.4566369021536e-06, 
     -2.1930690076858e-07,      -6.0515930653241e-07,       3.8833580001393e-07,      -2.3919729926160e-07,      -1.8558235185992e-07, 
      7.9979384590181e-07,       8.0289109851343e-07,      -3.3390142111389e-07,       1.2030332905114e-09,       3.4542413026250e-07, 
      4.3397393082265e-07,       3.8194759694031e-07,      -1.9171388957515e-07,      -2.6360703691128e-07,      -1.4536614945671e-07, 
      3.0592253100467e-07,       3.0886698315441e-07,      -1.9937087713119e-07,      -2.7709320642166e-07,       1.1078479731924e-07, 
      1.4987704009305e-07,       2.0973525309859e-08,       6.5907866839412e-08,       4.2320818316738e-09,      -8.9228824142964e-09, 
      9.4218169495485e-08,       5.8341997617834e-08,      -3.2727968772224e-08,      -1.5174951296085e-07,       3.7760690705900e-08, 
      8.6471564877470e-08,      -4.8429664321144e-08,      -8.8206213756179e-08,       7.1912481545413e-08,       2.3597949828772e-08, 
     -7.5782032686181e-08,      -6.0828607290154e-08,      -1.1124493316668e-08,      -4.9040619502658e-08,       5.6768249086620e-08, 
      2.5768597646998e-08,      -1.8629588565593e-08,      -3.3102612010966e-08,       1.6965723165525e-08,       5.0978431524878e-08, 
     -3.8834493493168e-09,       4.1863687795779e-09,       2.5120589995065e-08,       1.3608243955304e-08,       9.0807265433742e-09, 
      3.3020725983130e-09,       2.8481841194411e-08,       1.9360114067206e-08,       1.7903454140434e-08,      -6.7540867044083e-09, 
     -2.7012099850646e-08,      -9.3900374284642e-09,      -1.1989756675782e-08,       3.2342114375696e-10,       1.1748360948793e-08, 
      3.5511712100807e-08,       3.4245514516507e-08,       8.6425591623509e-09,      -8.2235743235047e-09,       8.3196410844160e-09, 
     -1.9034075968686e-09,       9.6729511633649e-09,       6.1619823653171e-09,       1.3828337127515e-10,       6.6857252258708e-09, 
     -8.7007436653910e-09,       1.2032812174656e-08,      -1.8574257904052e-08,       1.0006639045489e-08,      -1.7592246180823e-08, 
      5.5941061898150e-09, 
},
{
      1.4442117457415e-07,      -1.2904533441152e-07,       1.8100214820539e-06,      -1.2207784549871e-06,       1.5866931019861e-06, 
     -2.8183735255990e-06,      -9.5599877920940e-07,      -4.2471893831893e-07,      -3.1783805703280e-07,      -6.1225374183572e-07, 
     -1.4044666157342e-06,      -4.0266826541827e-07,       4.4834612822915e-07,       7.6091981962187e-07,       1.1412035615166e-06, 
     -3.6130776998698e-07,      -9.2091247731412e-07,      -3.2050677363792e-07,       2.2552919560178e-07,       3.8573458502091e-07, 
      1.7864588537009e-07,      -9.4958964606422e-08,      -3.0284890893446e-08,       1.0347913896544e-07,       3.2842814568059e-07, 
      2.0918083387299e-07,      -5.0879344685424e-07,      -3.8503746456283e-07,       4.2063510832962e-07,       3.2809139697703e-07, 
     -1.4151056355603e-08,      -3.7881113773362e-08,      -9.8134727164149e-08,       1.0568950686967e-07,       1.2008488518941e-07, 
     -4.4365185019595e-08,      -6.4211098547860e-08,      -4.8196020181185e-08,       1.4022018233299e-07,       1.6248764726980e-08, 
     -1.1988569027937e-07,      -1.9501451859427e-08,       5.1369916410425e-08,       3.6408462864319e-08,       6.1245464372566e-09, 
      6.8031942837560e-08,       1.4526835821870e-08,      -6.8453890897755e-08,       1.9297319491992e-08,       9.1241896197010e-08, 
     -1.3518411780585e-08,      -3.4744177361346e-08,       2.6980792694704e-08,       1.3661920051187e-09,      -2.5491524087210e-08, 
      2.8976341698270e-08,       2.7542771131781e-08,      -1.6806979599114e-08,      -2.1435894067361e-10,       1.5891521408193e-08, 
      4.7922791286457e-09,      -2.1231270239998e-08,       1.2334063269542e-09,       2.7953733130669e-08,       1.1302390381947e-08, 
      5.3594821677914e-09,       1.0527868825641e-08,       7.6351439056458e-09,      -1.1890069702573e-08,      -1.5168288599108e-09, 
     -1.8920219271599e-08,      -4.7344132336447e-09,      -1.6070868603764e-08,      -1.4232064399892e-08,      -1.7828236732169e-08, 
     -1.6008310943956e-08,      -6.9117363195682e-09,      -2.0954378216033e-08,      -5.5193672283405e-09,      -1.3561340768086e-08, 
     -6.7346379720056e-09, 
},
{
     -2.8745593244289e-07,       4.1743298827893e-07,       1.1385495484936e-06,      -1.0035199183447e-06,       3.2079095125259e-07, 
     -2.2970171000700e-06,       8.2020744110463e-07,      -5.9128904319118e-07,       1.1992792300607e-06,      -1.1923241516343e-06, 
      7.6193623951414e-07,       1.9449054488648e-06,       1.3521153280273e-06,      -6.3834053349288e-07,      -1.5805411521502e-06, 
     -1.4989148710418e-07,       3.6222033033374e-07,       2.8962148266299e-07,      -9.4810465055949e-08,      -1.0349337739528e-07, 
     -1.0435247651159e-08,       1.1820439495967e-07,       2.8902128641733e-07,      -1.4405809987966e-07,      -3.0140135882259e-07, 
     -2.5755712172913e-07,       3.8012335713704e-08,       3.6473955062595e-08,       1.5609810208321e-08,      -3.1141217839034e-08, 
     -2.4088907113551e-07,      -2.1821071986277e-07,       1.1086350047944e-07,      -1.0939147720901e-08,      -1.0944880314151e-07, 
     -6.8053676100104e-08,       3.1354655672476e-08,       5.3806932218297e-08,       4.1315098657821e-09,       8.8965744828152e-09, 
     -1.1620105031857e-07,      -6.9977959671345e-08,       3.9066754006329e-08,       2.7299785311152e-08,      -4.5126972323724e-08, 
     -9.3789931341862e-08,      -1.0860961990171e-08,      -2.5974803105918e-08,      -2.7440515466142e-08,       5.8187739726674e-08, 
     -2.4268348504983e-08,      -5.0630330784990e-08,       2.9767073874792e-09,       2.7687070539828e-08,       1.3219702757062e-08, 
     -2.7527005140683e-08,       9.7938082753904e-09,       4.2775007179188e-08,      -1.8138281549426e-08,       4.9885131653796e-09, 
      1.2585563615914e-08,      -2.3660012429757e-08,      -4.1395503370154e-09,      -3.0267227144411e-08,      -4.0030665164995e-08, 
     -8.3292193719512e-09,       4.7669780607262e-09,      -1.2413367149951e-08,       3.3865143344422e-10,      -5.0917861729704e-09, 
     -7.4913936693847e-09,      -2.1406386686779e-08,       4.4002196043969e-09,      -1.7037736969687e-08,      -5.0062154013371e-11, 
      3.3229660845952e-10,      -6.2719168248767e-09,       4.5312772316526e-09,      -3.5010840421413e-09,       1.8483558688249e-09, 
     -5.5257907517891e-09, 
},
{
      7.2586970184033e-07,       9.2212003081492e-07,      -2.1698263972956e-09,      -2.9275595477379e-07,      -1.2112906007514e-06, 
      3.9839975982151e-07,       6.9499178396903e-07,       2.9911814611400e-07,       5.6556749448508e-07,      -1.5064865665417e-06, 
     -2.4277051735088e-07,      -3.2013461955227e-07,      -1.6864131081621e-06,      -8.5419916802722e-07,       2.0181206830552e-07, 
      6.0499732095854e-07,      -3.0833185246732e-07,       3.5354260317608e-08,      -3.1345741040837e-07,      -3.9238448990828e-07, 
      2.7220617299529e-08,      -1.5823916152800e-07,      -1.5687894061081e-07,      -3.2797563249357e-07,       3.0915504653433e-07, 
      4.2193640157022e-07,      -1.9898237971716e-07,      -2.1423176515356e-07,       2.7273955283408e-07,       4.5742929551008e-08, 
     -1.2025161217795e-07,       1.9907916992783e-07,       8.3747710742040e-08,      -1.6807661092338e-07,      -2.1864018671670e-07, 
      3.4259711168245e-08,       4.0196531745607e-08,      -5.1020913506621e-08,      -9.7559862884990e-08,      -2.8020956341249e-08, 
     -6.2717455970038e-08,      -7.2000149507426e-09,       9.8714521861854e-08,       9.2961007340671e-09,      -1.4470231349997e-07, 
     -2.9884315131894e-08,       6.0365548089748e-08,       4.2575337716427e-08,      -8.6346984004788e-08,      -3.5712294965069e-09, 
      7.8566205443877e-08,      -2.7020393197179e-09,      -3.5848238837531e-08,      -1.0336489965000e-08,       6.8078249497292e-10, 
      1.2398804275624e-08,       3.7504777927324e-08,       2.2829537397021e-08,      -1.2625375602838e-09,      -9.4803948887888e-09, 
      1.7236051224281e-08,       1.4593403859407e-08,      -2.3408994990373e-08,      -8.7939024430991e-09,       1.8224206276661e-08, 
     -2.2518063783763e-08,      -8.7763576590849e-10,      -1.5270751308121e-08,      -1.8279083749979e-08,      -2.0840798182327e-08, 
     -2.5558035499328e-08,      -7.1600169774441e-09,      -2.0265427132374e-08,      -1.3312221623789e-09,      -2.7282584798622e-08, 
     -1.5826380406286e-09,      -1.8424891800561e-08,       9.6923452772768e-09,      -2.3469940179413e-08,       8.1008957312219e-09, 
     -2.1938171865205e-08, 
},
{
     -2.6649003866535e-07,      -8.1519392894443e-07,      -3.2104320936603e-07,      -1.2892409568787e-06,      -1.5791909175600e-06, 
      1.3703809961828e-06,      -2.4320602261743e-07,       6.3312547465221e-07,      -1.1526216305062e-06,      -4.2887218833227e-07, 
      4.1248741283896e-07,      -5.9129125196025e-08,      -8.8551160240719e-08,      -3.5633994441532e-07,      -2.8123541924842e-07, 
      7.0744643143345e-07,       6.4720068684210e-07,      -1.3079093383118e-08,      -1.0399482958457e-07,      -1.5548311289264e-08, 
     -1.4795540504239e-07,       6.4541115316012e-08,      -8.9063527407004e-08,      -1.2217476464312e-08,      -3.0429281336725e-07, 
     -2.2236094344922e-07,      -6.9385296018421e-08,      -8.8460963500727e-09,      -2.0457909203692e-08,       1.0946619933814e-07, 
      1.2135602798177e-07,      -4.1802616371664e-08,       2.2521676724264e-08,      -4.3788526045533e-08,      -4.6168471565230e-08, 
      4.9679959830521e-08,       8.1338662401160e-09,      -8.7603429403917e-08,      -8.6008156272069e-08,      -2.3161127924718e-08, 
      1.3994069734621e-08,       1.6107004253651e-08,       8.4347934667657e-09,       8.0403021621620e-09,       2.4118475635071e-09, 
     -1.2408142589624e-08,       7.0348185116722e-08,      -1.9250824541312e-08,      -4.5846866530719e-08,       4.3808379732012e-08, 
     -1.5712145980743e-08,      -6.4052101808592e-08,      -4.8000496597705e-09,       6.8850250959663e-08,      -4.6295397867578e-09, 
     -6.1806826407082e-08,       1.8187539859301e-08,       2.0189978026834e-08,      -2.5326884839778e-08,      -3.0069108831891e-08, 
      2.0862382491447e-08,       1.4760965337688e-08,      -1.5201455089912e-08,       1.8646342369912e-09,       1.3853505417795e-09, 
     -1.1618847909718e-08,      -1.1594443720086e-08,      -1.4605400507896e-08,      -1.1961577071004e-08,      -1.9356360365776e-08, 
      4.4962945424552e-09,       3.7084112938933e-09,      -1.0644402165158e-08,       6.9878922614575e-09,      -9.1042587957635e-09, 
      7.7777717029186e-09,      -1.9971241189446e-08,       1.3749722484470e-08,      -1.4929135650882e-08,       1.4077498800946e-08, 
     -1.6199449390021e-08, 
},
{
      2.5901010973448e-07,      -1.1232760242155e-06,      -9.3180509514092e-08,      -1.4328437159905e-06,      -9.8989762948795e-08, 
      7.3841719085192e-07,      -4.4199660810540e-07,       3.9950015269220e-07,      -1.6103036177639e-06,       7.2319162327704e-07, 
      5.4275397597080e-07,       7.8624501327329e-07,      -1.0856558755016e-08,       8.4684144373716e-07,       2.0166474791487e-06, 
      6.9692452639139e-07,      -5.9086298237427e-07,      -7.7483339436756e-07,      -2.5122404024047e-07,      -2.9076960333034e-08, 
      3.4234017008718e-07,       1.0116864535512e-07,      -1.6316979104797e-07,      -8.4294987746200e-08,      -2.7849631860021e-08, 
      2.7928595832259e-07,      -1.0433026848759e-08,      -1.0590711498148e-07,       4.2619780444183e-08,       1.7575001570676e-08, 
      5.6318659207429e-08,       1.4128537412595e-07,       1.6695087709747e-08,      -1.9834544529064e-08,      -1.2081902098228e-07, 
      1.5237402884358e-08,       1.7591776430694e-07,       3.9366188437952e-08,      -8.6074144792288e-08,      -9.0315047807129e-08, 
      3.2590936643575e-08,       2.3343830710948e-09,       4.2895604594033e-09,       1.6668650379244e-09,      -5.4019276646472e-08, 
     -2.0836777079939e-08,       7.2435849038390e-08,       1.1701764231398e-07,      -5.8636496229110e-08,      -8.3960012704327e-08, 
      8.4168853825395e-08,       6.8485976934800e-08,      -2.8345539286740e-08,      -6.1855946586193e-08,       2.7734951045143e-08, 
      2.8416596899984e-08,      -1.1531456784441e-08,       2.7880872789146e-08,      -5.5039857107314e-09,      -1.2762531030685e-08, 
      3.1833057034099e-08,      -8.9846692011106e-09,      -4.2983444724078e-09,      -1.5355320220804e-08,      -7.5510374028617e-09, 
     -1.0878535838740e-08,       1.7907297220383e-08,      -9.9649907268059e-10,       1.9110502531641e-09,       2.6341152970443e-08, 
      1.5913338803171e-08,       2.3312831331858e-08,       1.0550011525181e-08,       1.1970064958385e-08,       6.8259934514329e-09, 
      1.9611179251118e-08,      -9.3353076777423e-09,       4.0176406856821e-08,      -1.4784459967321e-08,       5.1489202272911e-08, 
     -2.4186366001015e-08, 
},
{
     -4.8952404831803e-07,      -5.6648398354797e-07,       1.9841104168070e-07,       2.1767220813221e-07,       1.8222961512093e-07, 
     -2.1635837716556e-09,       2.0889697822006e-08,      -7.5633516483174e-07,      -2.3166748437484e-07,       1.1327419797014e-06, 
     -1.8420690773034e-07,       7.2152491396419e-07,      -1.4713308304428e-06,       4.7249117577622e-07,      -7.4397446155338e-07, 
     -1.3675794263072e-06,      -9.2646534797515e-07,      -4.4794294782534e-07,       2.1245035795232e-07,       5.0561428737076e-07, 
      2.1671360097311e-07,      -3.9795307952092e-07,      -5.0922917414208e-07,      -3.1770480727319e-07,       3.9848536131461e-07, 
      2.6920677556668e-07,      -8.9757900507323e-08,      -4.1929659570349e-08,       1.2467634316902e-07,       1.3395399821072e-07, 
      4.3938012671177e-08,      -1.1716735262041e-07,      -1.8631661731998e-07,      -1.8654676706815e-08,       7.4710644016103e-08, 
      1.0354562488117e-07,      -4.4889184763152e-08,      -2.1589652872835e-07,      -2.9537328778986e-08,       5.7524655688521e-08, 
      5.1913782086675e-08,       5.4724464684394e-08,      -9.1892312588593e-08,      -2.3469552074919e-08,       5.6331461585802e-08, 
      6.3067690646384e-08,       4.1296463071040e-08,      -4.7139713071280e-08,       3.5568091087407e-08,       1.2424856734832e-07, 
      7.6394323676881e-08,      -3.7680007439772e-08,      -3.1377455745159e-08,       1.9837492840787e-08,       1.9162059350643e-08, 
     -9.9109789184269e-09,       8.5054419800780e-09,       1.3110467479759e-08,      -5.5199832398729e-09,       1.1634597752272e-08, 
      5.1858593199799e-08,      -2.4265074674296e-08,      -1.1422657934617e-08,       1.5452907644912e-08,      -4.2987766684076e-10, 
     -1.1895911150363e-08,       1.5532053708288e-08,       2.1374906969419e-08,       4.5571563281183e-09,       5.8863241601789e-09, 
     -1.7288587686399e-09,      -3.6585749246245e-09,      -1.2005088149135e-08,      -7.5947855393787e-09,      -1.4102816776235e-08, 
     -5.3122128393951e-09,      -2.4683766421580e-08,      -1.2001667211666e-10,      -2.2806227401399e-08,       3.3668686509474e-09, 
     -2.4486738625583e-08, 
},
{
      3.0219271864046e-07,       7.5309548515849e-07,       4.4431057610504e-07,       4.2086425064022e-07,       2.1086607659016e-07, 
     -4.7256009813145e-07,      -6.8240005934222e-08,      -4.3833797637763e-07,       8.2760862524880e-07,       2.5206510270110e-07, 
     -4.0006125111822e-08,      -9.1756400631669e-07,      -4.6098789395114e-07,       8.6159647817875e-07,       4.0566294949910e-09, 
      1.4679301357792e-07,       3.7522848734955e-07,       4.2775478707707e-07,       7.2717527650255e-07,       4.5122259786035e-07, 
     -2.9039462561300e-07,      -5.5740534092566e-07,       2.8477577528599e-07,       7.1651363037085e-07,      -4.2522142616756e-08, 
     -1.7103728129147e-07,      -5.4776152943268e-08,       8.8451767953049e-08,       1.3383638181939e-07,       1.3384672333717e-07, 
     -2.5325824294090e-08,       1.0936478913890e-08,       7.4475120792677e-08,       1.0667577514685e-07,       7.6542996763054e-08, 
     -1.7424767158548e-07,      -9.7021649942600e-08,       3.9027411416846e-08,      -7.2978104750846e-08,       2.5426920730708e-08, 
     -2.6810746744727e-08,      -5.7358728216130e-08,       7.8081651424870e-09,       7.5480018508543e-08,       3.1662857675478e-08, 
     -1.1425541970500e-07,      -3.4913567682375e-09,       6.1399267272348e-08,       1.9261911766125e-08,      -1.3708029051145e-08, 
      2.3929876088190e-08,       3.3954835076780e-08,      -2.7031519649154e-08,       7.9164254347134e-09,       3.1690672606607e-08, 
      5.7235755682309e-09,      -2.8213920063283e-09,       1.3578456246448e-08,      -6.7167294601888e-09,      -3.7505592204066e-08, 
     -2.3676682501497e-08,       2.6615225288869e-08,      -2.7557318117521e-08,      -1.3767017009901e-08,       2.3299596621459e-08, 
      1.1904730172792e-08,       3.3628148822003e-09,      -3.8585341394953e-09,       2.5054875408147e-08,      -6.1684767456698e-09, 
      1.6837768769751e-08,      -4.9420806144195e-09,       1.2418446931201e-08,      -8.2168640102559e-09,       1.4702473374406e-08, 
     -9.1636833905230e-09,       1.5820445586332e-08,      -5.6078084156027e-09,       1.8802105113414e-08,      -1.1526148860023e-08, 
      2.4953602836504e-08, 
},
{
      4.9338119977619e-07,       2.3504085774447e-07,      -3.5877664452027e-07,      -5.6235428831307e-07,      -7.3107741433902e-07, 
     -9.4418999262905e-07,      -4.6569424928889e-08,       9.3252509300586e-07,       1.1713557431122e-06,      -3.1361197239010e-07, 
     -1.6617979177074e-07,      -7.4449581533427e-07,       1.0125729414718e-06,       2.1632945779220e-07,       1.4287311615973e-07, 
     -3.2983911020274e-07,       1.0572655635748e-07,       4.9309080047219e-07,       1.9491720533030e-07,      -1.3538949530566e-07, 
     -2.7761158323092e-07,       5.5442768395247e-09,      -2.8750227028929e-08,       1.0929769880669e-07,       2.8516896440125e-07, 
      2.4780679724824e-07,      -8.4248120896246e-08,      -2.2375526433633e-07,       5.3584124607367e-08,       1.4792180554770e-08, 
      5.8193859688772e-08,       1.1169673736090e-09,      -4.9124912903019e-08,      -5.9001777810273e-08,      -2.0105444760175e-08, 
      6.9364285159169e-08,      -6.3431374593813e-09,       7.2253579465041e-09,       2.2557039578988e-08,      -2.1611023131837e-08, 
     -1.5392095664509e-08,      -4.5074798336150e-09,       1.5002549465408e-08,      -8.3266185026719e-08,      -1.2975366283878e-08, 
      3.5989321277322e-08,       2.8839133016603e-08,      -1.7713757486641e-08,      -3.3891614405057e-08,       3.2514403827523e-08, 
      4.1873047424387e-08,      -1.0500741483096e-08,      -4.9808563646618e-08,      -6.9883458666885e-09,       3.2689845798466e-08, 
      2.4135902934264e-09,       8.7421769261967e-09,       5.9707039337331e-09,       1.1681224069162e-08,       2.8758974462518e-09, 
     -3.3400658435872e-08,      -1.7219579638812e-08,      -2.5350499849952e-08,      -1.0872859509998e-08,       6.2157194776472e-09, 
     -2.8509849941932e-09,       5.0624127547366e-10,      -1.3859175863099e-08,      -9.6463501292197e-09,      -1.0542077678569e-08, 
     -1.9446524666631e-08,      -4.6602890813109e-09,      -5.1187053086574e-09,       2.9149710208361e-09,      -8.0998450215158e-10, 
      5.7857900040811e-10,       2.6425281006155e-08,      -2.1901115013134e-09,       3.2626403374281e-08,       1.7097575134616e-09, 
      3.4237594353960e-08, 
},
{
      6.2492272251973e-07,      -2.3576455388861e-07,      -4.8128515175366e-07,      -5.2884584512723e-07,      -7.7524880882120e-07, 
     -3.3156669814607e-07,       1.4873519233098e-07,       3.9540191879011e-07,       2.4726774880144e-07,      -3.9083254186985e-07, 
     -4.9887892959810e-07,      -8.0503692776154e-08,       4.4116504364058e-07,      -9.6676684214209e-08,      -2.2346863154784e-07, 
     -8.3320558932388e-07,       2.1693483565261e-07,       2.8783514545525e-07,      -1.1055839853856e-06,      -4.2595464334984e-07, 
     -3.4292939751667e-07,      -3.0837599867540e-07,       2.1188159428631e-07,       7.6096781011156e-07,      -1.5743112235115e-08, 
     -7.9124914881614e-07,      -3.7013988183926e-08,       3.4807209403587e-07,       3.6837259317906e-07,      -7.0045295120894e-08, 
     -1.7785010375396e-07,       5.1536615322554e-08,      -2.1331055075557e-08,       2.4765101992832e-08,       7.3834738497797e-08, 
     -7.9225958874617e-08,      -1.1551738332250e-07,       1.1342404950752e-07,       7.4411490243962e-08,       1.9101381207185e-08, 
     -3.1231163152072e-08,      -9.9882784338164e-08,       3.8312943419232e-08,       1.0443482734609e-07,      -1.6798474881230e-08, 
     -6.2755562162705e-08,      -6.1969901416681e-08,       3.7108029914748e-08,       5.4579615546872e-08,      -1.8634423688545e-08, 
     -8.1120443195920e-08,      -2.9670983222235e-08,      -6.1332286620946e-09,       1.1532899564588e-08,       3.5476438521018e-08, 
     -1.6781151368446e-08,       1.2478197972131e-08,       1.4042789694091e-08,      -3.6447320615214e-09,      -2.1938299757071e-08, 
      2.5009634169745e-08,       1.0368676022094e-08,       2.7034807211267e-09,       1.8866335532876e-08,       6.7448865385621e-09, 
      4.5265727055545e-09,       3.0592643580950e-09,       1.0045754838628e-08,       8.1585679044530e-09,       2.4055939926444e-08, 
      1.6547853726037e-09,       1.6491562634655e-09,       1.7826594669930e-08,      -1.0211270185854e-08,       1.6780956621800e-08, 
     -1.0930028987987e-08,       6.6349195754511e-09,      -3.7504291049909e-09,       1.1509899004015e-09,      -2.9707056947371e-09, 
      1.1962331638381e-09, 
},
{
     -5.4709542986931e-08,      -3.7399137381517e-07,      -2.0004915070625e-07,      -4.4054829757515e-08,       4.5617658067347e-07, 
      7.0352057270776e-07,       6.2735688086993e-07,       3.3067607545802e-07,      -3.7638667604706e-07,      -2.0630975795240e-07, 
     -5.5645632584498e-07,       3.5243509929603e-07,       2.0025673973077e-07,      -4.8612342952491e-07,      -3.8008064670124e-07, 
     -3.3804523377147e-07,       1.1049431287614e-06,       7.4847480457839e-08,       3.0810258604567e-07,       6.4337251024823e-07, 
      7.1919662036032e-07,       5.2143158077609e-07,       6.0333782848046e-08,      -5.9165257242253e-07,      -5.7222896549097e-07, 
      3.7143279380406e-08,       5.3888816219308e-07,       1.5127172664998e-07,      -3.5746993951466e-07,      -9.4109030401294e-08, 
      1.1056105864779e-08,       1.5114884345532e-07,       1.9222315559475e-09,       4.9682588850085e-08,      -9.4177461860617e-08, 
     -6.7618308230379e-08,       1.5112603824600e-07,       1.5337671225313e-07,      -9.0175956331260e-08,      -1.8299313978656e-07, 
      5.7378266470393e-08,       1.1322243917027e-07,       3.2160647815427e-08,      -2.4085970491632e-08,      -2.4186520246601e-08, 
     -3.1282446374317e-08,       4.7434479194610e-08,       7.6481633006868e-08,      -3.6656109603872e-08,      -5.7418690964179e-08, 
      3.9802656858975e-08,       2.7629980493199e-08,      -2.8948337399280e-08,      -6.1370744313839e-08,      -9.0053222874719e-09, 
      4.1021444845146e-08,       3.2846884773427e-09,       5.7368744895618e-09,       1.9426009155064e-08,       4.2225453930159e-09, 
     -3.2434893251115e-08,       1.5873613629791e-08,       1.2489286978839e-08,       4.9816702576110e-09,      -2.0608960605843e-08, 
      2.7571868182857e-09,       9.7283019657205e-09,       4.8839874008195e-11,       8.7543591965111e-09,       2.4443187452286e-08, 
      6.1420449570650e-09,      -2.5160294006566e-09,       7.4183914734368e-09,       2.6906342069222e-09,      -3.6137738492460e-09, 
     -2.7195403767574e-10,      -1.9976689360796e-09,      -3.9321007996801e-09,      -5.5569923673690e-09,      -2.5641666062873e-09, 
     -1.3933135231348e-08, 
},
{
     -3.1250064729225e-07,      -1.8296324000413e-07,      -1.0412207107656e-07,      -2.9939186240254e-07,       8.7501712948003e-07, 
      1.9313905997574e-07,       2.0688943917981e-07,      -2.0217971073446e-07,       5.2056773524533e-08,       7.7969026722604e-08, 
      6.6329434317302e-07,       2.6059961095134e-07,       6.8911605863124e-08,      -3.1271776039499e-07,      -3.5413778761108e-07, 
      4.0427231994549e-07,       4.2540458121371e-07,      -6.6185211446951e-09,       4.9076799412950e-07,      -8.0085248199827e-07, 
     -3.2472457615894e-08,      -7.8399759298237e-07,      -4.4970927422294e-07,       5.6605058404973e-08,       4.2087828662402e-07, 
     -3.2745841267602e-09,      -1.6653485548745e-07,       1.2894024808243e-07,       2.3285527480023e-08,      -1.3505178388051e-08, 
      6.2142940580670e-08,       9.4773927006365e-08,      -1.1451202158152e-07,      -2.1213398184407e-07,       1.9789558549790e-07, 
      8.1662940248482e-08,      -7.0982295220272e-08,      -7.7702062297069e-08,      -6.5001652205626e-08,       7.1684168850241e-08, 
      7.6350083673886e-09,       1.6920261273237e-08,      -4.8876387429211e-08,      -8.2465781317580e-08,      -5.6998281404252e-09, 
     -8.9575735474308e-09,      -4.0167648416254e-09,      -4.9927921104808e-08,       5.6803461722789e-09,      -9.1865210832788e-09, 
      5.2911081209437e-09,       2.2213790963872e-08,      -5.1366181075608e-08,      -2.9024852370222e-10,      -1.0892345287921e-08, 
      2.0680173720233e-09,      -1.1343487087107e-08,      -9.3713262858116e-09,       1.6190316469249e-08,       1.4066593209170e-08, 
     -4.5462551687540e-09,       3.8486624377279e-08,       2.4847339811281e-08,      -1.0690957080519e-08,      -1.0707300577864e-08, 
      2.5208021030743e-08,       8.2691117767757e-09,       2.6563367537715e-08,       1.4988210977706e-08,       1.7013733876648e-08, 
      2.1216015538632e-08,       2.2457998927492e-08,       1.4681156451832e-08,       2.2396627403927e-08,       8.8063779908965e-09, 
      2.2221091019353e-08,      -2.3222529412256e-09,       1.5459851261355e-08,       4.4328039045677e-09,       8.3861788625615e-09, 
      5.9986956470296e-09, 
},
{
      5.9593471480896e-09,       4.7984786635488e-08,      -5.2810415618862e-08,      -5.4861024791885e-08,       1.4263562742560e-07, 
     -2.9276850316068e-07,      -2.7765506917946e-07,      -4.8276286290870e-07,       4.2212800997514e-07,       2.2422934903486e-07, 
      5.9754731714712e-07,       2.6748761625196e-08,      -1.1353985029612e-07,      -2.0231048781492e-07,       1.8370489788656e-07, 
      8.5469937506494e-07,      -1.5178564199108e-08,      -1.4691049019411e-07,      -6.7605472888485e-07,      -4.2895397427419e-07, 
      1.0747723767163e-07,      -3.0137302609479e-07,       9.2797413487135e-08,       4.5045545106161e-08,      -1.4150417744733e-07, 
      6.8581143753310e-08,       3.5290024176266e-07,      -5.4762440538989e-08,      -3.9848909033500e-07,      -8.6822470688635e-08, 
      1.7379509825482e-07,       1.3257915418876e-07,       3.6307007193329e-08,      -3.7630183697908e-08,      -7.6271520420408e-08, 
     -1.0208799230801e-07,       7.8676120875160e-08,       8.7057509818667e-08,      -3.5504919380975e-08,      -1.0481196667220e-07, 
     -3.6682748646974e-09,       5.8044464641165e-08,       1.2032268815139e-08,      -6.2505704725978e-08,      -4.4555136940010e-08, 
     -2.9464093916812e-08,       4.2177565690708e-08,       5.3749854165846e-08,      -6.5581858147523e-08,      -2.8303741666208e-08, 
     -1.3151307173355e-08,       1.1757663548560e-08,      -1.4568512056101e-08,      -1.9281952576270e-08,       1.5773711905280e-08, 
      2.1700891663986e-08,      -4.9051441307418e-10,      -1.0019795285926e-08,       1.3661725487087e-08,       7.0336643826736e-09, 
      1.6959288955175e-08,       3.8810671014025e-08,      -1.9970529921678e-08,      -1.3947410885202e-08,      -1.0337467631336e-08, 
     -1.4391668058399e-08,       3.0497500095823e-09,       2.3387833017762e-09,      -1.8728960472695e-08,       1.5042947115555e-08, 
      5.6792159307970e-11,       7.6484765605507e-09,       3.9933533931540e-09,       2.3202686860515e-08,       3.0187285064100e-09, 
      9.8099131966942e-09,       7.8055666050250e-09,       1.4812011165582e-08,       2.8467961695773e-09,       1.6351909855961e-08, 
     -1.1645879334671e-09, 
},
{
      2.9881260537937e-07,       1.8580341470164e-07,       6.7077484529405e-08,       4.2629483620742e-07,      -3.5522136272434e-07, 
      1.6924862463125e-07,       2.0998547236303e-07,       7.0244713844181e-08,       3.2136235256076e-07,       6.5192996480357e-08, 
     -4.2083149137409e-07,      -1.6114641023950e-07,      -4.7994489225669e-07,       1.8109737849234e-08,       2.9344108002153e-07, 
      6.0208708189421e-08,       2.8414172567250e-08,      -5.1094548886475e-07,       8.9167321908968e-08,       1.7333602608013e-07, 
     -4.6655014134912e-07,       3.3555798221123e-07,       5.6231669757848e-07,       6.1353338185901e-07,       4.9620199514226e-07, 
      1.8939175435101e-07,      -5.5170201263527e-07,      -3.1039157162724e-07,       1.3419423339195e-07,       2.6509414861913e-07, 
      7.8131348871577e-08,       2.7003529896596e-08,      -2.2006564172550e-07,      -2.3457283311143e-07,       1.3735028836628e-07, 
      2.2539568227638e-07,      -4.1706629246174e-08,      -1.1213963263696e-07,      -7.4871070662502e-08,       6.9020629660381e-08, 
      7.4625674210358e-08,       7.6103953767527e-09,      -7.6504405037729e-08,      -1.0040409706186e-07,       6.1390113598153e-08, 
      5.5020158294226e-08,      -1.7033245141206e-08,      -4.9606225509938e-08,       3.3248858049502e-09,       1.2958362047488e-08, 
      4.5053087140208e-08,       1.6349508815494e-08,      -2.7487078212543e-08,      -3.3167635854992e-08,       3.4691725769198e-08, 
      8.2710599665939e-09,      -7.1913020853954e-08,      -3.1315575291157e-08,       1.6783131812982e-08,       2.4664626335781e-08, 
     -1.5981218452972e-08,      -1.4027611613524e-08,       1.2102811683585e-08,      -1.3996209166238e-08,      -1.1599086132586e-08, 
     -1.7409428699284e-08,      -4.5669178798036e-09,      -5.4530866671708e-09,      -2.6973926521039e-08,      -3.0063898824258e-08, 
     -1.0229597981398e-08,      -2.0506890009623e-08,      -2.1218228098805e-08,       9.0634840293188e-09,      -2.9439727799811e-08, 
      5.0901818605137e-09,      -2.0353664992428e-08,       5.1673639214873e-09,      -1.0197133124882e-08,       4.0713203039801e-10, 
     -3.4484342445663e-10, 
},
{
      1.2347586822151e-07,      -1.4966915629924e-07,      -9.7221100336763e-08,      -1.5552364970401e-07,      -4.0097666230991e-07, 
      3.2870712432166e-07,       6.9079939553383e-08,       2.3320857354460e-07,       5.1570907658036e-08,      -1.8008202114286e-07, 
     -2.7938955389264e-07,      -2.8796500726804e-07,       2.5731362205597e-07,       8.3708645895451e-09,       1.1134161192370e-07, 
     -3.6470794043295e-07,      -2.8556691172752e-07,      -2.8525352941552e-07,       2.8317542188568e-07,       1.2069812234461e-07, 
     -1.4923345109939e-07,       6.9990179109416e-07,      -3.1326857604805e-07,      -2.0327835563483e-07,      -6.9209106756932e-07, 
     -4.3844233143149e-07,       4.5750616882190e-08,       3.9791824063853e-07,       1.0399280108543e-07,      -2.0680632146693e-08, 
     -2.0456347280952e-08,      -1.5723930552253e-07,      -6.5706171114170e-08,       1.1984305878438e-07,       1.2819809899443e-07, 
     -1.0509548000082e-07,      -1.0495857453142e-07,       4.7873051414468e-08,       6.8387130079838e-08,      -1.1029185616235e-08, 
     -3.3115310471431e-08,      -3.0790208864840e-08,      -7.7247148133219e-08,       3.7076901982694e-08,       2.5931095822629e-08, 
     -1.0082689121919e-08,      -5.1936442954535e-08,      -2.0592778131918e-08,      -4.9924233757749e-09,       2.5669387356113e-08, 
      5.5110709458347e-09,       2.4760657365816e-08,       6.0857862853891e-09,      -2.9204187712910e-08,       3.0534599352053e-08, 
      6.1478809221211e-08,      -2.0974262127495e-08,      -5.5929039885979e-08,       2.2584725860829e-08,       4.1486787053903e-08, 
     -3.6244843463215e-08,      -2.9095642112579e-08,      -8.4821073918671e-09,       3.5932579945093e-08,      -6.0245486094388e-10, 
      8.3126594875122e-09,       5.6005857272691e-09,      -2.0066504872186e-08,      -6.0987388424415e-09,      -4.8907412244072e-09, 
     -1.8512780913010e-08,      -1.5094330683237e-08,      -2.0690035692550e-08,      -3.1566610529249e-09,      -7.3144262868252e-09, 
     -1.1630735277353e-08,      -1.1713769923491e-09,      -2.4648567299249e-08,       9.2180801400990e-09,      -3.1187816409330e-08, 
      1.4926530250858e-08, 
},
{
     -1.1264028279608e-07,      -4.0208656684925e-07,       1.0381732434953e-07,      -3.7677474476697e-07,       1.8933663793100e-07, 
      7.3369812805457e-08,      -2.8170834311132e-07,       2.6177231161259e-07,      -3.7895979428661e-07,      -1.9429436459151e-09, 
     -2.4257445288974e-07,      -9.3715993038995e-08,       3.7559620252873e-07,      -1.7940313993881e-07,      -1.7537860033055e-07, 
     -4.0193319616745e-07,      -2.0310502853512e-07,       3.4627242633573e-07,      -1.1210259579022e-07,       3.7629022242182e-07, 
     -4.3042697908639e-07,       2.7695836337858e-07,      -1.4347583619729e-07,       2.7878783895039e-07,       4.1208495271270e-08, 
      4.7197829147460e-07,       2.2709480739465e-07,      -2.7057833944663e-07,       9.8249634583056e-08,       3.1356707917145e-07, 
      9.5584411231038e-08,      -1.6740283644819e-07,       1.3422778859965e-07,       1.1866956881210e-07,      -5.9915928409728e-08, 
      5.2156564624232e-08,       9.0614876441402e-08,       3.2318312861779e-08,      -1.0098875200363e-07,      -1.1968974262989e-09, 
      7.8277455659345e-08,      -3.2075425395986e-08,      -9.5532279488758e-09,       3.9852254590482e-08,      -3.7199475467358e-10, 
     -4.2464669436464e-08,      -3.8418176892370e-08,       5.3791358775832e-08,       6.4918412890670e-08,      -1.5824983437765e-08, 
     -2.4761393210522e-08,      -1.4813259309490e-09,      -2.6816692934692e-08,       2.5346054928182e-08,      -2.5389799084361e-08, 
      1.9500420525504e-09,       2.4809049714962e-09,      -1.1844040442389e-08,       6.1863124735648e-08,       1.0337249402668e-08, 
     -3.7137298386869e-08,       9.5200986060912e-09,       1.5436539399696e-08,      -7.5820510940249e-09,      -2.1254358112118e-09, 
      5.2765129898845e-09,      -1.9035057160542e-08,       1.6030125090130e-08,      -2.0659245162034e-09,       6.0625423579077e-09, 
      3.1814321520416e-08,      -1.8356740998683e-08,       2.5198456371908e-08,       4.1447345397357e-09,       5.2570086718028e-09, 
      1.3782249641758e-08,       5.5749438117867e-09,       7.9174985239677e-09,       5.9259472384364e-09,       1.0110876428822e-08, 
      6.3492490207414e-09, 
},
{
      4.7326423023179e-08,       2.4374408042260e-07,       1.9843225742036e-07,       9.9820782624613e-08,       4.4503832725168e-07, 
     -3.1144276467443e-07,       3.6992172443827e-07,      -2.8487071785549e-07,      -2.2579336399058e-07,       2.7359227298598e-08, 
     -9.5790812490446e-08,       3.2113423215862e-07,       7.3832375707857e-08,      -2.3140846208712e-07,      -1.0224728887818e-07, 
     -2.3223458029351e-07,       4.4498981004519e-07,       3.6670408070543e-07,      -1.7642610439994e-07,       4.1926005181402e-07, 
     -4.8862524724288e-07,       4.9604626390306e-07,       1.5353129714946e-07,      -5.2692420718805e-07,       1.0611983382256e-07, 
      7.1057634707613e-08,      -2.8419292894155e-09,       4.6200158477059e-09,       2.0151109007883e-07,      -3.0469382582476e-07, 
     -2.3643420072473e-07,       1.1444246279428e-07,       1.5566011198719e-07,       1.3675531038335e-07,      -2.8476237200762e-08, 
     -4.8081363517502e-10,      -5.7741876862596e-08,      -1.9111012269063e-08,       4.0277524559843e-08,      -1.1366060449155e-08, 
     -5.9931342692570e-11,      -8.3378097064280e-08,      -1.6040599693175e-08,      -6.2013653216909e-09,       2.2522892183270e-08, 
      2.2566936447842e-08,      -6.9435840605644e-08,      -5.4278119146965e-08,       3.3357193677675e-08,       3.4757300406351e-08, 
     -2.1843917543260e-08,      -5.1854019646574e-08,       2.0998148353660e-08,      -9.4429903721035e-09,      -2.4814116718006e-08, 
      4.7283409137415e-09,       3.7236044785029e-08,      -1.7125111627194e-09,       4.3210625972034e-09,       2.1450436035769e-08, 
     -1.3315350467133e-08,      -3.7299217412467e-08,      -2.5457776578700e-08,      -3.6127920586659e-08,      -1.8353970354226e-08, 
     -3.6280898587319e-08,      -1.2562941517218e-08,       6.6964669050006e-09,      -1.1548026320364e-09,       1.5095176886668e-08, 
     -8.6183410004349e-10,      -2.9849119148758e-10,       5.0338620885429e-09,      -1.2614778301446e-08,       3.8737020804708e-10, 
      3.4096962487688e-09,      -3.4578222543005e-09,       5.6789638076045e-09,      -5.6186570044578e-09,       5.4501015736765e-09, 
     -2.5008483921827e-09, 
},
{
      2.6873303650461e-07,       1.9057622150480e-07,       1.7280977634452e-08,       3.2921208881991e-07,       5.9218617620265e-08, 
     -3.5012008481588e-07,       3.1642695265317e-07,      -3.9264498823451e-07,       1.8933598874194e-07,       1.2527409470495e-07, 
     -1.3450041125559e-07,       1.0843022480947e-08,      -3.1255874794964e-07,       7.5599798100225e-08,       2.6270393549554e-08, 
      2.1284441845551e-07,       6.2126031993091e-07,      -1.0668238261123e-07,       3.1846210628268e-07,      -2.5065325932672e-07, 
     -9.3603719702307e-08,       5.0245562931674e-09,      -1.6939863171227e-07,      -5.8779889641222e-07,       2.8572403319339e-07, 
     -2.9679761935163e-07,      -4.4013918971703e-07,      -5.7300191246279e-07,      -1.0472751263353e-07,       2.7162645618812e-07, 
      2.7613822597114e-07,      -8.8502450553843e-09,      -1.2956988000447e-07,      -5.8632154795252e-08,      -8.9601300097711e-08, 
     -4.2444888159175e-08,       1.1124132178198e-07,       5.2528174298110e-08,      -3.8968966243183e-08,      -8.6672589942710e-08, 
     -4.7314574994363e-08,      -6.0558536238174e-08,       7.0413032253180e-08,       5.8145896737270e-08,      -2.8243651922494e-08, 
     -6.3145875372853e-08,      -4.0034290714103e-08,       2.7271716452670e-08,       6.0435785326038e-08,       2.0867319047319e-08, 
     -2.9214677020141e-08,      -3.7467561377731e-08,      -1.6492631853621e-08,       3.7764159239042e-08,       1.7696057564614e-08, 
     -4.4899706894486e-08,      -1.2841939650032e-08,       1.5692134192674e-09,       3.9213295773486e-08,       2.6412184918244e-08, 
      1.1697190004464e-08,      -1.7135515675758e-08,      -2.4785466123361e-08,      -1.4957233990302e-08,       1.1577484419109e-09, 
      1.1973212969424e-08,       7.5698207618364e-09,       2.9629315405707e-08,      -3.7842728813905e-09,       4.7271858830435e-08, 
     -5.8551813813940e-09,       2.3400921025420e-08,       1.6585772746213e-09,       8.3743960752837e-09,       2.1872265728608e-09, 
      1.0196033044099e-08,       1.3853921065570e-08,       1.7627913133629e-08,       1.7566254567496e-08,       1.2662760846587e-08, 
      2.5472837659482e-08, 
},
{
     -1.3915637435630e-07,      -7.7127738215862e-08,      -1.7403806696812e-07,       1.0709464053996e-07,      -6.1577275010244e-07, 
      2.7870987142976e-07,      -1.5069102202669e-07,       1.2745235340382e-07,       2.5188727311854e-07,       8.8548350659178e-08, 
      2.0459340707432e-07,      -4.0208525901294e-07,      -3.4108004488017e-07,      -3.3913589664341e-09,      -6.0081500302783e-08, 
      4.3084430524139e-07,      -7.2389572160777e-08,      -4.0812396698157e-07,       1.3039868082470e-07,      -6.7379262122206e-07, 
      5.7252513267243e-07,      -6.7333893396917e-07,       2.9662492388194e-07,      -4.7106093096747e-07,       3.3585277049001e-07, 
      1.0811211693402e-07,       4.4794368613723e-07,       3.5159123462776e-07,       5.5288152018397e-07,       2.6538690568921e-07, 
     -3.3710802783892e-07,      -4.8176107290495e-08,      -6.8537066416396e-08,      -1.2038348936564e-07,      -1.1079395498102e-07, 
      3.8245564679829e-08,       7.5888958007032e-08,      -8.1641095176671e-08,      -1.1656011692344e-07,      -3.7483879524688e-09, 
      1.2100929081667e-07,       9.4476752114377e-08,      -9.0879720173483e-08,      -8.7607428576049e-08,      -5.3173451362796e-08, 
      2.2072431906074e-08,       3.3678749728784e-08,      -1.9916398660419e-08,      -5.8091946101487e-08,      -2.6967572635484e-08, 
     -4.3600221408866e-09,       5.3314459228114e-09,       4.0144029279420e-08,       2.8567991100722e-08,      -2.1998531847734e-08, 
      1.3427998748025e-08,       8.4491242196578e-09,       9.1834642026124e-09,      -2.3026039630125e-08,      -2.5609734872547e-08, 
      5.4713411424862e-08,       1.0193130700766e-08,      -1.7569935717630e-08,       1.9841475566081e-08,       4.3803129147250e-09, 
      1.9519863897160e-08,       1.4441135047716e-08,      -1.4663264320471e-08,      -8.8898209047252e-09,      -3.6692329486713e-09, 
     -1.0578194974234e-08,      -1.9963760619881e-08,      -7.7318467345781e-09,      -2.0788514546403e-08,       3.3528708643666e-10, 
     -8.2357350824666e-10,      -6.8741098596237e-09,       4.9849294596782e-09,      -1.7370921843394e-08,       1.9040072461730e-08, 
     -1.8557992993412e-08, 
},
{
     -1.7628448725189e-07,      -1.9213755004801e-07,      -2.0175674235328e-07,      -1.4909954219721e-07,      -3.6897114728501e-07, 
      2.0844964305891e-07,      -3.2567066782868e-07,       1.1641740455969e-07,       8.6298428878060e-08,      -7.2025186638855e-08, 
      1.4853026076296e-07,      -4.7167856753693e-07,       2.2527623574358e-07,       5.1145042075151e-08,       1.2480011835258e-07, 
      9.0209718719097e-08,      -5.0820149849513e-07,      -2.4657849080846e-07,      -2.3290580440167e-07,      -2.5970273573784e-08, 
      1.5281466506169e-07,      -3.1201209295351e-07,       4.0844874037238e-07,      -2.4275552862587e-07,       7.3201075677303e-07, 
      2.3151452106338e-07,      -1.1007952809535e-07,      -8.9847065707103e-08,       3.5884049270199e-08,       1.7349828302600e-08, 
     -2.4198363506992e-07,      -1.2083786428135e-07,      -1.0238839881171e-07,       4.6056492187872e-08,       1.2697196806340e-07, 
      1.5875449157599e-09,      -7.0293939734974e-08,      -7.9539227844172e-08,       1.0425749062421e-07,       1.2890360457969e-07, 
     -1.7294019656838e-08,      -6.5520567463968e-08,      -5.3325049336207e-08,       1.0433673431789e-07,       4.7515448598953e-08, 
     -3.7589942916291e-09,      -3.2339406308605e-08,      -1.2885048781084e-08,       4.5379759717073e-08,       2.5448201469517e-08, 
     -2.9879265242401e-08,      -1.9852236137281e-08,       1.6679124128243e-09,       2.3794926127698e-08,       1.6401679484838e-08, 
     -4.6824943394393e-08,       2.3027757067652e-09,       3.2556492901524e-08,      -2.6145367340126e-09,      -1.0496627129445e-08, 
     -1.5604018595000e-08,       2.6780787089180e-08,       2.9798041182600e-08,      -1.6962190771507e-08,       1.6447796974506e-08, 
      9.6565869752211e-09,       8.1868002362438e-09,      -2.8639813051532e-08,      -2.5294616180127e-08,       1.0491562360962e-08, 
     -2.8111399308176e-08,       2.3157791194601e-08,       1.7840796900349e-09,       1.7062074299847e-08,       2.6371128749702e-08, 
      1.3011408311724e-09,       3.1872819814189e-08,       1.1128680458941e-08,       2.5832528357660e-08,       1.0446895561495e-08, 
      3.2027234412456e-08, 
},
{
     -2.2429133670940e-07,       5.6344813457962e-08,      -6.5365457782954e-10,       1.2627092149005e-07,       3.4424611315323e-07, 
      1.0222231504240e-07,       2.6324849166295e-07,      -9.7211844450006e-10,      -3.4547432643060e-07,      -5.6074328514253e-08, 
     -3.0969727349976e-07,      -2.0254335758160e-07,       6.0235142746720e-08,      -7.4459935135365e-08,       1.7173555188447e-07, 
     -4.5952114701047e-08,      -1.1942685337678e-07,       2.4581814647318e-07,      -2.0923914984465e-08,       7.5026181480600e-07, 
     -2.5269557479531e-07,       2.5817973151246e-07,      -1.9717193142012e-07,       1.2012853555960e-07,       1.6193138480660e-07, 
     -1.5582978599657e-07,      -2.5066768488364e-07,       4.9198392164879e-07,      -5.6962748687959e-07,      -2.1918930385312e-07, 
     -3.0907353476336e-07,      -1.3145215370928e-07,       2.7652198344328e-07,       1.9390406026865e-07,      -2.4000607220929e-08, 
     -9.4181481113139e-09,       1.9367461081613e-07,       1.2705491672337e-08,      -1.2301460525968e-07,      -5.5199168562401e-08, 
      1.1870827729518e-07,       5.3360448749159e-08,      -3.6903252119609e-08,      -3.9205747691988e-08,       4.3288168671052e-09, 
      3.7010142461081e-08,       7.6558797730435e-08,       1.1681170810699e-08,      -9.8472372395267e-09,       2.4976605015528e-09, 
      2.2345745664451e-08,       1.6920317449100e-08,       1.2937493059483e-08,       4.3597313937908e-08,      -3.6734959695417e-08, 
     -1.2152113069977e-08,       1.1238310074177e-08,       4.6599773260689e-08,      -3.3592497547362e-08,      -3.2686185070610e-08, 
      2.8615082870361e-08,      -1.4537228785196e-08,      -3.0645532958038e-08,      -1.9732834012874e-09,       3.5679029733360e-08, 
      2.8153271783867e-08,       1.4538303036551e-08,       2.1174842434002e-08,      -1.3391758342744e-08,       2.0631655801348e-08, 
      6.7992677859043e-10,      -4.0596491729986e-09,       7.5201297610049e-11,      -1.4326692678052e-08,      -2.0441602759535e-08, 
     -2.5433844057489e-08,      -2.1554736627160e-08,      -2.7998652220864e-08,      -1.7595252584785e-08,      -2.7443632143430e-08, 
     -1.9463450344046e-08, 
},
{
      3.7688556434609e-08,       1.5783700928635e-07,       3.1017655862826e-07,       1.9313510743590e-07,       4.0313724493950e-07, 
     -4.8400167777081e-08,       4.5375184117557e-07,      -1.6823684799279e-07,      -2.4710103415388e-07,       1.0710413315088e-07, 
     -8.2870261985355e-08,       2.2512128014213e-07,       8.9524747741377e-08,      -1.2787142340077e-07,       8.9051930235576e-08, 
     -7.9032732095102e-08,       1.7615849583249e-07,       1.8637754507549e-07,       2.5127844343473e-07,       3.1908355132651e-07, 
     -2.9898302714106e-07,       2.2935452901297e-07,      -3.6507274474574e-07,       3.9683452222884e-07,      -2.7695608240874e-07, 
     -6.1515040223358e-08,      -3.2090104339849e-07,       5.5931795695476e-08,      -2.0401164017886e-07,       1.7717530296084e-07, 
      7.8234963744761e-08,       2.1177654546930e-07,       1.8604827587786e-07,       1.1772951094375e-08,       5.5038737301195e-08, 
     -5.3988464378971e-08,      -1.6850176167801e-07,      -1.0656217876793e-07,       2.0412514096122e-07,       2.2098597271240e-07, 
     -1.4283544336857e-07,      -9.9875722628776e-08,      -2.0070711819112e-08,       1.4882653996221e-07,       7.8290546289377e-08, 
     -1.5000358657276e-08,      -8.2175164374131e-08,      -1.1275646948486e-07,       4.6154199826601e-08,       9.3229817405744e-08, 
     -1.6147016813121e-08,      -2.0193105116910e-08,       4.4347180119491e-08,      -1.2570866714267e-08,      -1.5692683795595e-09, 
     -3.4052741707478e-09,       1.3229671714463e-08,      -1.5119394103802e-08,      -2.9174410008416e-08,       2.1734115584932e-09, 
      3.5869153661211e-08,      -3.5637875215108e-08,      -4.9885344027723e-08,       2.4083746321722e-08,       3.2413425183846e-09, 
     -1.3381067137354e-08,      -1.8292661258703e-08,       6.0465133895953e-09,      -1.4737038773034e-08,      -1.0542086250563e-08, 
      1.1163992765072e-08,       6.5723034144022e-09,       1.3063687414270e-08,       1.8576959117097e-08,       1.4290709851165e-08, 
      2.9148021009514e-08,       9.9739093367577e-09,       3.0347494878685e-08,       1.7392123093597e-08,       2.9251802728910e-08, 
      2.6392469990710e-08, 
},
{
      9.3702846930364e-08,       7.1348817189583e-08,       8.0655382026097e-08,       9.6836190539040e-08,      -1.8680363369921e-07, 
     -1.2983945214640e-07,      -9.0422606023952e-08,      -2.5192143983260e-07,      -4.2698625836008e-08,       1.0183111147611e-07, 
      1.3883747261811e-07,       2.9691958578529e-07,      -1.3427538075769e-07,       1.7506798719067e-07,       7.7837043194376e-08, 
      5.2109845392902e-08,       1.4794412969212e-07,      -3.3745554673021e-08,       2.1418855086524e-08,      -1.9709952597879e-07, 
     -1.3550431404915e-07,      -1.5030267724421e-07,       7.6578317345497e-08,       9.6924765746032e-08,      -1.4005500648213e-07, 
      1.3633949923829e-07,       1.6797261963369e-08,       4.7933639268462e-07,      -6.3045061240641e-08,      -1.3377254772957e-07, 
     -1.7506214508672e-08,       2.0043669526703e-07,      -8.0341209408403e-08,      -1.6664622274892e-07,      -2.3302196924809e-07, 
     -1.2639213420519e-07,       2.0300350645334e-07,       3.1382247811784e-07,      -9.0603406745824e-08,      -2.5138211429179e-07, 
     -6.1857317940726e-08,       1.0689722703554e-07,       1.0456360005424e-07,      -3.7809465777909e-08,      -5.4711399155710e-08, 
     -4.3632243838043e-08,      -4.1661066427301e-08,       4.4966992296574e-08,       8.7862016596814e-09,      -3.1789697680608e-08, 
     -6.4943913200275e-08,      -2.5076180409703e-08,       5.1725472523160e-09,       1.1295809029677e-08,      -2.3211084483854e-08, 
      1.2777650262624e-08,       4.2704496018687e-08,      -8.5013810612922e-09,      -3.1093920172654e-08,      -3.1044197978556e-08, 
      2.8032185975427e-08,       2.9899262696523e-10,       1.4874585323266e-08,      -6.1278281164164e-09,      -4.1264183964136e-08, 
     -1.8397873749283e-08,       1.1936359590318e-08,       9.7175075812297e-09,       9.3591906107527e-09,       6.9287680209073e-09, 
     -4.7161360203330e-09,       5.3618943184920e-09,       3.0621322411119e-09,       6.9522948784895e-09,      -2.2157672593338e-09, 
      1.4861830179316e-08,      -1.0449126853526e-08,       1.1124559242777e-08,      -1.6218206792996e-08,       2.9762342108526e-09, 
     -1.7408655887831e-08, 
},
{
      1.1145099036533e-08,      -1.4654000712291e-07,      -1.8998886339668e-07,      -3.5270525533382e-08,      -2.5787459990414e-07, 
     -9.1733739134504e-08,      -1.3497060122031e-07,      -8.1965937969819e-08,       5.5483344343331e-08,      -7.5045838407191e-08, 
      5.6994847624025e-08,       1.2792396133672e-07,      -2.9831960575819e-07,       1.0057243261067e-07,      -1.3508582102988e-07, 
      1.2018251166455e-07,       7.1709898974243e-08,      -1.4436063445510e-07,      -7.2068360221389e-08,      -2.5431419252392e-07, 
      1.3779199405606e-07,      -2.6415079885543e-08,       2.0178394500258e-07,      -1.5461409754926e-07,       9.0729028915192e-08, 
     -1.5661849280927e-07,       8.1106286134174e-08,       2.8782192752952e-07,      -2.6001883652509e-07,       2.6054562193386e-08, 
      8.1528975676899e-08,       1.0366944991723e-07,       4.0321705631569e-08,      -3.0499920741683e-09,       1.1935975196950e-07, 
      2.8790343528140e-08,      -1.5088055722481e-07,      -1.3247281712945e-07,       1.6708915299764e-08,       1.5852724149788e-07, 
     -1.1714023769748e-08,      -1.0859777542615e-07,       3.3107553848856e-08,       6.5448088623924e-09,       5.6696368420009e-09, 
     -3.0622063205300e-08,       5.6963804443524e-08,      -8.7299695372077e-09,      -2.6932469663205e-08,       1.6147468022603e-08, 
     -1.6651967391241e-08,      -6.7320675345395e-08,       1.8768516178764e-08,       4.2217634282962e-08,      -2.1952950141070e-08, 
     -5.3537321388998e-08,       3.1481391012759e-09,      -3.8052555878796e-09,      -5.4283131902508e-08,       2.5025684864257e-08, 
      3.2656442856011e-08,       4.7193195834991e-09,      -2.3356982632813e-08,      -2.0206976321950e-09,      -8.2059721167175e-09, 
      2.7030649219730e-09,      -1.6552063053244e-08,      -2.2915884987181e-08,       7.3127937489537e-09,      -2.6181409737364e-08, 
      1.5608092689936e-08,      -1.9681518909221e-09,      -4.2479903649993e-09,      -8.5016620132345e-09,      -3.5812345661719e-09, 
     -6.4457592785768e-09,      -5.1559623423233e-09,       2.8374134453620e-09,      -3.7505707209113e-09,       4.9407812622841e-09, 
     -3.1553917918727e-09, 
},
{
      1.1287170200726e-07,      -6.1861543402132e-08,       8.5025844206686e-08,      -3.2918743216094e-08,      -3.0693415303256e-08, 
      9.5050316393460e-08,       6.2956324201031e-08,       2.3776715964544e-07,      -1.9589863816685e-09,      -1.3343953784694e-07, 
     -9.2896662432773e-08,      -1.8542966166663e-07,      -8.7291074490034e-08,       3.8305025124044e-08,      -2.8077518866458e-08, 
      8.7898315698479e-08,      -1.3012232974640e-07,      -4.4201481315248e-08,       4.1257417256225e-08,       7.4906796232949e-08, 
      4.1356034912853e-07,      -1.1142387105449e-08,       1.2393827079206e-07,      -1.3879734508950e-07,       2.9885747457821e-08, 
      2.6975995832007e-09,       1.7125913226196e-07,      -1.0794395833441e-07,      -3.9968578077814e-07,      -5.1366359009730e-08, 
      4.8898788635707e-08,      -1.8770411750076e-07,       7.7107073389660e-08,      -4.0000930060880e-07,       9.7368420389680e-08, 
      2.2268803718402e-07,       1.5594694820139e-08,       9.9824161505700e-08,       2.7990428119870e-08,      -2.4387905056924e-07, 
     -5.6395574493422e-08,       1.5469110921302e-07,       1.0264434234319e-07,      -6.5907204135335e-08,      -1.1480721203836e-07, 
      4.6331145159683e-08,       5.7653353868610e-08,       1.3308402668685e-08,       1.1830337989638e-08,      -2.8996340502818e-08, 
     -1.4714356587999e-09,       4.3010231385512e-08,       4.5000864495490e-08,       2.0837229500576e-09,      -8.4353849684387e-09, 
     -2.6321663663961e-08,       1.5205317543234e-08,       3.3085574203564e-08,      -1.6915591003628e-08,      -1.1263180700286e-08, 
     -2.0099365896839e-08,       2.0751588640982e-08,       4.0816476569953e-08,      -2.1901469298434e-08,       3.8943986894286e-09, 
     -1.5206448188486e-08,      -2.5383918818776e-08,      -1.1236163069336e-08,      -2.7356819771892e-08,      -1.7704377101805e-08, 
     -8.5080454180460e-09,      -1.9127237364092e-08,      -1.4973579568647e-08,      -1.3540584118016e-09,      -5.7786076336430e-09, 
     -3.3878461271874e-09,       2.7630723894285e-09,       4.6602642351817e-09,       9.9449932172919e-10,       1.5470106395207e-08, 
      1.5105918278719e-09, 
},
{
      1.4199164415067e-07,      -6.9008301003050e-08,       1.3571452247432e-07,      -1.5237958885822e-07,       2.0243538484911e-07, 
      9.2088695039827e-08,       4.2216120461878e-09,       1.5998118485637e-07,      -2.3903048512526e-07,      -7.2496327817677e-09, 
     -1.8918870004901e-08,      -5.6222017412754e-08,       6.8589675912041e-08,       4.9231679841695e-08,       1.0886511036797e-08, 
      5.1757708843862e-08,      -1.8517999711913e-07,       1.0058940344280e-08,       7.7932779460411e-08,       2.1076515801857e-07, 
      1.6275293059885e-07,      -8.7015122326975e-08,      -1.3141983548182e-07,      -2.8311552278669e-08,      -1.4042290961880e-08, 
      9.2227713951456e-08,       2.5640567067652e-08,      -6.2037265088381e-08,      -2.5102619712448e-08,       6.4823341316125e-08, 
      1.5376018182583e-07,       1.1600838970023e-07,       9.8814690692256e-08,      -1.0160378841312e-07,       5.5371199259954e-08, 
     -2.0937342975520e-07,      -3.0051816790934e-07,      -1.6915326937568e-07,       5.2458046954483e-09,       1.1879831889164e-07, 
      1.2896122476894e-07,      -2.8927228186120e-08,      -1.8640078621906e-07,      -6.6456338416773e-08,       6.8675085783055e-08, 
      6.5918633199270e-08,       1.2546490744583e-08,      -2.0952992929531e-08,      -6.5394256683156e-08,      -2.1375051060920e-08, 
      6.0367040462300e-08,       8.2100122128363e-09,      -8.6751857754775e-10,       2.0658673297021e-08,       1.7699225827791e-08, 
      1.7596417593771e-08,       2.5560662073070e-08,      -2.2567664250473e-08,       3.0067905518930e-08,      -1.4656666546231e-08, 
      1.0319427932580e-08,       9.2103801168139e-09,       6.7459020995067e-09,      -9.8587973153149e-09,       2.9762120309613e-09, 
     -1.1246193249583e-08,      -3.6950371923428e-09,      -1.4518563433998e-08,      -1.0311359553041e-08,      -8.0580154096428e-09, 
     -2.9539150290258e-09,       1.3824708342100e-08,       1.9322927683885e-08,      -1.7755772274069e-08,       1.4948147833064e-08, 
     -1.1404533462432e-09,       1.8377877833734e-08,       1.3189180633136e-08,       6.7566468630021e-09,       1.7852610682087e-08, 
      1.0532264311498e-08, 
},
{
     -9.3041161995795e-08,      -3.9155619476504e-08,       6.0495095617281e-08,      -1.2635136701065e-07,       9.3039604687992e-08, 
     -1.5065698613804e-07,      -1.4655889148091e-07,      -8.2933999034545e-08,      -1.1613016656396e-07,       8.9989753058879e-08, 
      5.9820199909106e-09,       1.6713370934543e-07,       1.7300030910777e-07,      -2.8840622092310e-09,       5.8856684519503e-08, 
     -1.2161177303677e-07,       2.4639424579857e-08,       4.3606539106569e-08,      -1.2190341059056e-07,       2.0067276583451e-07, 
     -1.6804639835151e-07,      -6.7127255683312e-08,      -5.3737111456737e-08,      -5.3045917259878e-09,       1.5343563704201e-07, 
      4.3550430286284e-08,      -3.7299578526326e-08,      -4.8200608425043e-08,      -5.1790687097832e-08,       1.6008323713882e-07, 
      1.0982620523422e-07,      -1.6505664906863e-07,      -1.1726664325540e-08,       4.5174402586026e-08,       5.6821952047653e-08, 
      3.3038614834542e-07,       1.5200865678710e-07,       4.6625600984099e-08,       1.8964669066459e-07,      -6.6998431683726e-08, 
     -2.1542192002439e-07,      -7.6364501320177e-08,       3.7258492673237e-08,       1.9156392792913e-08,      -3.1219946448203e-08, 
      1.8605801408434e-08,      -2.8573074141847e-08,      -1.0430897798194e-07,      -3.9284748074610e-08,       4.4978986938764e-08, 
      5.4049742497375e-08,       3.6916920243981e-08,      -2.3811771190500e-08,      -4.8163347805705e-08,      -6.9519469040710e-09, 
      5.8653335485771e-08,       1.2773264421066e-08,      -5.9240379288161e-09,      -1.9786593599663e-08,       8.8164171379139e-09, 
     -2.5766316510051e-08,       1.6323826558519e-08,      -1.4623329643685e-08,      -1.1639560393035e-08,       3.8557911234177e-09, 
     -1.0434873744912e-08,      -1.6463823287468e-08,      -1.1989028496606e-09,       3.9990800946379e-09,       2.4260225944467e-08, 
     -6.8507166460511e-09,       8.9601994733948e-09,       5.4126598841253e-09,       1.4320146835806e-08,       1.7663456463909e-08, 
      3.8648224673190e-09,       2.4203589807593e-08,       1.3897274299833e-09,       1.9055959971506e-08,       3.7483570955424e-09, 
      1.7175081443761e-08, 
},
{
     -1.0632887732392e-07,       7.1415401897142e-08,      -1.0503626578363e-07,       8.7426691656420e-08,      -2.6225259217101e-08, 
     -1.4176810909250e-07,      -1.0099938127383e-08,      -1.7057769281099e-07,       2.2798882443567e-08,       4.0136265384012e-08, 
     -2.6202192746739e-08,       1.1353548626253e-07,      -7.3683620428852e-08,      -4.7579850021929e-08,       4.1492210791192e-08, 
     -1.0997482077329e-07,       2.3015340938088e-07,      -7.8588215654434e-08,      -3.4445364411746e-08,       2.6527544728217e-08, 
     -1.7884929132646e-07,       4.3553071302506e-08,      -5.6480634178510e-08,       1.2445272972257e-07,       1.1122139510233e-07, 
     -1.2252918749598e-07,       6.1971254618534e-08,      -9.7315257931023e-08,       7.8424659353232e-08,       1.1085126465881e-07, 
      8.2084920456088e-09,      -2.6560926919225e-07,       1.3459906830386e-07,      -3.7864802372635e-07,       1.2899929461847e-08, 
      2.0758703611699e-09,      -2.1443667465337e-07,       7.1822320072324e-08,       4.7481109769087e-08,       9.0275121736173e-08, 
      8.2091206778420e-08,       4.7505811923598e-08,      -2.7676663690450e-08,       1.2850018242571e-08,       8.5294851784950e-08, 
      2.2722675079391e-08,      -6.8719335366843e-08,      -3.4453397542849e-08,       1.7315051787370e-08,       1.2600487390318e-08, 
      1.1444145848827e-08,      -4.1549355480917e-09,      -3.3082861291913e-08,       1.6631180477439e-10,       4.4077387687170e-08, 
      8.0248811749606e-08,      -2.0392997489899e-08,      -7.3424145857240e-08,       9.3491926090918e-10,       2.5554551543430e-08, 
      1.2923405054371e-08,      -2.0211202389777e-08,      -2.4503406605708e-08,      -1.3436037276957e-08,      -2.5036190661754e-08, 
     -7.7723999802645e-09,       6.9126440116158e-09,      -2.5187862081643e-08,      -1.1110832811384e-08,      -5.1699046438866e-09, 
     -1.4196644634686e-08,      -6.6575281071535e-09,       2.0945486332795e-09,       1.9342711423254e-08,       2.3461507678400e-08, 
      8.1795421393297e-09,       3.0562695163728e-08,       1.3288754608315e-08,       2.2978240346278e-08,       6.6812094486717e-09, 
      3.0050347935913e-08, 
},
{
      3.4024288438554e-08,       7.1144467291398e-08,      -4.0982271089152e-08,       7.1213409593184e-08,      -1.7929286223618e-07, 
      7.5843741150328e-08,       1.6604305607685e-07,       3.4327777754990e-08,       1.8581591771855e-07,      -3.9190194801627e-08, 
     -5.7246798699595e-08,      -5.5866176479525e-08,      -1.5404403505834e-07,      -6.1235114141357e-08,      -5.7581877683415e-08, 
      6.8613484166471e-08,       1.1821256289905e-07,      -1.4970719875701e-07,       1.1065358799912e-07,      -1.0512687252785e-07, 
      1.3408159324451e-07,       6.8286897314519e-08,       6.2016696429320e-08,       3.6318691474752e-08,      -1.4111667891908e-07, 
     -5.8129176179973e-08,       6.5991573606638e-09,      -9.5783609026223e-08,       1.5153677193595e-07,      -1.3530417563281e-07, 
      8.8716100802110e-08,      -5.8321007488985e-08,       2.5531808292071e-07,      -1.1265421756798e-07,       1.8927628048535e-07, 
      1.0998534272364e-07,      -1.8993104225369e-07,      -1.4063251761484e-07,      -1.6947905597121e-07,      -6.4841144849370e-08, 
     -6.1202906971343e-08,      -5.0383898653871e-08,       6.7052447146477e-08,       1.1238488442878e-07,      -5.3999135982483e-08, 
     -7.9941687861233e-08,       5.9510942291544e-08,       5.3982163209911e-08,       9.5828716675090e-09,      -2.5978606803981e-08, 
      2.0165185707332e-08,      -3.7784328066978e-09,      -1.2182129829692e-08,      -1.1324425121403e-08,       2.2585998261805e-08, 
      2.5544260213065e-08,       9.7498403503222e-09,      -8.8800324746046e-09,       2.3502395496400e-08,       2.3489390627851e-08, 
      1.1381796973302e-09,      -1.7035973644771e-08,      -4.5808145535708e-09,      -3.8432582882081e-08,       1.3499765909527e-08, 
      1.7749107417295e-08,       4.4776671464013e-09,       1.6007559263141e-08,       4.7499419579773e-09,      -3.9639983713557e-08, 
      2.3805974252019e-09,      -1.9795667831988e-08,       7.4898289199419e-09,      -8.7650271232198e-09,       7.1967417856108e-09, 
     -3.1533093391336e-09,      -5.2895763194770e-09,      -7.0350701349120e-09,      -1.0265219513765e-09,      -4.2322757653387e-09, 
     -1.0253981210654e-08, 
},
{
      1.7352345802700e-07,      -9.2007856008371e-08,       1.0530738484892e-07,      -1.1771852403468e-07,      -1.5313565372215e-07, 
      8.1541689411796e-08,      -1.1711756774511e-07,       1.0130108131381e-07,       6.5650983855326e-08,      -4.6052228595997e-08, 
      7.7793593779078e-08,      -7.5941886551186e-08,      -3.2144990107619e-08,       1.6000633386292e-07,      -1.0071815566571e-07, 
      2.4731013684688e-07,      -1.4505743301733e-07,      -1.4215542344098e-08,      -2.1878663531801e-08,      -1.0375681711074e-07, 
      1.9031547678996e-07,       7.8982338009706e-08,       4.3102414379776e-08,       1.0009537462457e-08,      -1.3926800128973e-07, 
      3.8683102481228e-08,       1.1689001881253e-08,       5.8596021799723e-08,       1.5076159933213e-08,      -1.6405335298420e-07, 
     -7.4254465455895e-08,      -1.3240823573795e-07,       2.0674945258381e-07,       5.2539661504874e-08,      -6.9262542472926e-08, 
      1.6192670968370e-07,      -1.0044992897759e-07,       9.5724111685223e-08,       3.1912563596010e-07,       9.0444427821184e-08, 
      1.1666544956876e-07,       9.5184082798041e-08,       1.8757472258334e-08,      -5.8657085637391e-08,      -4.3287315369110e-08, 
      5.1675783240509e-08,       3.8299187959995e-08,      -6.3325244439165e-09,      -9.6995202952305e-09,       6.4085105242360e-09, 
     -1.7093082517859e-08,       1.1973753049614e-08,      -1.0521111213145e-08,      -8.0698840294974e-09,      -2.6543053317284e-08, 
      1.4389704726579e-08,      -1.8711256485879e-08,      -3.0109872919256e-08,       2.8977138289796e-08,       4.6491441134576e-08, 
     -2.1232802026805e-08,      -6.0257207365959e-09,       1.1428781780600e-08,      -1.6988121256301e-09,      -7.4978812404464e-09, 
      1.6665128322499e-08,       5.1821866305416e-09,      -7.7906855478180e-09,       2.4209948350930e-08,       6.8597360384491e-10, 
      1.7996265642523e-08,      -1.4269176741802e-08,       2.0502288699662e-08,       4.1129030362602e-09,      -9.4501969568586e-09, 
      1.7970738355990e-08,      -1.8508351080782e-08,       2.2171706132734e-08,      -1.1875507753171e-08,       1.7389995649766e-08, 
     -8.6270163459697e-09, 
},
{
     -6.3741046289057e-08,      -1.0611777630950e-07,       5.6009815733753e-08,      -1.1842092807006e-07,       1.0005914273017e-07, 
      7.2264811073959e-08,      -1.8449611937997e-07,       1.7391050683384e-08,      -2.5558233195870e-07,      -1.0620157770467e-07, 
     -2.7260453085020e-09,       7.4034346997526e-08,       7.5141166617708e-08,       7.9209639967712e-08,      -8.1065694344039e-09, 
      4.6533599379558e-08,      -1.3461496804366e-07,       6.9995333268277e-08,      -1.0608247963127e-07,       1.1576736332665e-07, 
      7.5075036055401e-08,      -1.4994230264514e-08,       4.4451651515338e-08,      -1.2391483089678e-07,       4.1417378852924e-08, 
      7.7326621210857e-08,      -5.2153906481779e-08,       1.3504069301523e-07,      -1.7512993499676e-07,       7.1470482599723e-08, 
     -5.2602301530057e-08,       1.3582137005274e-07,      -4.4326791130364e-09,      -2.5639009814894e-07,      -1.2681810372530e-07, 
      2.2560076674541e-07,      -3.1953116760543e-07,      -7.1841285233563e-08,       6.6003276570958e-09,      -1.5314143963628e-07, 
     -4.2416003480274e-08,      -1.1672670545990e-07,      -1.3743831882203e-07,       2.9648542185686e-08,       4.4964159828215e-08, 
     -3.7096821704852e-08,       3.3655627843065e-08,       6.3276885864227e-08,      -6.9569369141698e-08,      -8.1934023027526e-08, 
      3.5588033623319e-08,       5.8339751611620e-08,      -1.8981307305971e-08,       3.8218859146666e-09,       1.6539475858319e-08, 
     -2.7966911140071e-08,      -2.2656447180229e-08,       1.7627589382169e-08,       1.5078509727563e-08,      -3.5850292843106e-08, 
     -2.5850736439287e-09,       5.5811510020746e-09,       5.7275103076929e-08,       1.9971330821830e-08,       5.7763257225850e-09, 
      1.2988587498352e-08,       2.0143832158111e-08,       7.2676030436195e-09,      -7.0075040218609e-10,      -6.0247296255564e-09, 
     -3.1320380048512e-09,      -3.0612642511839e-09,      -1.2080609919362e-08,      -1.6225511562356e-08,      -1.6874806556435e-08, 
     -8.1717147649673e-09,      -1.3300991622501e-08,      -7.4505211127095e-09,      -9.0210705706669e-09,      -1.2842381759674e-09, 
     -1.2837065152314e-08, 
},
{
     -1.5405998574156e-07,      -1.8725150453836e-08,      -1.6539765166918e-08,      -9.1462668167889e-08,       1.7191699432976e-07, 
     -5.3649166964856e-08,       9.9768326570850e-08,      -5.1102547958079e-08,      -7.5344401017860e-08,      -2.8346125209541e-08, 
     -5.0959358077643e-08,       4.3019144239984e-08,      -1.7129305870775e-08,      -5.4530742921944e-08,       3.3067505299286e-08, 
     -7.4733537259587e-08,      -5.7136955760144e-08,       6.7089470986150e-08,      -3.4841800828917e-08,       1.2084635693766e-07, 
      1.4193912751913e-08,      -1.9782468811196e-08,      -9.7071896873554e-08,      -4.6197364882311e-08,       5.9689555035904e-08, 
     -3.0551847724495e-08,       3.0444961811858e-08,      -5.6550019523514e-09,      -1.2783776427157e-07,       1.5421865195310e-07, 
     -1.3929808499774e-07,       3.0879633377200e-07,      -1.2075088880432e-07,       8.2116489399666e-08,      -4.1154829117261e-08, 
      1.3762911451234e-07,      -1.3108468771968e-07,       7.2116642160147e-08,       1.3659382787784e-07,      -2.2609837027807e-07, 
     -8.8373941074186e-09,      -2.2343651058037e-08,       9.4783993450608e-10,       5.6817100944224e-08,       3.5305334520983e-08, 
     -1.6802746784833e-08,       8.6354543160772e-09,      -4.8770149122363e-08,       3.0377216890452e-08,       7.2450723366860e-08, 
      4.4230857411351e-08,      -6.6061487225217e-08,      -4.7119939331213e-08,      -9.2248762677727e-09,       4.2417810100264e-08, 
     -2.2729261446816e-08,      -1.0413181972359e-08,       1.2749240438007e-09,      -7.6762173132434e-09,       1.6873684517769e-08, 
     -2.9522087276308e-08,      -2.9951172321743e-09,       3.2980073222288e-08,       3.3133479841437e-08,      -4.3343440936830e-08, 
     -7.1719720833468e-09,      -1.4652716040434e-08,      -1.4761141556243e-08,      -1.6239072403863e-08,       2.8260255250295e-08, 
      1.6524798249333e-09,       1.1106773542292e-08,      -5.5246725573929e-09,      -3.9112606686175e-09,       1.8643884486159e-08, 
     -8.7584994060816e-09,       1.7495493331454e-08,      -3.7757932970086e-08,       3.2766453071360e-08,      -5.3764757974955e-08, 
      4.8205354525143e-08, 
},
{
      5.3300296518818e-08,       1.3292094229078e-07,       1.5266323043110e-09,       1.1544697443315e-08,      -1.3943081704578e-08, 
     -1.1318742467645e-07,       7.5952483998407e-08,      -7.9199947776868e-08,       1.3404990452029e-07,       1.0291991059301e-07, 
      8.7014607494870e-08,       5.1496874808933e-08,      -8.1395430631225e-08,      -2.5737302795979e-08,      -2.3273029493649e-08, 
     -4.4139258526119e-08,       6.5978882881335e-08,       4.3832121189280e-08,       5.0596479080772e-08,      -7.6265510349002e-08, 
     -9.7369681679613e-09,      -2.6240002446651e-08,      -6.6994970937120e-08,       8.9542132971258e-08,      -1.7041397913174e-08, 
     -5.1927520782574e-08,      -1.7081179165596e-08,      -8.1205253651219e-08,       1.9062945992976e-07,      -4.5299166976803e-08, 
      9.1090715649130e-08,       6.4382994407110e-08,      -1.1029173844852e-07,       1.7112465675371e-07,      -4.7767683725478e-08, 
      1.4071716839130e-07,      -4.6308462864084e-08,      -4.8600314891557e-08,       2.1996393733325e-07,      -5.1597207682441e-08, 
      8.5026569722695e-08,       1.4806586193813e-07,       1.4256046084826e-07,       6.3582318152205e-08,       1.3256528091230e-08, 
     -5.0700473636701e-08,      -3.1395531557854e-08,       3.3173933296198e-08,      -3.5603438761854e-08,      -3.8441943156038e-08, 
     -3.0659745719022e-08,      -1.1274386844345e-08,       3.8104193011362e-08,       1.1507172316276e-08,      -1.0395016022966e-08, 
     -6.3495321759772e-09,       7.8674679510912e-09,       2.8549012200682e-08,      -1.4164079832114e-08,      -2.5002977481647e-08, 
      1.5330230901399e-08,       2.0834768995023e-08,       2.2758704808721e-08,       4.1440567158598e-09,      -2.3071652648993e-08, 
     -3.0563488672475e-08,      -8.0207709984275e-09,      -9.0468847845580e-09,      -1.9386605063587e-08,       8.9854926177875e-09, 
     -1.1534449477681e-08,      -2.2465708140777e-09,      -1.8789353730747e-09,      -1.0214540035514e-09,      -2.4635873452907e-09, 
      1.9664993544377e-08,       1.7328158872593e-08,       6.6247824680072e-09,       1.9907894410642e-08,       1.1271045831613e-08, 
      2.1163233395032e-08, 
},
{
      1.1431642571856e-07,       3.1647660364934e-08,      -3.3315541741577e-08,       1.8701581254687e-08,      -9.0846175675476e-08, 
      5.0177116883189e-08,      -1.1217077677067e-07,       2.1718041200905e-08,       5.0790711991283e-08,       5.4145072508608e-08, 
      5.2353949617784e-09,       9.2282346940740e-08,      -1.5666361601992e-09,       9.2899519041466e-09,       9.2560115363515e-09, 
     -9.7810519581017e-08,       1.3511476653450e-07,      -7.4151417465337e-08,       6.4803210962662e-08,      -1.0626163688162e-07, 
      4.4546605643986e-08,       1.2842102102267e-08,       3.7840203669832e-08,       8.6159655778415e-08,       4.5210104573283e-08, 
     -7.5734740408268e-08,       2.7047726198365e-08,       4.6492553931193e-09,       1.7634915939065e-07,      -8.9324278875408e-08, 
      1.5463854684448e-07,      -2.1632223442409e-07,       9.9384010028092e-08,      -7.3948282093979e-08,       5.8934031083070e-09, 
     -7.5750529510709e-08,      -1.8911941880542e-08,      -1.9229968816438e-08,       1.0377193592993e-07,      -1.3635697439148e-07, 
     -2.7101100513344e-07,       1.5006966941898e-07,      -1.5665030746893e-07,      -3.4307045255617e-08,      -5.9021595782639e-08, 
     -1.2205899401810e-07,      -7.3069559603513e-08,       5.5436772513276e-08,       4.0577891870019e-09,       1.2185790948282e-08, 
      9.3692087639538e-09,      -3.2427449885976e-08,      -7.0018698154349e-08,       3.7640346461294e-08,       5.2252867723500e-08, 
     -2.5592644443258e-08,      -3.6160379984471e-08,       7.4195491414365e-09,       2.5570376925147e-09,       4.9162597200636e-09, 
      1.8260290052167e-08,      -2.0980672613247e-08,       1.3804061048910e-08,       3.9141296193609e-08,       9.9700017766030e-09, 
     -1.6984244807583e-08,      -8.7967945900204e-09,      -4.6961593373168e-09,      -3.1088151274537e-08,      -1.6366384409787e-08, 
      7.3295059439551e-09,      -2.6914495772114e-09,      -1.3060933193230e-08,      -8.7098777174848e-09,      -1.5494328822211e-08, 
     -1.1881286744552e-08,      -1.2853264487590e-08,      -5.0720001114834e-09,      -3.6877927764556e-09,      -8.8911425205244e-09, 
      6.9861928407038e-09, 
},
{
      7.9871997105760e-08,      -4.1043764165845e-08,       4.9179249652510e-08,      -8.2312573526093e-08,       3.8617443674674e-08, 
      1.1298131071201e-07,      -4.4944522954060e-08,       7.6006661332476e-08,       9.6423737198694e-09,      -7.0898379878253e-08, 
     -7.9036251409471e-08,      -2.5332751859083e-08,      -8.3779834167688e-08,       4.3832520518014e-08,      -5.2387436526443e-08, 
      9.2140921844138e-08,      -3.9377891900436e-08,       1.2925635359866e-08,      -1.0515459741049e-07,       9.1774661613065e-09, 
      3.9632674215208e-08,       1.0178759866291e-07,       6.2787577838307e-08,      -5.1007543902694e-08,      -3.3047895443994e-08, 
      1.6129623177286e-08,      -1.5002838254842e-08,       1.2136530532978e-07,      -8.7029992414525e-08,      -4.3867782895983e-08, 
     -1.4172518633342e-08,      -7.5750796045780e-08,       1.0990067595227e-07,      -1.4856416031272e-07,       1.3058340922205e-07, 
     -1.8715593868844e-07,       2.2862299407008e-08,       8.6528038465079e-08,       2.0697875088996e-08,      -5.5167197888633e-08, 
      9.6016911042051e-08,       9.4297429823070e-08,      -1.0699873237629e-07,      -5.1742819938212e-08,      -3.1841242105327e-08, 
      7.9912712116936e-08,       1.6768805906150e-07,       5.8593961667631e-08,       2.9193576849277e-08,      -1.8558769655221e-08, 
     -4.2668539015091e-08,       2.5624789120520e-08,       8.0875190816935e-08,      -1.9909290496674e-09,      -6.4474262502821e-08, 
     -3.6519512963967e-08,       6.1534629543356e-08,       6.2487645468054e-08,      -1.4487124682241e-08,      -4.7308379329146e-08, 
     -8.5448126017970e-09,       4.2547884423009e-09,      -8.7289276407054e-09,      -1.2809717854970e-08,      -7.7594686952157e-09, 
      6.4842609462148e-09,      -2.9759587688353e-08,       1.9529128967952e-08,       3.2750772325458e-08,      -7.3850916928753e-09, 
      3.7699825858005e-09,       5.6763295010056e-09,       5.3287840693303e-09,      -1.3530735779119e-08,      -7.3143502808522e-09, 
     -9.7409571670223e-09,      -2.0985136562177e-08,       5.5773107379983e-09,      -2.1770803826650e-08,       1.6523461188663e-08, 
     -2.9622241535939e-08, 
},
{
     -1.7137556396439e-08,      -3.1085555217210e-08,       5.8839602375954e-09,      -1.1164560247901e-07,       1.3329878375204e-07, 
      4.3066671070897e-08,       5.1967204239965e-08,       7.1622019173745e-08,       5.8311147114710e-08,      -1.9001578573783e-08, 
     -1.3435375341140e-08,      -1.0622266046406e-07,      -2.9156055296529e-08,       3.8083233571808e-10,      -6.7339003570920e-08, 
      9.7413956855713e-08,      -1.4850282586143e-07,       3.4946457205504e-08,      -7.2182285726355e-08,       7.1998416423079e-08, 
      2.9311588475206e-08,       3.2595107644244e-08,      -2.4316022333933e-08,      -5.7432782183942e-08,      -6.0236532348570e-08, 
      2.8551297372568e-08,       6.0661485042094e-09,       4.1464973076393e-08,      -1.3537264895831e-07,       3.9770580211220e-09, 
     -8.9197805112632e-08,       9.7777844196337e-08,       1.8825796918955e-09,       9.9393773922422e-08,       6.6586344005882e-10, 
     -1.2443040460241e-07,       8.2552359862342e-08,       1.7102320914113e-08,       7.0150903623200e-09,      -1.2087952580800e-08, 
     -1.9957656394902e-08,       7.4550314984643e-08,       7.5785726183164e-08,       3.1341189801873e-09,       1.0253780798043e-07, 
     -9.3263166085774e-08,      -3.8740377358284e-08,       2.9646485641977e-09,      -1.1546514332246e-08,      -7.8158379468501e-08, 
      2.8128874072328e-08,       1.3403953523999e-08,      -6.3339090052245e-08,       8.8740828524390e-09,       5.0841173313953e-08, 
     -1.0044070806770e-08,      -4.0353626301949e-08,       1.5424311548276e-09,      -1.2582895918467e-08,      -6.3306309091625e-09, 
      1.0594094195040e-08,      -5.5374200285791e-08,      -4.3873275702569e-08,      -1.1825406610819e-08,      -7.1833355198882e-09, 
     -1.2399029796778e-08,      -9.8381395749665e-09,       5.2292889461143e-09,      -8.4421212017225e-10,       1.3804056684096e-08, 
     -1.1733717053255e-08,       4.5080278025986e-10,       1.9351790994771e-08,      -1.1558351879538e-08,       1.3706598682104e-08, 
     -9.1245776790206e-10,       4.0956341521483e-09,      -1.2986159400614e-08,       1.6092632991880e-08,      -3.6181668092325e-08, 
      1.5184071707212e-08, 
},
{
      3.7471842745203e-08,       1.0940925204293e-07,      -2.7502886464459e-08,      -5.6634453941806e-08,       5.8773884977798e-08, 
     -5.7211615963801e-08,      -2.8183841998379e-08,      -1.5109491761492e-08,      -4.7414250585318e-09,       5.6927781297715e-08, 
      5.7090865770674e-08,       1.1870731193889e-08,       9.0647226275980e-08,      -4.9130097206985e-08,       2.6217930541456e-09, 
     -6.4975709624341e-09,      -8.2163284341294e-08,       5.7724632602488e-09,       1.7307091838775e-08,      -1.0235890752632e-08, 
     -3.4230932223468e-09,      -3.7149548149486e-08,      -6.3001129932942e-08,      -1.0723202701121e-07,      -2.0456039931410e-08, 
      4.3550529045119e-08,       3.5068242081835e-08,      -3.5308164199753e-08,      -8.4334891546170e-08,       1.8714465002737e-08, 
      2.8212679299797e-08,       1.4028441313330e-07,      -3.6540133060967e-08,       1.2489740204139e-07,      -1.8086846948943e-07, 
      1.1616167578340e-07,       2.0183663109732e-08,       3.8750508202635e-08,      -6.3244673688974e-08,      -7.4635923836724e-08, 
      9.9875709287124e-09,       8.7613415840494e-08,      -1.4901347533796e-07,      -1.1566099896651e-07,       1.9157201867455e-07, 
     -9.2947130324559e-09,       5.4720559910589e-08,       9.8336413661396e-10,      -1.4568607931726e-07,      -4.3979653544467e-08, 
      4.5832344442830e-08,      -1.2249138182468e-09,       1.8836035822316e-08,       1.5132009128551e-08,      -4.5201177079202e-08, 
     -1.7516756461603e-08,       6.7358317295382e-08,       3.0557632023930e-08,      -3.6295402617082e-08,      -5.3427916352357e-08, 
      2.7318223017862e-08,       2.2249604901400e-08,      -3.3079824827468e-09,      -1.4573448661338e-08,      -1.6580659027019e-08, 
      1.3375359606085e-08,      -1.6079537004986e-09,      -6.1244874856815e-09,       7.5317085386709e-09,      -1.4418396625911e-08, 
     -3.8010309117161e-08,       2.5122146068178e-09,      -6.4610891546808e-09,      -7.2172154836893e-09,      -5.2517252028765e-09, 
     -1.9399965598600e-09,       1.2881658770767e-08,       4.1047726241602e-09,       2.2786917071129e-08,       8.4480013773497e-09, 
      3.0829745426811e-08, 
},
{
      8.5524329039864e-08,       8.3850034826364e-08,      -4.7383539368391e-08,       8.6781111274101e-08,       4.2635426081388e-08, 
      2.2842110478575e-08,      -1.0455791021996e-07,      -1.0353451878592e-07,      -5.0553512133621e-08,       1.2305416456194e-08, 
      2.8702632299081e-08,       5.8117779943790e-08,       3.8619109743098e-08,      -2.6946599755024e-08,       5.2781117875213e-08, 
     -4.1425424068053e-08,       1.1381667483409e-07,       1.4242528464988e-08,       5.4584165288354e-08,      -5.4594231664254e-09, 
     -7.3487034811141e-08,      -4.1189532928051e-08,       9.0384080620170e-09,      -5.5985903118507e-09,       9.9954947413292e-08, 
     -3.6462773242079e-08,      -6.6483391857886e-09,      -6.1870101571912e-08,      -8.8922453061693e-09,      -9.2701585348726e-09, 
      1.0070698114291e-07,       6.4874257654951e-09,      -3.9507976334654e-08,      -1.0068234422754e-07,      -5.3958221083960e-08, 
      9.3310092392371e-08,       3.2480357689670e-09,       6.9878965021720e-08,      -1.0698171160101e-07,       5.2216479475137e-08, 
      1.0020580028867e-07,      -3.1576137868591e-08,       5.8575368170156e-08,      -6.8395396577632e-10,       5.0469092624835e-08, 
     -1.3131956375792e-07,       2.0342167500591e-08,       1.1855552840696e-08,       6.3010509122220e-08,       6.6129588102414e-08, 
      2.8644337935899e-08,       3.4007573246535e-09,      -2.7835380437460e-08,      -2.6337973614610e-08,       9.0262906458967e-10, 
      2.3862032000979e-08,       2.9008239805475e-09,      -4.4585190276121e-08,      -1.8036956983189e-08,       2.8488296800839e-08, 
      3.3875496356342e-08,      -4.8949003577835e-09,       5.1390233117784e-09,      -5.6054527630037e-09,      -4.8742945589521e-09, 
      2.9811617410850e-09,       1.1663773580019e-08,       1.6439363181945e-08,      -6.7543118094289e-09,       1.4287508116837e-08, 
     -1.0075860468348e-08,      -7.1265583036400e-09,       2.4986308895014e-09,      -2.0259807776413e-09,      -1.2198872455206e-08, 
     -1.0226266918236e-08,      -1.2923541118449e-08,      -6.8735071970499e-09,      -1.9161221480272e-08,      -9.6768720508613e-09, 
     -1.6022633320065e-08, 
},
{
      7.0816882022473e-09,      -1.3296976582755e-08,      -7.5859988876592e-08,      -3.1288336452637e-08,       4.4801136225444e-08, 
      5.5782576243612e-08,       3.0991118828510e-08,       3.9204071905402e-08,       1.2025282909252e-09,      -4.1689886151007e-08, 
     -9.4904206100350e-08,      -3.4612560624975e-08,      -1.0900885608371e-07,      -6.1089332147779e-08,      -4.2805435245292e-10, 
     -1.0093677530041e-08,       7.2495705193028e-08,       8.5104685390003e-09,       6.0500033515890e-08,       2.3247088768756e-08, 
     -3.1738876652874e-09,       4.7755250994173e-09,       5.7477301802602e-08,       4.3160171732371e-08,      -8.6949120978425e-09, 
      4.8261549571778e-08,      -1.3781083666783e-08,      -4.6343005056650e-08,       7.8148187644441e-08,      -1.6483929470658e-08, 
      3.6480077514276e-08,      -9.6047661469234e-08,      -3.0754307390408e-08,      -9.7621921347123e-08,       5.0261918034275e-08, 
     -3.0535133943113e-08,       3.0922367051313e-08,      -1.1239119887232e-07,      -2.9880709851305e-08,       9.0423983289436e-08, 
      2.0771503371137e-09,      -9.1701384497857e-08,      -4.2217657939705e-08,      -1.0311655878127e-08,       2.7671029844338e-08, 
      1.2207329320214e-07,      -6.1676338688784e-08,      -5.9960208767686e-08,      -2.6796519091463e-08,      -8.8822820888147e-08, 
     -1.3772036351400e-10,       9.9185446152200e-09,      -6.1489118191177e-08,       3.0033066282119e-09,      -3.9202232531854e-09, 
     -8.3976645580966e-09,       4.6678779795698e-08,       6.1019881645414e-08,       3.2872365133389e-08,      -3.1268568793447e-08, 
     -3.8992381867389e-08,       1.3245605516923e-08,      -1.4273101957531e-08,       8.4339169316858e-11,       8.6996466927462e-09, 
     -1.8310423713544e-08,       7.8230422616169e-09,       1.3895714685921e-08,      -5.4898695548706e-09,       1.2936600213232e-08, 
      7.1278540214887e-09,       8.7127693993754e-09,       2.5339961588515e-08,       2.9162116167723e-09,       6.8312529776235e-09, 
      9.2232465562030e-09,      -4.9700332234778e-11,       1.0700062690193e-08,      -6.3100591625703e-09,       4.4538413182463e-09, 
     -9.5516683889124e-09, 
},
{
      7.5987367097925e-08,      -2.5915102522951e-08,      -1.9650576990197e-08,      -4.9506857631355e-08,      -1.5782825623008e-09, 
      1.7502450665273e-08,       1.5814069559538e-08,       4.7768073377267e-09,       7.6139431128017e-08,       5.0854819120122e-08, 
      2.8101249933856e-08,      -3.8525417399716e-08,      -1.2884142131903e-07,       4.5803597678275e-08,      -1.0104159353350e-07, 
      1.1226059133059e-07,      -8.4220283407264e-08,       1.3135319549773e-08,      -4.0650277090905e-08,      -6.2657249028579e-08, 
      5.0371007082259e-08,      -1.6105832537483e-08,       3.2107379207395e-08,      -3.2155530442314e-08,      -6.0076479141730e-08, 
     -9.3487152177013e-10,      -1.2871097130107e-08,       1.4742517463960e-08,       3.6138205300871e-09,      -5.0684867347837e-08, 
     -2.5515291809644e-08,      -9.0500065907010e-09,       2.9220048537815e-08,       2.3061921547065e-08,       6.6128195828951e-08, 
     -3.3832021781669e-08,      -8.7462068973517e-09,      -1.2365684344914e-07,       5.1064888612002e-08,      -2.7508648084208e-08, 
     -7.3551417071972e-08,      -1.7118756362329e-08,      -6.1193128608633e-08,       5.0418991655279e-08,      -8.9823856959702e-09, 
      1.7942334640992e-08,      -1.5459355307663e-07,       1.4013084125490e-07,      -2.5423993864681e-09,       6.2689944831698e-08, 
     -3.1106957533503e-08,      -6.1566528039729e-08,      -1.9114839621822e-08,       1.7741904918561e-08,       3.3799518536846e-08, 
      5.1386942076275e-08,       7.2071325153695e-09,      -6.3739364556580e-08,      -6.3597445424838e-08,       4.2271568047757e-09, 
      3.9756671452646e-08,       8.6435694090469e-09,      -1.8025989986680e-08,      -3.3815780174300e-08,       9.3920250571009e-10, 
      2.7016685001210e-08,      -6.9230753712943e-09,      -1.5358438415360e-08,      -2.9540369917197e-08,       8.2993503630751e-09, 
     -1.8995829864122e-08,       1.0684440477626e-08,       5.7748563312878e-09,       2.5562850421019e-08,       1.4956354486090e-08, 
      2.0187849948558e-08,       3.3954909654783e-08,       1.8709103669225e-08,       4.0590540684757e-08,       6.9335781903548e-09, 
      3.9326146365601e-08, 
},
{
      1.5614301951303e-08,       2.3609025745226e-08,       2.9646393062244e-09,       5.2704918819670e-08,       8.1851609676822e-08, 
     -3.7402201275497e-09,      -2.0413793975061e-09,      -2.6096874623113e-08,       1.3818880298297e-08,       1.9372544607453e-08, 
      3.8836813477129e-08,       1.1656363575312e-08,       6.5057914860564e-08,       1.1995568065752e-08,       2.1456691067850e-08, 
      1.7524858871249e-08,      -1.1249604113749e-08,      -2.1454349663443e-09,      -5.6041038707307e-08,       5.2653009475560e-08, 
     -6.4701501854908e-09,       1.7267930904420e-08,      -6.4399127634676e-08,      -6.1265781995959e-08,      -6.0731889860468e-08, 
     -2.4833438094630e-08,       1.1324794090940e-09,       2.5162579317479e-08,      -6.7332273243278e-08,      -9.5616818536306e-09, 
     -4.8655336502166e-08,       3.2232108668396e-08,       5.9907918671450e-08,       4.1878874831375e-08,      -8.5950044430708e-09, 
      2.8934072637661e-08,      -2.6326153823112e-08,       5.7671174914857e-08,       1.7891910708106e-08,       7.0311880456087e-08, 
     -1.6027597113484e-08,      -1.6628981842620e-08,       5.7797659469230e-09,       1.3859206998217e-07,      -1.9102331435626e-08, 
     -2.0243580815915e-08,      -5.0494110664639e-09,       3.9016634733086e-08,      -3.2473999675112e-08,       3.8905623266605e-08, 
      6.3548965974157e-09,       4.8539180962100e-08,       5.2472384269907e-08,      -3.3033971734706e-08,       1.3236234765935e-08, 
     -3.2412205573667e-08,      -1.9519964262933e-08,       1.9891566410252e-08,       7.4243998925716e-09,       3.5031907135039e-08, 
      2.6107738260247e-08,       7.2205829690304e-09,      -3.2442066624647e-08,       2.5692447630745e-09,       1.2907566793828e-08, 
      1.7788682233758e-08,       3.6224466255426e-08,       2.5085260180078e-08,       2.1143807147040e-08,      -2.7323205582387e-08, 
     -1.2870489658920e-08,      -2.2850767290229e-08,      -3.2291470919922e-08,      -3.6210054636252e-08,      -1.4032042799955e-08, 
     -3.8310433309344e-08,      -3.5131714347239e-08,      -3.4281223981577e-08,      -5.2431032020475e-08,      -2.7957869552652e-08, 
     -5.3105370572886e-08, 
},
{
     -6.3750241134828e-08,      -1.9762579165320e-08,      -6.7394142368719e-08,       3.1501252776408e-08,       8.7113213298671e-08, 
     -1.8438600405829e-08,       2.2167200974869e-10,       2.4290147206033e-08,      -5.4724685141464e-08,      -2.6484662888791e-08, 
     -2.7412167214823e-08,      -1.6168441375189e-08,       1.0729327872636e-07,      -4.4650408335363e-09,       5.7722413946988e-08, 
     -9.7569047018104e-10,       7.3595596989961e-08,      -1.9339901087534e-08,       3.1243176920553e-08,       7.9703081102276e-08, 
     -1.0017600934078e-09,       2.5460022420248e-08,      -3.4140412149492e-08,      -3.8433009085633e-08,       2.3229396021088e-08, 
      6.0057041403144e-09,       3.6040279595974e-08,      -1.2785461164684e-08,      -4.2663598426513e-08,       7.5456155750597e-09, 
     -3.8421961280628e-08,       9.6022131165957e-08,      -1.7141580496130e-08,      -2.9458560564815e-09,      -3.6433567418369e-08, 
     -1.0809840538152e-08,      -4.4599978135483e-08,       8.6617633062467e-08,       2.1414062279446e-10,       4.0488623371388e-08, 
     -2.8874987367372e-08,       5.1180716729067e-11,       1.2344088160827e-07,       1.6155109205826e-08,      -3.9025840695116e-08, 
      3.7749362680767e-08,      -4.6298426798493e-08,      -5.5160436640002e-08,       1.2771364094736e-07,      -9.5048582292414e-08, 
     -1.3942102845329e-08,      -4.8216941875681e-08,      -4.9792721449843e-08,       3.5386699332999e-08,       4.0803002647829e-08, 
     -8.4213337921106e-09,       1.4271643703674e-08,      -1.4990982908637e-08,      -1.1000940432308e-08,       8.5315373284776e-09, 
      6.2413103119478e-08,       8.5056731039287e-09,      -6.2576428901604e-08,       1.2432215099747e-08,      -3.7873617031007e-09, 
      1.6273399730965e-08,       2.0746096782214e-08,       7.2249842144973e-09,      -1.1526735307806e-08,      -2.2254173703064e-09, 
      2.4216868961623e-08,      -5.5691612414828e-09,       1.0545622624836e-08,      -4.0942166371660e-10,      -1.1252952225701e-08, 
     -1.0344179675832e-08,      -2.6604252510247e-08,       6.6545419309829e-09,      -4.3141485986116e-08,       2.4928400471582e-08, 
     -4.5311088372339e-08, 
},
{
     -2.4331222300097e-08,      -4.2165875083441e-08,      -4.0787318991428e-08,      -3.5424948755476e-08,      -1.6375765390999e-08, 
     -1.4320990741186e-08,       4.6681329671375e-08,       4.5394108538369e-08,       9.6480660913729e-09,       1.4046426722772e-08, 
     -7.2810281401774e-09,       1.3885509441237e-08,      -3.6000634499406e-08,      -1.5741494034640e-08,      -6.6257106865837e-08, 
     -1.7857708005445e-08,       4.1730099054416e-08,      -2.6757273808305e-08,       4.8511057886282e-08,      -3.7159318539262e-09, 
     -3.6481146158294e-08,      -3.4098631562894e-08,      -2.4433338455858e-08,       4.1673657485321e-08,       2.0141023271968e-08, 
      1.9459015678263e-08,       3.8516365473709e-08,      -3.9670960758801e-08,       4.9114401080035e-08,       1.8999776588324e-10, 
      3.5213090409625e-08,       5.2590207307943e-08,      -5.6956279664887e-08,       2.0967857635557e-08,      -3.8317462542831e-08, 
     -2.4824498682148e-09,      -7.0874264428960e-09,       7.8179489380899e-09,      -2.5967217013353e-08,      -4.9024037418913e-08, 
     -6.2710985808800e-09,      -1.7518318450902e-08,       2.5884031949443e-08,      -2.7887373814444e-08,      -4.5700968787528e-08, 
     -7.7171616902294e-08,       4.6336356352455e-08,      -2.9101571862767e-08,       1.4530398741670e-08,      -1.0120468302635e-07, 
      7.7790588732530e-08,      -9.2491009408480e-09,       4.1129950546979e-08,       7.4290427012850e-09,      -8.0973487380146e-08, 
      3.2676249140724e-08,      -3.0807798627173e-08,      -1.1696632609939e-08,       2.5630718719409e-08,       3.4548304209639e-08, 
     -3.1661047792882e-08,      -4.1268630993803e-08,       3.8099888193077e-10,      -2.4908844982229e-08,      -3.0484224224851e-08, 
      2.2138198381060e-08,       1.7879099454058e-08,       2.1964521950255e-09,       1.1733218289064e-08,      -2.2482181188083e-08, 
     -3.0382098438613e-09,       4.0330838593116e-09,      -1.8243923500787e-08,       6.0306834735312e-09,       1.2866875283720e-08, 
     -9.0915621079922e-09,       3.8186460952231e-08,      -2.1221151812757e-08,       5.1926730280767e-08,      -2.8299550866746e-08, 
      6.8631082966286e-08, 
},
{
      5.5518316183221e-08,      -8.9146895385472e-09,       3.2929035769256e-08,      -2.5459565398317e-08,      -1.4219443845740e-08, 
     -4.3864879845662e-08,       4.9009673284829e-08,      -1.2112504086961e-08,       4.8350478013821e-08,       3.9596880587796e-08, 
     -2.7647989802064e-08,       1.6424064699652e-08,      -5.4725277778664e-08,       3.1639905362050e-09,      -5.8205650492158e-08, 
      3.3743293316659e-08,      -2.2172186144013e-08,      -6.6914992091900e-09,      -4.2969424993124e-08,      -4.9307579503999e-08, 
     -5.7844168993621e-08,      -3.9428044790699e-08,       2.2083169662580e-08,      -2.9476540976816e-09,      -2.3167380785833e-08, 
     -1.5149295783643e-08,       3.1525034017933e-08,      -1.9637544899872e-09,       3.7760142501198e-08,      -3.3379962195499e-08, 
      5.5626822040388e-08,      -1.3183561849284e-08,       3.3014021158890e-08,      -3.0397622393981e-08,      -1.3876658697445e-08, 
     -1.6061381334191e-08,       3.8460501215838e-08,      -2.2900232600051e-08,      -1.3077862187704e-08,      -3.0798378590851e-08, 
      5.7326599062175e-08,      -1.0191812185934e-08,      -1.3088127341330e-08,      -6.4205845483577e-08,       1.7331881280580e-08, 
     -5.4902599234380e-08,       7.7656580301768e-08,      -8.3828906326496e-08,       8.5158050861342e-08,       2.7467922569274e-08, 
     -6.1739297428030e-08,      -1.2609497913451e-08,       6.4810513354436e-08,       9.9883624817708e-09,       4.9335150932487e-08, 
      1.1478872642361e-08,      -3.2111733449172e-08,      -7.5584952917716e-09,       1.4570838989938e-08,      -2.8592771040615e-08, 
      3.5166982217626e-09,       3.8042974530093e-08,       9.2974945957550e-09,      -2.4457413764057e-08,       3.9640373769328e-09, 
      2.7898937929553e-08,      -7.3201833188762e-08,      -2.0417089758261e-08,      -1.6039784331927e-08,      -1.5019422746881e-08, 
     -3.3791449016226e-08,      -2.1109563865031e-09,       6.1218812463270e-09,       8.5835067168987e-09,       2.5235260033298e-08, 
      2.1482290312565e-08,       1.8654777173339e-08,       5.5253300949398e-09,       4.2362178988934e-08,      -2.3242000248461e-08, 
      6.2384243796602e-08, 
},
{
     -1.4040563887361e-08,      -2.5807225837877e-08,      -1.0426422018222e-08,       4.1289145072110e-08,       3.1731977629579e-08, 
     -2.0374747295269e-08,      -1.1842505205910e-08,      -4.6910135166159e-08,      -5.3334369559299e-08,       4.1061575767198e-09, 
     -2.4682452132810e-08,      -1.9516148426217e-08,       2.8497967307574e-08,      -5.1042199599653e-08,       2.4822824666958e-08, 
      5.6901186025051e-08,       4.7821133590500e-08,       2.0888245398168e-08,      -3.3494304644702e-08,      -2.4963244811027e-08, 
     -7.0543879987065e-09,       5.5155275750198e-09,       4.6871183054180e-08,      -4.7674186708855e-08,      -6.4295535384704e-09, 
     -4.7085096350693e-08,       7.4858689380451e-09,      -1.3505131178304e-08,      -3.5192140516645e-08,      -3.5806469551035e-08, 
     -6.8474702779975e-10,      -2.7433494685855e-08,       3.2706290050605e-08,       1.5338866864197e-08,       4.7999191903997e-09, 
      6.3995124607837e-08,       6.3904682931446e-09,       1.5992212894222e-08,      -3.5635931632274e-08,       2.4002563695187e-08, 
      7.8430934246473e-08,      -5.2848798399566e-08,       2.0655749951342e-09,      -3.4224859595932e-08,       9.3323835413448e-08, 
     -3.5977175181173e-08,       4.5427812368221e-08,      -2.0109373300981e-08,       3.9671130193404e-08,      -9.6295313432650e-09, 
     -8.2743608048788e-08,       6.5513195149779e-08,      -6.5761673085644e-08,      -6.7933921620453e-08,      -3.4894938614014e-08, 
     -3.6279101597158e-08,      -1.9993621847970e-08,       5.0538999901756e-08,       5.8032807572725e-08,       1.0715546914694e-08, 
     -5.2756977043447e-09,      -3.5168580491917e-08,       3.1420874280205e-08,      -2.2921855890019e-08,      -5.5677655380968e-08, 
     -1.6167801717581e-08,       7.1373128539888e-09,       3.4696313883169e-08,      -1.7114731407393e-09,       3.0458253153510e-08, 
      2.2562131911970e-08,      -4.3668667649641e-09,       1.1128405282782e-08,      -9.7961432962045e-09,      -3.0016630154808e-08, 
     -1.8723605672709e-08,      -4.2051928579463e-08,      -2.0618971497344e-08,      -5.7885360953355e-08,      -3.1043028031664e-08, 
     -3.9659759888552e-08, 
},
{
     -4.6998043401863e-08,      -7.3125989249549e-08,      -3.9162440267123e-08,      -1.0380686456440e-08,       2.9543026038370e-08, 
      2.1364265555602e-08,      -5.0212916735821e-09,       2.4097352531784e-09,      -2.4699904721745e-08,      -6.2582358849204e-08, 
      1.9006405217995e-08,      -7.6623875539401e-08,       3.2480711743472e-08,      -4.5011134897040e-08,       4.5519445887034e-08, 
     -1.5734315541709e-08,       4.9300208757768e-08,       6.4400954141948e-09,      -1.8891032342919e-08,       4.6431841068944e-08, 
      4.2906868844165e-08,       4.3849106348132e-08,       2.2129641912035e-08,      -2.7291304341375e-08,      -5.7325459793046e-08, 
     -8.8543516677017e-09,      -2.8298020291289e-08,      -4.8630297725007e-09,      -5.4708722719589e-08,       9.2450643784572e-09, 
     -2.5366126298360e-08,       1.3767739772073e-08,       5.4227866572064e-09,       3.2968499233536e-08,       2.4486825471472e-08, 
      1.0527840310867e-08,      -1.8757070788136e-08,       1.3727245216936e-08,      -4.4175843590177e-08,       3.1903296115492e-08, 
     -4.7331716245612e-08,      -4.5447411640280e-08,      -5.3922308897599e-08,       4.6428064903514e-08,       4.4192270666107e-08, 
     -4.8120400099369e-08,      -6.6899199735993e-09,       1.7392768758844e-08,      -6.8888508194771e-08,       2.0389298546466e-08, 
     -8.1668415940390e-08,       2.7881484013889e-08,      -2.7400623323859e-08,       3.0103050032315e-08,      -3.0461013444809e-08, 
     -1.4905022368990e-08,      -2.9119325437705e-08,      -6.2108950701616e-09,       3.7894814319005e-08,       1.4802828937143e-08, 
     -3.2588993781587e-09,      -9.8534605160238e-11,       5.1381699601684e-09,       1.0189376128409e-08,       1.1495155773228e-08, 
      3.6715874633191e-09,       6.0449606759056e-09,      -2.2937580799673e-08,      -1.7210698789309e-08,      -9.5326483414304e-09, 
     -3.2185599251038e-09,      -2.5319117048019e-08,      -1.3326906916446e-08,      -7.2576117741930e-09,      -1.3144062485991e-08, 
      8.3269792256716e-09,      -6.4473774956133e-09,       2.2145484523373e-08,       6.2664858835279e-09,       3.4093821139579e-08, 
      2.5145406028728e-09, 
},
{
     -1.6691019592370e-08,      -1.5666102397790e-08,      -1.4954443187894e-09,      -3.2251236580079e-08,      -9.3863432195235e-09, 
     -3.0712799637772e-08,      -2.3553763041212e-08,       4.0104995854708e-08,       2.6431132552207e-08,       3.7004888408356e-08, 
      5.1230315465902e-08,       1.8340782129712e-09,      -6.2052775075370e-08,       2.0460460601186e-08,      -6.2425954044582e-09, 
     -6.9601572151115e-09,      -9.2892990909517e-09,      -4.8668807783869e-09,      -2.0537468213377e-08,       9.6975161538131e-09, 
      2.2703555087580e-08,       2.7869736922405e-08,      -1.5409270683423e-08,       7.2927962340971e-09,      -1.1673750352505e-08, 
     -1.5844787546179e-09,       7.8433956440028e-09,       2.8723603650377e-09,      -1.5065759696539e-08,       4.5722543860344e-08, 
     -3.2657372209199e-08,       6.2565668631466e-08,       2.8766150712279e-08,      -1.8879650637939e-08,      -4.1190753717461e-08, 
     -5.5230420819606e-08,       1.2979922422762e-08,      -3.2126589158523e-08,       2.1769774829099e-08,       3.4298154117309e-08, 
     -8.0785510927543e-08,       7.1393641780884e-08,      -4.9654165937185e-08,       1.1101972682469e-07,      -3.5459649991908e-08, 
      4.9121650219101e-08,      -2.0202586161871e-08,       3.5392682181633e-08,      -6.7414254293144e-08,       8.4262361165396e-08, 
     -6.1889922005388e-08,       3.6218637647529e-08,       9.4627620407400e-08,      -6.4701085775141e-08,       4.8179833074196e-08, 
      8.3961247778335e-08,       1.5740387258521e-09,       6.6573613126338e-08,       2.6840692699293e-08,      -5.1370145254810e-08, 
     -3.0161967265026e-09,       2.1259484567588e-08,       7.6022286441441e-10,      -6.5595671661390e-09,      -2.2315904896199e-08, 
      1.0008427383058e-08,      -2.0937030210493e-08,      -2.1527961420639e-08,      -8.2692556042887e-09,      -2.7417551763642e-08, 
     -3.6031498495872e-09,       9.3392357392173e-09,       9.1179610420680e-09,       2.9437657299183e-08,       1.3835523394906e-08, 
      1.9737346783039e-08,       5.5462469156639e-09,       1.7374493724991e-08,       2.5189629199645e-08,       4.2821373026314e-09, 
      2.7212568876220e-08, 
},
{
      4.3926231289028e-08,       1.2008783927257e-08,       7.0721778187372e-08,       5.0819804558332e-08,      -4.5444717491000e-08, 
     -1.7671380390997e-08,      -4.6023216069340e-08,       4.3196250016040e-09,      -2.8565227288765e-09,       3.5778312217087e-08, 
     -9.0250277755165e-09,       5.2751760058383e-09,      -3.8354913258107e-08,       3.7734928592910e-08,      -4.1300802134346e-08, 
      6.3531836160299e-09,      -2.6533856826950e-08,       6.3847421477796e-09,       2.9457193534101e-08,      -6.2958073111271e-08, 
      3.1377467824840e-09,      -6.2671446988217e-08,      -4.1647315232253e-08,       2.2193135458413e-08,       2.5841093437670e-08, 
      2.0868551734792e-08,       5.0548419143543e-08,       1.5357905368815e-09,       1.0042633471445e-08,      -2.2556636069233e-08, 
      3.7943330926537e-08,       1.7965066655536e-08,       3.8241477061397e-08,      -3.0495857681778e-08,      -4.4975769991237e-09, 
     -1.5923034361738e-08,      -1.0143969383951e-08,      -1.5926314244131e-08,       7.0379785462622e-09,       2.2843731988396e-08, 
      1.6737942477516e-08,       3.3759743587777e-08,       6.5788129576289e-09,       4.8989325907204e-08,      -3.7290913064638e-08, 
      5.4855305925635e-08,      -4.0292437380048e-08,       4.1085250062970e-08,      -2.0721760942412e-08,      -8.8057281168314e-11, 
     -1.9754983881252e-08,       1.8546289446097e-08,       5.6815670289528e-08,      -7.4771215181303e-08,       3.7194903778081e-08, 
     -5.1715417671369e-08,      -4.5105162324430e-08,      -3.0174525200949e-08,       2.8679403475495e-09,       2.5066639639273e-09, 
     -2.1727304165027e-09,       2.3869613556866e-08,       2.7134453637223e-08,      -1.1520326893344e-08,      -2.3961277104260e-08, 
      1.1678890022092e-10,      -2.3838914174551e-08,      -1.0944493880215e-08,      -1.3481960618372e-08,      -1.3332755802820e-08, 
     -1.5288087240951e-08,      -9.8649387834764e-11,       1.1064831997948e-09,       1.8084463184397e-08,       1.1442276484206e-08, 
      3.2921909620133e-08,       2.2994083159371e-09,       1.6447231786796e-08,       3.0189019107963e-08,      -2.1436417595879e-10, 
      6.0636291133516e-08, 
},
{
      1.4848553196557e-08,      -1.4058680232162e-08,       2.6671590937996e-10,       1.7479439344561e-08,      -1.6232198893426e-08, 
      1.2491194101444e-09,       2.9546032548126e-08,      -6.2934723803025e-09,      -2.8699604371125e-08,      -2.0114994683042e-10, 
     -4.1892554273675e-08,      -3.1690494713281e-08,       2.5812554277740e-08,      -2.2304345023908e-08,       1.6368014467584e-08, 
     -7.9280371320809e-10,       3.7519218913760e-08,       3.0564895086806e-08,       6.7344323797809e-09,      -2.2214234476373e-08, 
      1.6052408128393e-08,       1.8403081882094e-08,       8.3646738693679e-09,       8.2019882925413e-09,       2.1085316689551e-08, 
     -2.4855216013694e-08,       2.3109032210127e-08,      -3.3069769476958e-08,      -1.4806325832100e-08,      -6.8087291176056e-08, 
     -1.7703627645541e-08,      -2.2530898560833e-08,      -2.4260286387375e-08,      -2.2815566601572e-08,       2.7723247133203e-08, 
      1.3326506650698e-08,       3.0284425469818e-08,      -4.9923156277013e-09,       5.6736176497117e-08,       1.1734236676502e-08, 
      1.3063950959503e-08,      -6.0493167978568e-08,       6.3287282201381e-08,      -8.2097749359317e-08,      -2.8286364381684e-08, 
     -3.0409410590102e-08,      -1.3749244330251e-08,       2.7127207716497e-09,      -2.1853760565014e-08,      -4.4266785150123e-10, 
      1.2732568684082e-08,      -1.6354635258231e-08,       2.4702648434863e-08,       8.7170999765779e-09,      -2.9323227972811e-08, 
     -2.2086028018407e-08,       6.5491351160329e-08,      -9.2417367195421e-08,      -6.4701730814571e-09,      -1.2008492805136e-09, 
     -1.8121887940580e-08,       7.4085640226178e-08,       2.6010517162053e-08,      -6.3128240915831e-08,      -2.6234657020469e-08, 
      1.4622436658367e-08,       2.0735196435222e-08,       1.1598478837466e-08,       2.1293365698639e-08,       1.2330375522769e-08, 
     -2.1918919236026e-08,       1.6396699295274e-08,       2.0182616818736e-10,      -3.1322259745320e-09,      -2.3892213010519e-08, 
     -2.5435481377501e-08,      -1.1352469519773e-08,      -2.4024139629688e-08,       8.1324017208831e-10,      -3.9828410101997e-08, 
      2.5306620135170e-08, 
},
{
     -1.1932734881649e-08,      -7.0871225166909e-08,      -3.3603114782430e-08,      -3.3107320973744e-08,       5.0032577285218e-09, 
     -4.1777382095887e-08,       1.4020291048803e-08,       7.5007086637425e-09,      -3.1252495535718e-08,      -3.7267895693271e-08, 
      2.0871073005265e-09,      -1.5843361391066e-08,       2.2483076910338e-08,      -4.0230969929810e-08,       3.5750146104206e-09, 
     -1.9876841997635e-09,       4.3726535566162e-08,      -1.4453560619039e-09,      -3.9915110550762e-09,       9.1004280092814e-09, 
      5.9467812860131e-09,       4.0464759336385e-09,       2.0179510382624e-08,       2.8219825636950e-08,      -8.8109793002205e-09, 
     -1.8687261149443e-08,      -2.4872429987073e-08,      -1.0400714598862e-09,       5.9634217450002e-09,      -3.1170168903601e-08, 
     -2.2352617740293e-09,       8.5790000981194e-09,      -2.7030611553293e-08,       1.4394403067515e-08,      -9.3467365009604e-09, 
      4.1855439251139e-09,       4.9531426593927e-09,      -2.5591660178740e-08,       1.5322101548935e-08,      -3.5472632100994e-08, 
     -1.4287698737673e-08,      -1.7404832757376e-08,      -2.4155919176974e-08,      -5.7955662029208e-08,       3.3684164125439e-08, 
     -5.8165632480347e-08,       8.0045538387697e-08,      -3.6829432969901e-08,       1.9956809546782e-08,       5.1503280793249e-08, 
     -4.4689067536613e-09,       2.5790077262081e-08,       1.8554812560000e-09,      -3.3530514139559e-08,       6.5078969513962e-09, 
      1.2738552004150e-07,      -2.1919178373421e-08,       4.5059601692362e-08,       7.5216170477841e-08,      -1.1065316936878e-08, 
      1.9407185362640e-09,       2.4537594708908e-08,      -1.2392053686854e-08,      -5.6483314238897e-08,       3.7724029179670e-08, 
      1.6180550426336e-08,       9.5555516927443e-09,      -7.2396081226709e-09,       1.3133246934454e-08,      -7.6319582872956e-09, 
     -2.1111548350055e-08,      -1.1228975245820e-09,      -3.4717037273112e-08,      -1.2341428361234e-08,       4.6287818157602e-09, 
      1.0425085082162e-08,       9.8518619349957e-09,       1.2018832230790e-08,       2.1154986103067e-08,       2.5934674432528e-08, 
      4.0812804128377e-09, 
},
{
     -2.1243891495712e-08,       4.1531225927031e-10,       4.3417614569584e-09,       7.2763017113695e-09,       2.8352091228297e-08, 
     -4.9042245170946e-10,      -1.0691815038230e-08,      -2.5327314704576e-08,      -1.3070032685695e-08,      -1.1660168794218e-08, 
      3.0903583289763e-08,       3.2685671623017e-08,       3.1556048497263e-08,      -8.9845618401068e-09,       2.4442288598511e-08, 
      5.4949748479116e-10,      -2.6828947713793e-09,       9.4349779495163e-10,      -6.6511240894019e-09,       1.5910348372004e-08, 
     -5.0618387304031e-09,      -2.6967703819320e-08,      -3.5344404747113e-08,      -5.6686179805741e-08,      -1.7020233517006e-08, 
      3.6562394595858e-08,      -4.8634076130040e-08,       4.6130375797864e-08,       5.4689481576063e-09,       3.6745930719476e-08, 
      7.7900543131802e-09,       1.8504594464248e-08,       3.5475679313499e-08,       1.4726033412290e-08,      -4.3056322345366e-08, 
      1.4552897679797e-08,      -4.9282339815759e-08,      -1.5213122638217e-10,      -4.1249824189077e-08,      -3.9129168006424e-09, 
     -1.8941950991629e-08,      -2.2113855580287e-09,       5.1678198013409e-09,      -1.4575337182998e-08,       1.3216504009769e-09, 
      5.8638050373894e-08,       5.3921909888684e-08,      -1.5886993766328e-08,       3.2355174011438e-09,      -1.6635479735933e-08, 
     -1.0138335766195e-08,       1.3666576278194e-09,       2.4540445362470e-09,      -5.4284527060827e-08,      -1.3647378052313e-08, 
     -1.3048754707485e-08,      -6.6601689101884e-08,       7.6691153671405e-08,      -7.1622010981230e-08,       4.7224842380253e-08, 
      6.8802901325973e-08,       2.6334614456163e-09,      -6.5769348915798e-10,      -5.9259095870345e-08,      -5.3971610062573e-08, 
      2.7629609662247e-08,      -1.2596737529274e-09,      -1.4291178878468e-09,      -2.2002012233997e-08,      -6.1511602741995e-09, 
     -3.0007715221803e-09,      -3.0182747552585e-08,       1.4160473820741e-08,      -8.9894781637201e-09,      -7.2525356592533e-09, 
      9.5760975006338e-09,       2.2733436814128e-09,       2.0039726655070e-08,       4.1961252310966e-09,       2.0287981019800e-08, 
      1.6848844518200e-08, 
},
{
      1.2047513260902e-09,       1.8823657610990e-08,       6.6137421776539e-09,       3.8047284062618e-08,       5.5737543807119e-08, 
      2.5055862915151e-09,       1.1726187366599e-08,      -6.1739502710403e-09,      -2.2337933506377e-08,      -2.0217869838145e-09, 
      3.7303900856691e-08,       2.5380019538382e-09,       1.9190552835155e-09,       4.3349935657125e-08,       2.6400208518653e-09, 
      2.2896118562856e-08,      -1.8814575065866e-08,      -1.2918549972594e-08,       1.7610499348107e-08,       1.7472656472487e-09, 
     -1.8627153910917e-08,      -2.0974739804714e-08,      -3.0029943880695e-09,      -4.5605096042277e-08,      -1.1172942407539e-08, 
      2.4901249666544e-08,      -3.5074484593945e-08,       2.4936154099689e-08,      -3.4510547743000e-08,       1.9908993362643e-08, 
     -1.2495981031819e-08,      -1.8705067364976e-08,       2.5565181696174e-08,      -2.6439019069163e-08,      -1.5246597035487e-08, 
      1.2793002485076e-09,      -4.6691491419155e-08,       1.3087725087609e-08,      -4.1402226929530e-08,       4.4214687863619e-08, 
     -3.0990227692192e-09,       2.0990087804697e-08,       3.3703528780649e-08,       1.4021584496293e-08,       3.2567836769241e-08, 
      4.2916409929425e-08,      -7.1144538258152e-08,       9.5521659354754e-09,      -4.7810928558461e-08,      -1.1742980318202e-08, 
     -9.3381588076666e-09,       1.6319329828925e-09,       1.8271757614160e-09,       2.5546615691538e-08,       1.5635265611710e-08, 
      1.9961030200841e-08,       2.6822056952803e-08,      -4.8004650079194e-08,       2.9862851975805e-09,       3.1334102107489e-08, 
     -6.7674814100363e-08,       3.3593287010681e-09,       2.2798363187571e-09,       2.5111463673350e-08,       6.2434348030642e-08, 
      2.7052110067150e-08,      -2.7508573062808e-08,       4.5025747276897e-08,       7.5891500024720e-09,      -1.4651119818567e-09, 
     -1.5279460471512e-11,       1.0220527043897e-08,      -1.7603353798347e-08,      -2.6291038423613e-08,      -1.6233989775165e-08, 
     -5.8152635322268e-09,      -6.5903650132202e-09,      -4.1600296163430e-08,       1.3547739175823e-08,      -6.6100280141440e-08, 
      1.6049933859608e-08, 
},
{
     -7.5091581591094e-08,      -1.9038071578597e-09,       2.0318680730819e-08,       2.3185171040540e-08,      -2.0501298053190e-08, 
      4.1831845702114e-09,       3.5221516357943e-08,       3.2000972955993e-08,       2.5430958332905e-08,      -1.4493939798646e-08, 
      1.2874284962696e-09,      -3.2806495147443e-08,      -7.8136808023976e-09,       4.0228082095788e-08,      -5.9028641583681e-09, 
     -3.2508033424530e-08,      -5.2234996422992e-09,      -1.2010233571955e-08,       5.1868305551151e-09,       5.8747968733478e-10, 
     -3.7582430819861e-09,      -7.8952599520639e-09,      -4.6400764232986e-10,       1.8873261728868e-08,       1.7712504152171e-08, 
     -2.2263659735898e-08,       1.6413954634663e-08,      -1.9828682667068e-08,      -2.8285367913794e-08,      -1.4577962014206e-08, 
     -8.5797045139897e-09,       2.5368981154947e-09,      -3.0376217549836e-10,       1.9964445388566e-08,       3.3952555621562e-08, 
     -1.7056905050651e-08,       3.5816639882685e-08,      -2.0323626740639e-08,       5.1771774762911e-08,       2.8797940652479e-08, 
      6.8679205939192e-09,      -3.1340550209916e-08,      -3.4660745619998e-08,      -8.8810821045888e-09,       6.4757674880955e-10, 
     -1.4954267628977e-08,      -1.9036033461664e-08,       3.9656198555561e-09,      -2.0641280280148e-08,       2.1222103459620e-08, 
      1.1327130843347e-08,       3.7628158169681e-08,       9.7025198985422e-09,       7.3038998467915e-09,       1.9530101503351e-08, 
      3.0875791679519e-08,       2.8809792820601e-08,      -3.2873226969815e-08,       5.3696086964138e-08,      -5.5454066056719e-08, 
      3.2671657999571e-08,       3.3375087509245e-08,      -2.2071484646483e-08,      -4.2272795648676e-08,       2.1329346999040e-09, 
     -1.8497742505408e-08,      -2.2709291942721e-08,       2.8910816244522e-08,       1.1346223649464e-08,       1.1856108117301e-08, 
      1.3749945641599e-08,       1.1800138264931e-08,       1.3684359824364e-08,      -1.0897321138695e-08,       1.1633309733254e-08, 
     -2.0928410389576e-08,      -5.9114365282622e-09,      -1.9969167926295e-08,      -2.6905744844190e-08,      -1.2660929361926e-08, 
     -3.0848877348280e-08, 
},
{
     -3.3108636764791e-08,       6.3245531296262e-11,       1.9917628107598e-08,      -5.3664678607414e-09,      -1.9702723680909e-08, 
     -3.1372550271836e-08,       2.7005349245877e-08,       6.8339248381043e-09,       4.1861779483395e-09,       2.4093985319316e-09, 
     -1.5008138379742e-08,       4.0929390562971e-09,       1.1122976597496e-08,       1.9375664288297e-08,      -7.6025086486352e-09, 
      2.0211657793549e-08,      -1.9360838497187e-08,       2.9353412859015e-08,      -2.7767092525730e-08,       1.0414563404276e-08, 
     -1.1057579273098e-08,       3.3209209507736e-08,       1.2478825021207e-08,       2.4340366484305e-08,       6.9303493912016e-09, 
     -6.8193795670070e-09,      -7.7822578175872e-09,      -3.0587836825738e-08,       3.3586045157244e-08,       4.2172744534238e-09, 
      3.0185643205040e-08,      -8.1002103258777e-09,      -4.2162348396286e-08,       2.5400824161615e-08,       1.3035789685760e-08, 
      5.5282965374147e-09,      -1.2742321344061e-08,      -1.6661615216550e-09,       3.0021625016960e-08,      -1.4648412475004e-08, 
      1.5473206744825e-08,      -1.3721112616587e-08,      -1.9402335532355e-08,      -7.4084173924364e-10,      -2.4931723796388e-08, 
     -2.1382153577429e-08,       3.2993927467382e-08,      -1.9201224723137e-08,       3.9387678175265e-08,       2.1849854251892e-08, 
     -3.1633782337289e-09,       9.2632542761943e-09,      -2.4168316693313e-08,      -4.2070791251197e-09,       1.1708264116050e-08, 
     -5.9913661584365e-08,      -3.4349111983263e-08,      -1.1491508456620e-08,      -2.0323657779750e-08,      -1.8435731254148e-08, 
      3.5480644283013e-08,      -4.8316793410787e-08,       3.8330530122948e-08,       4.3703780610828e-08,       1.7497056396859e-08, 
     -1.8661023655929e-08,      -2.3143456865729e-08,       2.7612280745647e-08,      -2.2388817620118e-08,      -1.5650088870785e-08, 
      3.5243726398226e-08,      -3.7037359850218e-08,       5.2303435451107e-09,       7.4345536795173e-09,       3.6576239767862e-09, 
     -8.7918602535506e-09,      -5.2510041396373e-09,      -5.5046481987866e-09,      -1.4141888252610e-08,       1.9672451463032e-08, 
     -2.6461204206886e-08, 
},
{
     -2.9130180219896e-08,       1.5529868065833e-08,       1.4149065639101e-08,       1.6457750563703e-08,      -2.9831405430522e-09, 
     -3.3143261645859e-08,      -3.0168647462828e-08,      -6.4657091528000e-09,      -1.0663425428490e-08,       3.0074241388434e-09, 
      1.9930166846039e-08,      -6.9389008014434e-09,       3.6514408191221e-08,       3.9344717569272e-08,       1.0063751701860e-08, 
      1.0756445290580e-08,       4.3158058429207e-09,      -7.0136574273283e-09,       1.9780118079406e-08,       3.6585976473784e-09, 
     -1.2104457686060e-08,      -2.0169405665128e-08,      -4.2652611167724e-08,       8.9313465924684e-10,      -3.4078779112168e-09, 
      4.0695776472108e-08,      -2.6037754530015e-09,       9.2865456393949e-09,       2.5554012749535e-08,       2.5280999273120e-08, 
      1.7582074742540e-08,      -1.9461396102115e-08,       1.9286211346272e-08,      -1.5850408859361e-09,      -1.4160166665933e-08, 
     -1.9594216975647e-08,      -3.0488919401608e-09,      -2.7772349810590e-08,       4.2172410190416e-10,      -1.1375231310602e-08, 
     -1.3969940626542e-08,       1.6011818928376e-09,       3.0729257136870e-08,      -1.4520699531901e-08,      -2.0015657687847e-08, 
      2.4953631732441e-08,       1.1233947058348e-08,      -9.6766872945171e-09,       1.4072970334353e-08,      -5.7078183596302e-08, 
      7.1930503799837e-09,      -4.7711693604013e-08,      -7.2881536601117e-09,      -3.2908535821920e-08,       1.4528655891090e-08, 
     -3.6668880715493e-08,      -2.4389956927734e-08,       1.1679374141286e-08,      -2.2395473238179e-08,       5.1684992799777e-08, 
     -6.7508690586050e-08,       3.6241042619557e-08,      -1.6276937368970e-08,      -1.5820159253095e-08,      -2.2609578386971e-08, 
      4.0496461171912e-08,       1.1278883433419e-08,       4.6760687913147e-08,       3.5199914455287e-08,      -1.2019765629813e-08, 
      3.0222864022735e-08,       1.9658084963051e-08,       1.9859815297658e-08,       2.0524931155827e-08,      -9.1145960807675e-09, 
      1.0343211168529e-08,      -1.0721046719933e-09,      -6.9067892780719e-09,       2.1843938416469e-10,      -1.2325140064760e-08, 
     -7.9262343324545e-09, 
},
{
     -1.5237515803024e-08,      -1.8531919623791e-08,       2.6108324327239e-08,       4.2407549595155e-08,      -7.7063873401823e-09, 
      3.2581293698565e-08,      -1.4658916811607e-08,      -3.9890929756252e-09,       9.5311643639131e-09,       1.2603488219636e-08, 
     -3.3586311941422e-08,       6.1661044849133e-09,       4.8757776369616e-09,       1.5883538421323e-08,       1.3433005727537e-08, 
     -1.2029071301056e-08,       7.7882338370000e-09,       4.9838941593199e-09,      -1.7288389745254e-08,       1.2281820432965e-08, 
     -1.0337069721714e-09,      -2.3690547845982e-08,      -1.5988580605384e-08,      -3.2092207693365e-08,      -1.1143510954643e-09, 
     -9.1111602875161e-09,       1.5086398695480e-08,       1.1961857516279e-08,      -8.3799048164308e-09,      -1.5772310985773e-09, 
      1.4967123397842e-09,       5.9851869110575e-09,      -1.7785868028923e-08,      -2.5858098267770e-08,      -7.9590917717541e-10, 
      2.9509128667747e-08,      -3.6209574607676e-09,      -2.0162433359425e-08,      -2.5236457595485e-08,       1.1712322362681e-08, 
      1.6212797664428e-08,       3.5410149297695e-09,       1.3384187922083e-08,       8.6505787374065e-11,      -6.3056408848102e-09, 
      2.2754650441098e-08,       3.0819811511665e-09,      -7.5348848260711e-09,       1.3809380157298e-08,       3.1318184977252e-08, 
      8.9179426240112e-10,      -2.7848743062216e-08,       9.7184651794905e-09,      -1.7804636772243e-08,       2.1683751028217e-08, 
     -7.9774227183647e-09,       5.0374589917885e-08,       5.6780152753494e-08,       1.0037816453422e-08,      -6.9343878286298e-09, 
     -2.7079507981401e-08,       1.6646941052809e-08,      -1.0215911116873e-08,      -6.4648636006585e-09,      -8.3667973718990e-09, 
     -3.7692957462359e-08,      -4.7795605926934e-08,      -2.8203260181717e-08,      -1.0517123461233e-08,      -7.7074677260288e-09, 
     -2.0023548038207e-08,      -1.0592030247184e-08,      -1.2547451780280e-08,      -1.3086725437076e-08,      -6.4996803071944e-09, 
     -3.9576713898458e-09,      -2.2062841195169e-08,      -1.1252617509579e-08,       4.9167262526171e-09,      -3.1732355109650e-08, 
      3.5246868459677e-08, 
},
{
     -7.5943791443929e-08,       2.7691886944838e-08,       2.9715992967966e-08,       3.6873414498163e-08,      -8.6167308610847e-09, 
      4.0651639086865e-08,       2.1585136644879e-08,      -1.1290846936463e-08,       2.3337178975136e-08,      -2.2275180302268e-08, 
     -1.2816806413405e-08,       2.5801605711007e-08,      -1.8389379773051e-08,      -8.4856291370786e-09,      -5.7087279085420e-10, 
     -2.1011376973991e-08,      -2.2581395192309e-09,       1.8134489519029e-08,       1.4017258991707e-08,      -1.1532560068250e-08, 
     -1.6216888705302e-08,       7.4627265733165e-09,       4.0529018113074e-08,      -7.4140290180825e-09,      -8.2268754280089e-09, 
     -2.1304690264749e-08,       1.7685548783221e-08,      -1.1455959894545e-08,       1.6142319292066e-08,      -2.1866482064642e-09, 
      3.1877162289185e-09,      -1.0248441393665e-08,      -2.7234181345503e-08,      -1.3681752825881e-08,       2.4508437244075e-09, 
      2.6985356025639e-08,       8.5539703263784e-09,       4.4998393615860e-11,       2.3426928395581e-09,       2.1915572602373e-08, 
     -1.4030583486449e-08,       1.0604175304375e-08,      -6.2309782507948e-09,       1.8283900942309e-08,      -1.4350276195346e-08, 
     -1.0734452180133e-08,       1.7038843727043e-08,      -1.4760539493376e-08,      -1.6937755172713e-08,       1.2180462333866e-08, 
     -1.2255077769720e-08,       5.6630020038145e-09,      -2.4661508290094e-08,       1.1637836156486e-08,       1.2442202938712e-08, 
      7.2766949901698e-09,       3.0654557296558e-08,       4.4031401037443e-08,      -5.3451733517514e-08,      -1.2320226727700e-08, 
     -5.4728023000677e-08,      -4.2589592191795e-08,      -2.0580522002390e-08,      -2.5449001938065e-08,      -9.9324223921493e-09, 
     -4.1958447869487e-10,       2.1151728593226e-08,       2.9928416840259e-08,       4.4181004491535e-09,      -4.8136725907074e-08, 
     -2.4650292634864e-08,       2.0211488351192e-08,      -1.2061135625039e-09,       6.4320600673166e-09,      -4.8242148396468e-08, 
      2.7251641718048e-08,      -1.9947530879960e-08,      -3.7389764862517e-08,       2.9411359430649e-09,      -5.3090015026229e-08, 
      5.3467015227895e-09, 
},
{
     -7.4449382843840e-08,      -3.2134535975874e-08,      -3.7492543129442e-09,       1.1949846982848e-08,      -2.2267209979357e-08, 
      3.3873868285291e-10,       8.9096702309750e-09,      -3.5382643338430e-09,      -1.1774387069060e-08,      -1.4973808522952e-08, 
      1.3055379067335e-08,       3.2870122447697e-10,      -5.9965209405001e-09,       9.0410021707575e-09,      -3.7209465964808e-08, 
     -4.4379149684779e-08,      -1.7626855847296e-08,       3.9374075132517e-09,       2.5398015896857e-08,       1.7961973559313e-09, 
      1.1344068421875e-08,      -1.6329697188217e-08,      -1.1826052197356e-08,       9.7865609250484e-09,       1.3326889233736e-08, 
      1.6039271648389e-09,       6.7419341769583e-09,      -4.2572441442898e-08,       1.8019192646612e-08,       1.2862418179504e-08, 
      2.7932509454074e-08,       1.2080390048981e-08,      -1.6945265954974e-08,      -1.4229095853173e-08,       3.1612763298350e-08, 
     -2.2895209443882e-08,      -2.6383351436710e-08,       9.6902701371694e-09,       3.2302734095519e-08,       9.2014524965312e-09, 
      1.2500707896538e-08,      -3.4261154811810e-08,      -6.0097416286279e-09,       5.5981717673729e-09,      -4.5141217304535e-09, 
      2.7892950242234e-08,       2.2514602818245e-08,      -1.2479549898600e-08,      -2.4785510931200e-08,       1.6972193536733e-08, 
     -3.0299127083562e-08,      -1.3252912803313e-08,      -3.3698528811639e-08,      -9.2669226579688e-09,       4.6573109109871e-09, 
     -2.6882956434640e-08,      -6.5945074783443e-10,      -3.7246900749064e-08,      -6.8754005123588e-08,      -4.8033710371110e-09, 
      2.3488664348531e-08,      -4.0000339574457e-08,       3.9607914432959e-08,      -2.6201067067444e-08,       4.0556285026030e-09, 
      2.8889954922094e-09,      -2.5555721526976e-08,       6.8953295337927e-08,       3.4444590324766e-09,      -8.6058649231401e-09, 
      1.8479864678456e-08,       4.8052328818708e-09,      -2.0621106375592e-08,       1.7825477299461e-08,       7.4997005562898e-09, 
     -7.2923895868523e-09,       1.3017093633185e-08,      -9.1403813720807e-09,       1.9204131108677e-08,      -2.6500876877896e-08, 
      3.3028631779662e-08, 
},
{
     -5.0373649385219e-08,       6.1440539320018e-09,      -1.4635090586905e-08,       6.2562626963645e-09,       3.3705657305246e-08, 
     -1.9246751793775e-08,      -4.5288519985819e-09,      -2.5659830547822e-08,       7.9347509260707e-09,       1.5401658170595e-08, 
     -2.5809139451388e-09,       1.4100032511658e-09,       4.3118968323305e-09,       6.8293793248579e-09,      -1.1081929376684e-08, 
      9.7889811481528e-09,      -3.1444998525805e-08,       1.6247572368627e-08,       4.1676774145369e-09,      -3.9612755821233e-08, 
      2.4577179208149e-09,      -9.6027204302834e-09,      -1.3545664642899e-09,       8.2090969518756e-09,       3.0660605977807e-08, 
     -2.4574278556145e-08,      -1.3646774177154e-08,      -3.1764100657396e-09,      -2.6050493131593e-09,       1.9295938033527e-08, 
      3.3409535004024e-09,       1.6279693651417e-08,       2.8202449046636e-09,      -1.5181683809517e-08,       1.2475890277340e-09, 
      3.9654905508864e-09,       5.2017553859623e-09,      -1.6850716526982e-08,      -2.7203615343007e-08,       2.3386662955670e-08, 
     -3.7129383033348e-09,      -7.8853995174649e-09,      -1.4020203210659e-08,       1.4769575954496e-08,       3.1050160585356e-08, 
      1.0781936561002e-08,       5.2390036686861e-10,      -1.2110801421474e-09,       3.1916534239582e-09,       1.5238141773082e-08, 
      3.6261009575424e-08,      -3.9446887953643e-10,      -3.6958133701971e-08,      -5.0835342477612e-10,      -2.5527075284464e-08, 
     -1.6940959074174e-08,       2.8881330745768e-08,      -2.4254486119916e-08,      -1.6510498842722e-08,      -3.3803670117320e-08, 
      4.9117828285767e-08,      -4.1991808355709e-09,       2.5437974304451e-08,      -8.7848509700082e-09,       1.5262114405324e-08, 
     -3.5922044167734e-08,       2.9564983621980e-08,      -4.5519797221911e-08,      -3.2922367632368e-08,       1.7926726805537e-08, 
     -1.8813863583772e-09,      -1.4390435672783e-08,      -3.7366723313259e-08,      -6.1659955876944e-10,      -3.4562456110418e-08, 
     -3.3073378539146e-08,      -4.2238387100520e-08,      -1.5497918181919e-09,      -3.9074902985096e-09,      -2.6248392167650e-08, 
      3.5338553550096e-08, 
},
{
     -2.2511520008358e-08,      -1.6650898506103e-09,      -5.3228575683501e-09,       2.5622026366652e-08,      -3.1719259730059e-08, 
      9.4272380599092e-09,      -1.3213214638994e-08,      -1.5758364019074e-08,       2.5988498687539e-08,       1.1201192054131e-08, 
     -1.3505846195285e-08,       1.3980382427165e-09,      -5.8152968995804e-09,       1.2113962392989e-08,       8.0736809527318e-09, 
     -4.6397092381545e-09,      -8.7048008115686e-09,      -2.3214176814475e-08,      -1.3406947591252e-08,      -2.0000254659363e-09, 
     -1.7885627099356e-08,       2.2070174374221e-08,       3.0942259867677e-09,       1.8327731091205e-08,       2.2157235068500e-08, 
     -1.6101902268020e-08,      -2.2455108028381e-08,      -1.5081279638113e-08,       1.1023013299869e-08,      -1.0336228434865e-08, 
     -3.6935775432822e-09,      -1.4738287090717e-08,      -1.0627479323610e-08,       4.3893191378796e-09,       7.5619769970967e-09, 
     -1.9457408572877e-09,       5.8793340758330e-09,      -2.0732252273475e-08,       7.0261452235978e-09,       1.7102912650891e-08, 
     -3.4308004111737e-08,       1.0276085800734e-09,       1.0046035536739e-09,      -8.1556571406131e-09,       2.0597780580480e-09, 
      4.8122618414413e-10,      -3.3876165105028e-09,       6.8412649450404e-10,      -6.4101798339056e-09,      -3.3831669373334e-08, 
     -1.8078863349352e-08,       1.4903526135906e-08,       7.7525366370604e-08,       1.3754236407926e-08,      -4.1283091106583e-09, 
      5.6967820170769e-09,      -1.6480363419493e-09,       6.5208399314249e-09,      -5.4735245973154e-09,       1.0776500690148e-08, 
      8.1623380947366e-09,      -6.0863558223074e-08,       2.3049304066903e-08,       5.2946531095619e-08,      -2.8958395621564e-08, 
      4.6351473973914e-08,      -1.3547574785928e-08,       1.7927704183024e-08,      -7.4157272687445e-09,       2.4387429854293e-08, 
      2.8233612944586e-08,       1.0368002686855e-08,      -8.5690219739167e-09,       2.2667132676949e-08,      -5.0447308844695e-08, 
      4.0793960126824e-09,      -3.6404084136809e-08,      -4.3052342995358e-08,      -1.7844752125446e-08,      -5.2226362665937e-08, 
      2.8538880314539e-08, 
},
{
     -8.2042364988053e-08,       3.4809886172157e-09,      -6.1922785732092e-09,      -1.2175396570356e-08,       4.7382759195033e-09, 
     -7.0945334894264e-09,      -1.3880352526323e-08,      -2.2874512834603e-08,      -7.0627659232543e-10,       1.3497846251708e-08, 
      2.4165076634525e-08,       1.0828139472109e-08,      -4.5729876137577e-09,       1.0842741781352e-08,       6.7663962114930e-09, 
     -2.8234164166358e-08,      -1.9653679309134e-08,      -3.7334415072929e-09,      -1.6494325876283e-09,       3.6884764560976e-09, 
      2.5908570138293e-08,       9.3071446621351e-09,      -7.4227114676430e-09,      -6.4879610717041e-09,       1.9970817171213e-08, 
     -3.0641949005003e-08,       5.6833031108645e-09,      -1.6262268385029e-08,       5.1976766917457e-09,       1.3784722957208e-08, 
     -3.8579051269073e-08,       1.2178729256050e-08,      -1.7934635512841e-09,       1.7571290432680e-08,       1.7000159203983e-08, 
      5.5176979192551e-09,       1.2268635209375e-08,      -3.4681867812802e-09,       5.2923507173437e-11,       1.0363255171172e-08, 
      8.5923714648108e-09,       2.4479981442525e-08,      -2.6643483756935e-08,       1.4762164864904e-08,      -8.0801490422467e-09, 
      9.2782423554687e-09,       2.3494960127012e-08,       2.6003655400199e-08,      -1.3483794694802e-08,       1.2026609978650e-08, 
     -4.1676817350044e-09,       1.9836118602525e-08,      -2.8742622036200e-08,       6.6794235737935e-09,      -2.7453628691545e-09, 
      2.2778803397720e-08,       5.4849274963716e-09,      -9.5188573150943e-10,      -1.6157726991065e-08,      -1.2457972772208e-08, 
     -2.9093693326445e-08,      -2.2721673729747e-08,      -2.4620275319967e-08,       3.2026611502940e-08,       1.3089454999768e-08, 
      3.9299839801993e-08,      -3.0235816266102e-08,       4.7305692250118e-08,      -2.7600451997188e-08,       1.8850663863822e-08, 
      2.8549064858644e-08,       4.6533588272513e-09,      -7.5335129350856e-09,      -1.4045722279352e-09,      -1.5283116324058e-08, 
      4.1510073368538e-09,       3.1373686013476e-08,       2.0760845737050e-08,       1.9268193534068e-08,       2.4664285766553e-08, 
     -3.0311470601815e-11, 
},
{
     -1.4060437580433e-08,       1.1856638668738e-08,      -2.1351118173656e-08,       2.5759527114722e-08,       9.8343907231008e-09, 
      5.8287856800556e-11,      -5.1145729003171e-09,      -9.4662662329647e-09,       9.2295708717323e-09,      -9.8879533757480e-09, 
     -1.7329742177764e-08,      -4.4200911192072e-09,      -1.1743697238529e-08,       6.4824018927448e-09,       9.8102118616334e-09, 
      2.3689701830813e-08,      -2.2459983786358e-08,      -3.2647560735597e-09,      -6.2907884183331e-09,       1.6952073194401e-09, 
     -3.6329819818853e-09,       4.8086139156727e-09,      -5.8364478763024e-09,      -8.5665897475465e-09,       2.6619401571512e-08, 
      5.5202498561049e-09,      -1.5133208447094e-08,      -5.9330008366678e-09,      -1.9752080985182e-08,      -1.4484064117092e-08, 
      3.2161862546335e-09,       1.2009248849353e-08,      -2.9998357558461e-08,      -8.8397763095839e-09,       6.7226859030170e-09, 
     -4.1152756508178e-09,      -6.7112938842462e-10,       2.6949727238918e-08,       1.7970956197970e-09,      -7.4941724921979e-09, 
     -2.5290110553892e-08,      -1.1104586684539e-08,      -1.7327354894842e-08,       1.2779547416731e-08,      -2.0858458630566e-08, 
      1.2501149175554e-08,      -3.0730634707345e-09,       1.3435546532733e-08,      -2.4665389481322e-09,       5.7214605732994e-09, 
     -2.3450888797539e-08,       1.1918236047817e-08,       2.2139904517737e-08,      -4.0088202002271e-09,      -5.2492071034749e-08, 
      2.8048688257384e-08,       1.6710417109443e-09,      -1.5575914489411e-09,      -4.1063302404071e-08,      -5.2371022647454e-08, 
     -1.8369954220723e-08,      -8.7610152835638e-09,       1.0852957387857e-08,       1.7375091341851e-08,      -2.2117086381405e-08, 
     -1.2591807752617e-08,       5.6267561134636e-08,      -5.6281853797892e-08,       1.5340438050082e-08,      -8.4236539141892e-09, 
      3.7090077381570e-08,      -4.1156264184691e-08,       3.5216462280055e-09,       1.1483182599622e-08,       4.6987237855780e-09, 
     -1.9875903626185e-08,      -2.2308442943132e-08,      -2.8766692588555e-08,      -2.6496448788205e-09,      -5.9110052787581e-08, 
      3.8383509799346e-08, 
},
{
     -1.1388687392689e-07,      -1.9474905102782e-08,       1.1543579001510e-08,       1.9154249287331e-08,       3.7522184613456e-09, 
      1.3175646197641e-08,      -6.8437704138621e-09,       1.6312239010580e-09,       4.7962853207595e-09,       2.5781332171137e-08, 
      2.4474994211828e-08,      -7.6396714493846e-09,      -5.8823174872237e-09,       2.9344148413499e-08,       2.3644664575164e-09, 
     -1.9835584985786e-08,      -5.0449778428580e-09,      -5.4585381826408e-10,      -1.1224222778328e-08,       2.3207958864514e-08, 
     -5.7387304636730e-10,       7.1112940863085e-09,      -1.7411591897696e-08,      -5.6386842701847e-09,       1.2508621050873e-08, 
     -5.0985199160502e-09,      -7.6563323510355e-09,      -4.3868902441823e-09,       1.6624505433733e-09,      -9.4254817748248e-09, 
      1.3929732891856e-08,      -3.3434595237403e-09,       2.0135387528713e-08,      -3.2014831035342e-09,       7.8902409830862e-09, 
     -5.1426332402853e-09,       2.7131818784367e-08,      -1.1692465759273e-08,      -1.3510230292102e-08,      -2.2146111663421e-08, 
     -4.5998540975414e-09,      -1.3890971571110e-08,      -1.7659384429111e-08,       4.0434339906986e-09,      -9.2140592911600e-09, 
      1.9837282237159e-08,      -9.2405068779751e-09,      -4.2127091487641e-10,      -2.4714969808106e-08,      -1.9233156083936e-08, 
     -1.7778738120161e-08,       5.1518240697247e-08,       2.5901349021544e-09,       1.3960566671437e-08,      -1.1062156850736e-08, 
      3.6608059713998e-08,      -9.1780995339035e-09,       7.1582524351818e-09,      -1.4203885832727e-08,      -3.8863419022904e-09, 
     -1.5202642869749e-08,       1.6550072259894e-08,       1.8595671792097e-09,       8.2229963314416e-10,      -2.8295721454598e-08, 
      1.2123244010608e-08,      -2.6142341365549e-08,      -5.9965898921057e-08,      -2.1671136714669e-08,      -1.0383571238487e-08, 
      1.6323937086419e-09,       2.9043610365190e-08,      -8.4436021284281e-09,       4.1734216780399e-08,       5.0194938793936e-09, 
     -2.4115044540884e-09,      -1.8240199445376e-08,       1.3632007112973e-08,      -2.8552579453118e-08,       9.2233343248650e-09, 
     -1.9836141583977e-08, 
},
{
     -2.8603563716425e-08,       1.1923057265959e-08,      -1.6928177120202e-08,      -6.9010609245023e-09,      -6.8272368808752e-09, 
     -1.9336399949221e-10,       4.4975395227937e-09,      -1.2019353197567e-08,       6.8766476637806e-09,       1.7277966048658e-09, 
     -2.5900083435112e-10,      -8.5245117521979e-09,      -1.7536754616242e-08,       9.0115833813112e-09,       2.0473272160462e-08, 
      1.5880157366049e-08,      -8.0595499204451e-09,      -3.9367599857540e-09,      -7.7662621646510e-09,      -4.4910420668357e-09, 
      2.6748651956661e-08,       1.6742744053192e-08,       9.5268440318648e-09,      -1.8266544198706e-08,      -8.2728325871810e-09, 
      1.0130032858544e-08,       3.3951932591010e-09,       6.2214513703576e-10,      -1.8140539283511e-08,      -7.9075242241583e-09, 
     -1.3703801400170e-08,       1.4003221372657e-08,      -1.6183549948464e-08,      -4.4786813657509e-11,       1.4649739859033e-08, 
     -4.8081095299320e-09,       6.9734105182904e-10,       1.4615749786219e-08,      -3.1045989942545e-08,       1.3148790281025e-09, 
     -1.3765722280346e-08,      -2.6111420022190e-09,      -1.1233762199403e-08,       1.5769352596787e-08,      -9.3263217941865e-09, 
     -2.6401922213001e-08,       1.1397124399645e-08,      -3.2075150947700e-09,      -2.1069454357051e-08,       6.1762788302812e-10, 
     -2.2646450355799e-08,       3.4426938830613e-08,      -4.7716242251803e-08,       1.9937872600147e-08,      -1.3612300490370e-08, 
      1.0079611623376e-08,       1.0422612037056e-08,      -3.0158829872560e-09,       1.4236432290351e-08,      -4.7165889902010e-08, 
     -1.9180703947654e-08,      -2.3048864121346e-08,       1.6206555395292e-08,       3.7354428350443e-08,      -1.2854662706361e-10, 
      1.7472670958113e-08,      -1.4809281282693e-08,      -4.5133348623732e-09,       6.8159336960864e-08,      -1.6589479214403e-09, 
     -2.6369438738046e-09,       1.6537157821883e-08,       7.6701154851348e-09,       4.3988808207129e-08,      -3.7384219772171e-08, 
     -1.0590150252497e-08,      -4.7104721658484e-09,      -4.1448751395953e-08,       4.3855516171038e-08,      -3.8798729843689e-08, 
      7.5624987216249e-08, 
},
{
     -9.9669551926998e-08,      -1.6972003167126e-08,       1.6410402991796e-09,       2.4048888325665e-08,       3.2714330064310e-09, 
      1.0171848540963e-08,      -3.8367363613918e-09,       3.1573302838679e-09,       2.0521284352012e-09,      -1.3961870462699e-08, 
      5.3782795028768e-09,      -4.9874586051620e-09,      -7.6633620504810e-09,       2.7826732434215e-08,      -5.0927725395166e-09, 
      1.5938846748911e-08,      -9.9075591615217e-09,      -7.8319674580579e-09,      -2.1016841004484e-08,      -1.4004550385970e-08, 
     -1.0224141971645e-08,       2.9756774379517e-08,      -6.3419035703899e-09,       6.4336129052406e-09,       1.7598099628477e-09, 
     -3.1065712260445e-10,      -5.9930109456383e-09,      -1.7070470307427e-09,      -5.1361783257442e-09,      -2.1168834032021e-08, 
      7.3959309096107e-10,       2.2587894740110e-08,       3.9637875866237e-09,       1.8166797460546e-08,       5.1837615324225e-09, 
     -1.9786395152533e-08,      -1.4000539013220e-08,      -2.4101638818300e-08,       1.7378614074190e-08,       1.3248124472055e-08, 
     -1.6798687786016e-08,      -3.1774220766312e-08,      -1.7876086568889e-08,       1.9785656197863e-09,      -3.1594992291650e-08, 
      5.1413684254886e-09,      -5.8581394222992e-09,       2.3720012877269e-08,      -3.1844358069399e-08,       9.2027595224474e-09, 
     -5.8195281279188e-08,       3.3818658089504e-08,      -1.1807119779700e-08,       2.0028043136215e-08,      -2.6927973889641e-08, 
     -9.5190611288506e-09,       2.9698432586223e-09,      -2.2932561074106e-08,      -9.7654235363318e-09,      -2.4790257069596e-08, 
     -2.4134647301549e-08,       2.6037040120130e-08,      -2.6786780288590e-08,      -3.0922936149158e-09,       2.1775137372323e-09, 
     -1.2027501868101e-08,      -2.2921343393367e-08,       1.3798342131329e-08,       3.5639111635704e-08,       6.1606342042181e-08, 
      5.1293175883268e-08,      -6.6330531868963e-09,      -5.9484322581029e-09,      -2.9657209661694e-08,      -5.1102401895543e-09, 
     -3.6040807302936e-09,      -2.8300589690111e-09,      -2.6883803117298e-08,      -6.1185921710598e-09,      -3.7281832449681e-08, 
     -1.9420146713508e-08, 
},
{
     -1.2400559997921e-08,       8.0861192619732e-09,      -3.9391354669143e-09,      -6.2821444142459e-09,      -4.8904146793068e-09, 
     -8.4558626964250e-09,       1.0750555071197e-08,       2.4797188144752e-09,       2.2223212062467e-10,       1.3738809088981e-08, 
      1.9970066349138e-09,      -6.1677571933725e-09,      -1.4180166323425e-08,       2.2302177334953e-08,       1.5366841919807e-08, 
      3.1513980674152e-09,       5.1300086631206e-09,      -1.3927324441701e-08,      -1.6793166246903e-08,       1.5981339487920e-08, 
      1.1837174149207e-08,       3.1978412055190e-08,       4.8208195055958e-09,      -6.6165346163196e-09,      -2.3319063280669e-08, 
      4.8940500819204e-09,       1.0008997001816e-08,       4.7823421503768e-09,      -6.3562096876582e-09,      -1.3846442903534e-08, 
     -1.5650544312813e-08,       2.6074970236616e-08,      -1.9886452766261e-08,      -5.2222999469853e-09,       8.1622293437081e-09, 
     -1.9365710153315e-08,      -9.3271509527984e-09,       1.1340633849627e-08,      -3.2549823652682e-08,       4.3673968816461e-09, 
     -1.2914207380118e-08,       2.3933716566862e-10,      -1.2194058585676e-08,       2.4260411797904e-08,      -1.6229856825341e-08, 
     -5.6359066767092e-09,      -1.0687980840826e-09,      -7.6809531123383e-09,       4.5393678115381e-10,       2.0535209074819e-09, 
     -1.8679363635244e-08,       4.4692291710315e-08,       1.3605728755702e-08,      -8.4977076744884e-09,      -1.7858468017709e-08, 
      7.0308975170499e-09,       4.4601868723281e-10,      -1.2531450217644e-09,       2.8779819477405e-08,      -2.9979959732671e-08, 
      5.1741634477704e-09,      -9.7817214437972e-09,       1.0908869399354e-08,       1.6414926909048e-08,       3.1876779365586e-08, 
      4.4707014123124e-08,      -2.9241167935940e-08,      -2.8994127712788e-08,       1.3585103235974e-08,       4.5490984189122e-09, 
     -3.6951704237316e-08,       1.4014721254530e-09,       3.0109512089084e-08,       1.7744208338833e-08,      -4.8503962606025e-09, 
      1.4697366851892e-08,       7.5511220796639e-09,      -2.3876118906692e-08,       2.0196353740244e-08,      -1.4921015165695e-08, 
      3.4309383774046e-10, 
},
{
     -5.4741093665271e-08,      -2.5693317519155e-08,      -8.0922326403307e-09,       2.3331695127012e-08,       2.0560672357391e-09, 
      2.1036617688508e-08,      -3.5450443043777e-09,      -1.0825912688911e-08,       1.2202191756818e-08,      -2.4721929170622e-08, 
      3.8304752833645e-09,      -4.1014454401116e-09,      -9.2048790452940e-09,       2.0171674662806e-08,      -1.1564044861758e-08, 
      5.4762781081226e-09,       5.3768934513216e-09,      -3.3024394527176e-09,      -2.1073279695129e-08,      -3.2108539387135e-09, 
     -5.3190341515864e-09,       1.8542022380512e-08,       4.4409278756621e-09,      -1.0532146277375e-08,      -1.3253913072055e-08, 
      1.5410644927128e-08,      -3.1482346640231e-09,       1.2198662639287e-08,       1.3029895157417e-08,      -1.2769099818439e-08, 
     -2.3426554312625e-09,       1.8543160489504e-08,      -4.8622132824035e-09,       8.7505934499859e-09,       2.9549936808802e-09, 
     -2.7746161904576e-08,      -5.7314244005564e-09,       1.6822268415223e-09,      -6.1822889155723e-09,      -7.5209593092276e-09, 
     -2.7517460483207e-08,      -4.3396022448907e-09,      -9.5261180864395e-09,      -2.9596129258802e-09,      -1.9725479802089e-08, 
      1.2109535796542e-08,      -1.1305474581607e-08,       1.7591304519975e-08,      -1.5241509582782e-08,       1.4673587515578e-08, 
      3.3063910496673e-09,       3.9793276665634e-08,      -1.5882375084015e-08,       7.9113005303860e-09,      -2.8303185352911e-08, 
      2.0877114712311e-08,       1.0093269685307e-08,      -1.8199346497611e-08,      -2.7227314818094e-08,      -1.9554747623991e-08, 
      4.2308201643079e-10,      -1.5303138052918e-08,      -1.6595563708347e-08,      -5.7194974429583e-10,      -2.0040041280622e-09, 
     -8.5518149983290e-09,      -1.4407254661105e-08,      -1.5906940974272e-09,       3.7404434051275e-08,      -1.6133961635388e-09, 
     -3.2270022345186e-08,      -6.2517853081283e-08,       5.4059865046867e-09,       3.1531773877332e-08,      -7.8497399090510e-08, 
      9.0478146947525e-09,       1.2023358233764e-08,       5.1333310765162e-09,      -1.8126404443645e-08,       2.4350363400317e-08, 
     -1.7576578428479e-08, 
},
{
      1.0075095302619e-09,       9.7280744073455e-09,       5.8382050022706e-09,      -6.2393781927675e-09,       6.7706886520846e-10, 
     -2.1302668974750e-08,       1.8887448284673e-09,       8.8910521172330e-09,       5.1231791832347e-09,      -6.8177226329305e-09, 
      1.6799790586647e-09,      -1.0502091304240e-08,      -1.1051955307535e-08,       1.3706727146468e-08,      -6.5828114269429e-10, 
      2.0929859994879e-09,      -7.3396905117352e-09,      -6.4586224604997e-09,      -2.5576044026497e-08,       4.5026250913407e-09, 
      1.4420627817619e-08,       2.8610205089438e-08,       3.7771142276217e-09,      -2.0439583641830e-09,      -3.4697069030418e-08, 
      1.2710262753414e-08,       9.9311429338501e-09,       1.4960304177396e-09,      -1.9166422256374e-09,      -1.3485586208902e-08, 
     -1.5281871399873e-08,       2.8490905907943e-08,      -1.1471024477268e-08,       5.9391419943654e-09,       1.1808556071113e-08, 
     -1.6215338381766e-08,       7.3663137674168e-09,       1.0555380051232e-08,      -1.6126661586148e-08,      -1.0821070428214e-08, 
     -2.8903992676262e-08,      -3.6501829178763e-09,       7.4281523917726e-09,       4.0090046755752e-09,      -1.6456097903567e-08, 
      1.1410400145280e-08,       5.0215385266106e-09,       1.0218386521398e-08,      -1.9385473035966e-08,       6.0798499458003e-09, 
     -4.0467447236503e-08,       1.3058369595419e-08,      -9.4925285851321e-10,      -1.1717606258202e-09,      -4.2979502454088e-09, 
     -1.3964582121448e-08,      -7.4355996700606e-09,       8.5893820495418e-09,       1.4223319749054e-08,      -3.1560945760426e-08, 
     -1.0044742383553e-08,      -1.3719551806473e-08,      -7.7568104335235e-09,       1.4158160495001e-09,      -9.3909834045483e-09, 
      3.4032045911106e-08,      -3.8764835942805e-08,      -3.2394347205966e-08,      -1.4533345021219e-08,       1.9694781066984e-08, 
      8.1001982648263e-09,      -1.3499424263447e-08,       4.3766182611447e-08,       1.1643052517375e-08,       3.9416412373467e-08, 
     -6.3413289624522e-09,       2.5476954128332e-08,      -2.8093520976808e-08,       6.0581028295660e-08,       4.5706895926528e-08, 
      3.6022191229826e-08, 
},
{
     -4.6896353147918e-08,      -2.2592220188599e-08,      -1.1489675614779e-08,       2.3917301221307e-08,       2.2431502654086e-09, 
      2.4557419415765e-08,       1.4593249956871e-08,      -5.6494043952309e-10,       1.7205734816054e-08,      -7.1861227215402e-09, 
      8.4184668515083e-09,      -1.3480374292945e-08,       5.5657154819099e-10,       1.7238187266364e-08,      -1.1014627571656e-08, 
      1.8123628394921e-08,       8.5615909432338e-09,      -1.3543572009815e-08,      -2.1945493454236e-08,       1.0041680689885e-08, 
      4.7540706040428e-10,       3.3473641591782e-08,       3.0905734568769e-08,      -1.2077910599332e-08,      -2.3454153833177e-08, 
      7.2552602308290e-09,       1.4954735791116e-09,       1.0166408650948e-08,       5.4859435063085e-09,      -2.1237084854367e-08, 
     -2.6135990199765e-09,       1.3028227968488e-08,      -2.1611515301591e-08,       4.4491836586970e-09,      -1.2966968824587e-08, 
     -3.2700622916455e-08,      -3.1736313896168e-09,       2.0433933002914e-08,      -1.9430804820972e-08,      -4.8658462139157e-09, 
     -4.2498272957354e-09,       4.7380510101969e-09,      -1.2302054753440e-08,       1.0568085129257e-08,      -6.5832878759307e-09, 
      1.1582704133515e-08,      -3.2627902505988e-09,       4.1950998728465e-08,       9.7818771333577e-09,       8.8023201980157e-09, 
      4.6929200000559e-10,       4.7166738224088e-08,      -1.1299759886722e-08,      -1.0464448973377e-08,      -1.9924729532870e-08, 
      3.1779917119005e-08,       3.9027133981583e-09,      -1.2612163164247e-09,      -1.6384850120441e-08,       2.8223034543076e-08, 
      7.0794721625293e-09,      -1.0646680294222e-08,      -2.3171923154298e-08,       2.7593746524158e-08,       3.1148780354187e-08, 
     -1.3058503363408e-08,       4.9739139505426e-10,       3.8476879717568e-09,      -6.6363768381986e-09,      -3.1667830476879e-08, 
     -1.5655056517276e-08,       2.8279821168558e-08,       2.1800540481196e-08,      -1.0906481447158e-08,       3.5346406472765e-09, 
      3.3081630082588e-08,      -8.3679785269692e-08,      -4.5329929440798e-08,      -1.2866571278288e-07,       9.3301033479905e-08, 
      4.2966533959805e-08, 
},
{
     -1.5275562265009e-08,       1.3542100665972e-08,       5.0657700631734e-09,      -1.1936117971845e-08,      -1.0124385549916e-08, 
     -2.1737994856807e-08,      -5.3327992829588e-09,       1.9008737776440e-09,       3.2313581266269e-09,      -1.4764992785650e-08, 
      1.4672751109052e-10,      -2.7338324615655e-09,      -1.1149644082277e-08,       1.3468297907093e-08,      -4.8838757883832e-09, 
     -9.5458664072040e-09,      -6.3690280879168e-09,       1.4498520996867e-09,      -2.2379111291655e-08,       1.8196016771932e-09, 
      1.2541618121941e-08,       2.2051692938196e-08,       3.7925707272445e-09,       9.9024830706731e-09,      -5.6185400353265e-08, 
      1.3078069608496e-08,       7.0858919667888e-09,       6.6077856813823e-09,      -4.7934972727197e-09,      -6.9561640400408e-09, 
     -1.7298850399054e-08,       2.0427945666551e-08,       4.6188133452199e-09,       1.5473241247945e-08,       1.8419218673326e-08, 
     -1.1576977790954e-08,       1.6842641027548e-08,       4.9878334002134e-09,      -5.8796709181567e-09,      -2.7255118627243e-08, 
     -4.2764383478624e-08,      -7.5639421613343e-09,      -4.9785954983282e-09,       3.1629980923832e-09,      -9.7600780864095e-09, 
      1.4562974744162e-08,       2.8031007045234e-09,       1.0563844804791e-08,      -5.7270565241558e-09,       9.9755836942707e-09, 
     -3.2393406975226e-08,       8.2363042876566e-10,      -5.4549961151072e-09,       4.3328811794342e-10,       7.7791880523865e-09, 
     -6.8513337728392e-09,      -1.6368328545899e-08,       1.9502980844023e-08,      -1.0428224595543e-09,       3.3076171807908e-09, 
      1.4122752076930e-08,      -3.4255838664772e-09,      -7.4038269195788e-09,       5.6962998814675e-09,       1.0337872067319e-08, 
      2.4819528792992e-09,      -3.5220416438795e-08,      -3.0661429493482e-08,      -3.9833577415097e-08,       2.2162033547726e-08, 
     -1.9414412729605e-08,       8.6782042079213e-09,       7.6652339064003e-09,      -9.1348519390794e-08,      -2.0155617172204e-09, 
      1.4435192685666e-08,      -1.7399521075397e-08,      -1.8342859868568e-08,       1.5206917869573e-10,      -2.1854205513145e-08, 
      4.2482015215950e-08, 
},
{
     -3.3175417267974e-08,      -2.3866987117813e-08,      -5.6504285348804e-09,       1.9502158111921e-08,      -6.7737358711472e-10, 
      2.4440475506094e-08,       9.6718891732389e-09,      -2.5042239603514e-10,       1.0019704173779e-08,      -5.3437911644650e-09, 
      5.6073647359258e-09,      -1.5431932759668e-08,       6.2253866165856e-09,       1.5801847470957e-08,      -7.2133863810242e-09, 
      2.8633786159682e-08,       9.2223040601533e-09,      -6.5702753710968e-09,      -3.3936853691972e-08,       9.7217939237696e-09, 
     -6.7837325866715e-09,       4.4190917660587e-08,       3.8384270534674e-08,      -1.5172212218230e-08,      -1.5091349711111e-08, 
      1.2483172531882e-08,       1.2661709780083e-08,       2.5926873419533e-09,       9.9625249234238e-10,      -3.3245345226564e-08, 
     -2.3264179601590e-09,       9.9654950230005e-09,      -3.0620307644790e-08,      -1.7102091694010e-09,      -3.7013703900786e-08, 
     -4.0009848430696e-08,      -4.6233234567264e-10,       1.8054556974615e-08,      -3.0210532855865e-08,       8.9682069096164e-10, 
      9.6648602092708e-09,       2.1735393822840e-08,       1.3767800851799e-09,       1.1148562980874e-08,       2.9619569317739e-10, 
     -3.9331790474298e-09,       2.7172208592960e-09,       4.6420626102514e-08,       1.3111536260333e-08,       7.5377140284312e-10, 
     -1.0523138935234e-09,       2.7920949126954e-08,       2.1865979719954e-08,      -2.7853088968287e-08,      -1.3557659475893e-08, 
      1.9470344318422e-08,       1.0273807462545e-09,      -1.8540320002196e-09,      -1.8772060070031e-08,       4.0663977766531e-08, 
      3.9306813456847e-09,      -4.1622337109333e-08,      -1.2448489605020e-08,       4.5852839944717e-08,       5.3578197763863e-08, 
      1.7895694066167e-08,      -3.0732396298080e-08,       4.2652856640314e-08,      -1.1407124511349e-08,      -2.1048696726472e-08, 
     -2.0901254918761e-08,       4.9097185798932e-08,       1.0406061832126e-08,      -9.3703314047005e-09,       4.2478267694708e-08, 
      4.2763313137673e-08,       3.1027345584731e-08,       4.1241019263910e-08,       1.7407733855812e-08,       4.7261929386015e-08, 
     -4.0326401796641e-08, 
},
{
     -1.3651871576432e-08,       2.0007574890191e-08,       5.5015226881158e-09,      -1.5846114998914e-08,      -2.3430980031731e-09, 
     -2.5664356989469e-08,      -4.2329063954188e-09,       3.5175015623793e-09,       3.3632024253884e-10,      -1.4031289397782e-08, 
      4.6561493893151e-09,       1.1124683888028e-09,      -1.4868007306047e-08,       1.6474788686008e-08,      -8.4387914942752e-09, 
     -1.9225095190516e-08,       1.7127843935319e-09,      -7.5622432795513e-09,      -1.9684626514578e-08,       8.7851044052141e-10, 
      1.4960110205561e-08,       2.2260973857673e-08,       1.6918113270808e-08,       1.8363442573372e-08,      -6.5168973335790e-08, 
     -8.0020149689859e-10,      -8.2456842487409e-10,       1.3054074184235e-08,      -2.1954569479846e-09,      -7.7154740621030e-09, 
     -1.3427583783324e-08,       1.4463264750810e-08,      -6.1223042481017e-09,       2.0489562195719e-08,       2.7571395955110e-08, 
     -1.3564025060229e-08,       2.9617739040252e-08,       1.4328040037044e-08,       4.5525139866867e-09,      -4.4208460736288e-08, 
     -5.4775320369153e-08,      -1.9457995138341e-08,      -1.9122347312175e-08,      -3.8034186892751e-10,       1.6272779595475e-08, 
      1.7758047251865e-08,      -8.6432470414736e-09,       1.1972538323826e-08,      -7.2490151276142e-09,       9.8093091502997e-09, 
     -1.4989609756122e-08,      -7.9977581382418e-09,      -3.9298114215323e-09,       1.2580059385347e-08,       6.8087934100149e-09, 
     -2.1999688002497e-08,      -2.4758465288995e-08,       1.4321935089204e-08,      -1.5044642459843e-09,       2.7366093240145e-08, 
      2.9279456595598e-08,       1.1466439837640e-08,      -1.9796134744631e-08,      -8.7975778397654e-09,       2.3532511325433e-09, 
     -3.5698843207340e-08,       1.7817849411511e-08,       5.2506177763956e-10,      -2.2841657154720e-08,      -2.3859852421257e-09, 
     -1.1958960176482e-08,       3.8418648990362e-08,       4.3838338903221e-09,      -8.0089805519323e-08,       3.9981913982536e-08, 
     -4.4786922638043e-08,      -3.2203280490700e-08,      -3.4304873140561e-08,       3.1916464057957e-08,       1.1264824975435e-07, 
     -1.9721419218430e-08, 
},
{
     -2.6580030737537e-08,      -2.1141447252752e-08,      -1.3778279671510e-09,       1.5752887151062e-08,      -2.5989916649176e-09, 
      2.3849844931274e-08,       1.2693918750352e-08,       7.2622025907125e-10,       6.2083459977640e-09,      -7.3729197241414e-09, 
      3.3595386898662e-09,      -1.0074489446158e-08,       8.1007918180071e-09,       1.8069577841353e-08,       8.1681676241915e-10, 
      3.2017184378223e-08,       3.7791328496748e-09,      -2.2704745380625e-09,      -4.1347583258882e-08,       1.1113670901972e-08, 
      2.0909369680074e-10,       4.0304227516878e-08,       2.4926830354469e-08,      -2.0960135677568e-08,      -2.5687447039432e-08, 
      1.3896953755161e-08,       1.0374944404687e-08,       6.4902426225915e-09,      -3.6019150179791e-09,      -3.8140445458126e-08, 
      8.2678515949940e-10,       1.4533424578182e-08,      -3.3850440008486e-08,       5.1482492244218e-09,      -5.0686057899308e-08, 
     -3.3805971674012e-08,      -1.0435712971753e-08,       1.7427425191685e-08,      -1.9044806554282e-08,       8.0549666023742e-09, 
      2.0270332155353e-08,       3.7857369162168e-08,       1.2389077098641e-08,       8.1925126641080e-09,      -4.0324254736892e-09, 
     -3.5876386976691e-09,       5.3668257793555e-09,       6.7852277040645e-08,       1.5956480925978e-08,      -6.4981800647078e-09, 
     -1.1486294039336e-08,       1.5985331395679e-08,       2.4518970713275e-08,      -3.9248704786472e-08,       5.0033326799261e-09, 
      9.3098384361994e-09,      -1.7909341351875e-09,       1.5628256617125e-08,      -1.2456951740396e-08,       5.0259401777492e-08, 
      6.0923734035883e-09,      -4.5160894518079e-08,       2.4321133263497e-08,       6.0517473672513e-08,       4.2562104356481e-08, 
      3.8771705558373e-08,      -6.0744235543601e-08,      -2.6048881406844e-08,       1.0890522127926e-08,      -2.1936907986688e-08, 
      7.4666285039833e-09,       4.1903761185085e-08,      -1.0966433703587e-08,      -2.3252182118600e-08,       4.5947638667769e-08, 
     -3.3686739590679e-09,      -5.5910246120075e-08,       6.1828489376380e-09,      -1.8979255881771e-08,       2.5286185979706e-09, 
     -5.3860308941805e-08, 
},
{
     -5.5581652244846e-09,       1.6105404539532e-08,       6.6996778257555e-09,      -1.4913771135926e-08,      -1.8616359355659e-09, 
     -2.1787117213660e-08,      -5.0324291407620e-09,       5.4258286154019e-09,      -3.2432500567628e-09,      -1.3575229751084e-08, 
      6.0338767165288e-09,      -8.0050257870554e-10,      -1.1320904524980e-08,       1.7856216845156e-08,      -1.3772590643255e-08, 
     -2.5127653175995e-08,       7.1008597667007e-09,      -1.3559531624408e-08,      -1.3313068257378e-08,      -6.5665171820663e-10, 
      5.3256747647972e-09,       1.7859384685588e-08,       2.8517546646613e-08,       2.1786189155316e-08,      -7.3642518997791e-08, 
     -4.1976675398836e-09,      -2.4839953626678e-09,       1.3524678562543e-08,       1.1788759692830e-09,      -3.0031703377047e-11, 
     -1.0905476474324e-08,       4.8453046289876e-09,      -3.8797294062137e-09,       1.4467562566795e-08,       2.9957090174493e-08, 
     -2.6679638290763e-08,       4.7882139135036e-08,       2.1335310056201e-08,       1.1733655877873e-08,      -4.2358818553316e-08, 
     -6.1925688280558e-08,      -1.4778028047205e-08,      -7.4516381551750e-09,      -4.6417899111813e-10,       2.9630914123461e-08, 
      1.3815009729209e-08,      -3.7622113836816e-09,      -8.3395782281607e-09,      -7.4165402895905e-09,       9.6883903202945e-09, 
     -1.8597550344268e-10,      -5.2323803606734e-09,      -9.9280364590896e-09,       3.0974627118803e-08,       1.4324249654998e-08, 
     -3.4611647087559e-08,      -2.1896688456436e-08,       1.6976934247192e-08,       7.5350958316827e-09,       2.7187534803989e-08, 
      4.1789798980956e-08,       1.0290268731821e-08,      -3.9933564935122e-08,      -2.6030744450061e-08,      -5.9943048904649e-09, 
     -7.2882879079013e-08,       1.8872555283807e-08,       5.4838625638221e-08,      -3.1178521587207e-08,      -2.6750142767822e-08, 
     -2.3386308516904e-08,       2.9529758800279e-08,      -1.0032595911957e-08,      -3.2735606783809e-08,       4.9461442700934e-08, 
     -8.4857257257285e-08,      -1.1068756994004e-09,      -7.4473875387362e-08,      -5.5783185324810e-08,       3.8147798704151e-08, 
      4.0582099786720e-08, 
},
} ;

gal_gm_t gal_gmgmm2b = {
GAL_SSB_MA,
"GMM-2B",
4.2828371901284e+13,
3.3970e+06,
80,
80,
1,
(double *) &gal_gmgmm2b_terms
} ;

__END_DECLS  
  
#endif /* !_GAL_GMGMM2B_H */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
