/*  
 *  - - - - - - - - - - - - - - - -
 *   g a l _ g m m g m 1 0 2 5 . h  
 *  - - - - - - - - - - - - - - - -
 *  
 *  This file is part of the General Astrodynamics Library  
 *
 *  Description:
 *
 *     This file defines the external variables for the MGM1025 Mars gravity model.
 *  
 *  Status: 
 *  
 *     Support file gravity model sub-system  
 *
 *  Defines:  
 *
 *     gal_gmmgm1025    gal_gm_t      MGM1025 gravity model structure
 *
 *  Notes:
 *
 *  1) This model was derived from radio tracking of the Mars Global Surveyor spacecraft; 
 *     no Mariner 9 or Viking data are included.                                                 
 *                                                                              
 * 2) The MGM1025 gravity model is an update to the GMM-2B gravity model.          
 *    It was determined from 155 arcs of MGS tracking data in Hiatus, SPO,         
 *    GCO and Mapping.  MGM1025 includes the same Mapping and GCO data             
 *    as were in GMM2B; in addition, it includes data from the first half          
 *    of 2001 (through July 21, 2001) when the MGS orbit orientation angle         
 *    with respect to the line-of-sight (LOS) was optimum for gravity              
 *    measurements.  It excludes data in the vicinity of solar conjunction         
 *    from May 08 to July 30 in 2000.                                              
 *                                                                              
 *               Comparison of  GMM2B and MGM1025                               
 *               --------------------------------                               
 *                                  GMM2B      MGM1025                          
 *                                --------    --------                          
 *                                                                              
 *           Model Size             80x80       80x80                           
 *                                                                              
 *           Coordinate System    IAU 1991    IAU 2000                          
 *                                                                              
 *           Observations                                                       
 *           ------------                                                       
 *            Hiatus                24,119      24,119                          
 *            SPO-1                 31,001      31,014                          
 *            SPO-2                157,972     136,667                          
 *            GCO                   76,813      80,795                          
 *            Mapping              665,210   1,352,661                          
 *            TOTAL                955,155   1,625,276                          
 *                                                                              
 *           Number of Arcs                                                     
 *           --------------                                                     
 *            Hiatus                     2           2                          
 *            SPO-1                      8           8                          
 *            SPO-2                     16          14                          
 *            GCO                        9           9                          
 *            Mapping                   47         122                          
 *                                                                              
 *  3) MGM1025 has improved correlation with topogaphy compared with GMM-2B.        
 *     The average correlation with MOLA derived topography (through degree         
 *     70) is 0.722 for GMM-2B and 0.756 for MGM1025.                               
 *                                                                              
 *  4) The new model has slightly greater power in the band from l=60 to 70.        
 *     The average RMS of fit to the F2 (two-way) tracking data is 0.13 to          
 *     0.20 mm/s with this model, excluding arcs in the vicinity of solar           
 *     conjunction.  The average RMS of fit for the one-way (F1) Doppler            
 *     tracking with this model is  0.10 to 0.15 mm/s.  The one-way data            
 *     contribute to solutions starting sporadically in February 2000 and           
 *     more consistently in arcs starting in March of 2000.  They are used          
 *     solely to fill in what would otherwise be gaps in the two-way tracking.      
 *     Frequency biases are estimated for each pass of one-way data.                
 *                                                                              
 *  5) The coordinate system for the new model is IAU 2000 (Seidelman et al.,       
 *     Cel. Mech. Dyn. Astron, 82, 83-110, 2002), defined by the Mars Cartography   
 *     Working Group.  It includes updates to the orientation of the Mars           
 *     Pole and rotation rate from a joint Pathfinder/Viking solution, and a        
 *     re-determination of the location of the prime meridian (with respect to      
 *     the crater Airy-0) from Mars Global Surveyor MOC and MOLA data.  Pole        
 *     right ascension (alpha) and declination (delta), prime meridian (Wo),        
 *     and rotation rate (Wodot) in IAU 2000 are:                                   
 *                                                                              
 *              alpha  = 317.68143 deg -0.1061 deg/century                      
 *              delta  =  52.88650 deg -0.0609 deg/century                      
 *              Wo     = 176.630 deg                                            
 *              Wdot   = 350.89198266 deg/day                                   
 *                                                                              
 *  6) This Mars gravity model was produced by F.G. Lemoine under the               
 *     direction of D.E. Smith of the MGS Radio Science Team."                      
 *
 *  References:
 *
 *    The analysis and results for MGM1025 were described by F.G. Lemoine,         
 *    G.A. Neumann, D.S. Chinn, D.E. Smith, M.T. Zuber, D.D. Rowlands,             
 *    D.P. Rubincam,  and D.E. Pavlis in 'Solution for Mars Geophysical            
 *    Parameters from Mars Global Surveyor Tracking Data', American                
 *    Geophysical Union Fall Meeting 2001 (EOS, Trans. AGU 82(47), Fall            
 *    Meeting Supplement, Abstract P42A-0545, F721, 2001).  The GMM2B              
 *    model was described by Lemoine et al., 'An Improved Solution of the          
 *    Gravity Field of Mars (GMM-2B) from Mars Global Surveyor',                   
 *    J. Geophys Res., 106(E10), 23359-23376, Oct 25, 2001.                        
 * 
 *  This revision:  
 * 
 *     2008 September 20 
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end. 
 *  
 *-----------------------------------------------------------------------  
 */  

#ifndef _GAL_GMMGM1025_H_  
#define _GAL_GMMGM1025_H_ 1  

#include "gal_gm.h"
#include "gal_const.h"
  
#undef  __BEGIN_DECLS  
#undef  __END_DECLS  
#ifdef  __cplusplus  
#define __BEGIN_DECLS extern "C" {  
#define __END_DECLS }  
#else  
#define __BEGIN_DECLS /* empty */  
#define __END_DECLS   /* empty */  
#endif
  
__BEGIN_DECLS  

double gal_gmmgm1025_terms[81][81] = {
{
                    0e+00,                     0e+00,   -1.1401847225988890e-10,    2.5155150744332390e-05,    3.7588917182210459e-06, 
   2.1199078107223171e-06,   -1.5154712831579200e-06,   -2.2693254012336890e-07,    7.4869335197712053e-07,   -4.8887826939648886e-07, 
   2.2250477035440471e-07,   -2.2078265839368059e-07,   -5.1290190208753003e-08,    2.2519671490043980e-07,    3.0949508730741862e-07, 
   2.5961987086160731e-07,   -5.5346995650063516e-07,   -6.3687648573340679e-07,   -5.7862275066300530e-07,    5.0580889644975032e-07, 
   5.5159048065933820e-07,   -4.2466628430159749e-07,   -1.1861574241658580e-07,    7.4492590496239651e-08,    1.6898337729283339e-07, 
  -1.6782838780194209e-08,   -3.8583254338416483e-07,   -4.2826946644146487e-08,    1.0245418978571070e-07,    2.0097501534675489e-07, 
  -1.8646620419890001e-09,   -8.2686085187457597e-08,   -1.8316285527029140e-07,   -9.3637017303617440e-08,   -5.1407090820137263e-08, 
   1.5318194346564610e-07,   -2.8160803509339771e-08,   -1.8555020643731501e-07,   -1.2915239202710580e-08,    1.1449391594282180e-07, 
  -1.2753203712806950e-08,   -6.7949821258338705e-08,   -1.6396289398252921e-08,   -4.3771996408462748e-08,   -1.2376736507647780e-09, 
   5.3832073271756547e-08,    1.5683302078249019e-08,   -9.5298601138480643e-08,   -5.9657889079683418e-08,    7.7816630739978461e-08, 
   3.9362579443894268e-08,   -5.0147019425721448e-08,   -7.6175189595044778e-09,    4.4470821222391353e-08,    5.8422934124296922e-08, 
  -2.7531333298184400e-08,    4.7425144454704977e-08,    1.2692149563230330e-08,   -6.2104080669803357e-08,   -7.8129455156601099e-10, 
   1.9250839858214460e-08,    2.9756964767288681e-08,   -3.6635669397708328e-08,    3.9026727963702033e-08,   -1.1666343243320209e-09, 
  -3.9507755076019483e-09,    1.3315627623449691e-08,   -9.0964859573059464e-09,    3.1922474126431379e-08,   -8.9309440163423867e-09, 
  -2.4655505132494091e-09,   -4.2602408922089037e-09,   -1.2030889796114969e-08,   -1.0741257587395120e-08,   -5.5499974865561951e-09, 
  -3.5174435080563542e-09,    1.5678335042096149e-08,   -2.8372251356007330e-09,    2.0084489528830919e-08,    2.2045740795526222e-09, 
   1.5356372022802360e-08, 
},
{
                    0e+00,                     0e+00,    4.8905551075504369e-05,    8.3539192403727920e-06,   -8.9701777491189892e-06, 
  -1.1641453008892719e-06,    1.4667268956886489e-06,   -6.2842100807605569e-07,    5.0596700143418395e-07,    3.8142891566533949e-07, 
  -1.1124225282454091e-06,   -9.9100594960733427e-07,    5.3128493253622975e-07,    8.5028075079997517e-07,   -5.2161616518212679e-07, 
  -7.8050858035765011e-07,   -8.7214358332510808e-08,    1.4579826763514441e-07,    4.3798807886695181e-08,    8.7664275315519483e-08, 
  -2.3739329968468131e-07,   -5.5617022532929142e-07,    7.4634801430612941e-08,    4.7058080251369898e-07,   -1.3833943024497469e-07, 
  -3.6206673055862051e-07,    1.3771086763274270e-08,    2.6908130569571379e-07,    2.5184065503879041e-07,    2.9109346693879082e-09, 
  -4.4165883077742748e-08,    1.3908167846995481e-08,    1.8305835915307691e-07,    2.0487537947297741e-07,    4.7320171392540857e-08, 
  -5.8882619512618549e-08,   -1.2311353910300489e-07,   -2.1919769425804610e-08,    1.1709291424090000e-07,    9.2699311123633477e-08, 
  -9.0368996680849946e-08,   -1.1102320608434710e-07,    8.5441307939682343e-08,    1.5019286440103390e-07,   -1.5758773652609421e-08, 
  -5.6546577893551452e-08,    4.6414838712203007e-08,    6.9440803211037008e-08,   -4.1543319320956092e-08,   -2.5453153619610959e-08, 
   6.1069806618382003e-08,   -2.1431871272039360e-08,   -2.7493738239855898e-08,    4.0499074786700592e-08,    1.6409989015642249e-08, 
  -4.6733116241997283e-08,   -4.9935750762260637e-08,    3.8916218999178619e-08,   -4.9768112095755469e-09,   -2.8668365214044219e-08, 
   1.0106627158973550e-08,   -1.5637139662540120e-08,   -2.0915792684196670e-08,   -5.4227075337161578e-08,    3.3432699268792882e-08, 
   1.0034791702217320e-08,    1.0133225197098260e-08,   -2.2905770890076610e-08,   -2.2301580854255910e-08,   -9.2177350430440059e-09, 
  -1.8780903598666010e-09,   -7.5542782412996675e-10,    4.9577307486525689e-09,   -1.0826784880675750e-08,   -2.3224199983071151e-08, 
   1.9561774315674380e-08,   -3.0216464519069360e-08,    1.7749568424106940e-08,   -3.3399757719077007e-08,    1.8010662015649149e-08, 
  -3.2871462541030177e-08, 
},
{
  -8.7450441550857710e-04,    9.4588820913966228e-11,   -8.4585751018071385e-05,    2.5551471726737059e-05,   -1.9274827646726580e-07, 
   2.7140581800371439e-07,    3.3222302672741608e-07,   -3.9609564442357342e-07,   -1.3382050309136059e-06,   -1.0048343370862559e-06, 
   4.4208842620839268e-07,    7.6239768915177568e-07,    3.1335143763597109e-07,    1.8130002960503509e-07,   -3.1104921120361652e-07, 
  -2.9856958137367162e-07,    4.2481073247225831e-07,    1.9122120603782851e-07,   -4.6117693571270348e-07,   -2.0023496082876669e-07, 
   2.0997193488830859e-07,    2.4698772474013000e-07,    1.4526401968646420e-08,   -1.3094420881434099e-07,   -2.8724262482356342e-07, 
  -1.4705252644311831e-07,    1.2595891565707761e-07,    3.1207723482287488e-07,   -2.7650809086232029e-07,   -3.0671076129864638e-07, 
   8.4155662713397797e-09,    5.4069483045577980e-08,    3.7773579574018842e-08,   -1.1854623883254660e-07,   -1.6136229886967589e-07, 
  -5.9238139036980372e-08,    5.2705208366376459e-08,    6.1587862484921053e-08,   -1.1594308999456870e-08,   -2.1618306258924469e-08, 
  -1.4792502688220051e-08,    6.2343085836212242e-08,    2.5134346110112430e-08,    2.4424514891413261e-08,   -2.6996983351597849e-08, 
  -7.2534663934445691e-09,    2.9618360439916831e-08,    5.2654231743026652e-09,   -1.0583447514475470e-08,    3.7626191938028962e-08, 
   2.5596290670975570e-08,   -2.3932391975685782e-08,   -4.9857747681036173e-08,    9.5895058624665488e-09,    7.1293575106710213e-08, 
   1.4572395176143741e-08,   -4.6910828885870282e-08,    3.5071316888314168e-08,    3.1409118702606701e-08,   -1.4417701951018060e-08, 
   1.3876650780031361e-08,   -3.5334741851824009e-09,   -3.0324625813371029e-08,   -3.2787634088217381e-08,    1.2694055876806559e-08, 
   2.2406210975383280e-08,   -1.8141161946837789e-08,    5.4521038956287010e-10,   -3.8138689619786877e-09,   -1.6093220344949739e-08, 
  -3.7036403872396132e-08,   -4.7186949728098018e-09,   -2.7956746206030168e-08,    8.5634852321390219e-10,   -3.8325087199962852e-08, 
   1.5398137020464111e-08,   -3.9023342002933852e-08,    1.9635939217429041e-08,   -3.5504514917566423e-08,    2.1761683080774509e-08, 
  -3.1625978448866311e-08, 
},
{
  -1.1889205541698310e-05,    3.8007291643503572e-06,   -1.5933741663501760e-05,    3.5023491711606023e-05,   -1.2857823170070161e-05, 
  -3.3773263335748999e-06,    2.6339507884397870e-06,   -4.2144144853043861e-07,    1.4777413181852259e-07,    1.6194710093434521e-06, 
  -6.9313507253818815e-08,   -6.4233300320774346e-07,    1.2301690995294911e-07,    6.8736009234055049e-07,   -9.5770079832859276e-07, 
  -8.3528061339268209e-07,   -5.4260378146250938e-08,   -9.3929405238052052e-09,    1.3191461217733701e-07,    2.5226344496632241e-07, 
   2.0621490254119131e-07,   -1.4043749966466351e-07,   -3.7858016062248879e-07,    7.3495913921711727e-08,    1.1779230311764150e-07, 
   1.5527691778752551e-07,    2.1058477382703609e-07,    8.9681836558223865e-08,    1.9622213253189150e-08,    4.7678131095150768e-08, 
   2.1380065806948211e-07,    7.5620818268704673e-09,    6.9970608136749094e-08,    3.1985403196956929e-08,    9.8787731189488762e-08, 
   7.9432952777436623e-08,   -2.2350132896333591e-08,    6.6789039516571817e-09,    6.4998554245919772e-08,    3.6097324429760158e-08, 
   5.3798620841362163e-08,   -6.0633572489981900e-09,    4.3908209925830883e-08,    6.9304474175145921e-08,    1.7136856044562281e-08, 
  -2.1172262663519841e-08,    1.5964270630662851e-08,    6.8319629051683618e-08,    2.2307463806328830e-08,   -2.2098747481582670e-08, 
  -1.3416105611403500e-08,   -2.8727639863574689e-09,    6.1362062327015258e-09,    2.8029179020573639e-08,    2.0493852005794970e-08, 
  -3.4076081538132071e-08,   -5.0027878148709403e-08,    2.5275768023371730e-08,    3.2984416637603998e-08,    4.6748302094912583e-09, 
  -2.8731083679469000e-08,   -1.2185426332212960e-09,    2.4196923372757359e-08,   -3.8300851302596521e-08,    2.3385333301277140e-08, 
   1.0699297135166180e-08,    2.4635886833334939e-08,    1.6525365641930680e-09,    1.1620271286384560e-09,    2.1844011370929310e-08, 
  -2.1954322860600260e-08,   -2.9656501717782581e-09,    1.1819742766063140e-08,   -3.3898434165157908e-08,    1.0552495877755150e-08, 
  -6.0657709996743813e-09,   -1.5629828556565758e-08,   -2.0599003025979290e-09,   -3.8749943891530398e-09,   -1.2713374207513781e-08, 
   2.2321713775650961e-10, 
},
{
   5.1231389950069357e-06,    4.2113282449448739e-06,   -9.5107786023564185e-07,    6.4490745811941448e-06,    3.0959206658010088e-07, 
   3.7742550130119230e-06,    1.6199010884387409e-06,   -1.3557075249867279e-06,   -1.6260186706174421e-06,   -1.5457469241660780e-06, 
  -1.0600209030636970e-06,    8.9636346823902639e-07,    9.9814527374598788e-07,   -4.0334461020521221e-07,   -9.6150455430911983e-07, 
  -4.7286535275866608e-07,    5.8730941024009775e-07,    3.1152083265288418e-07,   -6.1825374203407083e-07,   -4.4472448343506761e-07, 
   1.4586438492308650e-08,    1.6628168439163291e-07,    3.1241402527141072e-08,    1.8854458337510311e-07,   -1.6489726638893880e-07, 
  -3.1845421512103681e-07,    2.2721950714350840e-07,    2.8299545652662681e-07,   -3.7389057002835297e-08,   -1.7226603663226021e-07, 
   1.4710390042110071e-07,    1.7561089328596010e-07,   -6.5422322261088289e-08,    5.4998698313069993e-08,   -5.8162952622315107e-08, 
  -2.1460608956986769e-07,    1.0197746868170179e-08,    1.2520063761893520e-07,   -3.5506011727971469e-08,   -1.9201531312843980e-07, 
  -1.2269200040577989e-07,    8.9778390439824541e-08,   -4.1913786741450931e-08,   -9.1520006488999145e-08,   -4.4920044599259348e-08, 
   1.1643541732227160e-08,   -2.6360725053581281e-09,   -4.4760884506842032e-09,   -2.1592819756822170e-08,   -6.0937408379073696e-09, 
   2.7401279526375149e-09,    1.5851055218606960e-08,   -3.9887968690482421e-08,   -1.8343774352404431e-08,    6.2372930417057936e-09, 
   2.0924085053186049e-08,   -3.0622186799618989e-08,   -1.1748953359706671e-08,    2.3880590247309691e-08,    2.0034896605190929e-08, 
  -1.6471279024280172e-08,   -1.1357411549883670e-08,   -1.8049010749233350e-08,   -6.5094139439040935e-08,   -2.0737977692136750e-08, 
  -2.9791542438761412e-08,    7.8550958031710537e-10,    9.8305589918783227e-09,    1.5360752910204060e-08,    1.7205978100652821e-08, 
   8.2258548517498191e-09,    8.5106428921503302e-09,    1.1577667889130649e-08,    1.6308111802427870e-09,    1.4229372953147849e-08, 
  -8.2577367551857126e-09,    1.6419910665001310e-08,   -7.6141933727245829e-09,    1.5663078015234120e-08,   -3.8076118797540899e-09, 
   1.9338680156276400e-08, 
},
{
  -1.7246183479554800e-06,    4.8295248273192760e-07,   -4.2918839549229207e-06,    3.3076885084809829e-06,   -4.6336405889077189e-06, 
  -4.4434141649300242e-06,    8.2048914571916054e-07,   -1.8976252698758320e-06,   -1.7859907392664551e-06,    5.7635343927423907e-07, 
   1.1141482531981329e-06,    2.0520417204916651e-08,   -1.6241518863413170e-06,   -9.2898699384914000e-07,   -8.3030911917672840e-08, 
   6.3029479290680328e-07,    2.2377218327274191e-07,   -3.0803335024641408e-07,   -6.7899952282254050e-07,   -1.5250901091528529e-07, 
   3.7831534677240921e-07,    2.7709441869197688e-07,   -5.2996707240534168e-07,   -4.9676668701636046e-07,    3.6332436606583909e-08, 
   3.5015834406465162e-07,    5.8170241349480148e-08,   -3.2085152929534049e-07,   -2.6174056751663399e-07,    7.4912443471518832e-09, 
   3.6062403088968081e-07,    1.1445836997106400e-07,   -2.1026389477025110e-07,   -2.6176185843027003e-07,    2.7649159609721929e-08, 
   1.8659652364131681e-07,    6.4867610890406886e-09,   -1.2178155734874899e-07,   -1.1711628132854520e-07,   -5.4345146341479243e-09, 
   7.1059805395230056e-08,    4.6535261677560931e-08,   -1.9077964613059639e-08,   -6.1725941246726037e-08,    5.6827990615115460e-08, 
   4.9360626933475003e-08,   -4.4437585732807398e-08,   -1.6590532201585202e-08,    5.2118679119891358e-08,   -3.9270934787391670e-08, 
  -2.9200578663368939e-08,    7.1930752953129923e-09,   -5.5013112384309153e-09,   -4.1179828878416167e-08,    2.7775828195230462e-08, 
   4.0970764709541018e-08,   -9.3882334391395224e-09,   -1.9406697176473940e-08,    3.3469412443437821e-08,    1.2935720779419600e-08, 
  -1.1381909184848240e-08,    9.4081584158452847e-09,    4.7789557270427247e-08,    1.7622793297102039e-08,   -1.8345308909855719e-08, 
   2.6940425956764799e-09,   -1.2905439356089321e-08,   -1.9649164082367531e-08,    1.5817487307387550e-08,    9.8315960599906273e-09, 
  -3.6651513112466689e-09,   -3.1455261139310351e-09,    2.3442550631310959e-08,   -9.1447673426721770e-09,    1.2777811795929691e-08, 
  -3.8604892131951321e-09,    1.5707324950716461e-08,   -5.4637645120108159e-09,    1.2652007604581541e-08,    7.6513109485040331e-09, 
   8.0948836322870596e-09, 
},
{
   1.3442413561338150e-06,    1.7989300452430549e-06,    8.5990806408566938e-07,    9.5401012517447342e-07,    1.0065686648503400e-06, 
   1.6548025737625699e-06,    2.7571599805566621e-06,   -1.7718148905347299e-06,    1.6408397974219489e-06,    8.6647021106569304e-07, 
  -6.1835547459554625e-07,   -8.6232464665111764e-07,   -1.1248859759827440e-07,    3.9634821776234640e-07,    2.4045824377198663e-07, 
   3.6039156989872158e-07,    3.1060939091896088e-07,   -2.4009029696848650e-07,   -1.6932094993759669e-07,    1.8821371044436291e-07, 
   4.0126716006775391e-08,   -3.0263479586734012e-07,    1.2697718689314489e-08,    2.8287048180979589e-07,    5.0713252130312207e-07, 
   2.6061153429559518e-07,   -2.3148709970149159e-07,   -1.1121282776403090e-07,    1.9604577315001150e-07,    1.6686812676658749e-07, 
   3.0214879537025050e-08,   -1.3377877566803720e-07,   -1.6610438475314420e-07,    2.8746228761159373e-07,    2.2764174789090590e-07, 
  -1.0676698900773970e-07,   -1.1823947886320980e-07,   -1.8761169597968302e-08,    1.5498239194539170e-07,   -3.9950543926411047e-09, 
  -4.3229921049524192e-08,    1.1412007712193990e-07,   -1.4466968510795870e-08,   -5.0395367209663098e-08,    1.0038828070189320e-08, 
   8.9846934942603432e-08,    2.6646513249886731e-08,   -1.0731318307303060e-07,    4.2121798444175204e-09,    7.5577709045871592e-08, 
  -4.2621912089416710e-08,   -1.6964770982555049e-08,    2.2999036083794989e-08,   -2.0887288050775740e-08,   -4.4108867497604343e-08, 
   1.3930811021967430e-09,   -8.3764704949305420e-09,   -6.9153676523681668e-09,    1.8007382119490379e-09,    3.3336892845039198e-09, 
  -4.1896555386511267e-09,   -1.7039520923527651e-08,   -1.6712720904899660e-08,    3.7298748429176733e-08,   -2.5654109191058761e-08, 
  -1.3749720601388220e-08,    2.6676806808541049e-08,    1.6476181922272200e-08,    8.3007982073902181e-09,    2.6847074426587371e-08, 
   1.8339215465451859e-08,   -1.2096493390589861e-08,    3.0873049918127129e-08,   -2.2948720255903420e-09,    4.2303559984738979e-10, 
  -3.1468500927299450e-10,   -7.8036646136261435e-09,   -1.5461825889250879e-08,    3.5576129993784199e-09,   -8.7002735760481579e-09, 
  -3.4389487185570331e-10, 
},
{
   1.0568085417745059e-06,    1.3721377780492501e-06,    2.8084893201890269e-06,    8.7863220403752766e-07,    2.4640560610781930e-06, 
  -1.9096934491812029e-07,   -5.5805315254086452e-07,    4.3995886876870808e-07,   -2.4959849099076378e-07,   -1.4580693512086719e-07, 
   8.1805036262634951e-07,    7.6433996425428623e-07,   -3.8702672712393689e-07,   -6.4465263597708180e-09,    3.7300526843875260e-07, 
   4.7222387124156039e-07,    3.8955608515904091e-07,   -2.0383440752988559e-07,   -2.6151194759555579e-07,   -1.3178247598977940e-07, 
   3.1649702590754749e-07,    3.1101517689283971e-07,   -2.1168255118607190e-07,   -2.8466023855760351e-07,    1.1719052550134120e-07, 
   1.5843866010930290e-07,    2.3810692528316599e-08,    5.3647006877697068e-08,   -3.1906307271979281e-09,   -1.0391985530998420e-08, 
   9.5109571880006499e-08,    5.7365947063787198e-08,   -4.0518346014116999e-08,   -1.5499078054985251e-07,    3.7313770945501823e-08, 
   9.3476114898862046e-08,   -4.5262218231854492e-08,   -9.8638451420277030e-08,    6.9215062222509111e-08,    3.0032636960183570e-08, 
  -7.5098783816941106e-08,   -6.3812778667225328e-08,   -5.7734182666461992e-09,   -4.3605753090058559e-08,    5.3239834915912018e-08, 
   2.9151322995370440e-08,   -1.9230450020760760e-08,   -3.9920862610279297e-08,    2.7925566188812080e-08,    5.8064949635227837e-08, 
  -7.1988778892890529e-09,    7.8900516452217620e-09,    2.8429706686801620e-08,    7.6661527952012338e-09,    7.2627505164606536e-09, 
  -6.7541296281968769e-09,    1.7380975529251759e-08,   -6.4317567606288129e-09,    1.1915145445346560e-08,    1.2196090940292139e-08, 
  -2.7987670013252720e-08,   -7.1249626874001390e-09,   -5.1867829783309243e-09,   -1.9468386912617941e-08,    2.3098695913553902e-08, 
   2.8411589627993951e-08,    2.7127785981138291e-08,    2.0265388073624479e-08,   -6.9432862125621140e-09,    5.1173112821440760e-09, 
  -4.3588065245559408e-09,    6.1109017794535940e-09,    2.1118182460781360e-08,   -9.4860333532873014e-10,    4.3499469247455982e-09, 
   1.5440798733986631e-08,    4.2930395860814257e-09,   -1.0648979146836080e-08,    2.3716172947372990e-08,   -2.3048343056172849e-08, 
   1.6544765807105020e-08, 
},
{
   1.4344394468534911e-07,   -1.3172502269847639e-07,    1.8057628945403060e-06,   -1.2040062428688151e-06,    1.5844031607287429e-06, 
  -2.7850787272596641e-06,   -9.1195769387441463e-07,   -4.7261950038642442e-07,   -3.0973350203000572e-07,   -6.5627326888320462e-07, 
  -1.4595950764968139e-06,   -4.1836765661321091e-07,    4.7512601540372718e-07,    8.0247505155952854e-07,    1.1498533744602199e-06, 
  -3.7235910487196532e-07,   -9.3489733864835842e-07,   -3.2805356533853481e-07,    2.2858126868658801e-07,    3.9400348404034873e-07, 
   1.8072704192137361e-07,   -1.0183574008031450e-07,   -3.0654676245481902e-08,    1.0420719046341960e-07,    3.3274868234586679e-07, 
   2.1290437080171301e-07,   -5.1156668516244447e-07,   -3.8743075186968281e-07,    4.2432381937433310e-07,    3.3265775129989621e-07, 
  -1.4915562556087581e-08,   -4.1861144470827763e-08,   -9.9150362320510465e-08,    1.0711465229192910e-07,    1.2194543304260619e-07, 
  -4.6902631272439298e-08,   -6.6049672182927843e-08,   -5.2095734962229732e-08,    1.3573875181403410e-07,    1.8417451602228670e-08, 
  -1.1934084112825189e-07,   -1.8995682305051559e-08,    5.4219013565156567e-08,    3.5057697093395403e-08,    5.3305704921528158e-10, 
   6.4794407176128999e-08,    2.7331745831915839e-08,   -5.8988474395239229e-08,    1.7461117306504931e-08,    8.7270646852326507e-08, 
  -7.1342940132626266e-09,   -2.8435611154970312e-08,    1.1805683008097061e-08,    8.9143404074596527e-09,   -2.6555392074376541e-08, 
   3.3828855511917869e-08,    4.2546390083977342e-08,   -3.6734873423040852e-08,   -2.2395650708274639e-08,    2.4315885012473881e-08, 
   7.9944980951609937e-09,   -3.8296575561496958e-08,    7.0571132839722106e-09,    2.5038246911883700e-08,    3.4757865716422809e-08, 
   7.1465665945082241e-09,    9.6220861771691693e-09,    1.4907466291611251e-08,   -1.2459707429572590e-08,    2.5196834012392030e-10, 
  -2.4635603469986629e-08,   -3.4947072691406709e-09,   -4.0986826279926998e-08,   -5.3285000800155170e-09,   -2.1864929212363761e-08, 
   3.1655289123553060e-09,   -7.1972613348107120e-09,   -1.1715970978302610e-08,   -9.1581498788497476e-09,   -3.3289555113209000e-09, 
  -6.9618551966212376e-09, 
},
{
  -2.8623030841535118e-07,    4.1968715869938979e-07,    1.1356212264308400e-06,   -9.9094051068926957e-07,    2.9405976756682569e-07, 
  -2.2656267960896061e-06,    8.0627407047627008e-07,   -6.1651917619158619e-07,    1.2047847138462200e-06,   -1.1685977561306650e-06, 
   7.5110049124197241e-07,    1.9602479146368060e-06,    1.3735593875557210e-06,   -6.4528317351519280e-07,   -1.5806738741426529e-06, 
  -1.5651979227770559e-07,    3.4092895016213801e-07,    2.6625026138227628e-07,   -6.6632869044240570e-08,   -7.8558502011907168e-08, 
  -2.7558540599625649e-08,    1.0612069522760829e-07,    2.7759528560520360e-07,   -1.4762936279683491e-07,   -3.0649417359410672e-07, 
  -2.4934120573227498e-07,    4.5214442081101591e-08,    2.4920251008874630e-08,    1.1146872495122440e-08,   -2.6060426643667609e-08, 
  -2.3781098460739770e-07,   -2.2249872682332010e-07,    1.0939022689203720e-07,   -9.9274702786069417e-09,   -1.1057200235541350e-07, 
  -7.1666688130456159e-08,    3.4024516192872578e-08,    5.5363294504360870e-08,    3.5642895088881642e-09,    1.0576871280035400e-08, 
  -1.1697411911326500e-07,   -7.3996793185219174e-08,    3.8678791991800389e-08,    2.4828811765687890e-08,   -4.2505224541213297e-08, 
  -8.7400153715381820e-08,   -5.2257551226251256e-09,   -1.5139873000105430e-08,   -3.0765583056167147e-08,    3.7035367656631053e-08, 
  -2.5016564928436011e-08,   -3.5771827517194419e-08,   -3.3478355753907201e-10,    2.0219187490711780e-08,    3.8102648478185543e-09, 
  -3.4616352014803473e-08,   -5.1970170086516464e-09,    4.6109370443294658e-08,   -6.2288697447249697e-09,    1.6408443629482579e-08, 
   1.7080610897797409e-08,   -2.0496638449623440e-08,    8.8434962009343679e-09,   -4.5568632645146421e-08,   -3.2009339658893547e-08, 
   2.2650298617806909e-09,    1.1883874117332591e-08,   -2.9624723139076249e-08,    9.1697466414316346e-09,   -4.0427796463915134e-09, 
  -7.8382603351011469e-09,    6.2882121043254593e-09,    1.0388060801757530e-08,   -1.0887005067749671e-08,    9.3326955954817117e-09, 
  -3.5375814440110219e-09,    1.1440477826086340e-08,    1.1280465372382650e-08,    8.0737354952143070e-10,    1.3169751291096320e-08, 
  -8.9384411088562096e-09, 
},
{
   7.2517371380308813e-07,    9.2089843305933770e-07,    7.3405458338505767e-09,   -2.9834384339389502e-07,   -1.2101666736715110e-06, 
   4.2032262399202167e-07,    6.6759500742877016e-07,    3.1718853806594298e-07,    5.3865780719933689e-07,   -1.4529152650329050e-06, 
  -2.7418592728775249e-07,   -3.2243874465539981e-07,   -1.6488455183527350e-06,   -8.2051095635799292e-07,    1.5963288344651520e-07, 
   5.7043780534664939e-07,   -3.1162197414919378e-07,    5.1284823319059251e-08,   -3.0113265411809888e-07,   -3.9066464008848268e-07, 
   1.9716210205579591e-08,   -1.7102747377245650e-07,   -1.6030018161285941e-07,   -3.1284845289220749e-07,    3.0924886178203211e-07, 
   4.0328090713223910e-07,   -2.2008090349918671e-07,   -2.2263962027704620e-07,    2.8201322279299300e-07,    5.8131493898922101e-08, 
  -1.1375026639270130e-07,    1.8978094742895179e-07,    8.1541810295914165e-08,   -1.5861779452979239e-07,   -2.1333796420054630e-07, 
   3.3398335918710533e-08,    3.7795393184265451e-08,   -4.7045914061135697e-08,   -9.6238569513032256e-08,   -2.6332968760336390e-08, 
  -5.7618669052148588e-08,   -1.2609690722743140e-08,    9.2647921190134175e-08,    1.5554619277271501e-08,   -1.4729797978673760e-07, 
  -3.5970928874431242e-08,    6.3535970160862294e-08,    3.6411397717139100e-08,   -9.6957422611592524e-08,   -3.0295526388977462e-09, 
   7.1644391986671906e-08,    2.4307941537757450e-09,   -4.0647107856712387e-08,   -2.1995970977920559e-08,    1.0271836091160591e-08, 
   1.9536869823667010e-08,    2.8264297233668110e-08,    5.9982895719428391e-09,    5.2151716282264664e-09,   -2.1249449590777762e-08, 
   1.6590631640645089e-08,    3.0957968332036493e-08,    1.2664703332617739e-08,    5.8286283310618143e-09,   -1.5894064666470081e-08, 
  -1.0004824485460990e-08,    1.8897384981151702e-09,    9.2202405384102423e-09,   -4.1312478365988828e-08,   -4.7410459394041214e-09, 
  -1.3962678469304299e-08,   -2.9120421461712082e-08,   -3.3846955715306432e-09,   -2.1463688511712849e-08,   -1.5861238274070029e-08, 
   4.0683442664937549e-09,   -1.8831197923717399e-08,    1.2897496781261940e-08,   -8.9125352021773173e-09,   -1.3556648439712951e-09, 
  -4.4640224309969457e-09, 
},
{
  -2.6515503657960471e-07,   -8.1438583356007423e-07,   -3.1264422685095932e-07,   -1.2986012000904979e-06,   -1.5688434008849819e-06, 
   1.3520771564055899e-06,   -2.4393303094977732e-07,    6.5859011010242815e-07,   -1.1785529186851221e-06,   -4.1376264440044221e-07, 
   3.3152053925569229e-07,   -4.4684635932806288e-08,   -8.8920779082166641e-08,   -4.2925246963552852e-07,   -3.0381120209258508e-07, 
   7.5705454254369899e-07,    6.6822060944806552e-07,   -3.1080678295819988e-09,   -1.0087201702017610e-07,   -2.1529973577777809e-08, 
  -1.7140589471271229e-07,    7.7850994715885597e-08,   -6.9979530788203794e-08,   -9.3144143314537260e-09,   -3.1991542759974618e-07, 
  -2.3780819412333940e-07,   -5.7158660489078333e-08,   -6.2059213801999241e-09,   -1.5907547414197821e-08,    1.0171806953977730e-07, 
   1.0491439130093070e-07,   -4.5676262519329150e-08,    2.5768458653127482e-08,   -3.5446527289965230e-08,   -4.7116393079744128e-08, 
   4.5383703782855470e-08,    5.8386526496613906e-09,   -8.5162673042795557e-08,   -9.1882765548383077e-08,   -3.6025149381032277e-08, 
   1.4595185410301111e-08,    1.7593887978746791e-08,    9.2166455685116050e-09,    1.4563806235588480e-08,    6.3545789496187329e-09, 
  -1.7181064007162131e-08,    6.7254550365132462e-08,   -8.8853639772639814e-09,   -3.9625401175776209e-08,    3.3547808860120422e-08, 
  -2.7539465725799939e-08,   -7.2009659384084021e-08,   -6.5160563283951723e-09,    5.8297585674733701e-08,    1.6743434242418041e-09, 
  -3.1503739387470512e-08,    2.2844849793648989e-08,    1.2620994119193230e-08,   -2.8295430174200000e-08,   -2.3511171040328661e-08, 
   2.2816487987094719e-08,    1.7900096358017321e-08,   -1.9359220793238800e-08,   -2.0436015960463090e-08,    2.9421441916530989e-08, 
   2.5063647453935262e-10,   -2.3434053627948541e-08,    4.7996977707156246e-09,   -2.6536851961145259e-08,   -2.4253678258789979e-08, 
  -2.9390882380831198e-09,   -1.6333925954899610e-09,   -2.8490175642328230e-08,    6.0768142527697944e-09,   -7.2357878393461441e-09, 
   4.7286146894435443e-09,   -2.9640799063398910e-08,    7.7994725347342761e-09,   -2.5082417039952890e-08,    4.4238135506004766e-09, 
  -2.9369750400862519e-08, 
},
{
   2.5791004374137131e-07,   -1.1226169861947939e-06,   -9.7454248928456921e-08,   -1.4371536216266771e-06,   -1.0108862643404400e-07, 
   7.1777774077013873e-07,   -4.0190828647834588e-07,    4.0292072266071660e-07,   -1.5982435716481761e-06,    7.0595661731973224e-07, 
   4.8642163810406144e-07,    8.6209182518876898e-07,   -6.4231718972073026e-09,    8.7090151746401639e-07,    2.0603291432189770e-06, 
   7.0781194137062206e-07,   -5.9505211895114662e-07,   -7.9988519244723194e-07,   -2.6781919637356352e-07,   -3.9638127126334678e-08, 
   3.4308208665972148e-07,    1.0176613624133490e-07,   -1.7303916297882481e-07,   -9.7853601308964670e-08,   -2.3487959545684901e-08, 
   2.7930133682935182e-07,   -8.1776277087868792e-09,   -1.1040107048513820e-07,    3.5518665380932922e-08,    2.8024876055130319e-08, 
   6.2729815192088541e-08,    1.4212575392450731e-07,    1.8847039668974441e-08,   -1.8720676208874790e-08,   -1.2328174691029930e-07, 
   1.3471841102089050e-08,    1.8504594338397301e-07,    4.1332784858941007e-08,   -9.0322029947740062e-08,   -8.9696583112129118e-08, 
   3.1621240917420551e-08,   -1.0732345514734070e-09,    5.1671318931159944e-09,    1.8086307630788740e-09,   -4.9976630665190941e-08, 
  -2.8555583722464841e-08,    7.2434265587147602e-08,    1.1841653994144240e-07,   -6.3007329286237717e-08,   -8.1663659434407190e-08, 
   9.2299309105373738e-08,    6.1277108914370923e-08,   -3.1928594863024748e-08,   -4.2066672979786730e-08,    2.0881374939344150e-08, 
   2.3357346197626051e-08,    5.5376552249704136e-09,    2.6637506077607999e-08,    4.5853451895834620e-09,   -3.7810514693799933e-08, 
   1.7827259495441801e-08,    3.3606099974048057e-08,    1.1087419305904240e-08,   -1.8858176682939321e-08,   -1.2846138794470189e-08, 
   6.2418715082964174e-09,    1.7820386364415601e-08,   -8.6672830025846962e-09,    4.2984837759795762e-08,    2.2895749266151690e-08, 
   2.4048612493333321e-08,    3.5644430659659892e-08,    3.2707523090933428e-08,    2.2954078635022510e-08,    2.3616745111190058e-08, 
   4.2243201693742329e-08,   -4.1136165002182076e-09,    4.8575954733839563e-08,   -1.0767185336948430e-08,    6.6336704576548916e-08, 
  -4.4014299099341942e-08, 
},
{
  -4.8987732989966883e-07,   -5.6756560374700442e-07,    1.9140550616678571e-07,    2.1515088011756540e-07,    1.7054914228550610e-07, 
   6.1450262542325127e-09,    4.3978424085632703e-08,   -7.6808712383583886e-07,   -2.3194739260952509e-07,    1.1036467020707189e-06, 
  -1.5737288606158829e-07,    7.5993437561619698e-07,   -1.4518332762978941e-06,    4.2601241621664219e-07,   -7.4240282317234796e-07, 
  -1.3571091998453000e-06,   -9.3817219005892035e-07,   -4.6937395151751613e-07,    1.9153934057115151e-07,    5.1536173249611044e-07, 
   2.3375072844855070e-07,   -3.9050845702146591e-07,   -5.1863544921840549e-07,   -3.2332506607369358e-07,    3.9865595042181121e-07, 
   2.6591743031456203e-07,   -8.1802188971567649e-08,   -3.2291096639110703e-08,    1.2860175423285540e-07,    1.3830153071439119e-07, 
   3.5042509660983673e-08,   -1.1918938957785860e-07,   -1.8345702668221200e-07,   -1.3524513613962930e-08,    7.7822106322461904e-08, 
   9.8718013634758886e-08,   -5.2654027292183732e-08,   -2.1310515155308649e-07,   -2.8779444492386200e-08,    5.1388765792750899e-08, 
   5.1863412740192372e-08,    5.3744070843107582e-08,   -9.1839891177993474e-08,   -2.5400916794613929e-08,    5.4614253806951990e-08, 
   6.6912389017243148e-08,    4.4942897130641760e-08,   -4.6320048520029918e-08,    3.5565097794370423e-08,    1.2012861482544441e-07, 
   7.7541596409903606e-08,   -3.5353777578628798e-08,   -3.3571218394550461e-08,    3.0101593756227303e-08,    2.6974668151703520e-08, 
  -1.5995052196413370e-08,   -5.2692369031442228e-09,   -1.8302276242217749e-08,   -2.1796489423620469e-08,    2.1371899255291430e-09, 
   4.8769586142550840e-08,   -1.3661773678492171e-09,   -7.9691872794417281e-09,    1.2767619131777221e-10,    2.3277013161202072e-09, 
  -1.5345742502274022e-08,   -1.0229721399366130e-08,    4.0370458826900937e-08,    7.5088309600280788e-09,    6.9388818240716826e-09, 
   1.8188183034136602e-08,    1.5492869250358981e-08,   -1.5765666455538650e-08,    6.3309934038770420e-09,   -3.6176635096533139e-09, 
   8.5598158046521657e-09,   -2.0951869182447389e-08,    3.1145212456406452e-08,   -2.4169629065449672e-08,    2.0848670628370460e-08, 
  -9.4467363979311424e-09, 
},
{
   3.0149567154029062e-07,    7.5140494090486395e-07,    4.4883687385941919e-07,    4.2474467046937481e-07,    2.2728427855595541e-07, 
  -4.5276921372495279e-07,   -6.6013890282255170e-08,   -4.4557079395777563e-07,    8.1535531994532273e-07,    2.0920331569048591e-07, 
   2.5566932292312150e-08,   -9.2572155775018028e-07,   -4.4667389507500578e-07,    7.5129408112081054e-07,    4.7021295278235698e-08, 
   1.2600108653866140e-07,    3.2271595745797342e-07,    4.0586600900224850e-07,    7.5111672234084499e-07,    5.0346290834618834e-07, 
  -2.8657327016528642e-07,   -5.7915871656014379e-07,    2.5969276409393747e-07,    7.0089053193120345e-07,   -2.9883118930911948e-08, 
  -1.4451769473653080e-07,   -4.8198140002715003e-08,    8.6264490499589417e-08,    1.2886841925463041e-07,    1.3684825500462351e-07, 
  -1.8797149406363601e-08,    1.5358171628511770e-08,    7.8329095841779159e-08,    9.9712503238671238e-08,    6.7720736038058510e-08, 
  -1.7093110750895650e-07,   -7.8041032755812701e-08,    4.3826692760959531e-08,   -7.9099615504350303e-08,    2.2676114875732088e-08, 
  -3.4353729658172778e-08,   -5.4211660036876837e-08,    1.6078659653430470e-08,    8.1221155568093076e-08,    2.6945602783787059e-08, 
  -1.1550748808495660e-07,    6.4854612383679882e-09,    5.9305343934150717e-08,    1.7334533420205358e-08,   -2.6013901667132221e-08, 
   1.9676556187785489e-08,    4.3600441789107228e-08,   -1.7613984985821582e-08,    1.3042832953335460e-09,    2.1604516348254001e-08, 
   8.3649756938878529e-09,   -2.5031837850355801e-08,   -1.0202997939252269e-08,    2.0575074324127922e-08,   -1.2508788110161710e-08, 
  -7.8480710934674897e-09,    2.6665962449192560e-08,   -4.4229316448829603e-08,   -4.9351437360333348e-08,    3.7661603535803422e-08, 
   3.6167346808350111e-08,    5.1363730875905160e-09,    3.6600538010786050e-09,    2.0002172436516478e-08,    2.8148380444181371e-08, 
   2.1821541647165830e-08,    1.7456029122272799e-09,    3.7208080162655873e-08,   -1.5048696636328211e-08,    1.9767509098501770e-08, 
  -4.7994233940629027e-09,    1.4017048848830930e-08,   -1.1215950504154161e-08,    1.4580230802822490e-08,   -2.0740278485623641e-08, 
   1.8176997659370340e-08, 
},
{
   4.9309755579595783e-07,    2.3398249720387341e-07,   -3.5213615909879958e-07,   -5.5907478206269619e-07,   -7.1711294666294435e-07, 
  -9.3462951523554455e-07,   -6.2099703560131124e-08,    9.2204367511949259e-07,    1.1565702748603479e-06,   -3.0020191696171260e-07, 
  -1.5979532465480151e-07,   -7.7135611592180572e-07,    9.7595914392989837e-07,    1.7845595134875060e-07,    2.2219457857795241e-07, 
  -3.3826575599910181e-07,    1.1999639763359941e-07,    5.6520236837336642e-07,    2.2241299522814790e-07,   -1.3582747558850861e-07, 
  -2.7521114384638979e-07,   -1.3714024214609850e-08,   -4.2714935026342617e-08,    1.3846890751522431e-07,    3.2611904178743918e-07, 
   2.4278245987262481e-07,   -1.1672236873981120e-07,   -2.3027802135381071e-07,    6.4961121297676293e-08,    2.3471924216379409e-08, 
   6.3772434226170803e-08,   -7.3835040421860086e-09,   -6.1206732178321830e-08,   -5.5020494835376627e-08,   -4.2828380877650350e-09, 
   7.5980026207406140e-08,   -1.6217047689604311e-08,   -2.6913462260086581e-09,    1.8528209966076611e-08,   -1.9324089706529031e-08, 
  -8.2312570349735357e-09,   -5.4669670503534267e-09,    6.4355045434192478e-09,   -9.1015210205317364e-08,   -4.3879876041802684e-09, 
   4.6355226427945278e-08,    2.3826788645935640e-08,   -2.6727931830145219e-08,   -3.9825287398680147e-08,    2.7701521836882821e-08, 
   3.7425392830531738e-08,    3.2479270044008431e-09,   -3.1910867126780068e-08,   -8.7454377854953554e-09,    2.2758936660709239e-08, 
   8.3734593120842228e-09,    8.4285271391002605e-09,    3.5171485277020942e-09,    7.5832095687949718e-10,    4.3268168776163727e-09, 
  -9.5942808601990517e-09,    9.5403421274832111e-09,    7.6600691821438897e-09,   -1.4954024697104251e-08,    6.7348966750107543e-09, 
  -9.8517593621748509e-09,   -1.7651774758306599e-08,   -1.3048185705955441e-08,   -1.0775049205702990e-08,   -8.3608843251429479e-09, 
  -2.2850830348437981e-08,    2.2617862998312079e-08,   -1.1615177933684760e-08,    4.1249820870472274e-09,   -1.0011928436218820e-08, 
  -9.4657443577397178e-09,    2.0011823844754671e-08,   -3.3807858449145489e-08,    3.2016564260843387e-08,   -2.9026097371181341e-08, 
   2.2842416845736180e-08, 
},
{
   6.2303904221199939e-07,   -2.3315134603589729e-07,   -4.8079087360350329e-07,   -5.3391027929079721e-07,   -7.7468414495595085e-07, 
  -3.4377637201000711e-07,    1.4317921213443359e-07,    3.8659794764365372e-07,    2.3447441593592830e-07,   -3.5633738393986872e-07, 
  -5.1356597033173077e-07,   -6.6555587400324567e-08,    4.0830279631007288e-07,   -6.4644274826991374e-08,   -1.6944993310769370e-07, 
  -8.5495972949957601e-07,    2.0940180005885511e-07,    2.9248504614490481e-07,   -1.1033089461961469e-06,   -4.3514339734911649e-07, 
  -3.7811064797665531e-07,   -3.2773850863497802e-07,    2.3530841179301449e-07,    7.8411745594169242e-07,   -2.2796960437637571e-08, 
  -8.1775824768547060e-07,   -5.4832823201303572e-08,    3.6518698462664738e-07,    3.8124418820090138e-07,   -7.2547858089236096e-08, 
  -1.8838459479281139e-07,    4.7926572910547123e-08,   -2.0450598643053540e-08,    2.9165593938366810e-08,    6.9125694047976934e-08, 
  -8.7708918207653914e-08,   -1.1676243249569260e-07,    1.1419120111819401e-07,    8.2080852459117716e-08,    2.3240081183278839e-08, 
  -3.7879701407988917e-08,   -9.6433041548022631e-08,    3.8916730000796082e-08,    1.0053447126529320e-07,   -1.2019890556585981e-08, 
  -5.2972547052433667e-08,   -6.8212142440631874e-08,    2.6895107755748999e-08,    5.3081409381668360e-08,   -2.2951427108756511e-08, 
  -7.6202558407981011e-08,   -3.2349951224846139e-09,    1.1481715329838830e-08,   -5.9524666022699879e-09,    1.8813501639828239e-08, 
  -2.2940730979658259e-08,   -5.3348901787941621e-09,    1.7072079069305461e-08,    1.2881746245804490e-08,   -1.6563061398827498e-08, 
   1.9277069773991609e-08,   -3.9978892742045247e-09,   -1.6038939466945800e-09,    1.9128554124721451e-08,    1.1520684868881930e-08, 
   4.4875099081014539e-10,   -1.9609303908065659e-08,    1.8354623733186889e-08,    2.9301502723367649e-08,    2.8161118621373931e-08, 
   6.9095268314861619e-09,    4.1547099989173662e-09,    3.0357091060736760e-08,   -1.8609159497309450e-08,    4.3833534507556539e-08, 
  -2.2021390424856421e-08,    2.1569704607224092e-08,   -4.5260068167048984e-09,    3.0967907611003401e-09,   -1.5022630097897732e-08, 
   1.9496751617350381e-08, 
},
{
  -5.3940568680542071e-08,   -3.7162884465144292e-07,   -2.0190086133281380e-07,   -4.5940051707924282e-08,    4.5639058452256022e-07, 
   6.9789569926980317e-07,    6.3476326900736908e-07,    3.3821902436417920e-07,   -3.6982763604740258e-07,   -1.9460945904605780e-07, 
  -5.6809357230693815e-07,    3.5050392061217109e-07,    2.0089686057967560e-07,   -4.4363357576702789e-07,   -3.5316177030082569e-07, 
  -3.6408938792660590e-07,    1.0696458697612170e-06,    5.4701387168645043e-08,    3.4414061621345878e-07,    5.9127244706871836e-07, 
   7.2378561403061629e-07,    5.4121452249457995e-07,    5.2011524184896463e-08,   -6.0360508908717723e-07,   -5.4724968646783457e-07, 
   4.6999608659196613e-08,    5.1981672576762285e-07,    1.4846896174888541e-07,   -3.3779965470000940e-07,   -9.2157585525228111e-08, 
   5.3492902837147406e-09,    1.5359735482649331e-07,    9.8521227357962597e-09,    4.0659583739090792e-08,   -9.7787967430514886e-08, 
  -5.7606309931336868e-08,    1.4976973703166090e-07,    1.4384575033232869e-07,   -9.4105038960808888e-08,   -1.7770816278233630e-07, 
   6.2857306993194190e-08,    1.0564055594076490e-07,    2.6395600000872869e-08,   -2.2586048098758539e-08,   -1.9626803050804101e-08, 
  -2.6790029669804902e-08,    4.8875275415833532e-08,    7.7336313016547631e-08,   -2.8007132170748951e-08,   -5.6903480123028317e-08, 
   2.1859930554090490e-08,    2.6056945293627189e-08,   -1.7413777591014100e-08,   -6.5354897869392091e-08,   -9.4184192009345023e-09, 
   5.1900751533010470e-08,   -5.7408788836674720e-09,   -5.0384189794216321e-09,    3.2982260089338862e-08,    2.4308102652916909e-08, 
  -3.0314024384954032e-08,    4.6233654698602683e-09,   -1.0034917592269830e-08,   -2.5151953911156068e-08,   -2.7547219768777610e-08, 
  -1.2825473156738131e-08,   -2.3356444061668910e-09,    1.6196132089984969e-08,    1.1747662784129391e-08,    4.0196515918346987e-08, 
   8.4991016936327109e-09,   -1.6844142890714569e-08,    1.1605574724860640e-08,   -1.4117429773239770e-08,    1.0821358889875440e-08, 
  -9.1755950038817821e-09,    4.9454972151493847e-09,    8.8031137082582877e-09,    2.5538539368415808e-09,    3.3067900513528522e-09, 
  -2.6856994598150470e-09, 
},
{
  -3.1286409396935222e-07,   -1.8094168688735601e-07,   -1.0432508924443410e-07,   -2.9341890127157938e-07,    8.7264101737834245e-07, 
   2.0629370256866011e-07,    2.2350772799261780e-07,   -1.9710160923205100e-07,    6.1118874148441888e-08,    6.9551342431548922e-08, 
   6.6632156103218603e-07,    2.7473842288581168e-07,    7.3988670101664106e-08,   -2.9893151037383028e-07,   -3.6574949577333369e-07, 
   3.5819799150966082e-07,    4.1157939324288639e-07,    7.1135256682421871e-08,    4.6656982881352452e-07,   -8.3207181083117486e-07, 
  -1.9243210368147630e-08,   -7.7247799989911122e-07,   -4.1876045076903272e-07,    8.9358853172121405e-08,    4.0011464623022082e-07, 
  -5.6271728665350662e-08,   -1.6817956463516491e-07,    1.8805463102992420e-07,    4.8807625473715973e-08,   -2.7960321578933619e-08, 
   4.1704961518042438e-08,    1.0017377545950789e-07,   -9.9040199940944813e-08,   -1.9747524928825859e-07,    1.9999031060789309e-07, 
   7.3847531274333411e-08,   -7.7229614984629995e-08,   -6.6164882097242962e-08,   -5.7655690293397480e-08,    6.2929739483183434e-08, 
  -6.4102977423461944e-10,    1.7572199930565220e-08,   -4.2606475303313929e-08,   -7.9925299535827797e-08,   -2.4430081199529352e-09, 
  -4.0069459859954022e-09,   -9.0487367026726050e-09,   -4.6045184562652718e-08,    6.0516966760384523e-09,   -1.2727570691751751e-08, 
  -6.1817612034049586e-09,    1.7609953063319361e-08,   -4.3194132518131502e-08,   -5.2548737695946200e-09,   -1.2007188827659429e-08, 
   3.1582175037705960e-09,   -1.1497396834232790e-08,   -3.2165430513134730e-10,    3.2312688232480222e-08,    1.6256252932751131e-09, 
  -1.1796624470980040e-08,    2.4179493099146539e-08,   -1.2316628846490771e-09,    1.6770336871054870e-08,   -1.1401084406765420e-08, 
   1.6191494603283740e-09,    1.9016507804866110e-09,   -1.9853183621289682e-09,   -1.3392201323369740e-08,    2.7863708515733629e-08, 
   3.7308575408022468e-08,    1.4003822138421580e-09,    4.2743649987505817e-08,    2.4059852936671229e-08,    7.2128040264929442e-10, 
   3.6498605152584632e-08,   -1.4229114783173280e-10,    2.2176186379687901e-08,    1.6909636249028650e-08,    1.3548014160202261e-08, 
   1.6098574863555871e-08, 
},
{
   6.6506982323697388e-09,    4.6181639714625257e-08,   -5.2238899978893193e-08,   -5.2823002208831053e-08,    1.3800527907949701e-07, 
  -2.8358145151180168e-07,   -2.7396734006137092e-07,   -4.8845474893249627e-07,    4.2698157940794011e-07,    2.1017949476738100e-07, 
   6.0140162556967470e-07,    4.4343867592764599e-08,   -1.1269182077243070e-07,   -2.0081378465993091e-07,    1.5370674221947220e-07, 
   8.2529172013831370e-07,   -6.1844626633270183e-09,   -1.1665317418912200e-07,   -7.2203974438336986e-07,   -3.6488623031146409e-07, 
   6.8495628517140382e-08,   -3.1271698464021898e-07,    5.7051643647334642e-08,    4.6838729499972686e-09,   -1.4902251350049949e-07, 
   1.1568289451042040e-07,    3.6424260503753548e-07,   -7.5694899244258251e-08,   -4.2145265720544849e-07,   -9.7179348884585033e-08, 
   1.8431388850135510e-07,    1.6621600245408631e-07,    4.8973155179554472e-08,   -5.2738506468826451e-08,   -8.9743613430438306e-08, 
  -9.0198666076864037e-08,    9.1884351911658603e-08,    9.3363810701203137e-08,   -3.3630822298068970e-08,   -1.0605986819333720e-07, 
  -1.0691444909544581e-09,    5.9276915592852142e-08,    1.5815236396153940e-08,   -6.1838158769287729e-08,   -5.1267588638259218e-08, 
  -2.8526483573613731e-08,    4.6277117704401062e-08,    5.1681277500149897e-08,   -6.5171325042152472e-08,   -2.1247258261834839e-08, 
  -4.3771569363667827e-09,    3.4169491656334390e-09,   -9.7534013510140468e-09,   -1.1347312251365601e-08,    1.5467152210773731e-08, 
   4.0292347301224969e-08,   -1.3079962180249860e-08,   -4.7052245767118597e-08,   -8.2495766579039185e-09,    9.7114458103714551e-09, 
   1.9913011710780800e-08,    3.6330274198172573e-08,   -1.3478687494604389e-08,   -2.6320561902926072e-09,   -1.6223451913485531e-08, 
  -1.0574281830611929e-08,    1.3839348502219960e-08,    1.1574284005267609e-09,   -1.1394258845983780e-08,   -6.8757042573031982e-09, 
   2.6808323992675201e-08,   -2.0990759642604121e-08,    1.7962079718462720e-08,    1.4028330809314841e-08,   -2.4187878478029779e-09, 
   1.7239582900246340e-08,   -1.8791192207053770e-08,    3.0074987185535303e-08,   -3.0113578588280957e-08,    3.9571391512957528e-08, 
  -3.4183756475334110e-08, 
},
{
   2.9800506646171332e-07,    1.8344606355546611e-07,    6.9247343387461681e-08,    4.2381732878213438e-07,   -3.5839832070396620e-07, 
   1.6848241831807071e-07,    2.0104741582388691e-07,    6.8730006673844861e-08,    3.1067740467772798e-07,    5.8506560488758367e-08, 
  -4.2013699476282829e-07,   -1.6158145338116890e-07,   -4.7171328165673543e-07,   -3.8974995460658311e-10,    2.8054717681758090e-07, 
   7.8475364933386014e-08,    4.6528363403317667e-08,   -4.8568162906700499e-07,    3.5213761763876911e-08,    1.7498191632079431e-07, 
  -4.7388247284749259e-07,    3.9509696270180282e-07,    5.8412852268006408e-07,    6.5443933539250924e-07,    4.9488306227767846e-07, 
   1.3005647364852549e-07,   -5.7736507305759783e-07,   -2.8716704730464639e-07,    1.5344083253979369e-07,    2.5221193020449723e-07, 
   7.7537550128164289e-08,    2.7125424267040189e-08,   -2.2822771898707691e-07,   -2.4125249759174529e-07,    1.4008778097270370e-07, 
   2.2976364858201181e-07,   -3.3609303386721112e-08,   -1.1099515652415510e-07,   -7.8867820909183511e-08,    6.7538516214822959e-08, 
   8.0979401970730117e-08,    1.8693961079579420e-08,   -7.6253978031094304e-08,   -1.0584263309520850e-07,    5.9555481450138928e-08, 
   6.2478998656977050e-08,   -1.0407191719497019e-08,   -5.7007502243514723e-08,   -4.6275770111025713e-09,    5.6834403221334524e-09, 
   3.9607818527298968e-08,    2.9133654190181310e-08,   -2.1171185313687731e-08,   -3.3129279461782839e-08,    1.1092356803145050e-08, 
  -3.6856992077205010e-09,   -6.1171426857545734e-08,   -4.4966367677810662e-08,    2.8939146376837939e-08,    2.7997575907820029e-08, 
  -4.3559182682406851e-08,   -1.8396042855271870e-08,    3.8422180278897578e-08,    1.9545978340560189e-08,    1.1044904958005720e-08, 
  -1.2556088956422910e-08,   -1.2450193849506220e-08,   -9.0707423538274792e-09,   -1.5648720052534810e-08,   -2.7818304947497598e-08, 
   5.2571730877251882e-09,   -7.8485105342175411e-09,   -2.4361309893412840e-08,    1.8537092819574140e-08,   -3.1528850699924582e-08, 
  -1.2295009610783730e-08,   -2.6879033180146199e-08,   -4.8641495118473674e-09,   -2.7262229899390201e-08,   -3.1296070040174572e-09, 
  -1.8355253625983499e-08, 
},
{
   1.2382554869535340e-07,   -1.4791536512739419e-07,   -9.3994254289733108e-08,   -1.5864628605040871e-07,   -3.9829410795149749e-07, 
   3.2529795139055748e-07,    6.2410418046131448e-08,    2.4155063400434169e-07,    4.0705531212845761e-08,   -1.7704293895129409e-07, 
  -2.8400079019096941e-07,   -2.7987346427304440e-07,    2.5397802768283010e-07,    2.6038531389766372e-09,    1.3450955702606150e-07, 
  -3.2932122376643938e-07,   -2.8509034304189033e-07,   -2.6328670190301798e-07,    2.4334025394975689e-07,    1.8234844161542849e-07, 
  -1.2339000794407441e-07,    6.6801656361563312e-07,   -3.2472175304397040e-07,   -1.8794503883115069e-07,   -7.0495763436331983e-07, 
  -4.0985566966945011e-07,    8.2733514635286452e-08,    3.7746620514077799e-07,    6.9614132594898509e-08,   -1.3794766607726390e-08, 
  -2.2551051537638490e-09,   -1.4602895561312989e-07,   -7.5909083967743617e-08,    1.1406221093764710e-07,    1.2136146886712100e-07, 
  -9.8589998891183405e-08,   -1.0003304936051400e-07,    5.0298676434516290e-08,    6.0612538803716377e-08,   -1.3103547630008001e-08, 
  -3.0051950468690131e-08,   -2.6011654021800690e-08,   -8.1220118762204808e-08,    3.1474978731977612e-08,    2.8339826075713259e-08, 
  -3.8700086509404493e-09,   -4.6011104766624428e-08,   -2.7640275048025970e-08,   -1.0239800122766869e-08,    2.4734785595614220e-08, 
   1.4992914812251111e-08,    2.5393101822446192e-08,    3.8371746547475536e-09,   -1.9153595362559301e-08,    3.3803865148579468e-08, 
   5.6285859789713218e-08,   -3.8085937147590433e-08,   -6.3827478261482532e-08,    6.8254911727497930e-09,    3.1916386181268647e-08, 
  -2.8390268407219531e-08,   -5.1497624546057698e-08,   -1.0102801384017329e-08,    2.1202600642596261e-08,   -2.1960804438917089e-08, 
  -3.8562372640045974e-09,    5.0321543221398824e-09,   -1.1120594384824370e-08,   -3.4766929179415617e-08,    1.4560299724971490e-08, 
  -1.7208788676041169e-08,   -2.2412321730334679e-08,    3.4117018314396452e-09,    2.8254216720054611e-08,    1.7709979587694379e-08, 
   1.3675524334921180e-08,    3.3574552806070848e-08,   -4.9966310691078960e-09,    2.8734719794091891e-08,   -1.5906431570965179e-08, 
   3.5288814115457982e-08, 
},
{
  -1.1079454891979639e-07,   -4.0126140681541559e-07,    1.0295574560935000e-07,   -3.7694486993634550e-07,    1.9549557765957571e-07, 
   7.2679019916678936e-08,   -2.6852512844608291e-07,    2.6175060260013972e-07,   -3.7201577463816800e-07,   -7.9873680455104339e-10, 
  -2.5361012940756869e-07,   -8.6898719785704032e-08,    3.7922079263537608e-07,   -1.6993532987053260e-07,   -1.4565214032387209e-07, 
  -4.1965832774604339e-07,   -2.0032041830869750e-07,    3.3024327781270350e-07,   -1.1671446266874159e-07,    4.1049548405925833e-07, 
  -4.3652709220026701e-07,    2.2695041961074579e-07,   -1.1411133475898399e-07,    2.2719941596896781e-07,   -1.5396408753817271e-08, 
   4.2480863281236359e-07,    2.0336928244053230e-07,   -2.5760860961128168e-07,    1.3579469239490481e-07,    3.2187304031659198e-07, 
   8.0394556354472122e-08,   -1.7912333490658429e-07,    1.3220864045900401e-07,    1.1829940030533430e-07,   -4.7860233500407217e-08, 
   5.4187652460545508e-08,    8.9141708188153352e-08,    2.0676076210812320e-08,   -1.0261855286853750e-07,    3.6368105668424359e-09, 
   8.0548590305522015e-08,   -3.9402998138251942e-08,   -1.3044776330452620e-08,    3.5230822511695882e-08,   -3.8126285997105330e-09, 
  -4.1870291407727873e-08,   -4.0542175855105879e-08,    5.2512970896453262e-08,    6.4472339154467584e-08,   -1.3764138097831790e-08, 
  -2.3262961649640342e-08,   -5.4498090962074922e-09,   -4.0832137320425257e-08,    3.0883788965682198e-08,    5.9554143490002016e-09, 
   1.5826576402757781e-08,   -3.0546366389130611e-09,   -3.3710759479547653e-08,    4.2432292031114947e-08,    1.9055844739369311e-08, 
  -5.3493171836413377e-08,   -8.6122918322741606e-09,    4.2435124794369040e-08,    2.4086226827128541e-09,   -1.9299029335541980e-08, 
   2.7344753084320500e-08,   -6.4811007443059651e-09,    4.0723327050427736e-09,    1.2308992461488829e-09,   -1.3519766695142130e-08, 
   1.5952942060573241e-08,   -1.9862866658779651e-08,    2.1193483815863702e-08,    7.7746498722502819e-09,    4.6649362127191984e-09, 
   1.3571741248581670e-08,    7.7914367333070878e-10,    1.2620984254096850e-08,   -7.6843752977740239e-09,    1.4957902201148129e-08, 
  -1.1704671972041559e-09, 
},
{
   4.6651763615791213e-08,    2.4408804946295361e-07,    1.9547803118599971e-07,    1.0153362064588059e-07,    4.4405614702060399e-07, 
  -3.1654147385162842e-07,    3.8219653909365872e-07,   -2.9231102856545672e-07,   -2.1605680473364821e-07,    2.3863912649050702e-08, 
  -8.9752221004528850e-08,    3.3488893134310482e-07,    7.4687070585525714e-08,   -2.2669233943720719e-07,   -8.3807732025708336e-08, 
  -2.7719475994770262e-07,    4.3647221573199368e-07,    3.1284561172706530e-07,   -1.3241514416300951e-07,    4.1382769125263089e-07, 
  -4.9050613929173354e-07,    4.4090545303246129e-07,    1.7110677302269270e-07,   -5.5132911635500365e-07,    1.3365654513812429e-07, 
   1.0420440793780250e-07,    6.9892842255921726e-08,    2.0822951271180888e-08,    1.7328224754316771e-07,   -3.1771054193578883e-07, 
  -2.2658020777197179e-07,    1.1768365987850979e-07,    1.5392478445121239e-07,    1.4970977269238069e-07,   -1.8409701453662629e-08, 
  -1.3423591418765071e-08,   -7.1647913872668753e-08,   -1.5648959767528681e-08,    4.4608328778969287e-08,   -1.3572564408638251e-08, 
   4.4809188076787303e-09,   -8.5562804175540207e-08,   -1.7330890954670568e-08,   -7.5641223117803539e-09,    3.3642338348812230e-08, 
   2.2118487981986690e-08,   -7.6448411311210260e-08,   -5.9672118147121905e-08,    3.6943136668973922e-08,    2.7410232206408161e-08, 
  -3.6602861967874372e-08,   -4.9738771243184068e-08,    2.4689100919163949e-08,   -3.4229297600611630e-09,   -4.7632654023059054e-09, 
   2.2289622363860708e-09,    4.4689900647893668e-09,   -1.2928420382709690e-08,   -4.2174766304784097e-09,    2.1273250831510398e-08, 
  -3.3424298857639379e-10,   -1.2107587705231850e-08,    1.4317042771814211e-10,   -2.0993014525140581e-08,   -2.6778503005349911e-08, 
  -3.0292522435917392e-08,    1.7601994659046140e-08,    3.3698577624798200e-08,    1.2250204010051920e-08,    2.9217190072430390e-08, 
  -1.0819728157274280e-08,    3.9233527254074041e-08,    4.8275080073852114e-09,   -1.9264686446292220e-08,    1.7623540189088560e-08, 
  -4.3220085749331267e-08,    1.0621305199599020e-08,   -3.9080250417911349e-08,    2.1350367060357001e-08,   -4.6835778642193168e-08, 
   2.8507269098269191e-08, 
},
{
   2.6561879988827472e-07,    1.8984659529516391e-07,    1.9407504646310790e-08,    3.3326669401861979e-07,    5.7394522076625458e-08, 
  -3.4631841874184847e-07,    3.1595908792017292e-07,   -4.0727652556413810e-07,    1.8543841568707511e-07,    1.1269490152068370e-07, 
  -1.2256105013166050e-07,   -3.5108546304128052e-09,   -2.9603322643161770e-07,    7.7346455693604515e-08,    3.3039361477979390e-09, 
   2.1532172296135449e-07,    6.0074270247023810e-07,   -1.0503059994604940e-07,    3.6035680514514411e-07,   -2.8283847306804737e-07, 
  -8.1235739566792844e-08,   -3.7895350129349093e-08,   -1.0587573763554540e-07,   -5.8926412579959466e-07,    2.7360023822351037e-07, 
  -2.8343383249738237e-07,   -4.1376619591642829e-07,   -5.8673900423947004e-07,   -1.1103774475890300e-07,    2.8364746018767452e-07, 
   2.5965497175506852e-07,   -9.4438231555343685e-09,   -1.2000761429813649e-07,   -5.4415022292269699e-08,   -1.0164908575426680e-07, 
  -4.7046845571941142e-08,    1.1550555976001170e-07,    6.0618145789925103e-08,   -4.1389424022967831e-08,   -9.2966391031709051e-08, 
  -5.3736514318232089e-08,   -5.4497487858867011e-08,    7.2148313908372468e-08,    6.2334082759227805e-08,   -2.9218597413776001e-08, 
  -6.1029121259231891e-08,   -5.0983851941039407e-08,    1.8630917759057720e-08,    5.9003820157532960e-08,    2.8403235587667751e-08, 
  -2.2985892903289061e-08,   -3.3488421991056302e-08,   -1.2563713087658931e-08,    2.8423814410021019e-08,    9.0493803763162170e-09, 
  -3.4771934325338910e-08,   -8.6197138185888909e-09,   -5.0852900447309517e-09,    1.4205254460725851e-08,   -3.8952178709227067e-09, 
   1.8170442000333971e-08,    1.5252783788541949e-08,   -8.6902777480378833e-09,   -4.2928136365089877e-08,    2.9468803733682801e-09, 
  -9.3471377774844533e-09,   -1.0127788250041290e-08,    4.2852726412704818e-08,   -1.8592828646705100e-09,    1.6988875042301872e-08, 
  -1.8162904280886079e-08,   -2.9915694799725459e-09,   -1.7528084203898890e-08,   -2.5442757363903030e-08,   -2.5468049336640960e-09, 
  -3.1969511674932913e-08,    5.4675379007773608e-10,   -2.4783534205878080e-08,    2.5779347834228479e-09,   -3.2941556756682810e-08, 
   9.2235974771148104e-09, 
},
{
  -1.4012911779310929e-07,   -7.7644847446302989e-08,   -1.7219187149634989e-07,    1.0923543811362500e-07,   -6.1925818643782105e-07, 
   2.8611650642087971e-07,   -1.5880959481452550e-07,    1.1980582758861610e-07,    2.4648179571308932e-07,    8.0663857082553099e-08, 
   2.1528872721282950e-07,   -4.2067068385091708e-07,   -3.2919144778194879e-07,   -1.8200920903673560e-08,   -7.6090567719229420e-08, 
   4.4144073998088638e-07,   -8.8444347559312699e-08,   -3.5143134866897941e-07,    1.2798344905848919e-07,   -6.7171858587578107e-07, 
   5.6499626215346954e-07,   -6.8730646069251497e-07,    3.3521479699085880e-07,   -5.1315458270389307e-07,    3.2738384010407691e-07, 
   1.3827677523286640e-07,    4.3338187234426489e-07,    3.2255747503100490e-07,    5.1542611412935108e-07,    2.6605201857375819e-07, 
  -3.2663208942466019e-07,   -3.0707617643346703e-08,   -6.5448538173474397e-08,   -1.2366214261228229e-07,   -1.0310360826025121e-07, 
   3.9829968263619202e-08,    7.6407885525851115e-08,   -8.8826261416064885e-08,   -1.1340067571691050e-07,   -6.2812841030766831e-09, 
   1.2313744577301741e-07,    9.4051267435213590e-08,   -8.9213215251186038e-08,   -8.5416625541468901e-08,   -5.4529321002863843e-08, 
   1.7806700371046510e-08,    3.2277381280023478e-08,   -1.3854184904487480e-08,   -5.3769740665613890e-08,   -2.6659909255083171e-08, 
   3.3559732217126491e-09,    1.2995541672008120e-09,    4.0773157036140392e-08,    4.5692247832733528e-08,   -3.6732719547697858e-08, 
  -9.2533664791457738e-09,    8.6132244618482790e-09,    1.0846602869552460e-08,   -1.7247917928208019e-08,   -2.8413095500351760e-08, 
   2.2558628341088479e-08,   -4.1449878368045687e-09,    6.0769760888392385e-10,    1.9623277856483230e-08,   -1.4473895347379480e-08, 
   9.0417076513148461e-09,    1.6239691540042941e-08,   -1.4184759836241840e-08,   -8.7303978099636722e-09,    1.3089690945973181e-08, 
   6.2270462211982088e-09,   -9.5019319057694833e-09,    1.3705009796467440e-08,   -1.5879202025637012e-08,    5.2592361908251577e-09, 
   7.4244869289485153e-09,   -1.2607839461997080e-09,    3.1095151602912381e-09,    9.9793715366390294e-10,    5.1272824362602240e-09, 
  -5.7770178320491684e-09, 
},
{
  -1.7890980799685851e-07,   -1.8954371508812951e-07,   -2.0135410709838450e-07,   -1.5114438271846140e-07,   -3.7209534817515859e-07, 
   2.0360981554297329e-07,   -3.2691684424342452e-07,    1.2312238978367951e-07,    8.6142134273612885e-08,   -5.2332864057279438e-08, 
   1.4690117401347081e-07,   -4.6190939130906501e-07,    2.2776493253620239e-07,    5.1923621297858412e-08,    1.2905418648105269e-07, 
   9.4034486508636743e-08,   -5.0086802979081930e-07,   -2.4326830441430078e-07,   -2.7199670154688931e-07,   -1.3281287624360940e-08, 
   1.2278930428747630e-07,   -2.6279832988690318e-07,    4.0227056541478970e-07,   -2.6261888686332048e-07,    7.2863473401760145e-07, 
   2.7625280762581491e-07,   -1.5768781906644569e-07,   -3.4170443014580468e-08,    4.2909908753145482e-08,    7.0641170336060598e-08, 
  -2.0849406545547311e-07,   -1.3261660576630329e-07,   -1.0992100095683500e-07,    4.0746677241333557e-08,    1.1510647196810890e-07, 
  -9.7357586430324710e-09,   -6.1999880756535511e-08,   -6.2936756411612052e-08,    1.0171846329650301e-07,    1.2125582972906389e-07, 
  -1.6059653639407819e-08,   -5.0701162673003653e-08,   -4.3803028209664458e-08,    9.8345630252459553e-08,    3.7100350641786098e-08, 
  -7.5542753431232872e-09,   -3.1517137838157998e-08,   -1.2291518438071000e-08,    4.4004759412812858e-08,    2.4694589785261500e-08, 
  -2.3941178895794069e-08,   -2.2826126011044809e-08,   -6.6949746661043338e-09,    1.8135417630151670e-08,    2.9502084853046701e-08, 
  -4.1327952897795727e-08,   -9.6129223122568462e-09,    2.9900387474418440e-08,    7.9785180422400177e-09,   -2.6146583614979849e-08, 
  -1.2639543885775249e-08,    3.4889103817727353e-08,    1.4741697501236460e-08,   -1.4955246973965420e-08,    1.2973524043207010e-08, 
   3.3743032144454498e-08,    1.0104936959663369e-08,   -2.8782081297408890e-08,    1.3625943373120179e-09,    2.2799370217497160e-08, 
  -9.1103186516142893e-09,    1.1806369559136360e-08,    2.4960924930023961e-08,    1.3308222061161670e-08,    3.2700211987722942e-08, 
   3.9456678413889068e-08,    2.8884966557988399e-08,    5.0691069305749353e-08,    5.1318087982712334e-09,    5.6932129094163178e-08, 
  -5.3130371518947304e-09, 
},
{
  -2.2473934735541611e-07,    5.8215212507928022e-08,   -2.8273103642270949e-09,    1.2204330344987859e-07,    3.4334229006640278e-07, 
   9.6293497515718396e-08,    2.7157517394774910e-07,    2.4812236262542161e-09,   -3.4810645313143459e-07,   -4.0077218712097633e-08, 
  -3.1119309740965852e-07,   -1.9330288476282879e-07,    5.9673534864034129e-08,   -6.9534755150605322e-08,    1.7337430654230490e-07, 
  -5.0527553014781870e-08,   -1.0370177302161661e-07,    2.2100890791401239e-07,   -3.2523985662353268e-08,    7.3831317520578181e-07, 
  -2.4818904834720102e-07,    2.8469163064165152e-07,   -2.3272077782554099e-07,    1.4576740229800021e-07,    1.6093057770312700e-07, 
  -9.6240679400535512e-08,   -2.8716714447584602e-07,    4.9922745314866845e-07,   -5.8985837407318285e-07,   -2.2491706106928831e-07, 
  -3.3657612528292418e-07,   -1.7588007120397790e-07,    2.7198972538494000e-07,    1.8609546807247540e-07,   -1.4344940495240819e-08, 
   7.8461507290808741e-09,    1.9337648678169980e-07,   -7.2197020817564262e-09,   -1.3766557518625720e-07,   -3.3989003948112180e-08, 
   1.3716997268007350e-07,    4.3720861794535192e-08,   -5.3775665106865853e-08,   -4.9722185022982369e-08,    1.5179888848508479e-09, 
   4.9797683624109223e-08,    7.8626078282292282e-08,    2.9271105990368801e-09,   -1.2095485088283639e-08,    3.3592775142138589e-09, 
   1.4593614729016220e-08,    7.7588273282151470e-09,    1.6854138017508880e-08,    5.1531108406875057e-08,   -3.0953009796592670e-08, 
  -1.3159235460371639e-08,    1.2573303530113380e-08,    5.3297198998565012e-08,   -4.7285470038410377e-08,   -5.3724988753628529e-08, 
   3.2119661032478572e-08,    1.8521465315669699e-09,   -2.2863052872105901e-08,   -1.0582187950960950e-09,    3.1079660281111523e-08, 
   1.1364485225309420e-08,    2.2983251494079981e-08,    1.8454123546409341e-08,   -1.7287640656946561e-08,    1.8760264653711539e-08, 
   7.5169808875106474e-09,   -1.0219926273799319e-09,   -6.7842615858714454e-09,   -1.4976962407661010e-08,   -3.0469466429982878e-08, 
  -2.3386278766646180e-08,   -3.3580736734241812e-08,   -1.8394421066540041e-08,   -3.1594991341126829e-08,   -8.6844378634888888e-09, 
  -3.7054489276425817e-08, 
},
{
   3.5017911372557858e-08,    1.5662107285172520e-07,    3.0690987897185598e-07,    1.9906682949500119e-07,    4.0345026906393098e-07, 
  -4.7930164566392872e-08,    4.5910522899934418e-07,   -1.7273809020355719e-07,   -2.4819931440282882e-07,    9.2385377802570448e-08, 
  -8.2984621401518498e-08,    2.1188939514541801e-07,    8.9182305751498224e-08,   -1.3011181784464920e-07,    8.0857002198243854e-08, 
  -8.7669846139115541e-08,    1.7209430787185891e-07,    1.6019813922072989e-07,    2.7683282308885179e-07,    3.1697019030015482e-07, 
  -2.6539606385896239e-07,    2.1734973853846919e-07,   -3.7341707266587778e-07,    3.8585456798043638e-07,   -2.9589926512109959e-07, 
  -5.0080049447013268e-08,   -3.7837486086758739e-07,    5.1307032689722340e-08,   -1.3689973617542331e-07,    1.5934179139909901e-07, 
   8.0261183497610901e-08,    2.0452087491674511e-07,    1.9302949858414749e-07,    3.1044324018295548e-08,    6.8372561049158770e-08, 
  -6.8406151061338767e-08,   -1.8550487603784421e-07,   -9.8042903845355867e-08,    2.2138827313363319e-07,    2.1394124499928191e-07, 
  -1.5416201266810059e-07,   -1.0576508454304071e-07,   -2.2805079313001461e-08,    1.4827037599013551e-07,    7.5196844827512357e-08, 
  -2.1389377822180069e-08,   -8.7293909692996434e-08,   -1.0737236474157410e-07,    4.4305518712464868e-08,    8.6990542087036838e-08, 
  -1.5392293253890381e-08,   -2.7392242860975810e-08,    4.0015795231050527e-08,    4.7976448579177640e-09,    4.3940406414663019e-10, 
  -6.3088793315440132e-09,    1.7116906947311100e-08,   -2.4362425804243910e-08,   -3.1087444982469269e-08,    7.1810373620219256e-09, 
   4.4337931570665999e-08,    3.0994772588096002e-10,   -1.5456911802244779e-08,    2.7462379375534131e-08,   -1.8164946905033631e-08, 
  -3.1507596095267553e-08,   -1.9550489228411080e-08,    2.8930785623828351e-08,   -1.1451115042695049e-08,   -5.8469224805793571e-11, 
   1.3406669034784360e-08,   -1.4069122767833999e-08,    9.7192394157167851e-09,    2.8957457754385091e-09,   -1.1911867022075369e-08, 
   2.9834427818979390e-08,   -1.5518302956492269e-08,    2.0382105419019930e-08,   -7.8095369888891807e-09,    2.3614790722157261e-08, 
  -1.8284196055722439e-08, 
},
{
   9.6416933029588930e-08,    6.9848912908713176e-08,    7.9628272547827993e-08,    1.0324442774104630e-07,   -1.8728923925709430e-07, 
  -1.2691726734393480e-07,   -9.0360646208108568e-08,   -2.5850308737582849e-07,   -4.1746703183486042e-08,    8.9560884551152844e-08, 
   1.3876448127513709e-07,    2.9489368172660072e-07,   -1.4013340779858549e-07,    1.7478512424802341e-07,    7.0110690240570485e-08, 
   4.1888714845581669e-08,    1.4527833834916490e-07,   -2.8819396574268640e-08,    2.8581207181270500e-08,   -1.9570027691727679e-07, 
  -1.2786594632193610e-07,   -1.7343242283493979e-07,    7.8100415541801727e-08,    6.6995964161192621e-08,   -1.0991726774138390e-07, 
   1.0837288324825400e-07,   -1.2189316103848900e-08,    4.7342079945330848e-07,   -3.6388931964974831e-08,   -1.5397394928721781e-07, 
  -7.3208354445993621e-09,    2.0503197108988349e-07,   -6.0664330159171572e-08,   -1.5149502720144311e-07,   -2.2995321782695180e-07, 
  -1.1486429179361410e-07,    1.9271900187518120e-07,    3.0515933963324358e-07,   -1.0739721056435160e-07,   -2.3837351416915200e-07, 
  -4.3570935938291658e-08,    1.0306543986187510e-07,    9.5073214474988736e-08,   -3.1670675362917697e-08,   -4.3072082570832672e-08, 
  -4.2628687639845307e-08,   -4.6591332486109889e-08,    3.6297872037228882e-08,    5.0066873364918480e-09,   -2.0773077169859370e-08, 
  -5.6230260521248470e-08,   -2.3225006093591440e-08,    1.3150371355643680e-08,    1.3647901560826739e-09,   -3.4376051509690518e-08, 
   3.5961991143392650e-09,    4.6380988195390337e-08,    9.7444094524642340e-09,   -1.8212691120107551e-08,   -3.9712009869294731e-08, 
   3.0781051371393417e-08,    5.1745294237552877e-09,   -1.2859144651056139e-08,   -2.8232237860941070e-08,   -5.8781004111776893e-08, 
  -1.2682708120814700e-08,    1.5713937458396619e-08,    1.3893147215377560e-08,   -1.4738832789576251e-08,    8.4698454522225155e-09, 
   6.3319613781521923e-09,   -1.1737291055526179e-09,    2.0959946701376381e-08,    1.7291696084039941e-08,    3.3146482887149267e-08, 
   2.6747011919294239e-08,    3.2677623283849799e-08,    3.0887204285340792e-08,    2.0456256872413529e-08,    2.2274599354937570e-08, 
   1.3660597104177930e-08, 
},
{
   1.3454167912853999e-08,   -1.4594550925333691e-07,   -1.8900571342100260e-07,   -3.5165969895604363e-08,   -2.6245016435871812e-07, 
  -9.3858451381325565e-08,   -1.4350225793396779e-07,   -8.4399266886280721e-08,    5.3557629619835768e-08,   -7.4814774016662540e-08, 
   6.7547141689096876e-08,    1.3455548251108399e-07,   -3.0325844797735808e-07,    9.7172404864323379e-08,   -1.3733277347910611e-07, 
   1.2166056752935481e-07,    6.7423619085705126e-08,   -1.3171119227208211e-07,   -7.1344708930734659e-08,   -2.5865913112589179e-07, 
   1.2291704860035419e-07,   -3.2809610520171882e-08,    2.0280238119688860e-07,   -1.6251214080633741e-07,    1.1254291701803659e-07, 
  -1.8429883698662701e-07,    1.1694968385426280e-07,    3.1273964601629741e-07,   -2.2231722481904630e-07,    1.7163119431251219e-08, 
   8.3186343568163458e-08,    7.8953381289128117e-08,    5.5092681530910229e-08,   -2.4066812936349821e-08,    8.3331006094215622e-08, 
   2.0605195393677049e-08,   -1.6601047334463231e-07,   -1.1457522585645990e-07,    5.5916272890031003e-08,    1.6616746720777719e-07, 
  -3.7589902744299150e-08,   -1.1581940689458381e-07,    4.4661598930658178e-08,    2.3115976793491441e-08,    5.2789006379118533e-09, 
  -3.8801867403663133e-08,    5.8426457641534588e-08,   -7.3087469795559448e-09,   -1.5876001289289922e-08,    2.4498735694809700e-08, 
  -1.2124946374760809e-08,   -5.9637546214589724e-08,    1.5716912069639399e-08,    2.7156878636962728e-08,   -2.0598529734341381e-08, 
  -3.8168653542137523e-08,    1.8160363777274270e-09,    1.7309169075534150e-09,   -5.7335222802739200e-08,    1.8564145366184810e-08, 
   2.5766229579465960e-08,   -1.0333355906040020e-08,   -1.8464747507191400e-08,    1.3195542467325080e-08,    1.1997271372907261e-09, 
   3.0458308482370572e-08,   -5.2514627551796160e-09,   -3.2599509915356669e-08,    3.1415332439130209e-08,   -2.5740231453981451e-08, 
  -1.6680113918526870e-09,    1.1995163703204510e-09,   -6.3110056965273961e-09,   -2.7153087065670041e-08,   -1.9474317437066349e-08, 
  -2.0038597783690191e-08,   -3.2275924064217167e-08,   -1.6759991878209391e-08,   -3.5136289991140688e-08,   -2.3546381236919430e-08, 
  -3.6693928431794098e-08, 
},
{
   1.1415389076391271e-07,   -6.0978169516080482e-08,    8.3337491764167563e-08,   -3.7695255894016931e-08,   -3.1150685284645588e-08, 
   9.2431999857505967e-08,    5.8517088199897548e-08,    2.4130381448123768e-07,   -3.1189662495483330e-09,   -1.3348919881375349e-07, 
  -8.0968956240001903e-08,   -1.9411432800647201e-07,   -8.3515417019970120e-08,    2.9060801404821471e-08,   -2.1562170698916451e-08, 
   8.8299403590952145e-08,   -1.3012023367531629e-07,   -4.7817763167130353e-08,    3.0547665378528402e-08,    6.6189798286726947e-08, 
   4.0161300329302718e-07,   -1.2733505527465670e-08,    1.3784175106419170e-07,   -1.2238386862490220e-07,    1.7859073686593209e-08, 
   3.2165873057388239e-09,    1.7530693411769250e-07,   -9.3208680613625768e-08,   -3.8150827821588782e-07,   -7.5620640053598210e-08, 
   2.3812610706667191e-08,   -1.9971160085948569e-07,    8.9374420888902108e-08,   -3.9771492440453949e-07,    1.1469182814266361e-07, 
   2.5395957524142729e-07,    4.2129618578725373e-08,    9.8208473981999068e-08,    9.9469730680366883e-09,   -2.5745403534494468e-07, 
  -4.1443252825890082e-08,    1.6820069751869740e-07,    1.0308232626338610e-07,   -7.0038064535491452e-08,   -1.2196361595307099e-07, 
   4.2272108497803848e-08,    5.9377348437907360e-08,    1.8906628013296461e-08,    1.3649977026942311e-08,   -3.4490511565166681e-08, 
   4.3027917035399330e-10,    5.0270922076139099e-08,    4.6357304116043739e-08,   -2.4282795615852862e-09,   -9.0643338662239060e-09, 
  -2.3829540610693389e-08,    1.1711589064585240e-08,    3.5754022645867722e-08,   -4.8182753078852024e-09,   -2.3753633638613219e-08, 
  -2.2342169368797679e-08,    2.4521309772462120e-08,    3.9161940497230771e-08,   -2.1554336265665409e-08,   -2.8586080845641630e-09, 
  -9.7613286544950552e-09,   -3.3763392592834100e-08,   -3.8442901236260313e-09,   -2.4250680463402510e-09,   -9.7733825080326272e-09, 
   2.1796544995103839e-08,   -6.3533297575582164e-10,   -2.4344198631388579e-08,   -1.4144615871723910e-09,   -2.7606198840907830e-08, 
  -2.6461670063635530e-08,   -1.4595660921975691e-08,   -2.5425669305365591e-08,   -8.1070748800348975e-09,   -1.5184683821167421e-08, 
  -1.1268838420760531e-08, 
},
{
   1.4309722973487939e-07,   -6.9857883539046012e-08,    1.3315305225107259e-07,   -1.5441100504593691e-07,    2.0037736081892821e-07, 
   9.3351803773723517e-08,    8.2448774379965904e-09,    1.6317990329089319e-07,   -2.3684136584398699e-07,   -4.6162437050820047e-09, 
  -2.5061516036456650e-08,   -5.9424865170610327e-08,    6.9433465327683460e-08,    4.9415299254759157e-08,    2.1759747165201961e-08, 
   4.6689356080410793e-08,   -1.8209698545153200e-07,    1.2225078912847290e-08,    7.6591740848835366e-08,    2.1940030137739651e-07, 
   1.5962202179924019e-07,   -6.7932447668075091e-08,   -1.2420910000419701e-07,   -4.2458438711384667e-08,   -3.0011726079240041e-08, 
   1.0573172690567790e-07,    3.2497432436029587e-08,   -4.9604553155495787e-08,   -5.8287455217107727e-08,    4.2868420782768192e-08, 
   1.6269246219648551e-07,    1.0908816421836909e-07,    8.7589187448182994e-08,   -9.4208598006704204e-08,    2.9799617179318201e-09, 
  -2.2242110984292820e-07,   -2.9066411984174031e-07,   -2.0209988882639899e-07,    1.7897713731672811e-08,    1.3953494947431451e-07, 
   1.1413168482978320e-07,   -4.8813662280767362e-08,   -1.6926140355607811e-07,   -4.9953698561631457e-08,    5.2300068682532737e-08, 
   5.3569128202290350e-08,    1.6136373991568591e-08,   -1.4485682922361889e-08,   -6.5624463147832837e-08,   -1.9381554421885070e-08, 
   5.8309224409575312e-08,    9.8195847838631269e-09,   -2.6550731825423699e-09,    9.7682209709750590e-09,    4.2960391153540919e-09, 
   1.2797933236364781e-08,    3.8541856808678590e-08,   -1.2234250882912850e-08,    1.5517306753323989e-08,   -3.1018353753256418e-08, 
   2.2914717662037292e-08,    1.5804975374954871e-08,    5.0757151028675560e-09,   -8.0321210231905090e-09,   -1.2636820680965410e-09, 
  -1.7081053415114221e-08,   -1.6051416121923240e-09,   -2.8763013588894708e-08,   -1.8131621216844370e-08,   -2.3869942652725719e-09, 
  -6.1060341390309882e-09,    1.5176146381324019e-08,    4.0800040051723360e-09,   -1.4707421372002970e-08,   -8.8115310774511367e-09, 
  -1.9825518153810099e-08,    6.4698444424279608e-09,   -5.6801384886818479e-09,   -1.1924496262571081e-08,    1.8518675387124012e-08, 
  -1.9178282810397239e-08, 
},
{
  -9.3613803420433307e-08,   -4.0910599890024650e-08,    5.8675965618782470e-08,   -1.2566971141267641e-07,    9.1242269592696469e-08, 
  -1.5400246903553061e-07,   -1.4039660982872120e-07,   -8.9111302464619005e-08,   -1.1135804639784500e-07,    8.6098107102498953e-08, 
   4.8032933510956306e-09,    1.7417689865144350e-07,    1.7567234786505400e-07,   -6.3664146670116703e-10,    6.1333748496405536e-08, 
  -1.2797747227091999e-07,    2.9330141545847451e-08,    4.2623845131958858e-08,   -1.2586254793144800e-07,    2.1730441828880960e-07, 
  -1.6312204203801509e-07,   -4.7019512161784342e-08,   -6.3631476345334011e-08,   -1.8067172599804899e-08,    1.3915220352998491e-07, 
   5.0146203682854397e-08,   -2.3119735238601610e-08,   -5.2592873912419671e-08,   -7.4350715266179813e-08,    1.5799589034122649e-07, 
   1.2954915838059989e-07,   -1.6423185813898651e-07,    4.2337514614444823e-08,    5.8475398205839872e-08,    5.7891361833442308e-08, 
   3.5410000719728689e-07,    1.4032205000434729e-07,    2.7999725729822269e-08,    1.8242723452291801e-07,   -7.3527413966795819e-08, 
  -2.1144239516408381e-07,   -5.6269656280633493e-08,    3.7385595963483667e-08,   -6.1348664789110109e-09,   -3.5479484011716403e-08, 
   2.5877502023237778e-08,   -2.2933272566049581e-08,   -1.0917202035018020e-07,   -4.5419133217149473e-08,    4.1834613424254930e-08, 
   4.5564394341709228e-08,    2.9839224484536620e-08,   -2.1684207261625429e-08,   -5.2560461950635003e-08,   -4.9734569633855096e-09, 
   6.2609322210806362e-08,    2.3037019399123000e-09,    2.8567371343927179e-09,   -4.8283994827937849e-09,    8.5945902364988783e-09, 
  -1.6766221308051762e-08,    2.0397296405929511e-08,   -1.6348347560271630e-08,   -1.6633471743894992e-08,   -2.0720067762419671e-08, 
  -2.1684071991584589e-08,    4.3792547302981592e-09,   -4.4138759859463487e-09,    7.0357085654840500e-09,    1.1822517036221701e-08, 
  -1.2881206313722400e-08,   -1.9482515896061630e-08,   -6.7663252746500198e-09,   -2.7619766132433049e-09,    6.5622048076008653e-09, 
   1.3198689067665060e-08,   -7.2285366979371779e-09,    1.1673329617846589e-08,    5.8468649983395765e-10,   -7.5417288260743825e-09, 
   1.3374343775361620e-08, 
},
{
  -1.1634597651051050e-07,    6.9727112840256719e-08,   -1.0511750363253380e-07,    8.6388483626716261e-08,   -2.9153815376168640e-08, 
  -1.4119500703570820e-07,   -1.0319846464728249e-08,   -1.7537996827502841e-07,    2.1017986319690889e-08,    3.5831903511111689e-08, 
  -2.0507365083276451e-08,    1.2434837415706969e-07,   -7.0733077990147677e-08,   -4.2098806139770279e-08,    3.8829485595747358e-08, 
  -1.1305342583158870e-07,    2.3040995993151410e-07,   -8.3790307497045326e-08,   -2.7422892767732530e-08,    1.1070102602742880e-08, 
  -1.7246098146981131e-07,    3.1471635002655612e-08,   -6.5546742937670543e-08,    1.3009099109375881e-07,    1.1409795602059990e-07, 
  -1.1281578875296831e-07,    7.4636012461474003e-08,   -1.0971440832705100e-07,    8.1814502729350519e-08,    1.0232700385076671e-07, 
   3.6293181471302798e-08,   -2.7831701396601830e-07,    1.1983455625456269e-07,   -3.8256469157865249e-07,    5.1278731778469358e-09, 
   1.7574893437826171e-08,   -1.8917698132750789e-07,    1.0402270997036081e-07,    6.6196197312449245e-08,    1.0897013392005150e-07, 
   7.1306369032482633e-08,    2.1379564891250291e-08,   -4.5856563658786798e-08,    2.2318982455818519e-08,    9.5498176986744179e-08, 
   2.1977868445240051e-08,   -7.2451901992538865e-08,   -3.1058301957535217e-08,    1.6324095077608449e-08,    1.0429426214530740e-08, 
   9.4221774231592343e-09,    1.2176235287938051e-08,   -2.9172667049277550e-08,   -1.6589494701341781e-08,    2.6089459167720819e-08, 
   7.8345423397103316e-08,   -4.5583432726473916e-09,   -4.9458722169172898e-08,   -2.4416230031301162e-09,   -3.5624603264823811e-09, 
  -2.7603732186267701e-09,    9.1364997384809570e-09,    5.0467062635717164e-10,   -3.0528611453611647e-08,   -8.3018345618890701e-09, 
  -8.1366284734688281e-09,   -6.1185123425040787e-09,   -1.4965236741049810e-08,    5.7111160293270207e-09,   -1.3278372297937961e-08, 
  -2.4891598456516219e-08,    4.5291250627892327e-09,   -2.5883497180767419e-08,   -1.9594072388369771e-08,   -3.1778035058202601e-09, 
  -2.6856121714989591e-08,   -8.0253713217046386e-09,   -3.0881564979065109e-09,   -4.6166508756688244e-09,   -1.2906559027396101e-08, 
   1.3935082715952991e-08, 
},
{
   1.7390073509387640e-08,    6.9051821175597488e-08,   -4.1561363195630813e-08,    7.3898333015289403e-08,   -1.7807633359855120e-07, 
   7.8736519330474352e-08,    1.6365404957829601e-07,    3.6799721551060742e-08,    1.8144509931140561e-07,   -3.8733132408446337e-08, 
  -5.5221010597375603e-08,   -5.6095234006329932e-08,   -1.5850573423284350e-07,   -6.3199371645429396e-08,   -6.4086563137959657e-08, 
   7.9647332221832223e-08,    1.1137405742132790e-07,   -1.4399968540525639e-07,    1.1475323877321841e-07,   -1.0875568103679320e-07, 
   1.4159663364171011e-07,    4.9048388496591973e-08,    7.2321494313188707e-08,    3.1651928110491803e-08,   -1.3798663590998121e-07, 
  -5.4004629034111278e-08,    1.5395549829319551e-09,   -9.4295297611661844e-08,    1.5080464160424419e-07,   -1.2829305964441041e-07, 
   1.0376351794984271e-07,   -6.0764412378809638e-08,    2.2254793177250710e-07,   -8.2770977697642954e-08,    1.4088901232734369e-07, 
   1.0875503401031930e-07,   -2.0219346710156231e-07,   -1.8565703689858859e-07,   -1.8586053945668911e-07,   -7.1406867219383538e-08, 
  -6.3776123497809758e-08,   -4.7554070004202361e-08,    7.9512097443864732e-08,    1.1649586191650170e-07,   -5.0904431344213542e-08, 
  -7.5423388300266699e-08,    5.8602766101646320e-08,    4.6850361082441252e-08,    3.2015762470739140e-09,   -2.5335742724641189e-08, 
   2.6346357568252161e-08,    1.0879802316802830e-10,   -6.6981996635856539e-09,   -2.9306027844670968e-09,    1.6351763245746599e-08, 
   2.5856474578397420e-08,    1.3700179370321040e-09,   -2.7868568299404859e-08,    8.4458741057916767e-09,    3.7746613907334149e-08, 
   1.7836526402337689e-08,   -2.9162421924767730e-08,   -3.2836453597880660e-08,   -2.5289019775190129e-08,    1.2202549479009890e-08, 
   1.9022429206719762e-08,    9.9826883595768125e-09,   -1.2786222890282139e-08,    3.7875948566871603e-08,   -2.9062152850641090e-08, 
   3.9182214734232877e-09,    9.6862530007849773e-10,    9.0080155735125075e-09,    8.0087161731192718e-09,    3.8858346341064858e-09, 
   1.1475665208162571e-08,    1.9320641646835959e-08,   -9.5972419672989506e-11,    1.2611076496036040e-08,    1.5892552740599140e-08, 
  -6.1614213870784032e-09, 
},
{
   1.7980990446828880e-07,   -8.9123393751658063e-08,    1.0803644254117600e-07,   -1.1654986577645010e-07,   -1.5303133769981999e-07, 
   8.3329148294895763e-08,   -1.1439331698275219e-07,    1.0372056536400849e-07,    6.8093513349117660e-08,   -4.3099792134628630e-08, 
   7.5914839445849477e-08,   -7.8614167217230720e-08,   -3.7550527011772138e-08,    1.4925139462609210e-07,   -1.0153809047224471e-07, 
   2.5153748542570391e-07,   -1.4322365665331739e-07,   -6.3350654236969787e-09,   -3.3482636659461398e-08,   -9.8549961802302259e-08, 
   1.8338783821004461e-07,    8.3329503886603881e-08,    5.1436658429770372e-08,    1.1978687288708781e-10,   -1.3157126113546209e-07, 
   2.8592437724991400e-08,    2.0013793882873982e-09,    6.6563298481375158e-08,   -7.5436706016173784e-09,   -1.4293188494880819e-07, 
  -9.9078257625298609e-08,   -1.1192741536181750e-07,    2.0223389264695711e-07,    9.3631906354653705e-08,   -9.0304181898181489e-08, 
   1.9141905282068390e-07,   -7.0916055549076759e-08,    8.2499963689137141e-08,    3.2579548514251070e-07,    8.2129925904679946e-08, 
   1.1123696638986840e-07,    1.0814123499530490e-07,    2.0875184329936021e-08,   -5.3648197571687131e-08,   -3.0090988672809352e-08, 
   3.2274694930965652e-08,    2.0143534109540291e-08,    7.4917476342431903e-09,    4.0429547752281752e-10,    2.7519728689204190e-10, 
  -1.9402358295503702e-08,    2.2498893646524579e-08,   -1.0868384024413190e-08,   -1.6461898658393240e-08,   -2.6565798924258539e-08, 
   1.0062120351788281e-08,   -3.5329493726134717e-08,   -3.4725348468397467e-08,    3.8650836668817957e-08,    4.7928999771503067e-08, 
  -2.1037700929038389e-08,   -2.3348386689476272e-08,   -3.3175121606318379e-09,    1.0813339572816740e-08,   -9.8037281949979088e-09, 
   1.6641096036251611e-08,   -2.0239999348762880e-09,   -8.6697474572006111e-09,    4.7546227967429632e-08,   -1.1331337838452621e-09, 
   2.5441637443214179e-08,    8.2327691620187160e-09,    1.3909970929049980e-08,    1.9755954609374670e-08,    1.2156382486042150e-08, 
   6.1724690151772388e-08,   -7.2090808068582747e-09,    7.2313923016550104e-08,    1.1118751637188080e-08,    5.5826430259919158e-08, 
   1.6853621311489489e-08, 
},
{
  -5.8813753768475502e-08,   -1.0308616478520181e-07,    5.7900788447265169e-08,   -1.2337255642019479e-07,    1.0039017742705130e-07, 
   7.3174483987067686e-08,   -1.7957148759723989e-07,    1.9570404665205879e-08,   -2.4994894975000060e-07,   -1.0107397896815700e-07, 
  -3.4872065650434662e-09,    7.6271352504045446e-08,    7.8044879320410746e-08,    7.7616737374773061e-08,    3.2039980307239888e-09, 
   4.3048298307129619e-08,   -1.3393323975086560e-07,    6.1044104459294967e-08,   -1.1596384891874821e-07,    1.1773175276403740e-07, 
   6.5842534620178247e-08,   -4.9282623952816373e-09,    3.9640401394404297e-08,   -1.2629933344704959e-07,    4.3616254907619917e-08, 
   7.3009647804797694e-08,   -4.2502753577933277e-08,    1.4317673509148099e-07,   -1.7476378746928300e-07,    8.2381952665582834e-08, 
  -9.3028550280416412e-08,    1.5141181019967299e-07,   -1.7352387443073941e-08,   -2.3063691191785141e-07,   -1.3093622779341420e-07, 
   2.1205540234216299e-07,   -2.9552977164803152e-07,   -8.5045436427459940e-08,    2.7223825235871101e-08,   -1.1797781782116480e-07, 
  -2.7052502411251748e-08,   -1.1205128441236530e-07,   -1.3264118511389630e-07,    1.8137299951393632e-08,    2.5366425674262760e-08, 
  -3.9955814072124277e-08,    4.0592068927744287e-08,    6.6094637996259841e-08,   -5.9480576006429687e-08,   -8.4877407686126883e-08, 
   2.7760798622301201e-08,    5.2906318561677083e-08,   -2.8076115668294658e-08,    6.7679253181968113e-09,    2.5023820910351289e-08, 
  -1.1048359651356439e-08,   -7.6902740526226359e-09,    1.5112418885969269e-08,   -4.9008942050066543e-09,   -4.2835038959171717e-08, 
  -6.4952785851025490e-09,   -4.5589164370351800e-10,    5.1483704670459643e-08,    1.5181653233648769e-08,   -1.2355377536275141e-09, 
   7.4811315736455839e-09,    1.3310719431885600e-08,    3.5815003168421322e-08,    3.8129468651772650e-08,   -1.2798508066515530e-08, 
   2.0274720379769480e-08,   -1.9832787862815111e-08,    2.0011499089307359e-08,    1.8873273793083590e-09,    1.1229187536924750e-08, 
   4.7505456955470377e-08,    7.3479965358183842e-09,    2.2438227895970231e-08,    2.2393204715969110e-08,    3.3354869887150603e-08, 
   3.4794547967602250e-09, 
},
{
  -1.5639701438662511e-07,   -1.7953527802479601e-08,   -1.0674339261125270e-08,   -9.3452853607311618e-08,    1.7157873926808530e-07, 
  -5.5893430456265157e-08,    9.9909642061381220e-08,   -5.5267439226572703e-08,   -7.8471090833385259e-08,   -3.4748056946680338e-08, 
  -5.2058651133104803e-08,    4.4466538643799788e-08,   -1.0785624108894570e-08,   -4.9196687691755122e-08,    3.6304249021625633e-08, 
  -6.9563590983603029e-08,   -5.8158427107805481e-08,    6.1949450540369975e-08,   -2.5844182306635140e-08,    1.2373075793389769e-07, 
   1.7607805933064699e-08,   -1.2925156961751280e-08,   -1.0409129234201430e-07,   -3.7130646665922510e-08,    5.3242550915174582e-08, 
  -2.4905250419934319e-08,    4.3313630950955388e-08,   -1.7144489535359060e-08,   -1.1431195964043630e-07,    1.2901950578174691e-07, 
  -1.2621296536070310e-07,    3.0323807895754642e-07,   -1.2309263008739970e-07,    7.9175188405788722e-08,   -6.6317165476431059e-08, 
   1.2835760211067629e-07,   -1.0590143858948030e-07,    2.4140798605315671e-08,    1.3347014331245299e-07,   -2.3100635007645359e-07, 
  -2.7132087150900669e-08,   -2.9897783129875589e-08,    4.5265121596468390e-10,    4.2604362762869178e-08,    3.9685524039415013e-08, 
  -2.3165310740645468e-09,    4.8756411069903643e-09,   -3.7235630952126348e-08,    3.4506784357156197e-08,    6.3774228923100138e-08, 
   3.7698756216118558e-08,   -6.3429968977591187e-08,   -3.4314284304190889e-08,   -1.4510670384083869e-09,    4.0910022347703042e-08, 
  -1.0674556987582380e-08,    8.8658932627124604e-10,    1.1712834589807249e-08,    2.7155416083045209e-08,    2.2173455156329389e-08, 
  -4.7702136132581312e-08,   -8.1528797843478420e-09,    3.1748754541902328e-08,    3.2090501264959988e-08,   -2.5061816495101091e-08, 
  -2.9457360270732378e-09,   -7.2222793814466662e-09,   -2.6685180842147279e-08,   -2.8893311138220351e-08,    4.9541153990283271e-09, 
   2.0220364716009601e-09,    1.7994294427791900e-09,    3.8180894115192513e-09,   -8.1797098238473933e-09,    1.6597033668736969e-08, 
   1.2839057150194420e-08,    1.9423668585256451e-09,    2.3922240782046771e-09,    2.0899374431030328e-08,    1.0939143624706680e-08, 
   3.3971126423981383e-08, 
},
{
   6.7338858450204688e-08,    1.3357163900312811e-07,    1.0267822284623321e-09,    1.5866384390936051e-08,   -1.4539420941323901e-08, 
  -1.1157629707787770e-07,    7.3601014779208580e-08,   -7.9573733294899556e-08,    1.3239300047411379e-07,    1.0009476196909211e-07, 
   8.4942358720889779e-08,    4.9697346366542962e-08,   -7.7044658435730122e-08,   -2.1612344963652151e-08,   -2.7257848252935181e-08, 
  -4.6081191209893837e-08,    6.6403824552258084e-08,    4.4177767550150509e-08,    6.5617178872133189e-08,   -8.0672746880079887e-08, 
   1.6630905489238000e-09,   -3.1963257671986481e-08,   -6.5354707774874172e-08,    8.6734371358330734e-08,   -1.5872770405754440e-08, 
  -4.2476689752654260e-08,   -1.7243272467393708e-08,   -9.4722990492320838e-08,    1.9545174111151640e-07,   -7.2815490635224773e-08, 
   1.2295135568983569e-07,    4.3022525943111178e-08,   -7.7038893054048552e-08,    1.5217645575777919e-07,   -3.7316803541154437e-08, 
   1.2759888990090329e-07,   -3.5195335816752382e-08,   -6.2842977823985603e-08,    2.4047024641936212e-07,   -1.2498518201364731e-08, 
   3.7633854063966080e-08,    1.5948666943186880e-07,    1.3930277589365969e-07,    6.6549248594837830e-08,    3.0909904541082032e-08, 
  -4.9584762111329902e-08,   -4.4018295076621861e-08,    3.0405240826239040e-08,   -3.9008575624905587e-08,   -4.3461828371225431e-08, 
  -2.2996589710628190e-08,    2.1230992940218648e-09,    2.5943906999772222e-08,   -3.6429058564066910e-09,   -6.7648234541438230e-09, 
   1.6197265528846980e-09,    1.5403161449800142e-08,    2.4091423149442790e-08,   -2.5958650400231199e-08,   -3.0090295714211807e-08, 
   2.2328902928060860e-08,    8.7894198549763938e-09,    1.6722121284546929e-08,    2.4822384736756191e-09,   -1.3224757347677540e-08, 
  -1.5709124253837320e-08,    3.3822511715929480e-09,   -5.1688211527444958e-09,    1.0228655575234339e-09,   -8.4616272515865037e-09, 
  -1.4335359703048521e-08,    1.0305188346011911e-08,   -1.7198291224937080e-08,    1.4138217077586610e-08,    8.8432263233330904e-09, 
  -5.1690588014883200e-10,    7.0026887954992044e-09,   -6.3782994128775598e-09,   -7.2332619059322996e-10,   -4.2733879792313932e-09, 
  -5.3694026424618403e-09, 
},
{
   1.0015015531020300e-07,    3.2997141656491241e-08,   -3.9409739046749078e-08,    2.2621856963862381e-08,   -8.9280013487567792e-08, 
   5.4238258568734047e-08,   -1.1129691323559520e-07,    2.3027537491821820e-08,    5.4880323402335971e-08,    6.0783352459746695e-08, 
   1.1866701531354789e-08,    9.5342048484994783e-08,   -4.3096549983760090e-11,    8.0541885220445315e-09,    5.3269190848855418e-09, 
  -9.8718472252428619e-08,    1.3326888331571451e-07,   -7.1427176328117030e-08,    5.8005502905904672e-08,   -1.0499627369546131e-07, 
   4.7066879402687899e-08,    6.6590167520987506e-09,    4.2634055748587811e-08,    8.0611044030297052e-08,    4.9378347054287422e-08, 
  -7.2060583598888261e-08,    1.6182982494337051e-08,    4.3786436520366630e-09,    1.6305356191225591e-07,   -7.2543507067564962e-08, 
   1.6096277489877190e-07,   -2.1100144591716410e-07,    1.0648215450483210e-07,   -9.0179486378834552e-08,    3.6525759389134921e-08, 
  -8.6444568960824226e-08,   -7.6751593371798234e-09,   -3.6861072623084687e-08,    1.0798059966788179e-07,   -1.3249419606610051e-07, 
  -2.8282625688147381e-07,    1.6361583052024469e-07,   -1.4270106868286651e-07,   -2.1622197626878691e-08,   -6.3359839274285578e-08, 
  -1.3327859682952549e-07,   -6.9118344660528099e-08,    5.5641732790066723e-08,    4.8222948428843349e-09,    9.4428120484846889e-09, 
   8.8766067357839915e-09,   -4.2503796506277121e-08,   -7.2736915711941708e-08,    4.8149716729818993e-08,    5.4294075001544198e-08, 
  -2.9081387916231091e-08,   -3.8764691292696980e-08,    2.2870772994381780e-09,    5.4967585178153903e-09,    7.3958775748365267e-09, 
   1.7255365571717309e-09,   -3.1948069897761798e-08,    9.7542386001342903e-09,    2.8835943902524709e-08,    1.0094744488280891e-08, 
  -3.3852368620707559e-09,   -1.5899017687539781e-08,   -7.7570233005493244e-09,   -8.9675282337750978e-09,   -1.0455947048287089e-08, 
   1.2388769941906620e-08,    1.5698764962763249e-08,   -3.6472860036888931e-09,    7.9706161045881830e-09,    2.8522677490985950e-09, 
  -3.1802752389756270e-09,   -4.8429000222025537e-09,    1.1117759385866420e-08,    5.7121298774039587e-09,    5.5007918672073674e-09, 
   1.0741095553645990e-08, 
},
{
   6.5659089401047017e-08,   -4.2770439863939582e-08,    4.8560442200681291e-08,   -8.2261088157715761e-08,    3.7666735858963632e-08, 
   1.1263379495700320e-07,   -5.0363372367066272e-08,    6.9887735189113276e-08,    1.3430167979081371e-08,   -7.0182088303398746e-08, 
  -7.6495579940316031e-08,   -2.2060919870346651e-08,   -7.9751941321667653e-08,    4.3986031382998402e-08,   -5.1651425829049323e-08, 
   9.4967876174955801e-08,   -3.6830244580687703e-08,    1.6646511539951240e-08,   -1.1349233087355540e-07,    9.7463003969700009e-09, 
   3.1993670191674433e-08,    9.8817058942398748e-08,    6.5460387769598075e-08,   -4.4577951142381287e-08,   -2.3370839834228409e-08, 
   2.0897240094877989e-08,   -2.4319674509891630e-08,    1.2572169813857380e-07,   -9.3078528856659097e-08,   -3.0558594101122299e-08, 
  -2.7673871698104801e-08,   -5.9251904915923860e-08,    8.9715620444345946e-08,   -1.4315529062634270e-07,    1.4011876832441030e-07, 
  -1.9167486373494019e-07,    3.0079574120526600e-08,    7.2215177795741101e-08,    3.9114089924291399e-08,   -5.1104602604330048e-08, 
   7.1688952427537166e-08,    6.6269264403178366e-08,   -9.4068189248922009e-08,   -7.8475574428158516e-08,   -2.1291124423595140e-08, 
   7.2712292796957494e-08,    1.5721274969429380e-07,    5.8508120683539040e-08,    5.0802973859490363e-08,   -1.2163182901949929e-08, 
  -4.8060046663381298e-08,    2.1016277449897689e-08,    7.0639423628635005e-08,   -1.3442592402474030e-08,   -6.8730543364773275e-08, 
  -2.6145802044600279e-08,    5.2023033546749288e-08,    5.5216866997476687e-08,   -8.9221508510051813e-10,   -2.8969136741613149e-08, 
  -4.7262881525007627e-09,    4.9644823278567197e-09,    1.4674788264441320e-08,   -1.3846385454178749e-08,   -1.4302505306490499e-08, 
   2.4585348266528972e-09,   -1.9036969477211170e-08,    1.9388854163556651e-08,    2.8229706002094581e-08,   -4.7726239636899194e-09, 
  -1.4550935657970841e-08,    4.9995071977585988e-09,    1.4730620563667760e-08,   -1.9699606456276371e-08,    4.5987930383571100e-09, 
  -1.2764967951112000e-08,   -6.5963694759358257e-09,    1.3145141507264090e-09,   -1.3092518502488951e-08,    2.2064865780192621e-08, 
  -2.4244728742283300e-08, 
},
{
  -3.2828754909310241e-08,   -3.3815214882692112e-08,    4.4295705013232476e-09,   -1.1509240581167001e-07,    1.3264285074014119e-07, 
   4.1202421137030150e-08,    4.8970749788252207e-08,    7.2321482138544869e-08,    5.6339230993142742e-08,   -1.8055961756054098e-08, 
  -1.7727920207916849e-08,   -1.0627362439600211e-07,   -2.7619361101060550e-08,    5.3831179685585147e-10,   -5.7946053082765702e-08, 
   9.7997180838958703e-08,   -1.4702764073939110e-07,    3.0889394313482082e-08,   -7.2573977433579114e-08,    7.7667013884903576e-08, 
   2.4112045504797410e-08,    3.7605383750700960e-08,   -1.8109241916821521e-08,   -5.4936752461265137e-08,   -6.1613101099447127e-08, 
   1.6619890321858571e-08,    1.1703675729423980e-08,    4.6379869838390687e-08,   -1.2897344777905761e-07,    4.8650112950609603e-09, 
  -1.0023188068847250e-07,    9.4353917088774468e-08,   -1.1317612632298120e-08,    1.2455438073450099e-07,   -7.2015594055707056e-09, 
  -1.1961658002800891e-07,    7.0733237972441034e-08,    1.2829880604610350e-08,    2.8125967035619918e-08,   -1.4888223222036670e-08, 
  -4.1047158588585283e-08,    9.9485360418763245e-08,    9.2084705347499325e-08,   -1.7175615617359941e-08,    1.0258719927513740e-07, 
  -9.3605270868609097e-08,   -2.9653575732994101e-08,    2.7866959534308252e-08,   -6.7860105464751663e-09,   -7.9717452180601027e-08, 
   1.7773008164419560e-08,    7.8598952090166114e-09,   -5.7943976379674662e-08,    2.3321268480130161e-08,    6.2760408057170077e-08, 
  -2.0315736754032071e-08,   -5.0337164678802558e-08,   -8.8098873811897587e-09,   -2.0279041166094200e-08,   -1.8403190307266211e-08, 
   1.4374202707385840e-08,   -3.9945112984149781e-08,   -2.5125706256732350e-08,    1.1054654858015500e-08,    6.0269555058882842e-09, 
  -1.3495157784040870e-08,   -8.7315372152657635e-09,    1.2785861073392880e-08,    1.7894615605783590e-08,    7.9559030798354898e-09, 
  -1.7732617097839301e-08,   -2.5969192658430471e-08,    1.0460427938408179e-08,   -2.5004808857820070e-08,   -6.3896670164525589e-09, 
   5.1701135999391418e-09,   -2.1221841431201431e-09,    1.1158689146173281e-08,    1.8183513032212351e-08,   -2.2844797597349758e-08, 
   1.4056355185348559e-08, 
},
{
   5.5320735747522307e-08,    1.0228125797069250e-07,   -2.3863651808964599e-08,   -5.1209031157573187e-08,    5.1205577350747280e-08, 
  -5.9032315787152588e-08,   -2.1003915377398501e-08,   -1.0565869255953150e-08,    2.8565133925337201e-09,    5.7484699400282097e-08, 
   6.1463584510654353e-08,    6.4554255720815986e-09,    8.6397321275641517e-08,   -4.8153297585659868e-08,    4.5498065486750500e-09, 
  -5.3778195033674760e-09,   -7.6430545168527338e-08,   -5.9842571662946847e-10,    1.6836709714452029e-08,   -2.5448050543305809e-09, 
   2.9386948733192639e-09,   -2.7830621504435101e-08,   -6.5632458727538259e-08,   -1.1297736606126150e-07,   -1.9440049821244380e-08, 
   3.4629351316774773e-08,    4.0833570563848772e-08,   -4.6811398187818302e-08,   -7.7923049190565256e-08,    2.8832565940202382e-10, 
   3.4525964033799158e-08,    1.3777426702155250e-07,   -2.9920121867975157e-08,    1.3091780059605629e-07,   -1.8591326784171879e-07, 
   1.1232157498662980e-07,    5.1232856265249797e-09,    4.7597533262804493e-08,   -6.6988229940973058e-08,   -8.1923363205968507e-08, 
  -1.3949634065030079e-09,    9.3705529606587919e-08,   -1.3577783088227281e-07,   -1.1442187755961451e-07,    1.9649743701830490e-07, 
  -5.7499258737927044e-09,    5.2681752369750662e-08,   -1.7819888430493831e-09,   -1.4807072952223430e-07,   -4.8971146987035022e-08, 
   5.0108159887150130e-08,    1.9588526493264431e-08,    3.2170405238601117e-08,    6.5214326301844011e-09,   -6.4208210163437213e-08, 
  -2.2741537933768510e-08,    7.5815480934253639e-08,    2.3262449193373278e-08,    1.7883947143873390e-09,   -3.6630210562996223e-08, 
  -3.5269048564885490e-08,    4.6518011697369108e-08,   -7.5934903981466040e-10,   -8.4924522238898060e-08,    7.0285558573001175e-08, 
   3.8084206122098097e-08,   -5.5269253309188077e-08,    4.7795929245733298e-08,    1.0429536893844411e-08,   -3.9285221715526898e-08, 
  -1.5979873468227830e-08,    7.0623045381241664e-09,   -2.8306028666130699e-08,   -2.0005201856888001e-08,    1.8800919344200181e-08, 
  -2.8527082293397609e-08,    3.8386032796612332e-08,   -3.8906574388033187e-09,    4.5375767288143674e-09,    5.6513112459830610e-08, 
  -1.9255397328033050e-08, 
},
{
   1.0719796171993241e-07,    8.3199427365935640e-08,   -4.0529365741888609e-08,    8.7755823722093657e-08,    4.2197628209559828e-08, 
   2.6883253020710628e-08,   -9.9990391085427799e-08,   -1.0151552325076610e-07,   -4.2488219823149110e-08,    1.0553683342487520e-08, 
   3.3270487334671981e-08,    5.8642333698728172e-08,    3.9211827033959253e-08,   -3.7336817198337943e-08,    4.7767471675605378e-08, 
  -4.2357934669159933e-08,    1.1263069331412030e-07,    1.3614720720524970e-08,    5.8205565043270568e-08,   -8.4328415252216907e-09, 
  -6.3550823151513155e-08,   -4.0418029820324242e-08,    6.8983050838697692e-09,   -8.3269881447660323e-09,    1.0079463392137010e-07, 
  -2.9466152701850050e-08,   -3.3754590797787109e-10,   -6.7977000624104914e-08,   -9.7268960102325666e-09,   -2.0017089623150991e-08, 
   1.0836442675596510e-07,    2.3134424874715549e-09,   -2.6650675104411320e-08,   -1.0659899187999330e-07,   -4.8810626144485470e-08, 
   8.1707928150756998e-08,    1.2026768299596250e-08,    7.3830430107757088e-08,   -1.1179251119048410e-07,    4.7012056247529963e-08, 
   9.7186473366003416e-08,   -1.9515115240073241e-08,    6.6054997633427127e-08,   -1.8708421375589420e-08,    1.5034955386022581e-08, 
  -1.0865082700048109e-07,    2.2449081799764321e-08,    1.1452550163553801e-08,    7.1124305689778756e-08,    5.2740137523616447e-08, 
   1.3691364917272610e-08,   -9.2681462753583683e-09,   -4.1161019223282620e-08,   -1.7672853921606941e-08,    1.8050146388353049e-08, 
   2.5155932496392229e-08,   -8.2071719711664200e-09,   -3.6716978291219003e-08,   -1.5962763701681520e-08,    2.0212472566844680e-08, 
   3.6085656631686698e-08,   -6.2079380929852770e-09,    6.1419783719518103e-09,    8.4355508741461467e-09,   -7.5785809211491802e-09, 
  -3.1540365747448902e-09,    1.3059243935779441e-08,    2.6074913879975441e-08,    2.8232459150080959e-09,   -2.6158484508233790e-09, 
  -2.3761634344636101e-09,    1.0813245864093461e-08,    3.3671248775671782e-08,    2.5201712831273741e-08,    4.6237802256801737e-09, 
   1.3216404078550699e-08,    1.4791030326727730e-09,    2.0800712258151200e-08,   -2.3900170752780868e-09,    1.3299013133179270e-08, 
   4.3964054988727550e-09, 
},
{
  -2.4466821475645600e-08,   -2.6716533044487591e-09,   -7.2544669649419614e-08,   -3.2736783199659467e-08,    3.7851610019159781e-08, 
   5.1890763975186212e-08,    3.3708262897174648e-08,    3.5931009870256988e-08,   -7.3817974736042964e-09,   -4.2685258985361598e-08, 
  -8.7602100996216848e-08,   -2.6890924444447519e-08,   -1.0868277448053400e-07,   -7.2522229447115873e-08,   -5.5594018064779924e-09, 
  -1.2123269508550411e-08,    6.3796262698772451e-08,    1.1726912716674980e-08,    6.7135385454244386e-08,    1.9663700560578720e-08, 
   5.0430699402187613e-09,    9.1859461635090196e-10,    5.5442014524559542e-08,    4.9991835706266949e-08,   -1.4693885308817781e-08, 
   5.5075897055935548e-08,   -1.5309772857120120e-08,   -3.9846423793424633e-08,    7.4039577562575084e-08,   -1.2708975149658069e-08, 
   4.2389965745143490e-08,   -9.0228954967828103e-08,   -3.3637956681838890e-08,   -1.0237156989508740e-07,    4.4297320015627717e-08, 
  -3.4076762837327649e-08,    4.2192228750503132e-08,   -1.1811188081236310e-07,   -2.3819711611368600e-08,    9.4195726890302187e-08, 
   1.2331926439725090e-08,   -6.8356932414673131e-08,   -5.5789097880558622e-08,    6.1895517531316857e-09,    2.9116782959401359e-08, 
   1.4265682580740531e-07,   -8.8356225965377634e-08,   -6.4760424058702144e-08,   -3.9826277930573432e-08,   -7.5906935850517477e-08, 
   9.8672161286397219e-09,    2.0659809230717871e-08,   -5.8253254250571808e-08,   -3.9453247431161773e-09,   -1.5453009145983490e-08, 
  -1.0065623045060870e-08,    6.4678697152749798e-08,    6.9102225799175825e-08,    1.2211266501666981e-08,   -3.1701203022192550e-08, 
  -3.5969777153588152e-08,    1.1654300141701580e-08,   -4.1135319043058731e-09,   -7.4714099779694468e-09,   -1.7431396789402969e-09, 
  -3.2480237129338427e-08,   -2.2636362469650320e-09,    3.9752977211401869e-08,   -4.1201164173970150e-09,   -1.9071890092420050e-09, 
  -1.0675912037546300e-08,   -1.6867147025880710e-08,    6.7612347551718191e-09,   -9.0103490948792256e-09,    5.7580821456753441e-09, 
   2.2528547467379860e-08,    1.9236683341945871e-08,    3.2723809997015163e-08,    1.5739454322480252e-08,    2.0756800713408912e-08, 
   2.1001965327917288e-08, 
},
{
   5.3066022003621437e-08,   -2.1968332747551540e-08,   -3.0840437495884448e-08,   -4.4469896535062468e-08,   -7.5655211066112850e-09, 
   1.3952729851129290e-08,    1.2638028137007560e-08,    7.5225923562368944e-09,    6.9193895041098138e-08,    4.9309943027769407e-08, 
   2.6372866601972559e-08,   -3.5211105586851789e-08,   -1.3572773598540909e-07,    5.2595884906077529e-08,   -1.0999591526209771e-07, 
   1.1349722928786700e-07,   -8.7686464926144181e-08,    1.5012106749066642e-08,   -4.2278595866491158e-08,   -5.7579508769270537e-08, 
   4.1103919023345968e-08,   -1.9730249807614719e-08,    3.9443958851055717e-08,   -2.8159240767129948e-08,   -5.7817890838879190e-08, 
  -1.5017910423016839e-09,   -1.1040468272218790e-08,    1.8625166975217659e-08,   -4.5808062259144511e-09,   -3.2574403218796780e-08, 
  -2.3482682177554769e-08,   -1.2517418053937010e-08,    2.2088137286030979e-08,    2.2138057630585382e-08,    7.2841636235943371e-08, 
  -2.7400516712105909e-08,   -1.5831748222012730e-08,   -1.2248817840432460e-07,    4.2118175811780448e-08,   -2.8033365586129430e-08, 
  -6.7038586580409795e-08,   -1.3908385672116930e-09,   -9.0848449752461647e-08,    5.7517781137046648e-08,   -1.7559317091249239e-08, 
   1.5292837930746640e-08,   -1.4124569438263821e-07,    1.4713449426785701e-07,   -1.4490673119231450e-08,    5.8241696161682048e-08, 
  -3.9377256236388550e-08,   -6.6624987073184105e-08,   -1.5390784582860119e-08,    2.3609855345166711e-08,    3.1331887295154102e-08, 
   5.3148542810257822e-08,    5.6560670984931104e-09,   -7.5416563810170281e-08,   -6.8686622162162595e-08,   -6.1226247817557383e-09, 
   4.2852299221085888e-08,    1.8568547550282429e-08,   -1.1500339104735390e-08,   -4.3090253077911542e-11,    8.0779319148836901e-09, 
   2.9102735381094030e-08,    7.3412240002891084e-09,   -1.4108928666897930e-08,   -4.9923372973142299e-09,   -1.9528244915968349e-08, 
  -1.8079336718714960e-08,   -1.7072216033031659e-08,   -1.9817637709924071e-08,   -8.0644078505365197e-09,    1.5869731761827809e-09, 
  -7.0347199851672618e-09,    2.6620112804347770e-08,    2.6024658824095321e-08,    3.0006950515014808e-08,    4.1591832853395818e-08, 
   1.4920507656653200e-08, 
},
{
   1.8183459032732659e-09,    2.6051927992495871e-08,   -1.0134355839673150e-08,    5.3202827198090260e-08,    9.0026651213638856e-08, 
   8.3317364677176902e-09,   -9.1631664850956703e-09,   -2.2752655202284079e-08,    2.0359281649318981e-08,    2.2793754906479860e-08, 
   3.0349490906782340e-08,   -1.0464139564663590e-09,    6.7101554496870464e-08,    1.1224855683888149e-08,    1.8923122289816299e-08, 
   1.1067875281430060e-08,   -9.7964463362823706e-09,    2.5102121647612108e-10,   -6.9071860661362365e-08,    6.2220402666774291e-08, 
  -2.4645662834438291e-08,    1.1851628452068391e-08,   -5.7185005444179608e-08,   -6.8223851181465220e-08,   -5.7254998897842733e-08, 
  -3.4302255994406162e-08,    3.9941386102419489e-09,    2.0793584765986390e-08,   -6.9851857908156664e-08,    3.4663095824221259e-09, 
  -5.8934570584880498e-08,    3.5862897194960017e-08,    6.0744666629907207e-08,    4.6071502629398033e-08,    9.6218257796546582e-09, 
   3.4995215911192512e-08,   -3.3434991659727018e-08,    6.0659863233175354e-08,    4.4074049448197022e-09,    7.2678982196797887e-08, 
  -2.3701097252137931e-08,   -2.8006145007972320e-08,   -2.5582225100060149e-09,    1.3652878643040739e-07,   -1.8860928689845420e-08, 
  -2.1445895294115520e-08,    1.2506343805339171e-09,    1.4104959906971319e-08,   -8.5825814090879360e-09,    4.0424701944199478e-08, 
   2.7571321637423639e-08,    5.8168004029702173e-08,    3.9701694424485078e-08,   -4.7797012917056901e-08,    6.8366852961632361e-09, 
  -2.9732342377243180e-08,   -2.4298702145464441e-08,    1.5659575360552299e-08,   -1.0742059006886089e-09,    3.3194866195169478e-08, 
   3.4023828374198462e-08,    1.7927001976014230e-09,   -2.7907183126807700e-08,   -1.3600043604844320e-09,    3.3174845311097328e-09, 
   5.7892016321729959e-09,    4.2572312647152401e-08,    2.6056621586497721e-08,   -5.9818467585085322e-09,   -2.2532828133696391e-08, 
  -9.9543454356126783e-09,   -6.9725754731764660e-09,   -1.6967058726840290e-08,   -2.1269195383781701e-08,   -4.3940549399125883e-09, 
  -2.2513525598338389e-08,   -1.1404204479013769e-08,   -1.4328969595886900e-08,   -4.0363436125631082e-08,    3.6945342616492559e-09, 
  -4.4130987055631422e-08, 
},
{
  -9.0336249640170878e-08,   -2.0011329156204451e-08,   -7.4066104086250536e-08,    3.1840012781999389e-08,    9.3009448368906320e-08, 
  -1.3102674596668469e-08,   -8.8122254176770371e-09,    8.9441389869943966e-09,   -4.7559903158973998e-08,   -2.3998217097359761e-08, 
  -2.7923311429486300e-08,   -1.8663789655520981e-08,    1.0473935783813820e-07,   -8.4039896860963830e-09,    6.1960720902588381e-08, 
  -1.3053510212506910e-08,    7.9365091027521089e-08,   -1.3071448281776950e-08,    2.7022559026842270e-08,    8.0456306652160750e-08, 
   5.3048318352020974e-09,    1.4639167924278990e-08,   -3.4467977713549492e-08,   -3.9901537310457901e-08,    1.5034522215739651e-08, 
   6.1340681274206774e-09,    3.7957000702939700e-08,   -1.6229061557653159e-08,   -3.8470248635591917e-08,    3.1860141170626899e-09, 
  -3.6157018585747122e-08,    9.4098714309385847e-08,   -1.6552897447257321e-08,    5.7083405416726230e-09,   -2.9381533458598369e-08, 
  -1.2038435759850531e-08,   -4.2199573302385932e-08,    8.4979491220722245e-08,    1.0270838687361911e-08,    3.2175051925216962e-08, 
  -2.7951691934561069e-08,   -4.7709422194968472e-09,    1.1413175256445880e-07,    1.9555034319472171e-08,   -1.0326269581702030e-08, 
   2.0341197365456051e-08,   -3.9402913988663077e-08,   -5.6545643851863878e-08,    1.3183786875221599e-07,   -1.1260526377236121e-07, 
  -1.0635221628594400e-08,   -4.6731148814368423e-08,   -4.7249561144026993e-08,    4.7589248753034038e-08,    3.7343882195670112e-08, 
  -3.3983604958279119e-09,    2.6655237671409591e-08,   -2.1709226762107781e-08,   -1.5462558454324460e-08,    1.1967295783702781e-08, 
   6.8721394585309690e-08,    2.0059662005921528e-09,   -5.8975984561641613e-08,   -1.6660034054480110e-10,    9.1325709578375970e-09, 
   1.1002498982300290e-08,   -2.2791133905584561e-08,    9.3887282819033627e-09,    6.6094156933658179e-09,   -2.7007489870656691e-09, 
   2.9936712231288798e-08,    1.7294441517682801e-08,   -1.8010949037562939e-08,    1.8182500570283501e-08,   -2.6102567975111900e-09, 
  -1.6396642101500341e-08,   -8.3725776177244450e-09,   -5.7245831551523511e-09,   -1.5982186385014810e-08,   -1.9515174299654600e-08, 
   9.9399969558360569e-09, 
},
{
   1.0172719809899609e-08,   -4.6000606601472322e-08,   -4.2575092353870551e-08,   -3.9439367510788582e-08,   -2.3184611520204991e-08, 
  -2.1274731423139899e-08,    4.0675867295780418e-08,    3.7220465089297659e-08,    1.1527250499104450e-08,    1.0914696187723860e-08, 
  -1.3302497453274750e-08,    3.6421059241948541e-09,   -4.4412396872398852e-08,   -1.0002921042260560e-08,   -6.0598476698240894e-08, 
  -1.4638954657635631e-08,    4.7651494645735779e-08,   -3.4637835249061759e-08,    5.4608578248483528e-08,   -1.0942297172432180e-08, 
  -1.6932289464471600e-08,   -2.1754507960562560e-08,   -3.4596063089222498e-08,    4.8584499142797093e-08,    1.9077209840090000e-08, 
   2.9036834928663789e-08,    3.7206048721621843e-08,   -4.1254092172753478e-08,    4.9105275517027700e-08,   -3.1449739233846041e-09, 
   4.7357700819729942e-08,    4.2723201776514092e-08,   -5.5388812557025377e-08,    2.1112663812877810e-08,   -3.4294171926132021e-08, 
  -4.0104793213949626e-09,   -5.6358286053356656e-09,    7.0853251954796677e-09,   -1.2385049538435350e-08,   -5.4587681320482082e-08, 
  -1.0094153922805679e-09,   -1.4037285758001351e-08,    2.2357274453810929e-08,   -1.7818932260147350e-08,   -3.7636204272158362e-08, 
  -8.9532491837207754e-08,    6.4742134407597066e-08,   -3.8175920466331883e-08,    1.0087023421292490e-08,   -8.3893778506802932e-08, 
   6.3310931071962905e-08,   -3.2426966034316778e-08,    2.7758360215090049e-08,   -7.3657968897853362e-09,   -8.3108567351798986e-08, 
   3.5777826327563280e-08,   -3.3090782260912371e-08,   -7.7057505632743384e-10,    3.2552459967128809e-08,    1.6367778009433800e-08, 
  -5.0405170622168029e-08,   -4.1804341485481527e-08,    5.6537902950171400e-09,   -3.1947010347959359e-08,   -4.0373010107807598e-08, 
   2.5315974135675959e-08,    3.6806906177224138e-08,   -2.1929380770970351e-08,   -2.9828341034869078e-08,   -4.8995486788421879e-08, 
  -3.4696480864670082e-08,   -4.2692532548815768e-08,    1.3317126321925800e-08,   -2.8270557313784499e-09,    1.3636799004785460e-08, 
   1.4139798253564869e-08,    2.3979956644393480e-08,    3.1689199109142038e-09,    3.8193030778588059e-08,    1.2136339665175671e-08, 
   4.5078308829264612e-08, 
},
{
   1.4157647949965829e-07,   -5.0465401285307434e-09,    3.8002915272366179e-08,   -2.4919100537213499e-08,   -2.0719026291426401e-08, 
  -5.4059556337885757e-08,    5.2310566613043178e-08,   -8.5192448435310319e-09,    3.1827816790805160e-08,    3.2781688335376748e-08, 
  -2.5820559835019550e-08,    3.9530294301079856e-09,   -5.8344190655475947e-08,    2.0111357105294489e-08,   -6.7740190638225453e-08, 
   4.9823097696748937e-08,   -2.4066271282983172e-08,   -3.2933308128325968e-10,   -5.1026025277596713e-08,   -5.9666734494806858e-08, 
  -4.1841399284242977e-08,   -2.4067375212202860e-08,    1.3892672880795980e-08,    1.4446762547443650e-09,   -9.5208092046963296e-09, 
  -8.1096146062156972e-10,    3.3144313356696022e-08,   -1.1133624841478869e-09,    3.0297015546051037e-08,   -2.8462300498112501e-08, 
   6.3047674075322833e-08,   -1.2902144742637890e-08,    3.0675953304965422e-08,   -4.0987304628856543e-08,   -2.2011655861774171e-08, 
  -1.6886724287599250e-08,    2.3883933279817601e-08,   -1.6687012678264368e-08,   -8.9625479508237292e-09,   -3.5906860360573508e-08, 
   6.3522211342457646e-08,   -1.5162775455964760e-08,   -6.2716570436003506e-09,   -7.5669723906276909e-08,    1.2467321887836670e-08, 
  -5.7507075673079717e-08,    7.7238528885076455e-08,   -7.6892238928919501e-08,    8.1723772372625720e-08,    2.7064741304335260e-08, 
  -7.8655304961772721e-08,    2.1036377950648129e-10,    7.1544713892764217e-08,    2.9826211749575053e-08,    5.5548242411778523e-08, 
   1.3136323014289839e-08,   -2.1254117753256249e-08,   -1.4524205674211550e-08,   -8.8440457924636710e-09,   -2.9418514317946751e-08, 
   9.3091893442430223e-09,    2.1319212441324321e-08,    2.3212297956107098e-09,   -1.5081366020778491e-08,    2.6453080769705749e-08, 
   4.5639925827968687e-08,   -5.4163027325769578e-08,   -9.9129065883353414e-09,    1.0400901583622770e-08,   -3.3509274100875748e-09, 
  -3.8675690405383247e-08,    7.5392364674283107e-09,    2.6504284412248671e-09,    1.8874294804080831e-08,    1.8106664634766931e-08, 
   3.5138122344853688e-08,    1.8575295478563220e-08,    1.5983899109469341e-08,    2.4893470078327248e-08,    3.3685374825783310e-09, 
   3.4671956334330237e-08, 
},
{
  -1.3459597844272500e-08,   -2.1435559836597338e-08,    3.0850031943561448e-09,    2.1683500372067279e-08,    3.4422439963500421e-08, 
  -1.8854105667822909e-08,   -1.3272662627538630e-08,   -4.0081109799497060e-08,   -6.2623816165508583e-08,   -6.2506643838801157e-09, 
  -2.3374649723249150e-08,   -4.6538292713927427e-09,    3.4682409657114919e-08,   -3.7326778289763820e-08,    2.5780522864083821e-08, 
   5.6629472909395948e-08,    5.6223103817103081e-08,    3.8939007315884322e-08,   -3.6922133821202410e-08,   -2.9821353916073302e-08, 
  -1.1495118139598379e-08,    2.8599563504452438e-09,    4.4209988486807582e-08,   -5.0994668094025687e-08,    1.0282440206743350e-08, 
  -4.2957902037936510e-08,   -1.9472123432831432e-09,   -9.5346373542353120e-09,   -3.4991597752384633e-08,   -3.5729047384193128e-08, 
  -2.8469935204260430e-09,   -1.7588938173710099e-08,    2.7637435278865389e-08,    8.8179277427948425e-09,   -7.1549393377880877e-09, 
   6.5342450503192279e-08,    2.6370392520937161e-09,    1.4630482125012401e-08,   -4.2945144119608581e-08,    3.5743456986383649e-08, 
   8.1590490393667676e-08,   -4.9284491497796671e-08,   -7.4847824791414388e-10,   -4.0222254874502539e-08,    9.3317756497593797e-08, 
  -3.3405316514918087e-08,    4.8117475078108067e-08,   -7.8104320931308959e-09,    2.6523736965108922e-08,    5.9735502015113152e-10, 
  -7.6718587761634898e-08,    7.1649831664664959e-08,   -7.0651930540010530e-08,   -4.1950384236510232e-08,   -3.3194791172936609e-08, 
  -3.9405376929366047e-08,   -2.5413271840268719e-08,    4.2567249395158992e-08,    6.8249763828672906e-08,    3.9070291708969212e-08, 
  -1.2569698684176491e-08,   -4.5417003465731510e-08,    3.7861444823119718e-08,   -1.6508195158349051e-08,   -5.2838568901772328e-08, 
  -1.3031666041770171e-08,    8.8823811106076984e-09,    9.9335228524425774e-09,   -3.8245337922748310e-08,   -2.0037012000484638e-08, 
  -1.5952667327444799e-08,   -3.0878355546524647e-08,    4.9328447297288087e-09,   -2.5137219351314269e-09,   -2.6317381627957099e-08, 
  -1.0197093108604670e-08,   -2.8128754088149558e-08,    2.0995695694403159e-08,   -2.6561726441059431e-08,    1.1886220694606540e-08, 
   1.7753071244395349e-08, 
},
{
  -1.0770557778749000e-07,   -7.9586940432080087e-08,   -3.8896999892434102e-08,   -3.3140152676634049e-09,    2.1952192711956989e-08, 
   2.2621073263953149e-08,   -7.3904952552898120e-09,    2.3073769709322511e-08,   -3.5933127317170791e-08,   -6.4979961127410968e-08, 
   8.2265363238743723e-09,   -7.3516296354175441e-08,    4.4490481568391131e-08,   -4.9297223414475121e-08,    6.3555181447773866e-08, 
  -2.7650738137218371e-08,    4.7985593815185722e-08,    1.3581147762298280e-09,   -2.1243464334118012e-09,    5.2731420460539853e-08, 
   3.6232278648845402e-08,    3.5681365916782293e-08,    1.0896735238304449e-08,   -1.7651577544800530e-08,   -4.6351326670846422e-08, 
  -9.4697605834800430e-09,   -3.6716371681056410e-08,    3.8083286492210570e-10,   -5.1839954778737063e-08,    2.3769432318296619e-09, 
  -2.7982829983926771e-08,    1.3165185712010400e-08,   -7.8186216052302933e-09,    2.0761917487267559e-08,    3.3432039816190612e-08, 
   2.1523009086677050e-08,   -1.5649192586338270e-08,    1.9236863718464739e-08,   -4.4067169866758172e-08,    4.5527074760768132e-08, 
  -5.2115468198459698e-08,   -2.7703139523506828e-08,   -6.9677744138901222e-08,    6.0811877672992776e-08,    3.2832347845314159e-08, 
  -4.1281866726819281e-08,    6.5934142496894346e-09,    1.9157556304477480e-08,   -7.5389297257785775e-08,    3.0218896960282821e-08, 
  -8.9359338973498389e-08,    1.6063833192547140e-08,   -1.1917850450220031e-08,    9.7962180638266727e-09,   -4.5183423878581021e-08, 
  -4.8324882271014676e-09,   -3.4896744810624000e-08,   -2.3690015587008630e-08,    3.8747326759475668e-08,    1.3113418525450011e-08, 
   3.3962232603378542e-09,   -1.5142561871762940e-09,   -3.8150568764116004e-09,    3.2246974551837960e-09,    1.6024365607515441e-08, 
  -8.9546432656163951e-09,    1.0225322836894311e-09,   -1.7315652243657551e-10,   -2.7938667603039981e-08,   -1.2245001428011511e-09, 
   2.5485633978498751e-09,   -2.6784892522196278e-08,   -1.5376969443525919e-08,    1.1406429223801971e-08,    5.3529327504559966e-09, 
   1.0681455381124931e-08,    8.3390598556216579e-09,    1.9510573348419811e-08,    2.1111791659573111e-08,    2.7664945312980119e-08, 
   2.6483685256206909e-08, 
},
{
   4.1656444281045878e-08,   -2.1721909216359851e-09,   -2.0811133913028741e-09,   -1.8205948135763891e-08,   -2.1041597028035310e-08, 
  -1.9805104368574410e-08,   -1.4993717253759462e-08,    4.5667290438653139e-08,    1.9711901123881930e-08,    5.1096919194120650e-08, 
   4.6393708341138223e-08,    7.1800656224742564e-09,   -6.0142679556923301e-08,    2.4567721109945991e-08,   -1.2055036245110330e-08, 
  -1.0838656591511430e-08,   -2.7226622049034990e-08,   -9.3264032646212120e-09,   -6.3537119606441156e-09,    1.6921809036510418e-08, 
   1.5835361411647181e-08,    9.7529859432950851e-09,   -1.7661974329943021e-08,    1.5463684721893759e-08,   -1.0863182835033330e-08, 
  -1.7030074324832309e-08,    1.2402559308799151e-08,   -3.2630560970930430e-10,   -1.3214778203739550e-08,    4.6161104813679561e-08, 
  -3.2706828381456332e-08,    6.1512672049866501e-08,    1.5699836962563740e-08,   -2.1153986027313799e-08,   -3.0479096304568638e-08, 
  -6.2022321859295414e-08,    9.5648409726558960e-09,   -2.2491318978290600e-08,    2.6040844656555329e-08,    3.3476912203896157e-08, 
  -8.6155361382133705e-08,    6.2703453874591142e-08,   -4.9174179537698131e-08,    1.1049247406638631e-07,   -4.2941186913526887e-08, 
   4.9242933525227847e-08,   -2.7167517524648439e-08,    2.0290009300674261e-08,   -6.3839178227448414e-08,    7.8701606316707617e-08, 
  -6.3253751970260930e-08,    3.1663668748921298e-08,    1.0178324076333870e-07,   -6.8906317081097721e-08,    4.7513077720641098e-08, 
   6.9657504196109252e-08,    6.5192698677921143e-09,    7.1003456137053826e-08,    2.3737682516615220e-08,   -5.1609046219115410e-08, 
  -3.4218740125707981e-09,    2.9132938123487250e-08,    5.7302906541253018e-09,   -1.2238570956266640e-08,   -1.9117351656597601e-08, 
  -1.2367589994689249e-08,   -3.3864393915753492e-08,    8.0448539923811934e-09,   -7.1081539754366030e-10,   -4.0972477236838367e-08, 
   1.0061847376391740e-08,    7.1702987132682334e-09,    1.5580346865279062e-08,    1.2406339655760890e-08,    2.2252425626580641e-08, 
   2.2043889058061491e-08,    2.7329153380725340e-08,    3.2570864320264948e-08,    3.2754415245410267e-08,    3.7315320924441948e-08, 
   2.1477785942637149e-08, 
},
{
   2.3491811928995782e-08,    1.1211857004569020e-08,    6.0282320372300103e-08,    4.3727885184963341e-08,   -2.4228687045471161e-08, 
  -1.9550955358517451e-08,   -4.4698503381971988e-08,   -1.7445936216360080e-08,   -7.7427771586048054e-09,    2.9356063667929791e-08, 
  -1.5072675889248700e-08,    1.9838048143693171e-08,   -4.1393872946390063e-08,    3.6389985182290558e-08,   -5.3230826865349597e-08, 
   1.5888344512036701e-08,   -3.1213765163699148e-08,    9.6767939090607247e-09,    3.5311423634545988e-08,   -6.6440525931938527e-08, 
  -1.7140178972305481e-08,   -7.5983263026241240e-08,   -5.3634574743682917e-08,    1.7832090824118700e-08,   -7.4793148216454751e-10, 
   7.7264677944890839e-09,    4.0800283942105582e-08,   -1.7581841044420280e-09,    2.2477820102354201e-08,   -9.4831705493118918e-09, 
   2.1802672309297258e-08,    2.1734143961999582e-08,    3.6391188947904399e-08,   -1.6223554683601911e-08,   -1.3037337002686940e-08, 
  -2.8373306059328259e-08,   -1.5123091187137830e-08,   -9.5007356401955401e-09,   -3.6358336030659881e-10,    2.1777990528632989e-08, 
   8.4227815420622237e-09,    1.6410550192500098e-08,    2.2202981900827571e-08,    4.8427088590005712e-08,   -3.1413798106671843e-08, 
   5.3303213636083299e-08,   -5.2970215357704147e-08,    2.9724165786258649e-08,   -2.7153787256252349e-08,   -4.6582548862016393e-09, 
   9.6908722492313610e-09,   -9.6481014932877989e-10,    5.8929881779204942e-08,   -6.0139427876213703e-08,    2.5146386421732519e-08, 
  -5.4398801812037843e-08,   -6.6889995585567767e-09,   -2.1058372235603781e-08,    3.7081685359186161e-09,    7.1654115252568636e-09, 
  -1.7916046801928911e-08,    1.3295320170211629e-09,    2.1185601523102210e-08,    3.7634078455465097e-09,   -1.3822363141095040e-08, 
   4.7425549068939584e-09,   -1.1252877422222160e-08,   -1.9606476005546451e-08,   -1.1798201001950800e-08,    3.5865636994738991e-09, 
  -1.0121100056995580e-08,   -7.4298850862300856e-09,    1.3196373038602211e-08,    8.4763716554278461e-09,    1.6066201576665580e-08, 
   3.9494115243290252e-08,    9.7091141641523790e-10,    3.7145136854223909e-08,    1.8199323664615899e-08,    2.9703556083205730e-08, 
   2.6213441306470079e-08, 
},
{
   3.9514870435299713e-08,   -1.4572008323947151e-08,    6.6842630552045087e-09,    1.4256829781278420e-08,    3.7895570193812956e-09, 
  -7.0267276107722340e-09,    1.7039893002879262e-08,   -1.5369846125183719e-08,   -4.1303575042149707e-08,   -1.7802875815949711e-08, 
  -3.4347539063149912e-08,   -2.7800604308575421e-08,    2.4090662325969111e-08,   -3.3801457283124670e-08,    8.5375653220950286e-09, 
   8.6772124063542034e-09,    2.7525580536844280e-08,    3.6659358735423610e-08,   -6.4441967139306905e-10,   -7.7889674318441348e-09, 
  -6.0642737543763621e-09,    2.9918164273647073e-08,   -1.7248553870907171e-08,   -4.2173396292640086e-09,    9.3620343855328087e-09, 
  -1.1146747060136371e-08,    1.8524878935786270e-08,   -4.0120425280531513e-08,   -1.3908576065961330e-08,   -5.6340321229327222e-08, 
  -2.5004109572925729e-08,   -3.2452109194103029e-08,   -1.6401826604118110e-08,   -1.3943481594436500e-08,    1.1644996746541840e-08, 
   6.3117998229222828e-09,    2.0918159294583550e-08,   -4.0253426495363707e-09,    4.0094057796099357e-08,    2.3226980951240850e-08, 
   1.8715156588865940e-08,   -6.6846435652822617e-08,    6.6096468373952753e-08,   -7.8582760780144568e-08,   -1.4791229842654950e-08, 
  -3.4108191093865003e-08,   -8.9538854076998225e-09,   -3.1083742120194639e-09,   -1.3374928239397191e-08,   -3.4068124375425501e-10, 
   2.5257480614649641e-09,   -1.5373391967241461e-08,    3.4829088506542142e-08,    1.5391096176413441e-08,   -4.1312492468982162e-08, 
  -9.8051494924926283e-09,    6.2867991403505636e-08,   -1.0499416242555700e-07,   -8.2067734075626998e-10,    2.3715074606582080e-09, 
  -2.9945665088491297e-08,    6.4656896720422606e-08,    2.7965100961511900e-08,   -4.9862906019926931e-08,   -6.8567957419056142e-09, 
   1.0491020009097320e-08,    8.3354258331500852e-09,    2.4779337805286791e-08,    1.5281431067373809e-08,   -1.0231918583867300e-08, 
  -4.1218471396085418e-08,    1.1789407325686600e-08,   -1.4359946183019991e-08,   -1.7711757980606270e-08,   -6.3020580377855023e-09, 
  -3.1543715348338600e-08,   -2.4275167790506142e-08,   -1.5141392099066842e-08,   -8.1947242971174589e-09,   -1.0894082730477291e-08, 
   1.2019962018136821e-08, 
},
{
   1.7750185036482870e-08,   -7.6165251339757678e-08,   -1.5054903643693332e-08,   -3.3010270260414909e-08,   -1.9352611895628521e-08, 
  -3.0278638914855682e-08,    1.5830410793047949e-08,    1.8826249672075399e-08,   -1.5072982855835211e-08,   -3.3534152808031299e-08, 
   2.0485320872554110e-08,   -2.3549993100805021e-08,    1.9446206959575118e-08,   -4.5368225288631197e-08,   -1.8483807864022450e-08, 
  -8.0460750479536309e-10,    4.0704550615353212e-08,    3.7491483020845831e-09,   -6.3934099899106214e-09,    2.5265777071564379e-08, 
   1.3380551924737540e-09,    3.1950356789542478e-08,    3.0432449984705691e-08,    9.5349773671057287e-09,    2.9068723779422362e-09, 
  -9.4023525814261527e-09,   -2.7461362896829349e-08,   -5.3321988305912846e-09,   -1.2162546127106290e-08,   -4.5657689848635303e-08, 
   1.0570594075490550e-08,    4.8910497644944897e-09,   -7.0290099949869814e-09,    1.4425864738889961e-08,   -2.4663480766096390e-09, 
   1.6876051399852439e-08,   -7.0802809683391209e-09,   -1.6646635097155158e-08,    1.9688765599996850e-08,   -4.3380426291088820e-08, 
  -6.7972245257240449e-09,   -8.2250945164371586e-09,   -2.7445455755822611e-08,   -6.8780516844109125e-08,    8.8408079487054164e-09, 
  -6.2113473636493449e-08,    7.2924442906163590e-08,   -4.3551560493261098e-08,    2.5304555690119780e-08,    4.8514433884466287e-08, 
   6.5906394738951313e-09,    3.1492453053932372e-08,    1.6503415265138121e-09,   -3.3805643074269583e-08,    1.3899542785488351e-08, 
   1.4126817716778359e-07,   -4.0123407345616477e-08,    5.9397751117805988e-08,    5.9131586715797702e-08,   -2.3803196729421090e-08, 
  -8.5821146174170129e-09,    2.2187588995929750e-08,   -8.1106326561041778e-10,   -4.7795036028833409e-08,    2.9029196654898119e-08, 
   3.0446553284564849e-09,   -6.9944760388022840e-09,   -3.7134178308185027e-08,   -6.6037981229569761e-09,   -8.2272540097334869e-10, 
  -3.0806810457633602e-08,   -5.3033059572942427e-09,   -9.7638239605024872e-09,   -1.3427624432836259e-09,   -5.7168157396985094e-09, 
  -4.8107615558298053e-09,    1.0473602200355690e-08,   -1.7519450355492612e-08,    1.9487549535547299e-08,   -1.9116598372941910e-09, 
   1.7285407211804430e-08, 
},
{
  -1.6389790284881938e-08,   -3.3685497326864088e-08,   -1.6272429639032039e-08,    1.3439525530206170e-08,    1.6368584240791590e-08, 
  -8.0729568890358501e-09,   -1.4936960045191309e-08,   -3.1417790708495603e-08,   -2.0451938702364369e-09,   -1.1201661074046119e-08, 
   4.2233478341289372e-08,    2.3355590833905001e-08,    1.9876152940267350e-08,    9.7773492056029452e-09,   -2.5455211194516552e-10, 
   2.0227305510350121e-09,    1.4539391121679549e-08,   -3.3698632494569629e-09,   -1.7517136269817741e-08,   -1.9961563366706850e-09, 
  -3.0162880909350401e-09,   -1.8132609646459151e-08,   -1.5796666457768790e-08,   -5.2830499167672012e-08,   -1.5419884256602081e-08, 
   4.9020310280130158e-08,   -5.3435381799614892e-08,    6.2440969854787841e-08,   -1.5722553589094670e-08,    2.9094738968035670e-08, 
   2.0347369544622520e-08,    3.3392689067592412e-08,    5.0425652873628577e-08,    1.2394851169920891e-08,   -1.5438293532936279e-08, 
   2.5868272424564820e-08,   -3.6492181914187938e-08,    8.2754017205747516e-09,   -4.7801829982397867e-08,   -4.5781622243591573e-09, 
  -2.4573951818748611e-08,    1.9896704641882961e-09,    1.9616284961735720e-09,   -2.1773151329278190e-08,   -1.9625091623408151e-08, 
   7.6198176751553231e-08,    3.5820881327144220e-08,    7.7487657315157255e-09,    2.6820681196692042e-09,   -1.6947411657877081e-08, 
  -6.4046436732056776e-09,   -1.1570563810667690e-10,   -3.2575071175231750e-09,   -5.0938541055425773e-08,   -2.7243615989483830e-08, 
  -1.3467101173673351e-08,   -4.8078870485104472e-08,    6.3662142430205933e-08,   -6.6548671848598867e-08,    6.3395712510759817e-08, 
   5.2290763405760303e-08,   -1.6021621469904140e-09,    5.1950671773504278e-09,   -7.6078998983894673e-08,   -5.7436902457981929e-08, 
   1.7272421765173560e-10,   -7.7008978846624066e-09,    9.9101754211039255e-09,   -9.2143342790255829e-09,    5.8096749493958788e-09, 
   2.7298999535042239e-09,    1.1267532846780861e-08,    2.2042424604762790e-08,    1.5132827763681350e-08,    2.4075334526328609e-10, 
  -1.9292540048521129e-08,   -1.1267257099436710e-08,   -1.1102199313804240e-09,   -1.7385969304235670e-08,   -2.2510357135487770e-08, 
   1.2383489683128910e-08, 
},
{
   1.5924966924562999e-08,    2.9095996986080870e-08,   -7.7062433134402385e-09,    1.9680334210525611e-08,    6.9419737541584444e-08, 
  -3.3069309873431889e-09,    6.0206055639022531e-09,   -2.4984816683585290e-08,   -3.7398071041519379e-08,   -1.7348653702843710e-08, 
   5.0401390086353892e-08,    1.2048348807616160e-08,   -8.0326007048200410e-09,    3.2131377937283973e-08,    1.2082251417561990e-08, 
   3.1307506718065762e-08,   -1.3130877228085870e-08,   -2.3932301146386579e-09,   -1.2479573707963160e-08,    3.4843747062012658e-09, 
   1.9626397354767388e-09,   -2.9257205779927140e-08,   -8.7713858685771111e-09,   -3.8825709417982738e-08,   -6.0395360286349852e-09, 
   2.0124054899183531e-08,    7.4740768845563106e-09,    2.7465497133955132e-08,   -3.3487420235316211e-08,    3.6711216012873239e-08, 
  -1.3128767510777900e-08,   -3.8347685177227499e-09,    4.6358498149770887e-09,   -3.5004298789192041e-08,   -9.7851886351453774e-09, 
   7.0500786720980040e-09,   -2.7325960701347601e-08,    1.3998509257893040e-08,   -5.1146761471813162e-08,    5.4269052639050377e-08, 
  -2.2061955816572789e-09,    2.2316449818608471e-08,    2.8918259082415361e-08,    1.7147740562777871e-08,    5.1543244270833708e-08, 
   5.7042231324263303e-08,   -7.9457083115506605e-08,    3.4053742630076607e-08,   -4.9324278938910268e-08,   -5.4934651340397364e-09, 
  -2.4866048819382560e-08,   -2.8931597834426829e-09,    4.7579921152148172e-09,    1.6348008538981399e-08,    1.6963677848444169e-08, 
   8.2297465056758571e-09,    1.9069834981466719e-08,   -6.1005760103546879e-08,    3.0404168717791852e-08,    1.1992279747726060e-08, 
  -6.7555608702794572e-08,    3.5146698133388512e-08,    7.2605128314059086e-09,    1.5792666009730708e-08,    4.6736651429319048e-08, 
  -8.9443881475131255e-09,   -1.7133916471255260e-08,    1.6914786297516151e-08,   -3.2717129405300288e-08,   -7.8943031116754625e-09, 
  -2.7967469760782049e-08,    6.0310276155844517e-09,    1.4975836860357810e-08,   -1.1638995483247140e-08,   -5.5780076970926549e-09, 
   1.7748789793815890e-08,    1.4157337242761700e-09,   -2.5127423122844169e-08,    3.1117970326566748e-08,   -7.1570880714313169e-08, 
   5.4507766391812109e-08, 
},
{
  -5.2269191539423040e-08,    1.1183726327719681e-08,    2.2152915027637791e-08,    4.9353515402636417e-08,   -6.9539185815160878e-09, 
   2.0020433625436021e-08,    4.6368464974162267e-08,    3.7629174651362012e-08,    2.3820342762430219e-08,    3.0891923032633550e-09, 
  -1.0171279820395430e-08,   -3.5020125986908298e-08,   -1.1205579119765700e-08,    2.6674049173606900e-08,    9.3215676397531324e-09, 
  -2.1600268000035209e-08,    1.4699653481614890e-08,    4.2250810294219830e-09,    7.9659850821092879e-09,    2.6913236517536979e-09, 
   4.1233270172503457e-08,   -3.7200365621068479e-09,   -2.0939165130728381e-08,    1.7027700586923428e-08,    3.9581769608063829e-08, 
  -1.7995425121176219e-08,    2.1871523310841070e-08,   -2.9902266610927467e-08,    4.7044156737569626e-09,    1.5306448205221081e-09, 
  -2.0356843497471229e-08,   -4.4165074507785380e-10,   -2.3250058492860469e-08,    2.0642131984743040e-08,    1.4521584137480251e-08, 
  -1.2251863005692011e-08,    3.7477801504421149e-08,   -3.2988321707420348e-08,    4.7886017097437580e-08,    1.3474235123674951e-08, 
   1.2130463609119161e-08,   -2.7565696280756941e-08,   -2.2802650617593639e-08,   -2.9014997969292449e-09,   -1.2919504987765870e-08, 
  -2.0561091210655040e-08,   -8.8463103236000815e-09,   -3.4855336573876658e-10,   -3.1186651188466933e-08,    2.4107767614797711e-08, 
  -5.6934326330242246e-09,    4.1435796906410363e-08,    1.1888762468345209e-08,    4.9039386929626988e-09,    3.0057873584804788e-08, 
   2.9225038907521109e-08,    2.6403983071577061e-08,   -3.4773117369158840e-08,    3.6637732444766493e-08,   -5.4197484848083507e-08, 
   3.3806073951768470e-08,    1.0314740165104120e-08,   -3.7478064741543372e-08,   -3.4252775468114393e-08,    4.8642575011429559e-09, 
   7.7230576340195572e-09,    7.0295432867863381e-09,    5.5957228805018031e-09,   -2.0126527793621389e-08,    6.3914199971801833e-09, 
   3.4074235087431800e-09,    4.9656381631241759e-09,    2.8421693627135610e-08,    9.8889600397304813e-09,    1.7917471647633479e-08, 
   1.1360752022602330e-08,    9.6148498384901487e-09,    2.3931814635793268e-09,    7.9182961499719944e-09,   -1.3685622855362790e-09, 
   2.8073495024369441e-08, 
},
{
   2.2651535424788360e-08,   -2.9984787445527163e-08,    3.3331254807162938e-08,   -3.2647840865207958e-09,   -1.8799793363084828e-08, 
  -2.5864119973521232e-08,    4.0230875207352959e-08,    5.6899536588022499e-09,    2.5502369443081801e-08,    3.1455792355521943e-08, 
  -3.5575784347795710e-08,    1.3173194177869290e-08,    1.6730592865467559e-08,    8.8098981589738812e-09,   -2.2104077649681929e-08, 
   2.0834762794784641e-08,   -9.1637998362304985e-09,    5.0024857363612302e-09,   -1.8721276925730591e-08,   -2.1092730784263351e-08, 
   2.1408192120022329e-08,    3.8205597192254442e-08,    1.9574575636056719e-08,    3.3326808633736508e-08,   -2.6508552555905430e-09, 
  -5.6268220366364423e-09,   -1.9021180048422868e-08,   -2.2972128426252119e-08,    2.8198960167965300e-08,   -1.4249087220870760e-08, 
  -9.6912610461840986e-10,   -1.7841906031136440e-08,   -3.3095184207837803e-08,    1.4431777555027540e-08,    5.3921040095296828e-09, 
  -9.3566015604112693e-09,   -1.4643991148462480e-08,   -4.1060253450443323e-09,    2.7525666149222099e-08,   -3.1128483256093937e-08, 
   2.1499168174430421e-08,   -1.7661700212443208e-08,   -8.8137084110374962e-09,    7.6737763879791016e-09,   -1.3264958891253770e-08, 
  -3.2671481821249171e-08,    4.8770163670524769e-08,   -3.0695640747835691e-08,    3.3338897659264088e-08,   -2.5104549570906841e-09, 
   2.3431408908594790e-09,    1.3070549173928720e-08,   -1.7557956528633160e-08,    4.4413621448349266e-09,    9.0897022651945428e-09, 
  -6.4093659413410866e-08,   -2.0851446900970661e-08,   -1.3499097103984430e-08,   -4.8187228617949988e-08,    1.3195419173401981e-08, 
   2.8593707509686582e-08,   -4.1407423035896688e-08,    5.5979029634435751e-08,    2.5829311090825919e-08,    1.0619620266283410e-10, 
  -1.7222850065129111e-08,   -6.6553701157538390e-08,    1.3121462219589649e-08,   -1.7207105471158540e-08,   -7.7984903301219645e-09, 
   6.0514850047505811e-08,    2.0293526490477559e-08,    1.4539943854966291e-08,    2.3092662969079811e-10,    3.0129310624357247e-08, 
   7.3560537701318419e-09,   -6.1566914554129924e-09,   -3.7151541335308279e-08,   -3.6254812177093158e-08,   -1.4577961521527960e-08, 
  -6.8865787626503232e-08, 
},
{
  -2.2088875934790802e-08,    3.2521236160126767e-08,    4.7393585702228732e-08,    8.1100619477578114e-09,    1.4374232953336579e-08, 
  -3.9757987838197107e-08,   -1.5769084210497532e-08,   -1.0496967073751110e-08,   -1.5910304881317700e-08,   -1.5441400708973599e-08, 
   4.2127433292415122e-08,    5.0660334043554637e-09,    3.0935461684387153e-08,    2.2112055523099031e-08,    2.3226932687473031e-08, 
   1.9649645104048131e-08,    8.1179669745568042e-09,   -1.5884841625309151e-08,    1.7670204724543481e-08,   -2.7368683972921899e-08, 
  -7.8802683142366845e-09,    1.1272521808559980e-08,   -3.0975426084543849e-08,    8.6978868777464409e-09,   -1.8491414748868068e-08, 
   3.3779675058182972e-08,   -2.6836181875339582e-09,    3.3610641602111607e-08,    7.3303752073192388e-09,    2.8649671796700241e-08, 
   1.1291487103603969e-08,   -2.7569789564735349e-08,    3.1577510302840738e-08,    5.8679802259371616e-10,   -1.1477146333922850e-09, 
  -8.4019414365513006e-09,   -9.5999339767452981e-09,   -2.9000352325950949e-08,    4.2213139440540787e-09,   -1.5497264978552102e-08, 
  -1.2609775667311759e-08,    1.2602239023716139e-08,    3.1929626108722987e-08,    1.6512977570142780e-08,    2.0677079745552301e-08, 
   2.0167512122980110e-08,    6.8898336547070298e-09,    3.1835869509672691e-09,    2.0864299491934471e-08,   -5.7972944552728618e-08, 
   4.2512188872395838e-08,   -5.6997555582699983e-08,   -1.0272219459390701e-08,   -3.2225383168231701e-08,    1.4362518907252709e-08, 
  -4.7913699208843419e-08,   -3.8687964516931830e-08,    1.7126155435824730e-08,   -1.8450902782090610e-08,    4.5503356796074732e-08, 
  -7.5616956756271098e-08,    5.2319776819197819e-08,   -3.1215048975303773e-08,   -1.6628989592644491e-08,   -6.3131986269690911e-10, 
   2.4720488679536151e-08,    2.8429277587590271e-08,    3.3906855794908860e-08,    1.7720872432398209e-08,   -1.8494273870061432e-08, 
   1.2648422962004901e-08,    2.5810442308040902e-08,    1.6440552812411529e-08,    4.7745083076850391e-08,   -1.3048173614386310e-08, 
   9.6979252154748365e-09,    3.7706894171803581e-08,   -1.7925278771155179e-08,    3.6200148328790742e-08,   -1.5225954817015260e-08, 
   2.6744454027209451e-08, 
},
{
  -8.9365975311230262e-08,    8.1714334232116575e-09,    2.4590842039888232e-08,    4.3104153603246051e-08,   -2.4130754111131971e-08, 
   6.4985926165148760e-09,   -2.1166941664642661e-08,    2.8100413921519548e-08,    1.3795120944056879e-08,   -4.8101211929862044e-09, 
  -1.0118118317467411e-08,   -9.3139166850522820e-09,    6.3355437631645296e-09,    2.6945186382453709e-09,    3.6234693962067358e-08, 
  -1.0319384192510410e-08,    1.7151092609236979e-08,    1.6657425735480638e-08,    4.3540870673701006e-09,    1.0436698163346460e-08, 
  -1.7958417108301542e-08,   -1.1664113135659350e-08,   -1.0973232656097341e-08,   -2.3749175485775999e-08,   -1.7172922202434471e-08, 
   1.8273518403616352e-08,   -1.8952070737695429e-08,    2.4584322369888730e-08,   -1.8370041251986440e-08,   -1.1416285183052660e-08, 
   6.7482106273809683e-09,    1.3380484859282720e-08,   -1.7001480715715291e-08,   -6.3721540402708863e-09,    5.2975867054377384e-09, 
   2.6742010109668769e-08,   -1.4701469821658989e-08,   -1.7074531725919999e-08,   -1.7814299187378570e-08,   -1.0038525100272500e-09, 
   1.1832773538245470e-08,   -3.6581893103833810e-09,   -1.4807107399537140e-09,    2.5950586898876071e-08,   -6.5029971790237901e-08, 
   3.0195507431502353e-08,    5.6198496682383226e-09,    3.6686279312461820e-09,    9.5898773671841230e-09,    4.2758974997714898e-08, 
   8.4098611284313500e-09,   -3.1280643852365022e-08,   -5.6820460819979962e-09,   -8.9356017798620731e-09,    2.1614788154162750e-08, 
  -1.0389687527534931e-08,    4.0027130893790417e-08,    6.4963959932636250e-08,    2.3639019012449221e-08,   -1.8488950216058469e-08, 
  -5.5700540200929453e-09,    1.5023349539380370e-08,   -6.0237139592493736e-09,   -2.2558645110679561e-09,   -4.9151193940631491e-09, 
  -3.9402932663715162e-08,   -4.6036703667574742e-08,   -2.0977839121650411e-08,    1.6002110773292550e-08,   -1.2683397255975710e-08, 
   1.7657362300959040e-09,   -1.5143763158201621e-08,   -3.0101354549421972e-08,    1.0328233855825931e-09,   -1.1458505549839529e-08, 
  -6.0474192455122209e-09,   -1.6121389244903509e-09,   -5.3676492634260516e-10,    1.3707435993822430e-08,   -1.4249148783387310e-08, 
   4.9464024873434183e-08, 
},
{
  -2.2314891242664121e-07,   -4.4106457563709957e-09,   -2.5081905036699061e-08,    4.1737189429632709e-09,   -3.6015801612886979e-09, 
   1.9392998715642450e-08,    1.8703755701938838e-08,    4.5442449577999777e-09,    3.2525287884179197e-08,   -6.7324611707600307e-09, 
   9.1817545738375481e-09,    1.0367939361457540e-08,   -8.0774330138625503e-09,   -3.7446774164464263e-08,    1.1914217891799970e-08, 
  -2.8311597849162219e-08,   -7.4429374406358886e-09,    2.4035489426910522e-08,    1.6298063385002539e-08,    3.4728429204960391e-09, 
  -5.6071100273365661e-08,   -7.3057985316198819e-09,    4.0264187905896720e-08,   -3.0714494159291572e-08,   -2.9424835187963041e-09, 
  -2.7665906223904541e-08,    1.9662374227624631e-08,   -2.4389544807378371e-08,    1.2349279004625649e-09,   -3.5195295471855880e-08, 
  -8.9895652575622185e-09,   -7.5272826765232056e-09,   -2.2013692833669810e-08,   -2.3478906602072390e-08,    5.6175520709770006e-09, 
   7.6057211425958154e-09,    1.8978276808262891e-08,    1.1390580203762179e-09,    2.9031052627424770e-08,    4.8634086698810154e-09, 
  -7.7427790428474901e-09,    3.8730066928903080e-10,   -2.6965637758466641e-08,    2.1419877306604661e-08,    9.8131242873874890e-09, 
   9.5719760972733367e-09,    7.6879764196924389e-09,   -2.2215743048624889e-08,   -1.2398556095697610e-08,   -6.4445010884033651e-09, 
  -2.1477523224098470e-08,    3.9321121551819149e-08,   -3.5737699480519242e-08,    9.4239635687397070e-09,    6.7266755587643057e-09, 
   4.9810414202377149e-09,    5.6000185804382828e-08,    5.4259025484028687e-08,   -3.1789808240153892e-08,   -1.3960575345108240e-08, 
  -2.2091231827129820e-08,   -7.0027422021409517e-08,   -2.0625629252480190e-09,   -2.2756202330126390e-08,   -8.7127007987507759e-09, 
   4.5115224024109743e-09,    3.7998742533734080e-08,    3.7513599916172808e-08,   -5.6026408905093932e-09,   -2.7550665136848160e-08, 
  -4.1030973914308043e-08,    6.1569852234093523e-09,    1.6205387444014780e-08,    6.8623221548349780e-09,   -1.9499253018975470e-08, 
   2.2039916029745061e-08,    1.2512336543455440e-08,    1.0273752680107899e-09,    4.2106957858972642e-08,   -5.3641252498077222e-09, 
   3.1671170597038883e-08, 
},
{
  -1.0126090956465731e-07,   -1.1522745649086689e-08,    8.5705073676947950e-09,   -7.6395988054220353e-09,    4.0250447914755653e-09, 
  -1.2325977875120421e-08,   -2.7691990214751940e-09,   -1.1540662509263980e-08,    1.3809423551226451e-09,   -2.3034248154764211e-08, 
   3.5421298579918023e-08,   -2.0853446969930110e-08,   -5.4235063151269787e-09,    2.4823107737634120e-08,   -1.7905878561971750e-08, 
  -7.2646727376409733e-08,    6.7003182535718752e-10,   -1.4758055967310239e-08,    6.5394780694312543e-09,   -2.1415899983516841e-08, 
   2.1343376042477771e-09,   -2.7677612090994491e-09,   -1.7368952968310979e-08,    1.3103887643843080e-08,    1.9662057722625201e-08, 
   1.3771301241879051e-08,    5.3486771190448659e-09,   -6.2052229565562247e-08,    3.5007731749391930e-09,    1.9563969323385370e-08, 
   3.9542250836941560e-08,   -4.5360521108784773e-09,   -2.4269775264513638e-08,   -3.3635494239517401e-08,    1.0829415430944950e-08, 
  -2.2491965600774710e-08,   -1.5637269426543441e-08,    7.0220783291551901e-09,    3.5779061759295900e-08,    9.5461834588077841e-09, 
   1.9520948878564549e-08,   -2.7027514350908369e-08,   -1.5718904895240109e-08,   -1.1142692166081350e-08,    2.5244962626009900e-08, 
   3.6321603100966422e-08,    2.8406084271575770e-08,   -5.0574708035914132e-08,   -1.0627481591800429e-08,    8.6496732192467423e-09, 
  -2.1031569730424831e-08,   -8.8565493270597659e-09,   -1.6699373339017350e-08,   -8.7572493735643535e-09,    8.0274054593026195e-09, 
  -2.2994709008642180e-08,   -4.7512071486663231e-09,   -5.2186134100487957e-08,   -5.1495679858299280e-08,   -3.6197787334472862e-08, 
   2.8948480397681489e-08,   -3.4638400597221978e-08,    3.0807889241947042e-08,   -6.6785580121160001e-09,    1.6001141443897722e-08, 
  -8.6154990439638273e-09,   -1.3856725505751540e-08,    6.1620647865603731e-08,    1.1049275161976949e-08,   -4.8761580928670653e-09, 
   2.9630825455902791e-08,    1.9096852773588379e-09,   -6.4028481933194006e-09,    2.6046180016633889e-08,    4.1200616073615563e-09, 
  -5.0220689549103342e-09,    4.0170494053698461e-10,   -1.3684208231148481e-08,    1.7683956031767841e-09,   -3.4641154618707218e-08, 
   4.5758113500030063e-08, 
},
{
   5.3472579669405208e-08,    2.4452822525910369e-08,    6.0565718726132809e-10,    1.8729578607081921e-08,    1.0342517649972949e-08, 
  -2.3164237582528511e-08,   -3.3352911189790162e-08,   -2.5710679867462761e-08,   -1.0812715236635200e-10,   -8.7353984493366249e-09, 
   1.2182613264687889e-08,    1.5681558651405850e-08,   -9.0466913004511682e-09,    1.6925015623815631e-08,    1.1619420494160191e-08, 
   2.3316763995365979e-08,   -3.5789700257475618e-08,    2.2469107130498401e-08,   -1.4960967688678900e-08,   -2.9172479955474111e-08, 
   5.4170022859116655e-10,    3.6040573095370261e-09,    4.3794519119159991e-09,    1.6155192522717299e-08,    2.4066937436564950e-09, 
  -1.4506820228763319e-08,   -2.7400639652928818e-09,    2.0781774132365340e-08,   -2.3224498552509401e-08,    2.1661845663114582e-08, 
   9.0599837235250029e-09,    1.8960524919854909e-10,   -3.9725406675138209e-09,   -5.0026523423954832e-09,   -3.0524661947070031e-08, 
  -2.5038314711882210e-08,    5.4689016064711622e-09,    4.6659847901809612e-09,   -2.7282827507959410e-08,    1.5479454147057101e-08, 
   3.0749231518606242e-08,    2.8227954080530779e-08,    3.0913064719716639e-09,   -1.5667713090307158e-08,   -1.3905280467247169e-08, 
   5.6831220959254799e-09,    5.1038041852556290e-09,   -2.0035066392556739e-08,   -9.2468866785722687e-09,    1.1232181522789740e-08, 
   4.1137055754029763e-08,   -2.2640084711285680e-08,   -2.0041144180385070e-08,    1.3209339403167920e-08,   -1.4779647252088350e-08, 
   1.7242577871404089e-08,    2.9803130463985339e-09,   -2.2130732676742541e-08,   -2.2612778319004130e-08,   -3.3970411942423827e-08, 
   6.2989187973610083e-08,    1.4985893846734460e-09,    1.9055891691251661e-08,    1.4062329305520750e-08,    2.6376404806719510e-08, 
  -3.7923340594246609e-08,    3.8291404049821490e-08,   -5.3098489196634348e-08,   -5.8400680212275852e-08,   -2.6152182582589400e-08, 
  -1.4540154170139170e-08,   -3.0976964233252838e-08,   -3.2977526416182799e-09,   -1.4845165931175709e-08,   -8.9271052657335534e-09, 
  -3.5245788463029471e-08,   -5.0100770484762031e-08,   -7.1556364263463746e-09,   -3.6334712997024590e-08,   -5.8207980725588190e-08, 
   8.9675259412811672e-09, 
},
{
  -7.9239790651783958e-08,    3.9582110377419212e-09,    1.3996463097735929e-08,    1.7754380139907039e-08,   -3.7158460287582418e-08, 
   1.2950766375034049e-08,   -3.5608979285729612e-08,   -1.9698525852962119e-08,    6.7634725831509869e-10,    2.9023336917156911e-08, 
  -6.4310568888629864e-09,   -1.4422762490918280e-08,   -1.8000612328190190e-08,   -1.6280148223969211e-08,    5.7319890444537717e-09, 
  -2.6509433663467459e-09,   -2.2138650131816840e-08,   -4.6668229709954808e-08,   -1.1950207010582309e-08,    2.0484328937737641e-08, 
  -3.1859741637541618e-08,    2.5787279693229281e-08,    1.3406416109298360e-08,    3.2984699484047798e-08,    1.7953685293943199e-08, 
   1.5878668828641790e-09,   -1.6533488030241511e-08,    2.4924741317855608e-08,    1.3970133302313960e-08,    1.0551643257578251e-09, 
  -2.2073492422253180e-08,    5.6356045681231340e-09,    1.7237680450052232e-08,    3.4255035230903808e-08,    7.7871891153686001e-09, 
  -3.4041829506929343e-08,    6.4229928471165402e-09,   -1.7328699515012389e-08,    1.4753903190741620e-08,   -1.4549195991839789e-09, 
  -1.0000105914878080e-08,    2.5878266572920139e-08,    1.4991231218581000e-08,   -2.2924332340414909e-08,    6.1066655051074809e-08, 
  -8.3012494997678281e-09,   -1.8592227300312770e-08,    8.1522797029569165e-09,   -9.4963352921815985e-09,   -3.7864499506032899e-08, 
  -2.1919227094243141e-08,    1.8325345120305500e-08,    4.6210866588471170e-08,    2.7687647322888688e-10,    2.6377341781642370e-09, 
   2.1061388375067470e-08,   -1.1097075764009550e-08,   -5.4542285960445618e-09,    3.3350776016663070e-09,    3.1570141904187600e-08, 
  -7.1384896383999116e-09,   -2.9791974365691461e-08,    2.3197555972264410e-08,    5.7591865682234340e-08,   -4.4667259109841848e-08, 
   5.7908038036214937e-08,   -4.2645750642652543e-08,    3.0399187730912853e-08,   -3.6782955347180933e-08,   -1.3394025889653190e-08, 
   2.7411801870784780e-08,   -3.0025299874282962e-08,   -7.9953714271450658e-09,    4.6236008509557922e-08,   -2.6169940270100989e-08, 
   2.0961793125775809e-08,   -6.8893632994121142e-08,   -2.7660409661773841e-08,   -7.3197636664677654e-08,   -1.0205753070714769e-07, 
   1.4902266951516181e-08, 
},
{
  -9.3403592836397743e-08,   -1.6048574963929059e-08,    3.6801218056836112e-08,   -8.4496500704375663e-09,   -3.5013020730217671e-09, 
   2.8954128332615542e-10,   -7.0033417115896719e-09,   -1.3303329727189911e-08,   -1.6676212050010818e-08,   -1.2812531346711059e-08, 
   4.6161869451084367e-09,    1.9077120844381011e-09,    3.6176316060518632e-08,    1.3036214805849721e-09,    1.9784210676846139e-08, 
  -2.6642380677339091e-08,   -3.0092279766274267e-08,   -3.0884264246268561e-08,    1.6994741177371760e-09,   -7.7003006269710074e-09, 
   5.3342732542923539e-08,   -8.6957805251398437e-09,    3.7085940789818902e-08,    5.6546884026073717e-09,    9.5222343380675775e-09, 
   1.7622768093748181e-08,    1.3897698716282721e-08,   -4.0707642790285202e-08,   -8.9120626545944804e-10,    1.4730370872548750e-08, 
  -4.1919069815472723e-08,    3.0023740484481307e-08,    9.6163156520466802e-10,    1.4400063700946861e-08,   -5.0818167995810892e-10, 
   1.6062129005521268e-08,    2.3849761413833271e-08,    5.5327166917023805e-10,   -1.6579971933733500e-09,    2.5879413188807139e-09, 
  -8.8965453695868858e-09,    2.9373762962171720e-08,   -4.2132291844844869e-09,    2.6159412835283442e-09,   -4.3741884460755640e-08, 
   1.8359905888740360e-08,    3.1702157827592630e-08,    2.0022103306297641e-08,   -2.0438806970464710e-09,    1.9317408091002902e-08, 
  -5.7077805469914937e-09,    1.8139330298322391e-08,   -3.1160658888732618e-08,    1.1123610748244049e-08,    1.3119241916864510e-08, 
  -6.8768515944441008e-09,   -9.8398333106897698e-10,   -1.2538641918909540e-08,   -3.0328810291124859e-09,   -2.2622266641646401e-08, 
  -4.5844593434290657e-08,   -9.0679449958986908e-09,   -4.1975845620425718e-08,    3.8626292276262779e-08,   -3.3013127101210713e-08, 
   3.9678249190651443e-08,   -3.5890545057486489e-08,    1.3746247493082460e-08,   -3.1480609254160812e-08,    1.3384874521101789e-08, 
   7.7155956538290899e-08,   -6.6866541422553473e-09,   -3.1147076800037963e-08,    1.3639437365474581e-08,   -4.3860203396214768e-08, 
  -4.9178247117405399e-08,   -2.6699372673610941e-08,   -6.7382415045806944e-09,    1.4412917377966301e-09,    4.8342457723864391e-09, 
   1.7390883601169140e-08, 
},
{
  -9.2958885757064534e-08,   -1.0635293597363360e-09,   -1.7804762229461629e-08,    1.6529568807174619e-08,   -2.6839843046240912e-10, 
   1.4496023097163681e-08,   -1.9185441063505108e-08,    1.0982345162823020e-08,    1.2322542466310701e-08,   -7.4928735796058148e-09, 
  -2.9013715978110180e-08,   -1.4617125298417760e-08,   -1.4836236343949370e-08,   -5.7340326176228620e-09,   -1.7912811632288879e-08, 
   3.0153600914929809e-08,   -1.8685560165448039e-08,   -2.8919828125255239e-09,    6.1450979011809984e-09,    6.8077110643877928e-09, 
  -2.1166186689023880e-08,   -5.5649103460140458e-09,    1.0617163289152700e-08,    8.2254206219378432e-10,    2.1946265479023428e-09, 
   2.9476695214199010e-08,   -5.2270927859002383e-09,    2.1050431435801271e-10,   -7.9376188101557718e-09,   -1.3561004099640891e-08, 
   2.8348949353530490e-08,    8.4992532727178680e-09,   -2.9832574133303203e-08,    2.6176792756362249e-09,    3.0032772156280291e-09, 
  -1.0548112606565881e-08,   -2.2910566563468369e-08,    5.3167674136826763e-08,   -5.7436727657305722e-09,   -4.1548366603569050e-09, 
  -2.0541193801204210e-08,   -8.2278483119245850e-09,   -4.6684718650143057e-09,    6.4597941450654170e-09,   -1.9657163308199010e-08, 
   2.8494515715017018e-09,   -3.0109462601346329e-09,    1.5718793088803521e-09,   -1.7983398277992611e-08,    1.7397051050411732e-08, 
  -1.1200861055523431e-08,    2.0664491841578919e-08,    1.2946214273948290e-08,    3.8325877465571103e-08,   -3.6825921062611107e-08, 
   4.5347017660203947e-09,   -8.9812932768307458e-09,    1.4420623833334280e-08,   -1.2511875027624470e-08,   -2.3545771401745590e-08, 
  -1.9217972358171629e-08,    1.2857956782801290e-08,   -4.9644119375292849e-10,    1.5931686122385341e-08,   -2.4688575424350279e-08, 
  -3.2980329401939630e-09,    4.8737014786926708e-08,   -4.6840571421663822e-08,    1.6680960733165940e-08,   -1.3798990953075250e-08, 
   3.9375140480277659e-08,   -3.4762758993926123e-08,   -2.7182018774015660e-08,   -3.8370797062332862e-09,   -3.6338066725224841e-09, 
  -1.5205391846379089e-08,    1.2763287796531020e-08,   -1.1792058947693840e-09,    3.3239509418844052e-08,   -1.0252760607482590e-08, 
   3.0007375851130359e-08, 
},
{
  -2.3268566991841740e-07,   -2.5348757056472259e-09,    1.5279165045385720e-08,    1.6310377740880250e-08,    7.6971770252262024e-10, 
   3.5344064539467743e-08,   -3.2700471757675242e-08,   -2.1402856717439720e-09,   -8.7952271938768120e-09,    1.8566108048566759e-08, 
   1.9689845799256381e-08,   -2.7984412638651599e-08,   -1.0115866668774620e-08,    2.9455152151527881e-08,   -8.0003248139404052e-09, 
  -3.4775082982130571e-08,   -2.6432788454162130e-08,    2.8658969794462869e-09,   -2.4717849546370769e-08,    2.7576319284877218e-08, 
  -2.8514542148273910e-09,    1.5265548801377081e-08,    4.6762767510144606e-09,   -1.3077802587555600e-08,    2.3364113366356529e-09, 
   2.6577367028634420e-08,   -1.5466373293019290e-08,   -1.6447647711240969e-08,    3.5387467400758681e-09,   -2.0476363454595351e-08, 
   3.6447692780696693e-08,   -5.9599812309999847e-09,    4.4200002774656893e-08,   -4.0449361853318017e-09,   -9.9777924570012990e-10, 
  -8.8880184970767644e-09,    3.2871975932697009e-08,   -6.6684357806224212e-09,    3.6564824924530202e-08,   -3.8736734081212459e-08, 
   7.5723105050777752e-09,    9.0009074627913755e-09,   -2.2935192150384660e-08,   -7.4105375701350981e-09,    4.4381263132876242e-08, 
  -1.0647112912967331e-08,   -2.1910454839201990e-08,   -2.8678333511384340e-09,   -3.0340242280292973e-08,    8.0501430900920772e-09, 
  -3.1850325078366818e-08,    3.7650603546457099e-08,   -2.3434559023730749e-08,    2.7840788777680549e-08,    1.5505522683942169e-08, 
   4.7904452762682278e-08,   -2.7444091868881851e-08,    2.1102228863191188e-08,   -1.8952692994230719e-08,    2.6108287400461451e-08, 
  -1.9635478036358191e-08,    5.3845517212863052e-08,   -5.1833992488220616e-09,    1.9912556468545200e-08,   -1.6536702551015591e-08, 
  -1.2573178107347769e-08,    8.9928827974055535e-09,   -4.6082937833651639e-08,   -5.2083592951270664e-09,   -1.2245535537515381e-08, 
  -4.2747259376631286e-09,    5.8453055678280487e-08,   -3.5390991644398469e-08,    5.1806667480986830e-09,    8.8448286469801852e-09, 
  -1.1810715988297760e-08,    1.0938269758611480e-08,    2.3304378325923091e-08,   -1.9234121923197790e-08,    2.1629308852771321e-08, 
  -1.4769034041884840e-08, 
},
{
  -6.1104272230080800e-08,   -1.3990070916061660e-08,    1.1881995727714230e-08,    3.5280078353266372e-09,    1.7192596869176990e-08, 
   1.1948634893181440e-08,    1.2564201099495920e-08,   -6.4088891211599723e-09,    7.0662206807584433e-09,   -8.8858650319843389e-09, 
  -1.0549308957055410e-09,    1.2427476941900229e-09,    6.1568005209749026e-10,   -1.4619484493505151e-08,    2.3602690947874119e-08, 
  -1.5669476712055110e-08,    5.0424290960414867e-09,    2.9255472177866779e-08,    2.1767138894176531e-08,   -1.7063671948983581e-08, 
   2.7951518506445750e-08,    3.5448812479814672e-08,    3.0719518942791979e-08,   -4.1592406679984851e-08,   -2.0275669559082061e-08, 
   1.1677120879496590e-08,    2.2100777349174859e-08,   -3.6497401984732590e-09,   -1.3220441921214999e-08,   -6.7750299933166941e-10, 
  -7.0187849639355134e-09,    3.0639656550983768e-10,   -7.9566261925044000e-09,   -5.2362825164384482e-09,    9.8682117429245418e-10, 
   3.1750901623980631e-09,    1.2911775666931991e-08,    4.0490753477360339e-08,   -3.2991506827444718e-08,    8.2514376192888786e-09, 
  -1.2781738343996379e-08,   -1.0582409007454559e-09,    1.6358324993681431e-09,   -5.7090236353884973e-09,   -1.0264324063236790e-07, 
  -8.8631691215426591e-09,    2.8039934921293180e-08,   -2.6607709402547540e-08,   -2.1676501819313300e-08,    1.6955407897328310e-08, 
  -3.9860295573898376e-09,    3.2543754149647023e-08,   -8.3481726529724894e-09,   -8.8360645883773890e-09,    1.5039615228944840e-08, 
   1.8448559507243749e-08,    7.1394078207807386e-09,    2.6963740902659391e-09,    1.6125248447426781e-08,   -1.0133573729510189e-08, 
  -1.1957403033924530e-08,   -1.7458835856658641e-08,    6.7550663105708086e-09,    3.9780213948433731e-08,    3.3616196659676543e-08, 
   2.1840245123388171e-08,    4.5315771776624116e-09,   -1.7875821555121601e-08,    3.2325341968541947e-08,    1.0287607959452510e-08, 
   2.6129165325730092e-09,    1.9811987374228759e-08,   -3.2001567638459490e-08,    1.6854298985710160e-08,    1.0196641563198999e-08, 
   4.8703440603700974e-09,    1.1880687702064290e-09,   -3.0652418851886191e-08,   -1.8887828748998140e-08,   -3.0638177018873032e-08, 
  -4.5786303998232158e-08, 
},
{
  -1.5227130308935940e-07,   -2.1113532040349009e-08,   -2.3621731481700992e-08,    1.8307764248237191e-08,    2.6611715724885898e-09, 
   5.0615198739124507e-09,   -1.5126602104397991e-08,   -1.3008094605730580e-08,    9.7306837784428772e-09,   -4.4843642059847006e-09, 
   1.7281557475445460e-08,    1.4146068560766600e-10,   -6.3328475344204648e-09,    9.0805605878317523e-09,   -9.4580549890193481e-09, 
   5.8140866847644328e-09,   -2.8808648811522759e-08,    3.7611588847544152e-09,   -2.9289376420572699e-08,    3.5652582279771599e-09, 
  -1.0307834534859660e-08,   -6.8589306764545998e-09,   -1.1985554100366109e-08,    1.3722687204234780e-08,   -2.9967567672062320e-09, 
  -3.7909563759774528e-08,   -1.8112639846698041e-08,    1.1138804780996920e-08,   -3.2123127538395330e-09,   -3.5005990687414253e-08, 
   1.6788401195783890e-08,    1.3947996581212380e-08,   -1.3613272106422320e-08,    1.0143959437298360e-08,   -7.6516873233812684e-09, 
   4.2044182945616731e-09,   -3.4242915583168060e-09,    7.6012426198717281e-10,    1.6195339671984780e-08,    1.4486363767362310e-08, 
  -2.4448621383419321e-08,   -9.3034890642952677e-09,   -1.3419448164149140e-08,   -8.9446579989595608e-09,    1.4578568501114230e-08, 
  -2.1502271205195329e-10,   -3.7140052867617810e-08,    4.1520598257673897e-09,   -3.5822028310006869e-08,    3.8286819337311657e-08, 
  -3.9638944627352018e-08,    2.6063198733519061e-08,    9.2231887371208896e-09,    1.3562389883347110e-08,   -1.6702220423832381e-09, 
  -2.1244351613833290e-08,    8.0232100103553343e-09,   -1.6541292896987290e-08,   -1.2079424125372269e-08,   -2.5833239151630339e-09, 
  -1.2261960577181220e-08,    3.6191908982050682e-08,    1.0323538786659850e-08,   -6.4204764298785025e-08,    8.2053664939066756e-09, 
  -1.5649518181756290e-08,   -6.7900004779096703e-09,   -1.3324915725139509e-08,   -1.6496832468463451e-08,    4.8907175215348342e-08, 
   3.9445680827133713e-08,   -2.3979906811711839e-08,    1.4619987101330669e-08,   -2.8385543652244602e-09,    2.0754818105081301e-08, 
   9.1782741587553809e-10,   -1.1348075853817900e-08,   -1.6743464096756040e-08,   -2.1718438590061899e-08,    1.9282431527263480e-08, 
  -1.8371376363970309e-08, 
},
{
   4.4022260088072989e-08,    2.1388767403741999e-08,    1.6890385593438011e-08,    3.1724949328092099e-09,    5.1616950532301003e-09, 
   2.9805375871243090e-09,    1.3317694048512400e-08,   -8.6969840430305276e-09,   -1.0409665918863299e-08,    1.4316683400633950e-08, 
  -1.1057461689039649e-08,    1.0794013713742210e-08,   -1.3228133600473540e-08,    7.0049802313740466e-09,    1.4153322210681011e-08, 
  -1.5813244179083199e-08,   -1.1382697449659430e-08,    8.4076306333865543e-09,   -1.4163742552876860e-08,    5.1331374560065839e-09, 
   1.5107322121887781e-08,    3.1834576620701632e-08,    3.2837674655834319e-08,   -3.9592855730196008e-08,   -5.3160274878373082e-09, 
   2.5008418617247430e-08,    3.4923579670437758e-08,    2.0916302338556459e-08,    4.4176267253961037e-09,   -6.5643894247055888e-09, 
  -2.3089232450708819e-08,    1.6382973370411448e-08,    2.7937227740734359e-09,   -2.2030297152042161e-08,   -9.6833533366251387e-09, 
  -1.1988809888886290e-08,    1.1392274884801549e-08,    1.5572657080339199e-08,   -3.5675973184679562e-08,    1.5291206955103820e-08, 
   1.1948259811745960e-08,    1.0047844986012871e-08,   -2.5778244251829532e-09,    1.4337002102459949e-08,    4.5166455610180491e-08, 
   4.7858427168375874e-09,    1.1943303499421160e-09,   -1.1803899095499890e-08,    1.4350716357889809e-08,   -1.0128367419506730e-08, 
   2.7386483149971349e-08,    3.2848204100458190e-08,    3.1895493452823228e-09,   -6.6732701659572294e-09,   -1.5348632944714702e-08, 
  -1.3105884046395289e-09,    8.8993436969500175e-09,    1.3496408458052870e-08,    1.1802305307719850e-08,   -1.3609862257131250e-08, 
   6.5877363610952816e-09,    2.5837294831374590e-08,    1.5241950767747910e-08,    1.7881688771297538e-08,    5.3768906241930119e-09, 
   3.7446874360709448e-08,   -2.2716964517559719e-08,   -3.4047797587000469e-08,   -2.0643422798399469e-10,   -6.6055000909424459e-09, 
  -3.6440945745060088e-08,    8.1589711992019407e-10,    2.0935785099319259e-08,    2.8162386123264500e-09,   -1.1088863947686960e-08, 
   4.4883608270605878e-09,   -1.0342902486516149e-08,   -2.0982837873543481e-08,   -4.4623528381893246e-09,   -2.9457122452920788e-08, 
   1.6518231847475559e-08, 
},
{
  -1.8296622662985701e-07,   -4.5295107975469143e-08,   -2.0283358613252511e-08,    1.1816052480632840e-08,    1.7438582702883951e-08, 
  -6.7955847102354354e-09,    1.3006332176297331e-08,   -2.2626636302945841e-08,    2.2526300287359209e-08,   -5.0703872752400799e-10, 
  -9.7301930678866008e-09,   -3.3633551806084599e-09,    1.1675415257144961e-08,   -1.7737979012555010e-08,   -9.4356315047271776e-09, 
  -2.1739180642429569e-08,   -1.4815829721152340e-09,    8.6650572592168048e-09,    4.5636403434965347e-09,   -1.6726262326640430e-08, 
   3.3817694479123249e-10,   -4.9374229123814948e-09,    1.8015628046873871e-08,    3.7758246583069031e-09,    3.1489670100518512e-08, 
  -2.8380435542434619e-09,    9.5812667845168306e-09,    3.6258873465064680e-08,    6.7659583418973614e-09,    2.1692423049340341e-09, 
   1.4948522539138059e-08,   -1.1097442635373600e-09,   -9.3001102663036506e-09,    6.7502982264843024e-09,   -1.0819444526079860e-08, 
  -6.9820172758214112e-11,   -7.5910173414701231e-09,   -8.2052508194241399e-09,   -2.6513674991593970e-08,    1.3652057707307150e-08, 
  -2.1398505614221911e-08,    2.3913638286220081e-08,   -2.5467697514424721e-09,   -8.2877772512053151e-09,   -5.8415182390034488e-08, 
   3.8933163129512268e-08,   -1.8540140679957959e-08,    3.6826455634889361e-09,   -4.3515657192582606e-09,    2.0312064206338679e-08, 
  -3.3781222070150489e-09,    1.6593720400871011e-08,    2.2255625341152631e-08,    4.1933879004779113e-09,   -2.4829612157751429e-08, 
   3.3496923412302218e-09,    1.5966538088772009e-08,    4.7681230402104039e-09,   -9.8850212842382991e-09,    1.2741460641083921e-09, 
  -1.7113095123597122e-08,   -1.2606088590518130e-08,    2.3488887949895029e-09,   -2.6418452436418361e-08,    2.2133367848765330e-08, 
  -3.6013087655694872e-08,   -1.7907817841494151e-08,   -4.6711868852490777e-08,    2.1679139252239500e-08,   -1.8998722014041339e-08, 
  -3.4304469545119317e-08,   -1.2038754975650800e-08,    1.5457694715163639e-08,    1.0665385729218361e-08,   -9.0679068924708538e-08, 
   1.1943656675702070e-08,   -1.2287476815057050e-08,   -8.6534126471311637e-09,   -3.6699382529634117e-08,    3.9699432381805470e-08, 
   9.0511319573331192e-09, 
},
{
  -2.1563284613745612e-08,    1.1061952017768300e-09,    6.4980567456639097e-09,    1.7494675215840401e-08,    1.1010503509019120e-08, 
  -6.8758792996420337e-09,   -7.1969446649702457e-09,    5.4862757485681914e-09,   -1.1929360719089871e-08,    8.0343938717078116e-09, 
  -8.1094277056530076e-09,    7.3440033006450541e-09,   -8.8084298812366700e-09,    1.0487531174343339e-08,    2.8953059753019871e-09, 
   5.1335559578316854e-09,   -3.5217346892953490e-08,    1.5425043157404759e-08,   -4.8803178398435988e-08,    1.7879784259479659e-08, 
   2.6777201832759691e-08,    1.6439779910660370e-10,    2.8297092215667550e-08,   -2.4256660738866771e-08,   -1.4624284525145219e-09, 
   1.0649666747561220e-08,    1.4320091388088630e-08,    1.4782292380843151e-08,    1.4056659707926799e-08,   -2.2267588946525691e-08, 
  -9.3865279422310411e-10,    2.8179014724022589e-08,   -2.2116499900137352e-08,    9.8139417034179374e-10,    1.0514207644296481e-09, 
   9.1115164241102441e-09,   -9.1071088434134677e-09,   -7.1427980308793620e-09,   -3.1202448371750903e-08,    8.8101634633753492e-09, 
   8.2732733199091721e-09,   -9.0193920166047331e-09,    1.8493268392668429e-10,   -8.1212139359209045e-09,    3.3722342847192552e-08, 
   2.5025007992657869e-08,   -3.0158913772799170e-09,    5.8832581399846982e-09,   -1.2839602474257761e-08,    2.4389096991360981e-08, 
   9.9179260059346498e-09,    2.2770517219111549e-08,    2.1680626238654779e-08,    2.7542979980989360e-09,    7.8502933547880200e-09, 
  -1.3093431332955601e-08,    3.8662741665250141e-09,    9.6128372730776112e-09,    6.4901372670500284e-09,   -4.8779453360634831e-08, 
  -2.7127106512782721e-08,   -2.5171077476141360e-09,   -7.4696335029352279e-09,    1.8081288199855602e-08,    3.4709204101415039e-08, 
   2.6242447015255680e-08,   -2.2089058870163070e-08,   -3.5449274763391120e-09,    3.9106999354482293e-08,    5.0721545495667488e-08, 
   9.0666251366811545e-09,   -3.3769050389209961e-09,    4.3118438437429020e-08,    1.0893726176098870e-08,    3.5533577546674058e-08, 
   3.8068956857789360e-09,   -1.1022066868993900e-08,   -6.6351939341888704e-09,    8.4753383878958894e-09,    3.4003428729587337e-08, 
   4.5474580203247819e-09, 
},
{
  -1.4408830353912591e-07,   -2.0070701321974639e-08,   -2.3260084626746361e-08,    2.6118248858655898e-09,    6.1518542523363436e-09, 
   1.0638093088951391e-08,    2.8709756345816509e-08,   -8.3509452181554850e-09,    5.6724970381372638e-09,    2.4856787548674499e-08, 
  -3.7042327999666210e-10,   -1.9989334493278400e-08,   -1.6421185729936090e-09,   -2.4750045534932982e-08,   -2.5026524449756860e-08, 
  -1.4775847459000061e-08,   -1.1363933421473161e-08,   -1.3780132543492239e-08,    4.8548247736960096e-09,    6.8971937496097298e-09, 
   1.2375624289777931e-08,    3.1044128392424208e-08,    2.5034784697645501e-08,   -2.6000421236925481e-08,    2.8207731919307189e-08, 
   2.4119782709760019e-08,    3.5129192097712141e-09,    3.6989493200004731e-08,    2.0844639281022040e-08,   -1.7568510128029731e-08, 
  -1.8807804688485081e-08,    4.2297861194097783e-09,   -6.8369804873005730e-09,    2.2460790031195440e-09,    3.0582673848055218e-09, 
  -1.1609547895818110e-08,   -2.0378647678455491e-08,    1.5040299820799312e-08,   -4.8994367964207332e-08,    7.4584143811032635e-11, 
   1.3044211664951140e-08,    5.7658148193283396e-09,   -1.3303291742363200e-08,    1.4519859525651989e-08,    2.3189641608262680e-08, 
   1.4841842949943750e-08,    8.5438958070823636e-09,    2.0245747297436218e-08,    5.2903331325952059e-09,    1.9831553378101649e-08, 
   1.4836368757641380e-09,    2.1571734230322751e-08,    2.6803795127611821e-09,   -2.6217514680132372e-09,   -6.7078194155253677e-09, 
  -5.5420200956179543e-09,    8.9148213228962750e-09,    4.0469998860768047e-09,   -6.5035971316783495e-11,    3.4181500763575050e-09, 
   8.3263511549958796e-09,   -3.5504806941465458e-08,   -1.0698619291425580e-08,    2.6357469243572860e-08,    1.1497386113963160e-08, 
   6.5993616223791410e-09,   -2.2542089210874569e-08,   -2.0397141981446328e-08,    1.8143968667045990e-08,    1.3625539452154720e-08, 
   9.8845829432444332e-09,    2.2626329292769010e-08,    4.4347445470689849e-09,   -3.9069862760944668e-08,    2.4381875264283319e-09, 
  -2.0557935405622949e-08,   -4.7755842568498977e-08,   -3.1455773211009471e-08,   -1.2677631609514751e-07,    7.5135393078467319e-08, 
   2.9637278271696530e-08, 
},
{
  -3.1971691137663799e-08,   -8.1623263977222643e-09,    9.9374517344099773e-09,    3.0023266822151403e-08,    3.9330429681511211e-09, 
  -1.4851134350421070e-08,   -1.9623113496586061e-08,   -1.2666008338105000e-08,    3.9296322296041602e-09,    1.0960775781967729e-09, 
  -1.5641894574580080e-08,    1.8759121278193971e-08,   -2.8705724964639389e-09,    1.5308268186488610e-08,    9.1427701028891226e-09, 
   4.5298066015885667e-09,   -2.9903695425997102e-08,    2.1776929781401659e-08,   -1.9930049143878250e-08,   -6.1963011248937546e-09, 
   3.0069089333642388e-08,   -3.0113345576157588e-09,    3.4219864341146213e-08,    8.3798077844145685e-09,   -1.3192466585347331e-08, 
  -5.4017796573998496e-09,    2.1728683861324418e-08,    4.3421887974998837e-09,    1.7272049921387580e-08,   -2.5388068203378352e-09, 
   3.6938784201910891e-09,    9.4844315150208962e-09,   -2.2934832888321419e-08,    3.8068505390520728e-09,    3.9220734316602458e-09, 
   1.1516958940067780e-08,    2.7905963048534358e-09,   -6.9944438257928899e-09,   -3.4750817055747330e-08,    5.4102488893796379e-09, 
  -1.5609725733119851e-08,   -6.7469936719169076e-09,   -1.7476449335408690e-08,    2.4246669613919272e-09,   -2.4921693853060739e-08, 
   1.2748094097082760e-08,    4.0976066867797547e-09,    9.6155820778274690e-09,   -1.2157397860099279e-08,    1.6471155022668030e-08, 
   7.3951694721135847e-09,   -4.4162812278580483e-09,    1.1705238582241630e-08,    1.0740428081552930e-09,    1.4748767487733561e-08, 
  -1.6499505957783541e-08,   -1.3968865312220130e-08,    2.5058187955984491e-08,    1.2462278158386950e-09,   -1.1496318806930121e-08, 
   2.9824364947494430e-09,    2.1289043925315600e-11,   -2.8652339175346772e-08,    3.5714299208398293e-08,    2.8299933040158759e-08, 
  -8.9022251743086386e-09,   -2.4111771883861031e-08,   -1.1108360493264589e-08,   -6.8931580196855726e-09,    2.0921948458560639e-08, 
   2.0848195762777831e-08,    3.4705206656060311e-09,    8.6935013976378715e-09,   -6.8738761190500857e-08,   -1.6956003331521781e-08, 
  -1.1445288933741240e-08,    1.6947695586139080e-08,   -2.8273200616637652e-08,   -3.0006709911530498e-08,   -4.6078138454365170e-08, 
   4.7083765379288881e-08, 
},
{
  -9.6143919013693970e-08,   -4.8608889440241989e-09,   -3.2363754554166560e-08,   -6.5712049623255782e-09,    7.0796199616499803e-09, 
   1.9291099080096781e-08,    1.8195733917348091e-08,   -7.6562284824962040e-09,    4.0729954548785248e-10,    2.5742924795830739e-08, 
   1.1854403909781860e-08,   -1.9463700567277359e-08,    7.6454526940509207e-09,   -1.3983560080126529e-08,   -2.3200692086839421e-08, 
   1.2785646702053969e-09,   -1.0568165816868920e-08,   -1.8096281174059390e-08,   -5.5322134805482388e-09,    9.0614875079606794e-09, 
   3.4309026025202922e-09,    3.9170181976378393e-08,    2.2944444993649049e-08,   -4.8513087131602851e-08,    3.5850722943136159e-08, 
   1.9111003800307701e-08,   -1.2469401072512109e-08,    4.1521520832111481e-08,    2.2371913041314941e-08,   -2.2367038245313090e-08, 
  -1.5504731737757769e-08,    2.4016512447751750e-08,   -2.4642366270290851e-08,   -1.5652074355205299e-09,   -1.6301991141856082e-08, 
  -2.1074821878739539e-08,   -1.6130379168335961e-08,    1.6974340870149419e-08,   -6.7185675417512482e-08,    1.1294842282176670e-09, 
   1.6822678035570399e-08,   -3.2940382954877701e-09,   -2.9458611799454889e-08,    1.8897270806944559e-08,   -3.8291464174010932e-08, 
   1.7726062828373069e-08,    3.2634408061461343e-08,    1.7867757804120042e-08,    8.7611039507311787e-09,    2.7719829269070919e-08, 
   6.3976287061155716e-09,    2.8007202452446420e-08,    2.8329758737763542e-08,   -2.5936431338945799e-08,   -1.3101636965933861e-08, 
   2.0582488512699419e-09,   -4.4765328926920637e-09,    4.8739736631978158e-09,   -1.1518357795713240e-08,    1.8047284149486890e-08, 
   1.9921028326643488e-08,   -6.6199539992972931e-08,    2.4374250151510012e-09,    3.1287884421194033e-08,    4.2666219442627648e-08, 
   2.5086514838981871e-08,   -3.2975407909178037e-08,    1.1381321576695511e-08,    3.3085534802760222e-08,   -8.0026826707920263e-09, 
   6.5496386810648611e-09,   -4.7557144208901573e-09,    1.4238230603767400e-08,   -2.5753617667176000e-08,    1.4996059285110611e-08, 
  -1.3998374279198390e-08,    4.8271839875411987e-08,    2.2222570253966311e-08,   -2.7390694608716481e-08,    1.0101212031672539e-08, 
  -7.7640066465978421e-08, 
},
{
  -1.4039664820363040e-08,    4.8605157923197206e-09,    1.0856848087609970e-08,    2.4493993741606520e-08,   -7.8748564738901217e-09, 
  -1.6916285273421060e-08,   -2.1640275443293021e-08,   -1.7724487244369909e-08,   -1.4579810396258910e-08,    8.4686476194344379e-09, 
  -5.4294732577520832e-09,    1.0058388000952170e-08,   -9.7983270912012694e-09,    1.5885401503703930e-08,    7.2605453361048359e-09, 
  -1.6274874220888271e-08,   -1.9737582568468650e-08,    8.0052085590603382e-09,   -2.1643701140752159e-08,   -4.3906604006747076e-09, 
   1.5330082776950978e-08,   -5.9917985487533920e-09,    3.5818440943536170e-08,    1.5559617982592469e-08,   -1.3251015428246591e-08, 
  -3.1631113712615529e-08,    2.5525630309300239e-08,   -2.4515004678780380e-09,    8.7387875836527156e-09,    2.7866557535430518e-09, 
  -8.6966446791838073e-09,   -5.9973313546418229e-09,   -1.4311989857057150e-08,   -2.1939585571663939e-09,    2.3167286395576420e-08, 
   3.4835485227049239e-08,    1.3527489004341080e-08,   -2.4435107865475192e-08,   -1.1320947600947400e-08,   -1.6518184430927660e-08, 
  -2.3368023000363171e-08,   -2.7510094448350351e-08,   -1.1589069751727521e-08,    2.4274786938760301e-08,    3.4358181778215190e-08, 
   9.3737960399374872e-09,   -9.0090093293770244e-09,    3.4855665927061547e-08,   -2.7391677973794741e-08,    2.7858782388775061e-08, 
  -3.7047176831862009e-09,   -2.2122967357936061e-08,    2.1223322726205932e-08,    1.2336307137724869e-09,    1.3844005003075619e-08, 
  -4.4222802265207559e-08,   -1.9401767715379181e-08,    8.5817486067055359e-09,    1.7927360960238061e-08,    1.7360033625305459e-08, 
   4.6332146449538617e-08,   -9.3599768844640658e-09,   -3.3061642688536698e-08,    1.9831070181321749e-08,    8.9976141970644005e-09, 
  -1.3654570164779699e-08,    1.8032489207428720e-08,   -6.3488647439425351e-09,   -1.1037676026853180e-08,    1.0498380995639790e-09, 
   1.3420363140932221e-08,   -1.2837520837664341e-08,   -7.5862730206882076e-09,   -4.2049642957661857e-08,    1.5017114043667299e-08, 
  -8.6094853130987902e-08,    8.7890863155167154e-08,   -3.5567341235072749e-08,    4.2469008564635799e-08,    6.4488227584257642e-08, 
  -7.2740512544235668e-09, 
},
{
  -5.6173045626133889e-08,   -7.2265799247382383e-09,   -2.7919914518472159e-08,   -8.1982981193597014e-10,    7.7449061439054953e-09, 
   1.7689701598385022e-08,    1.1458350447296040e-08,   -3.6520982438645939e-09,    3.3817539135385079e-09,    7.6200924005946248e-09, 
   7.8724534170822341e-09,   -8.2265261612786326e-09,    9.3094685912930519e-09,   -2.7785701635592859e-09,   -1.2468131635802410e-08, 
   7.2392959718484278e-09,   -1.9551425947930629e-08,   -1.6578597468070251e-08,    4.1623489747570979e-09,   -3.8438442046202979e-09, 
   1.4757179279054570e-08,    2.3178362595261841e-08,    2.1635353557979409e-08,   -5.5293533765552678e-08,    2.9557122352243730e-08, 
   2.2478056142447350e-08,   -2.7617997939105019e-09,    5.2012055408943368e-08,    1.9380306095852260e-08,   -2.4300705562890811e-08, 
  -3.7600224133010468e-09,    2.6764883203517759e-08,   -2.9557459108402700e-08,    2.2810602352599191e-09,   -3.9324638318926540e-08, 
  -2.1629803665303129e-08,   -2.5215869054318691e-08,    2.9149038795301331e-08,   -9.0812483442621842e-08,    8.6319238945331581e-09, 
   1.9885107540686631e-08,    1.4175735259075319e-08,   -3.5071126898183749e-08,    8.9619348006896802e-09,   -7.7493084150848102e-08, 
   3.7839699704908217e-08,    6.8672076020273104e-08,    2.8893007548977821e-08,    9.5069694460083222e-09,   -1.0207394251252581e-08, 
   1.2257327135527680e-08,    1.9328668658252690e-08,    1.6061455486413630e-08,   -5.8450093285967710e-08,    7.2503899731970724e-09, 
  -7.7237356795638548e-09,   -3.9704639568239687e-09,    9.1923573652913943e-09,   -2.0106153109405009e-08,   -9.3953597834784417e-11, 
   3.5514037943076013e-08,   -9.6226191599109642e-08,    1.4350862995234780e-08,    7.1195365286147076e-08,    6.1504928080787300e-08, 
   4.1828803742268468e-08,   -6.7365391398798686e-08,   -4.8538968483360137e-08,    3.1808918194417577e-08,   -2.6003036261121668e-09, 
   2.4097504159691081e-08,   -4.7143600956229596e-09,    1.8694963412678232e-08,    9.6057051523230222e-09,    2.8157653772660720e-08, 
  -4.4073733643326433e-08,   -4.7066652207508979e-08,    1.5074521892096669e-08,   -7.5948714508048756e-09,   -1.2617301383200531e-08, 
  -1.9642737190084260e-08, 
},
{
  -4.2587385931102982e-08,    1.2959728064204351e-08,    1.6116790335364660e-08,    1.4472986941000220e-08,   -2.5351771157557039e-09, 
  -3.8699679010122199e-09,   -1.2170377130639880e-08,   -1.6859220330868949e-08,   -1.2114249017571250e-08,    1.2750704377667440e-08, 
   4.2317866507286668e-09,    2.3951018907817610e-09,   -1.4952267692180739e-08,    1.1282900601153281e-08,    4.8904006092653284e-09, 
  -2.3845399951141900e-08,   -1.6322989519909769e-09,   -1.3357084307771800e-09,   -2.0210577532281082e-08,   -6.5132030997369602e-09, 
  -3.8003438288289331e-09,   -1.2786737597268310e-08,    3.3894259709795649e-08,    2.0134258862280069e-08,   -1.9331113253331850e-08, 
  -3.9976017400590649e-08,    1.6711466880933181e-08,   -2.2821743159856520e-08,    2.4314259472559599e-09,    1.1905917970882580e-08, 
  -1.0561182421299740e-08,   -4.8425109191680549e-09,   -6.1874821463049859e-09,   -4.5829111183152331e-09,    3.6060892185870130e-08, 
   3.4293942445702037e-08,    3.5975273158689228e-08,   -3.5587716469846677e-08,    3.6964635550072262e-08,   -2.1355768760937321e-08, 
  -2.6675411298632640e-08,   -4.4034849277346981e-08,    2.2849369637845840e-09,    1.9895050638066379e-08,    3.4141243790682197e-08, 
   4.7862829358011973e-09,   -1.9362365837173519e-08,    3.8683398105125753e-08,   -2.5340201833080010e-08,    3.7372005385793269e-08, 
  -6.5840102450554042e-10,   -2.9308862022510371e-08,    2.2122360251331381e-08,    2.3015764407574930e-08,    2.5821120091196211e-08, 
  -4.5631690754147323e-08,   -2.2012530731357349e-08,    2.1580207304600590e-08,    2.3847471373294970e-08,    3.8800928176601639e-08, 
   4.8865245673134221e-08,   -3.2834066503532119e-08,   -5.1276446311964503e-08,   -1.7057535049469500e-08,    4.6337885997584988e-09, 
  -2.1721222732774920e-08,    2.7165847045611051e-08,   -7.1983453260027593e-08,   -1.0952551120856480e-08,   -1.8329141763226072e-08, 
  -6.1345329316369506e-08,   -1.3673596061185441e-08,   -2.2644291755096152e-09,   -5.4754957010107504e-10,   -1.0857895553919330e-08, 
  -9.7888515027292988e-08,   -1.8420259011702940e-08,   -6.5806552524786797e-08,   -1.6243257517501719e-08,    1.6728015999556119e-08, 
   5.4813675815846304e-09, 
},
} ;

gal_gm_t gal_gmmgm1025 = {
GAL_SSB_MA,
"MGM1025",
4.2828369773938997e+13,
3.3970e+06,
80,
80,
1,
(double *) &gal_gmmgm1025_terms
} ;

__END_DECLS  
  
#endif /* !_GAL_GMMGM1025_H_ */ 

/*
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *    
 *  Contact:  
 *    
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */  
  
